@@ -389,7 +389,7 @@ int     streamInqByteorder(int streamID);
 
 void    streamDefShuffle(int streamID, int shuffle);
 
-void    streamDefFilter(int streamID, int filterId, int nparams, const int *params);
+void    streamDefFilter(int streamID, const char *filterSpec);
 
 //      streamDefCompType: Define compression type
 void    streamDefCompType(int streamID, int comptype);
@@ -526,9 +526,6 @@ void    vlistDestroy(int vlistID);
 //      vlistDuplicate: Duplicate a variable list
 int     vlistDuplicate(int vlistID);
 
-//      vlistCopy: Copy a variable list
-void    vlistCopy(int vlistID2, int vlistID1);
-
 //      vlistCopyFlag: Copy some entries of a variable list
 void    vlistCopyFlag(int vlistID2, int vlistID1);
 
@@ -548,11 +545,11 @@ int     vlistNumber(int vlistID);
 //      vlistNvars: Number of variables in a variable list
 int     vlistNvars(int vlistID);
 
-//      vlistNgrids: Number of grids in a variable list
-int     vlistNgrids(int vlistID);
+//      vlistNumGrids: Number of grids in a variable list
+int     vlistNumGrids(int vlistID);
 
-//      vlistNzaxis: Number of zaxis in a variable list
-int     vlistNzaxis(int vlistID);
+//      vlistNumZaxis: Number of zaxis in a variable list
+int     vlistNumZaxis(int vlistID);
 
 //      vlistNsubtypes: Number of subtypes in a variable list
 int     vlistNsubtypes(int vlistID);
@@ -568,7 +565,7 @@ int     vlistZaxis(int vlistID, int index);
 int     vlistZaxisIndex(int vlistID, int zaxisID);
 void    vlistChangeZaxisIndex(int vlistID, int index, int zaxisID);
 void    vlistChangeZaxis(int vlistID, int zaxisID1, int zaxisID2);
-int     vlistNrecs(int vlistID);
+int     vlistNumRecords(int vlistID);
 int     vlistSubtype(int vlistID, int index);
 int     vlistSubtypeIndex(int vlistID, int subtypeID);
 
@@ -831,6 +828,7 @@ SizeType gridInqYCvals(int gridID, char *ycvals[]);
 #define  CDI_KEY_DATATYPE                      946  // Data type
 #define  CDI_KEY_REFERENCEURI                  947  // Reference URI to grid file
 #define  CDI_KEY_CHUNKS                        948  // Chunks
+#define  CDI_KEY_FILTERSPEC                    949  // NetCDF filter spec
 
 // Integer keys
 #define  CDI_KEY_NUMBEROFGRIDUSED              961  // GRIB2 numberOfGridUsed
@@ -1360,7 +1358,7 @@ void cdiQueryPrintEntriesNotFound(const CdiQuery *query);
 // streamOpenReadQuery: Open a dataset for reading and apply query
 int streamOpenReadQuery(const char *path, CdiQuery *query);
 
-// CDI interface for  paraview vtkCDIReader.cxx
+// CDI interface for paraview vtkCDIReader.cxx
 
 #include "cdi_datetime.h"
 
@@ -1431,6 +1429,9 @@ extern int (*proj_lcc_to_lonlat_func)(struct CDI_GridProjParams gpp, double, dou
 extern int (*proj_lonlat_to_stere_func)(struct CDI_GridProjParams gpp, size_t, double*, double*);
 extern int (*proj_stere_to_lonlat_func)(struct CDI_GridProjParams gpp, double, double, size_t, double*, double*);
 
+// Used on CDO remap_scrip_io.cc
+void cdf_def_var_filter(int ncid, int ncvarID, const char *filterSpec);
+
 #ifdef __cplusplus
 }
 #endif
