@@ -1,4 +1,3 @@
-#include <assert.h>
 #include <limits.h>
 #include <stdio.h>
 #include <string.h>
@@ -200,7 +199,7 @@ cdiInqAttLen(int cdiID, int varID, const char *name)
   for (int attid = 0; attid < (int) attsp->nelems; attid++)
     {
       cdi_att_t *attp = &(attsp->value[attid]);
-      if (attp->name && strcmp(attp->name, name) == 0) length = (int) attp->nelems;
+      if (attp->name && str_is_equal(attp->name, name)) length = (int) attp->nelems;
     }
 
   return length;
@@ -219,12 +218,28 @@ cdiInqAttType(int cdiID, int varID, const char *name)
   for (int attid = 0; attid < (int) attsp->nelems; attid++)
     {
       cdi_att_t *attp = &(attsp->value[attid]);
-      if (attp->name && strcmp(attp->name, name) == 0) type = attp->exdtype;
+      if (attp->name && str_is_equal(attp->name, name)) type = attp->exdtype;
     }
 
   return type;
 }
 
+static void
+cdi_attribute_free(cdi_att_t *attp)
+{
+  if (attp->name)
+    {
+      Free(attp->name);
+      attp->name = NULL;
+      attp->namesz = 0;
+    }
+  if (attp->xvalue)
+    {
+      Free(attp->xvalue);
+      attp->xvalue = NULL;
+    }
+}
+
 int
 cdiDeleteAtts(int cdiID, int varID)
 {
@@ -236,13 +251,7 @@ cdiDeleteAtts(int cdiID, int varID)
   for (int attid = 0; attid < (int) attsp->nelems; attid++)
     {
       cdi_att_t *attp = &(attsp->value[attid]);
-      if (attp->name)
-        {
-          Free(attp->name);
-          attp->name = NULL;
-          attp->namesz = 0;
-        }
-      if (attp->xvalue) Free(attp->xvalue);
+      cdi_attribute_free(attp);
     }
 
   attsp->nelems = 0;
@@ -261,17 +270,11 @@ cdiDelAtt(int cdiID, int varID, const char *name)
   for (int attid = 0; attid < (int) attsp->nelems; attid++)
     {
       cdi_att_t *attp = &(attsp->value[attid]);
-      if (attp->name && strcmp(attp->name, name) == 0)
+      if (attp->name && str_is_equal(attp->name, name))
         {
+          cdi_attribute_free(attp);
           status = CDI_NOERR;
-          Free(attp->name);
-          attp->name = NULL;
-          attp->namesz = 0;
-          if (attp->xvalue)
-            {
-              Free(attp->xvalue);
-              attp->xvalue = NULL;
-            }
+          break;
         }
     }
 
