@@ -11,8 +11,8 @@
 struct CdiFallbackIterator
 {
   CdiIterator super;
-  int streamId, vlistId, subtypeId;
   char *path;  // needed for clone() & serialize()
+  int streamId, vlistId, subtypeId;
 
   int variableCount, curVariable;
   int curLevelCount, curLevel;
@@ -26,55 +26,45 @@ cdiFallbackIterator_getSuper(CdiFallbackIterator *me)
   return &me->super;
 }
 
-// For more information on the condestruct() pattern, see comment in src/iterator_grib.c
-static CdiFallbackIterator *
-cdiFallbackIterator_condestruct(CdiFallbackIterator *me, const char *path, int filetype)
+CdiIterator *
+cdiFallbackIterator_new(const char *path, int filetype)
 {
-  if (me) goto destruct;
-
-  me = (CdiFallbackIterator *) Malloc(sizeof(*me));
+  CdiFallbackIterator *me = (CdiFallbackIterator *) Malloc(sizeof(*me));
   baseIterConstruct(&me->super, filetype);
-
-  me->streamId = streamOpenRead(path);
-  if (me->streamId == CDI_UNDEFID) goto destructSuper;
-  me->vlistId = streamInqVlist(me->streamId);
-  if (me->vlistId == CDI_UNDEFID) goto closeStream;
-  me->variableCount = vlistNvars(me->vlistId);
-  if (me->variableCount <= 0) goto closeStream;
   me->subtypeId = CDI_UNDEFID;  // Will be set in cdiFallbackIterator_nextField()
   me->curSubtypeCount = -1;     // Will be set in cdiFallbackIterator_nextField()
   me->curLevelCount = -1;       // Will be set in cdiFallbackIterator_nextField()
-
   // These values are chosen so that the natural increment at the start of cdiFallbackIterator_nextField() will correctly position
   // us at the first slice.
   me->curTimestep = 0;
-  if (streamInqTimestep(me->streamId, me->curTimestep) <= 0) goto closeStream;
   me->curVariable = -1;
   me->curSubtype = -1;
   me->curLevel = -1;
-  me->path = path ? strdup(path) : NULL;
-  if (!me->path) goto closeStream;
-
-  return me;
-
-  // ^        constructor code        ^
-  // |                                |
-  // v destructor/error-cleanup code  v
-
-destruct:
-  Free(me->path);
-closeStream:
-  streamClose(me->streamId);
-destructSuper:
+  me->streamId = streamOpenRead(path);
+  if (me->streamId != CDI_UNDEFID)
+    {
+      me->vlistId = streamInqVlist(me->streamId);
+      if (me->vlistId != CDI_UNDEFID && (me->variableCount = vlistNvars(me->vlistId)) > 0
+          && streamInqTimestep(me->streamId, me->curTimestep) > 0 && (me->path = strdup(path)))
+        {
+          return (CdiIterator *) me;
+        }
+      Free(me->path);
+      streamClose(me->streamId);
+    }
   baseIterDestruct(&me->super);
   Free(me);
   return NULL;
 }
 
-CdiIterator *
-cdiFallbackIterator_new(const char *path, int filetype)
+void
+cdiFallbackIterator_delete(CdiIterator *super)
 {
-  return &cdiFallbackIterator_condestruct(NULL, path, filetype)->super;
+  CdiFallbackIterator *me = (CdiFallbackIterator *) (void *) super;
+  Free(me->path);
+  streamClose(me->streamId);
+  baseIterDestruct(super);
+  Free(me);
 }
 
 // Fetches the info that is derived from the current variable. Most of this is published by the data members in the base class.
@@ -100,20 +90,21 @@ cdiFallbackIterator_clone(CdiIterator *super)
   CdiFallbackIterator *me = (CdiFallbackIterator *) (void *) super;
 
   // Make another stream for this file. This yields an unadvanced iterator.
-  CdiFallbackIterator *clone = cdiFallbackIterator_condestruct(NULL, me->path, me->super.filetype);
-  if (!clone) return NULL;
+  CdiFallbackIterator *clone = (CdiFallbackIterator *) (void *) cdiFallbackIterator_new(me->path, me->super.filetype);
+  if (clone)
+    {
+      // Point the clone to the same position in the file.
+      clone->variableCount = me->variableCount;
+      clone->curVariable = me->curVariable;
+      clone->curLevelCount = me->curLevelCount;
+      clone->curLevel = me->curLevel;
+      clone->curSubtypeCount = me->curSubtypeCount;
+      clone->curSubtype = me->curSubtype;
+      clone->curTimestep = me->curTimestep;
 
-  // Point the clone to the same position in the file.
-  clone->variableCount = me->variableCount;
-  clone->curVariable = me->curVariable;
-  clone->curLevelCount = me->curLevelCount;
-  clone->curLevel = me->curLevel;
-  clone->curSubtypeCount = me->curSubtypeCount;
-  clone->curSubtype = me->curSubtype;
-  clone->curTimestep = me->curTimestep;
-
-  clone->super.isAdvanced = super->isAdvanced;
-  if (super->isAdvanced) fetchVariableInfo(clone);
+      clone->super.isAdvanced = super->isAdvanced;
+      if (super->isAdvanced) fetchVariableInfo(clone);
+    }
 
   return clone;
 }
@@ -124,9 +115,10 @@ cdiFallbackIterator_serialize(CdiIterator *super)
   CdiFallbackIterator *me = (CdiFallbackIterator *) (void *) super;
 
   char *escapedPath = cdiEscapeSpaces(me->path);
-  char *result = (char *) Malloc(strlen(escapedPath) + 7 * (3 * sizeof(int) * CHAR_BIT / 8 + 1) + 1);
-  sprintf(result, "%s %d %d %d %d %d %d %d", escapedPath, me->variableCount, me->curVariable, me->curLevelCount, me->curLevel,
-          me->curSubtypeCount, me->curSubtype, me->curTimestep);
+  size_t len = strlen(escapedPath) + 7 * (3 * sizeof(int) * CHAR_BIT / 8 + 1) + 1;
+  char *result = (char *) Malloc(len);
+  snprintf(result, len, "%s %d %d %d %d %d %d %d", escapedPath, me->variableCount, me->curVariable, me->curLevelCount, me->curLevel,
+           me->curSubtypeCount, me->curSubtype, me->curTimestep);
   Free(escapedPath);
   return result;
 }
@@ -252,8 +244,9 @@ cdiFallbackIterator_inqTime(CdiIterator *super, CdiTimeType timeType)
   int year, month, day, hour, minute, second;
   cdiDecodeDate(date, &year, &month, &day);
   cdiDecodeTime(time, &hour, &minute, &second);
-  char *result = (char *) Malloc(4 + 1 + 2 + 1 + 2 + 1 + 2 + 1 + 2 + 1 + 2 + 4 + 1);
-  sprintf(result, "%04d-%02d-%02dT%02d:%02d:%02d.000", year, month, day, hour, minute, second);
+  size_t len = 4 + 1 + 2 + 1 + 2 + 1 + 2 + 1 + 2 + 1 + 2 + 4 + 1;
+  char *result = (char *) Malloc(len);
+  snprintf(result, len, "%04d-%02d-%02dT%02d:%02d:%02d.000", year, month, day, hour, minute, second);
   return result;
 }
 
@@ -410,28 +403,21 @@ cdiFallbackIterator_copyVariableName(CdiIterator *super)
 }
 
 void
-cdiFallbackIterator_readField(CdiIterator *super, double *buffer, size_t *nmiss)
+cdiFallbackIterator_readField(CdiIterator *super, double *buffer, size_t *numMissVals)
 {
   CdiFallbackIterator *me = (CdiFallbackIterator *) (void *) super;
   SizeType missingValues = 0;
   streamReadVarSlice(me->streamId, me->curVariable, me->curLevel, buffer, &missingValues);
-  if (nmiss) *nmiss = (size_t) missingValues;
+  if (numMissVals) *numMissVals = (size_t) missingValues;
 }
 
 void
-cdiFallbackIterator_readFieldF(CdiIterator *super, float *buffer, size_t *nmiss)
+cdiFallbackIterator_readFieldF(CdiIterator *super, float *buffer, size_t *numMissVals)
 {
   CdiFallbackIterator *me = (CdiFallbackIterator *) (void *) super;
   SizeType missingValues = 0;
   streamReadVarSliceF(me->streamId, me->curVariable, me->curLevel, buffer, &missingValues);
-  if (nmiss) *nmiss = (size_t) missingValues;
-}
-
-void
-cdiFallbackIterator_delete(CdiIterator *super)
-{
-  CdiFallbackIterator *me = (CdiFallbackIterator *) (void *) super;
-  cdiFallbackIterator_condestruct(me, NULL, 0);
+  if (numMissVals) *numMissVals = (size_t) missingValues;
 }
 
 /*
