@@ -2,6 +2,7 @@
 #include "config.h"
 #endif
 
+#include <assert.h>
 #include <inttypes.h>
 #include <limits.h>
 #include <stdbool.h>
@@ -17,29 +18,24 @@
 #include "pio_impl.h"
 #include "pio_util.h"
 
-typedef struct
+struct fileMPIFWO
 {
+  char *name;
   MPI_File fh;
   int fileID;
-  char name[];
-} aFiledataM;
+};
 
-static listSet *bibAFiledataM;
-
-static int
-fileIDTest(void *a, void *fileID)
-{
-  return ((aFiledataM *) a)->fileID == (int) (intptr_t) fileID;
-}
+static struct fileMPIFWO *openFiles;
+static unsigned openFilesSize, openFilesFill;
 
 /***************************************************************/
 
-static aFiledataM *
-initAFiledataFileWriteOrdered(const char *filename, size_t bs)
+static void
+initAFiledataFileWriteOrdered(struct fileMPIFWO *of, const char *filename, size_t bs)
 {
   MPI_Comm commPio = commInqCommPio();
-  aFiledataM *of = Malloc(sizeof(*of) + strlen(filename) + 1);
-
+  size_t nameSize = strlen(filename) + 1;
+  of->name = Malloc(nameSize);
   strcpy(of->name, filename);
 
   MPI_Info open_info = MPI_INFO_NULL;
@@ -55,16 +51,13 @@ initAFiledataFileWriteOrdered(const char *filename, size_t bs)
   }
   xmpi(MPI_File_open(commPio, of->name, MPI_MODE_CREATE | MPI_MODE_WRONLY | MPI_MODE_UNIQUE_OPEN, open_info, &of->fh));
   xmpi(MPI_Info_free(&open_info));
-
-  return of;
 }
 
 /***************************************************************/
 
 static int
-destroyAFiledataFileWriteOrdered(void *v)
+destroyAFiledataFileWriteOrdered(struct fileMPIFWO *of)
 {
-  aFiledataM *of = v;
   /* close file */
   MPI_Offset endpos, fsize;
   xmpi(MPI_File_get_position_shared(of->fh, &endpos));
@@ -75,28 +68,19 @@ destroyAFiledataFileWriteOrdered(void *v)
   xmpi(MPI_Allreduce(MPI_IN_PLACE, &trailingOctets, 1, MPI_INT, MPI_LOR, commPio));
   if (trailingOctets) xmpi(MPI_File_set_size(of->fh, endpos));
   int iret = MPI_File_close(&of->fh);
-
-  Free(of);
+  Free(of->name);
+  of->name = NULL;
 
   return iret == MPI_SUCCESS ? 0 : -1;
 }
 
 /***************************************************************/
 
-static bool
-compareNamesFileWriteOrdered(void *v1, void *v2)
-{
-  aFiledataM *afm1 = v1, *afm2 = v2;
-  return !strcmp(afm1->name, afm2->name);
-}
-
-/***************************************************************/
-
 static size_t
 fwFileWriteOrdered(int fileID, const void *buffer, size_t len)
 {
-  aFiledataM *of = listSetGet(bibAFiledataM, fileIDTest, (void *) (intptr_t) fileID);
-  xassert(of);
+  assert(fileID >= 0 && (size_t) fileID < openFilesSize && openFiles[fileID].name);
+  struct fileMPIFWO *of = openFiles + fileID;
 
   /* write buffer */
   xassert(len <= INT_MAX);
@@ -110,54 +94,46 @@ fwFileWriteOrdered(int fileID, const void *buffer, size_t len)
 static int
 fcFileWriteOrdered(int fileID)
 {
-  aFiledataM *of = listSetGet(bibAFiledataM, fileIDTest, (void *) (intptr_t) fileID);
-  if (!of) xabort("listSet, fileID=%d not found", fileID);
-  int iret = listSetRemove(bibAFiledataM, fileIDTest, (void *) (intptr_t) fileID);
+  assert(fileID >= 0 && (size_t) fileID < openFilesSize && openFiles[fileID].name);
+  struct fileMPIFWO *of = openFiles + fileID;
+  int iret = destroyAFiledataFileWriteOrdered(of);
+  --openFilesFill;
   return iret;
 }
 
 /***************************************************************/
-static void
-elemCheck(void *q, void *nm)
-{
-  aFiledataM *afm = q;
-  const char *name = nm;
-
-  if (!strcmp(name, afm->name)) xabort("Filename %s has already been added to set\n", name);
-}
 
 static int
 fowFileWriteOrdered(const char *filename, const char *mode)
 {
-  static unsigned long buffersize = 0;
-  int id;
-  enum
-  {
-    bcastRoot = 0
-  };
-  MPI_Comm commPio = commInqCommPio();
-  int rankPio = commInqRankPio();
-
   if ((mode[0] != 'w' && mode[0] != 'W') || mode[0] == 0 || mode[1] != 0)
     xabort("Unsupported mode \"%s\" in parallel file open.", mode);
 
-  /* broadcast buffersize to collectors ( just once, for all files )*/
+  struct cdiPioConf *conf = cdiPioGetConf();
 
-  if (!buffersize)
+  size_t fileID = SIZE_MAX;
+  if (openFilesSize == openFilesFill)
     {
-      if (rankPio == bcastRoot) buffersize = findWriteAccumBufsize();
-      xmpi(MPI_Bcast(&buffersize, 1, MPI_UNSIGNED_LONG, bcastRoot, commPio));
+      fileID = openFilesSize;
+      if (openFilesSize == (size_t) INT_MAX + 1) return CDI_ELIMIT;
+      openFilesSize = openFilesSize ? openFilesSize * 2 : 4;
+      if (openFilesSize > (size_t) INT_MAX + 1) openFilesSize = (size_t) INT_MAX + 1;
+      openFiles = Realloc(openFiles, sizeof(*openFiles) * openFilesSize);
+      for (size_t i = fileID; i < openFilesSize; ++i) openFiles[i].name = NULL;
     }
-
-  xdebug("buffersize=%lu", buffersize);
-
-  listSetForeach(bibAFiledataM, elemCheck, (void *) filename);
-  aFiledataM *of = initAFiledataFileWriteOrdered(filename, (size_t) buffersize);
-
-  if ((id = listSetAdd(bibAFiledataM, of)) < 0) xabort("filename %s not unique", of->name);
-
-  of->fileID = id;
-  return id;
+  else
+    {
+      for (size_t i = 0; i < openFilesSize; ++i)
+        if (openFiles[i].name == NULL)
+          {
+            fileID = i;
+            break;
+          }
+    }
+  struct fileMPIFWO *of = openFiles + fileID;
+  ++openFilesFill;
+  initAFiledataFileWriteOrdered(of, filename, conf->writeAggBufLim);
+  return (int) fileID;
 }
 
 /***************************************************************/
@@ -165,13 +141,10 @@ fowFileWriteOrdered(const char *filename, const char *mode)
 static void
 finalizeFileWriteOrdered(void)
 {
-  if (!listSetIsEmpty(bibAFiledataM))
-    xabort("set bibAFiledataM not empty");
+  if (openFilesFill)
+    xabort("files still open on exit!");
   else
-    {
-      xdebug("%s", "destroy set");
-      listSetDelete(bibAFiledataM);
-    }
+    Free(openFiles);
 }
 
 /***************************************************************/
@@ -179,14 +152,10 @@ finalizeFileWriteOrdered(void)
 void
 cdiPioFileWriteOrderedInit(void)
 {
-  bibAFiledataM = listSetNew(destroyAFiledataFileWriteOrdered, compareNamesFileWriteOrdered);
-
   namespaceSwitchSet(NSSWITCH_FILE_OPEN, NSSW_FUNC(fowFileWriteOrdered));
   namespaceSwitchSet(NSSWITCH_FILE_CLOSE, NSSW_FUNC(fcFileWriteOrdered));
   namespaceSwitchSet(NSSWITCH_FILE_WRITE, NSSW_FUNC(fwFileWriteOrdered));
-  cdiPioFileWritingFinalize = finalizeFileWriteOrdered;
-
-  if (bibAFiledataM == NULL) xabort("listSetNew did not succeed");
+  namespaceSwitchSet(cdiPioExtraNSKeys[cdiPioEKFileWritingFinalize], NSSW_FUNC(finalizeFileWriteOrdered));
 }
 
 /*
