@@ -19,8 +19,8 @@ enum
 
 union SRV_HEADER
 {
-  INT32 i32[SRV_HEADER_LEN];
-  INT64 i64[SRV_HEADER_LEN];
+  int32_t i32[SRV_HEADER_LEN];
+  int64_t i64[SRV_HEADER_LEN];
 };
 
 static int initSrvLib = 0;
@@ -29,7 +29,7 @@ static int srvDefaultDprec = 0;
 
 // A version string.
 #undef LIBVERSION
-#define LIBVERSION 1.5.0
+#define LIBVERSION 2.0.0
 #define XSTRING(x) #x
 #define STRING(x) XSTRING(x)
 static const char srv_libvers[] = STRING(LIBVERSION);
@@ -67,8 +67,8 @@ srvLibInit(void)
               {
                 switch ((int) envString[pos + 1])
                   {
-                  case '4': srvDefaultHprec = EXSE_SINGLE_PRECISION; break;
-                  case '8': srvDefaultHprec = EXSE_DOUBLE_PRECISION; break;
+                  case '4': srvDefaultHprec = EXSE_PREC_FP32; break;
+                  case '8': srvDefaultHprec = EXSE_PREC_FP64; break;
                   default: Warning("Invalid digit in %s: %s", envName, envString);
                   }
                 break;
@@ -77,8 +77,8 @@ srvLibInit(void)
               {
                 switch ((int) envString[pos + 1])
                   {
-                  case '4': srvDefaultDprec = EXSE_SINGLE_PRECISION; break;
-                  case '8': srvDefaultDprec = EXSE_DOUBLE_PRECISION; break;
+                  case '4': srvDefaultDprec = EXSE_PREC_FP32; break;
+                  case '8': srvDefaultDprec = EXSE_PREC_FP64; break;
                   default: Warning("Invalid digit in %s: %s", envName, envString);
                   }
                 break;
@@ -141,8 +141,8 @@ srvCheckFiletype(int fileID, int *swap)
 
   if (fileRead(fileID, buffer, 4) != 4) return 0;
 
-  size_t blocklen = (size_t) get_UINT32(buffer);
-  size_t sblocklen = (size_t) get_SUINT32(buffer);
+  size_t blocklen = (size_t) get_uint32(buffer);
+  size_t sblocklen = (size_t) get_swap_uint32(buffer);
 
   if (SRV_Debug) Message("blocklen = %d sblocklen = %d", blocklen, sblocklen);
 
@@ -152,36 +152,36 @@ srvCheckFiletype(int fileID, int *swap)
      *swap = 0;
       fact = blocklen>>3;
       if (fileRead(fileID, buffer, blocklen+8) != blocklen+8) return 0;
-      pbuf = buffer+4*fact;      dimx = (size_t) get_UINT32(pbuf);
-      pbuf = buffer+5*fact;      dimy = (size_t) get_UINT32(pbuf);
-      pbuf = buffer+blocklen+4;  data = (size_t) get_UINT32(pbuf);
+      pbuf = buffer+4*fact;      dimx = (size_t) get_uint32(pbuf);
+      pbuf = buffer+5*fact;      dimy = (size_t) get_uint32(pbuf);
+      pbuf = buffer+blocklen+4;  data = (size_t) get_uint32(pbuf);
     }
   else if (blocklen == 64)
     {
      *swap = 0;
       fact = blocklen>>3;
       if (fileRead(fileID, buffer, blocklen+8) != blocklen+8) return 0;
-      pbuf = buffer+4*fact;      dimx = (size_t) get_UINT64(pbuf);
-      pbuf = buffer+5*fact;      dimy = (size_t) get_UINT64(pbuf);
-      pbuf = buffer+blocklen+4;  data = (size_t) get_UINT32(pbuf);
+      pbuf = buffer+4*fact;      dimx = (size_t) get_uint64(pbuf);
+      pbuf = buffer+5*fact;      dimy = (size_t) get_uint64(pbuf);
+      pbuf = buffer+blocklen+4;  data = (size_t) get_uint32(pbuf);
     }
   else if (sblocklen == 32)
     {
      *swap = 1;
       fact = sblocklen>>3;
       if (fileRead(fileID, buffer, sblocklen+8) != sblocklen+8) return 0;
-      pbuf = buffer+4*fact;       dimx = (size_t) get_SUINT32(pbuf);
-      pbuf = buffer+5*fact;       dimy = (size_t) get_SUINT32(pbuf);
-      pbuf = buffer+sblocklen+4;  data = (size_t) get_SUINT32(pbuf);
+      pbuf = buffer+4*fact;       dimx = (size_t) get_swap_uint32(pbuf);
+      pbuf = buffer+5*fact;       dimy = (size_t) get_swap_uint32(pbuf);
+      pbuf = buffer+sblocklen+4;  data = (size_t) get_swap_uint32(pbuf);
     }
   else if (sblocklen == 64)
     {
      *swap = 1;
       fact = sblocklen>>3;
       if (fileRead(fileID, buffer, sblocklen+8) != sblocklen+8) return 0;
-      pbuf = buffer+4*fact;       dimx = (size_t) get_SUINT64(pbuf);
-      pbuf = buffer+5*fact;       dimy = (size_t) get_SUINT64(pbuf);
-      pbuf = buffer+sblocklen+4;  data = (size_t) get_SUINT32(pbuf);
+      pbuf = buffer+4*fact;       dimx = (size_t) get_swap_uint64(pbuf);
+      pbuf = buffer+5*fact;       dimy = (size_t) get_swap_uint64(pbuf);
+      pbuf = buffer+sblocklen+4;  data = (size_t) get_swap_uint32(pbuf);
     }
   // clang-format on
 
@@ -231,38 +231,28 @@ srvInqData(srvrec_t *srvp, int prec, void *data)
 
   switch (dprec)
     {
-    case EXSE_SINGLE_PRECISION:
+    case EXSE_PREC_FP32:
       {
-        if (sizeof(FLT32) == 4)
-          {
-            if (byteswap) swap4byte(buffer, datasize);
+        if (byteswap) swap4byte(buffer, datasize);
 
-            if (dprec == prec)
-              memcpy(data, buffer, datasize * sizeof(FLT32));
-            else
-              for (size_t i = 0; i < datasize; i++) ((double *) data)[i] = (double) ((float *) buffer)[i];
-          }
+        if (dprec == prec)
+          memcpy(data, buffer, datasize * sizeof(float));
         else
-          {
-            Error("not implemented for %d byte float", sizeof(FLT32));
-          }
+          for (size_t i = 0; i < datasize; i++) ((double *) data)[i] = (double) ((float *) buffer)[i];
+
         break;
       }
-    case EXSE_DOUBLE_PRECISION:
-      if (sizeof(FLT64) == 8)
-        {
-          if (byteswap) swap8byte(buffer, datasize);
+    case EXSE_PREC_FP64:
+      {
+        if (byteswap) swap8byte(buffer, datasize);
 
-          if (dprec == prec)
-            memcpy(data, buffer, datasize * sizeof(FLT64));
-          else
-            for (size_t i = 0; i < datasize; i++) ((float *) data)[i] = (float) ((double *) buffer)[i];
-        }
-      else
-        {
-          Error("not implemented for %d byte float", sizeof(FLT64));
-        }
-      break;
+        if (dprec == prec)
+          memcpy(data, buffer, datasize * sizeof(double));
+        else
+          for (size_t i = 0; i < datasize; i++) ((float *) data)[i] = (float) ((double *) buffer)[i];
+
+        break;
+      }
     default:
       {
         Error("unexpected data precision %d", dprec);
@@ -274,15 +264,15 @@ srvInqData(srvrec_t *srvp, int prec, void *data)
 }
 
 int
-srvInqDataSP(void *srv, float *data)
+srvInqDataFP32(void *srv, float *data)
 {
-  return srvInqData((srvrec_t *) srv, EXSE_SINGLE_PRECISION, (void *) data);
+  return srvInqData((srvrec_t *) srv, EXSE_PREC_FP32, (void *) data);
 }
 
 int
-srvInqDataDP(void *srv, double *data)
+srvInqDataFP64(void *srv, double *data)
 {
-  return srvInqData((srvrec_t *) srv, EXSE_DOUBLE_PRECISION, (void *) data);
+  return srvInqData((srvrec_t *) srv, EXSE_PREC_FP64, (void *) data);
 }
 
 static int
@@ -311,19 +301,19 @@ srvDefData(void *srv, int prec, const void *data)
 
   switch (dprec)
     {
-    case EXSE_SINGLE_PRECISION:
+    case EXSE_PREC_FP32:
       {
         if (dprec == prec)
-          memcpy(srvp->buffer, data, datasize * sizeof(FLT32));
+          memcpy(srvp->buffer, data, datasize * sizeof(float));
         else
           for (size_t i = 0; i < datasize; i++) ((float *) srvp->buffer)[i] = (float) ((double *) data)[i];
 
         break;
       }
-    case EXSE_DOUBLE_PRECISION:
+    case EXSE_PREC_FP64:
       {
         if (dprec == prec)
-          memcpy(srvp->buffer, data, datasize * sizeof(FLT64));
+          memcpy(srvp->buffer, data, datasize * sizeof(double));
         else
           for (size_t i = 0; i < datasize; i++) ((double *) srvp->buffer)[i] = (double) ((float *) data)[i];
 
@@ -340,15 +330,15 @@ srvDefData(void *srv, int prec, const void *data)
 }
 
 int
-srvDefDataSP(void *srv, const float *data)
+srvDefDataFP32(void *srv, const float *data)
 {
-  return srvDefData(srv, EXSE_SINGLE_PRECISION, (void *) data);
+  return srvDefData(srv, EXSE_PREC_FP32, (void *) data);
 }
 
 int
-srvDefDataDP(void *srv, const double *data)
+srvDefDataFP64(void *srv, const double *data)
 {
-  return srvDefData(srv, EXSE_DOUBLE_PRECISION, (void *) data);
+  return srvDefData(srv, EXSE_PREC_FP64, (void *) data);
 }
 
 int
@@ -379,13 +369,13 @@ srvRead(int fileID, void *srv)
 
   switch (hprec)
     {
-    case EXSE_SINGLE_PRECISION:
+    case EXSE_PREC_FP32:
       {
         binReadInt32(fileID, byteswap, SRV_HEADER_LEN, tempheader.i32);
         for (int i = 0; i < SRV_HEADER_LEN; i++) srvp->header[i] = (int) tempheader.i32[i];
         break;
       }
-    case EXSE_DOUBLE_PRECISION:
+    case EXSE_PREC_FP64:
       {
         binReadInt64(fileID, byteswap, SRV_HEADER_LEN, tempheader.i64);
         for (int i = 0; i < SRV_HEADER_LEN; i++) srvp->header[i] = (int) tempheader.i64[i];
@@ -422,7 +412,7 @@ srvRead(int fileID, void *srv)
 
   srvp->dprec = (int) dprec;
 
-  if (dprec != EXSE_SINGLE_PRECISION && dprec != EXSE_DOUBLE_PRECISION)
+  if (dprec != EXSE_PREC_FP32 && dprec != EXSE_PREC_FP64)
     {
       Warning("Unexpected data precision %d", dprec);
       return -1;
@@ -458,15 +448,15 @@ srvWrite(int fileID, void *srv)
 
   switch (hprec)
     {
-    case EXSE_SINGLE_PRECISION:
+    case EXSE_PREC_FP32:
       {
-        for (int i = 0; i < SRV_HEADER_LEN; i++) tempheader.i32[i] = (INT32) header[i];
+        for (int i = 0; i < SRV_HEADER_LEN; i++) tempheader.i32[i] = (int32_t) header[i];
         binWriteInt32(fileID, byteswap, SRV_HEADER_LEN, tempheader.i32);
         break;
       }
-    case EXSE_DOUBLE_PRECISION:
+    case EXSE_PREC_FP64:
       {
-        for (int i = 0; i < SRV_HEADER_LEN; i++) tempheader.i64[i] = (INT64) header[i];
+        for (int i = 0; i < SRV_HEADER_LEN; i++) tempheader.i64[i] = (int64_t) header[i];
         binWriteInt64(fileID, byteswap, SRV_HEADER_LEN, tempheader.i64);
         break;
       }
@@ -486,14 +476,14 @@ srvWrite(int fileID, void *srv)
 
   switch (dprec)
     {
-    case EXSE_SINGLE_PRECISION:
+    case EXSE_PREC_FP32:
       {
-        binWriteFlt32(fileID, byteswap, srvp->datasize, (FLT32 *) srvp->buffer);
+        binWriteFlt32(fileID, byteswap, srvp->datasize, (float *) srvp->buffer);
         break;
       }
-    case EXSE_DOUBLE_PRECISION:
+    case EXSE_PREC_FP64:
       {
-        binWriteFlt64(fileID, byteswap, srvp->datasize, (FLT64 *) srvp->buffer);
+        binWriteFlt64(fileID, byteswap, srvp->datasize, (double *) srvp->buffer);
         break;
       }
     default:
