@@ -380,6 +380,8 @@ streamFilename(int streamID)
 static int
 cdiInqContents(stream_t *streamptr)
 {
+  if (streamptr->lockIO) CDI_IO_LOCK();
+
   int status = 0;
   int filetype = streamptr->filetype;
 
@@ -418,6 +420,8 @@ cdiInqContents(stream_t *streamptr)
       }
     }
 
+  if (streamptr->lockIO) CDI_IO_UNLOCK();
+
   if (status == 0)
     {
       int taxisID = vlistInqTaxis(streamptr->vlistID);
@@ -667,7 +671,7 @@ streamOpenID(const char *filename, char filemode, int filetype, int resH)
   if (CDI_Threadsafe)
     {
 #ifndef HAVE_LIBPTHREAD
-      Error("CDI threadsafe failed, pthread support not compiled!");
+      Error("CDI threadsafe failed, pthread support not compiled in!");
 #endif
       if (filetype == CDI_FILETYPE_NC4 || filetype == CDI_FILETYPE_NC4C) streamptr->lockIO = true;
     }
@@ -1023,9 +1027,7 @@ streamDefaultValue(stream_t *streamptr)
   streamptr->sortname = (cdiSortName > 0);
   streamptr->lockIO = CDI_Lock_IO;
   // netcdf4/HDF5 filter
-  streamptr->filterId = 0;
-  streamptr->numParams = 0;
-  streamptr->maxParams = sizeof(streamptr->params) / sizeof(streamptr->params[0]);
+  streamptr->filterSpec = NULL;
 
   basetimeInit(&streamptr->basetime);
 
@@ -1099,6 +1101,12 @@ cdiStreamCloseDefaultDelegate(stream_t *streamptr, int recordBufIsToBeDeleted)
   int fileID = streamptr->fileID;
   int filetype = streamptr->filetype;
 
+  if (streamptr->filterSpec)
+    {
+      free(streamptr->filterSpec);
+      streamptr->filterSpec = NULL;
+    }
+
   switch (streamptr->protocol)
     {
     case CDI_PROTOCOL_ACROSS:
@@ -1665,16 +1673,17 @@ streamDefShuffle(int streamID, int shuffle)
 }
 
 void
-streamDefFilter(int streamID, int filterId, int numParams, const int *params)
+streamDefFilter(int streamID, const char *filterSpec)
 {
   stream_t *s = stream_to_pointer(streamID);
-  if ((int) s->filterId != filterId)
+  if (filterSpec)
     {
-      if (numParams > (int) s->maxParams) Error("Too many filter parameter %d (max=%zu)!", numParams, s->maxParams);
-      s->filterId = filterId;
-      s->numParams = numParams;
-      for (int i = 0; i < numParams; ++i) s->params[i] = params[i];
-      reshSetStatus(streamID, &streamOps, RESH_DESYNC_IN_USE);
+      // if (s->filterSpec) Error("Filter spec already defined!");
+      if (s->filterSpec == NULL)
+        {
+          s->filterSpec = strdup(filterSpec);
+          reshSetStatus(streamID, &streamOps, RESH_DESYNC_IN_USE);
+        }
     }
 }
 
