@@ -12,6 +12,8 @@
       Arithc     subc            Subtract by constant
       Arithc     mulc            Multiply by constant
       Arithc     divc            Divide by constant
+      Arithc     minc            Minimum of a field and a constant
+      Arithc     maxc            Maximum of a field and a constant
       Arithc     mod             Modulo operator
 */
 
@@ -26,16 +28,16 @@
 static void
 fill_vars(const VarList &varList, std::vector<bool> &vars)
 {
-  auto nvars = vars.size();
+  auto numVars = varList.numVars();
 
   if (Options::cdo_num_varnames() > 0)
     {
       auto found = false;
-      for (size_t varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
           vars[varID] = false;
           for (size_t i = 0; i < Options::cdo_num_varnames(); ++i)
-            if (varList[varID].name == Options::cdoVarnames[i])
+            if (varList.vars[varID].name == Options::cdoVarnames[i])
               {
                 vars[varID] = true;
                 found = true;
@@ -47,7 +49,7 @@ fill_vars(const VarList &varList, std::vector<bool> &vars)
     }
   else
     {
-      for (size_t varID = 0; varID < nvars; ++varID) vars[varID] = true;
+      for (int varID = 0; varID < numVars; ++varID) vars[varID] = true;
     }
 }
 
@@ -86,7 +88,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);
@@ -109,10 +111,10 @@ public:
 
     vlist_unpack(vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     auto nvars = vlistNvars(vlistID1);
-    // for (int varID = 0; varID < nvars; ++varID) varList1[varID].memType = MemType::Double;
+    // for (int varID = 0; varID < nvars; ++varID) varList1.vars[varID].memType = MemType::Double;
 
     vars = std::vector<bool>(nvars);
     fill_vars(varList1, vars);
@@ -131,7 +133,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     Field field;
     int tsID = 0;
@@ -147,7 +149,7 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field.init(varList1[varID]);
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
 
             if (vars[varID])
@@ -170,7 +172,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
