@@ -8,7 +8,6 @@
 #include <cdi.h>
 
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "cdo_options.h"
 #include "pmlist.h"
 #include "param_conversion.h"
@@ -247,7 +246,7 @@ set_global_attributes(int vlistID, const BitroundParams &params, int numVarsHave
 static std::vector<int>
 get_vars_numbits(const VarList &varList, const std::string &filename)
 {
-  auto numVars = varList.size();
+  auto numVars = varList.numVars();
   std::vector<int> varsNumbits(numVars, -1);
 
   if (filename.size())
@@ -266,14 +265,14 @@ get_vars_numbits(const VarList &varList, const std::string &filename)
           if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
           if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
 
-          for (size_t varID = 0; varID < numVars; ++varID)
+          for (const auto &var : varList.vars)
             {
-              if (key == varList[varID].name)
+              if (key == var.name)
                 {
                   const auto &value = kv.values[0];
                   auto numBits = parameter_to_int(value);
                   check_range(numBits, 1, 23, key);
-                  varsNumbits[varID] = numBits;
+                  varsNumbits[var.ID] = numBits;
                 }
             }
         }
@@ -314,11 +313,8 @@ public:
   int vlistID2;
 
   BitroundParams params;
-  int ntsteps;
-  int nvars;
 
   VarList varList1;
-  Field field;
 
   std::vector<VarStat> varsStatGlob;
   std::vector<bool> varsCheckMiss;
@@ -328,7 +324,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     params = get_parameter();
     if (Options::cdoVerbose) print_parameter(params);
@@ -337,7 +333,7 @@ public:
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     taxisID1 = vlistInqTaxis(vlistID1);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     varsNumbits = get_vars_numbits(varList1, params.filename);
     auto numVarsHaveNumbits = num_vars_have_numbits(varsNumbits);
@@ -349,34 +345,35 @@ public:
     check_attributes(vlistID1);
     set_global_attributes(vlistID2, params, numVarsHaveNumbits);
 
-    nvars = vlistNvars(vlistID1);
-    for (int varID = 0; varID < nvars; ++varID)
+    auto numVars = varList1.numVars();
+    for (const auto &var : varList1.vars)
       {
-        if (varList1[varID].memType == MemType::Float)
+        if (var.memType == MemType::Float)
           {
-            int nsb = (varsNumbits[varID] != -1) ? varsNumbits[varID] : params.numBits;
-            if (nsb >= 1 && nsb <= 23) set_local_attributes(vlistID2, varID, nsb);
+            int nsb = (varsNumbits[var.ID] != -1) ? varsNumbits[var.ID] : params.numBits;
+            if (nsb >= 1 && nsb <= 23) set_local_attributes(vlistID2, var.ID, nsb);
           }
       }
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varsStatGlob = std::vector<VarStat>(nvars);
-    varsCheckMiss = std::vector<bool>(nvars, true);
-    varsCheckFloat = std::vector<bool>(nvars, true);
+    varsStatGlob = std::vector<VarStat>(numVars);
+    varsCheckMiss = std::vector<bool>(numVars, true);
+    varsCheckFloat = std::vector<bool>(numVars, true);
 
-    nsbVarLevels = std::vector<std::vector<int>>(nvars);
-    for (int varID = 0; varID < nvars; ++varID) nsbVarLevels[varID].resize(varList1[varID].nlevels, 0);
-
-    ntsteps = vlistNtsteps(vlistID1);
-
-    progress::init();
+    nsbVarLevels = std::vector<std::vector<int>>(numVars);
+    for (int varID = 0; varID < numVars; ++varID) nsbVarLevels[varID].resize(varList1.vars[varID].nlevels, 0);
   }
 
   void
-  run()
+  run() override
   {
+    Field field;
+    auto numVars = varList1.numVars();
+    auto numSteps = varList1.numSteps();
+    cdo::Progress progress;
+
     int tsID = 0;
     while (true)
       {
@@ -386,18 +383,17 @@ public:
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
         cdo_def_timestep(streamID2, tsID);
 
-        std::vector<VarStat> varsStat(nvars);
+        std::vector<VarStat> varsStat(numVars);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            auto fstatus = (ntsteps >= 0) ? (tsID + (recID + 1.0) / nrecs) / ntsteps : 1.0;
-            if (!Options::cdoVerbose) progress::update(0, 1, fstatus);
+            auto fstatus = (tsID + (recID + 1.0) / nrecs) / numSteps;
+            if (numSteps > 0) progress.update(fstatus);
 
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
             cdo_def_record(streamID2, varID, levelID);
 
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             field.init(var);
             cdo_read_record(streamID1, field);
 
@@ -427,8 +423,9 @@ public:
                     else if (params.numSteps == 1) { nsb = nsbVarLevels[varID][levelID]; }
                   }
 
-                varsStat[varID].nsbMin = std::min(varsStat[varID].nsbMin, nsb);
-                varsStat[varID].nsbMax = std::max(varsStat[varID].nsbMax, nsb);
+                auto &varStat = varsStat[varID];
+                varStat.nsbMin = std::min(varStat.nsbMin, nsb);
+                varStat.nsbMax = std::max(varStat.nsbMax, nsb);
 
                 if (nsb >= 1 && nsb <= 23) bitround(nsb, field.size, field.vec_f, var.missval);
 
@@ -445,19 +442,23 @@ public:
         if (Options::cdoVerbose && params.numBits == -1)
           {
             fprintf(stderr, "NSB: step=%d:", tsID + 1);
-            for (int varID = 0; varID < nvars; ++varID)
-              if (varsStat[varID].nsbMin >= 1 && varsStat[varID].nsbMin <= 23)
-                {
-                  fprintf(stderr, " %s=%d", varList1[varID].name.c_str(), varsStat[varID].nsbMin);
-                  if (varList1[varID].nlevels > 1) fprintf(stderr, "-%d ", varsStat[varID].nsbMax);
-                }
+            for (const auto &var1 : varList1.vars)
+              {
+                const auto &varStat = varsStat[var1.ID];
+                if (varStat.nsbMin >= 1 && varStat.nsbMin <= 23)
+                  {
+                    fprintf(stderr, " %s=%d", var1.name.c_str(), varStat.nsbMin);
+                    if (var1.nlevels > 1) fprintf(stderr, "-%d ", varStat.nsbMax);
+                  }
+              }
             fprintf(stderr, "\n");
           }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            varsStatGlob[varID].nsbMin = std::min(varsStatGlob[varID].nsbMin, varsStat[varID].nsbMin);
-            varsStatGlob[varID].nsbMax = std::max(varsStatGlob[varID].nsbMax, varsStat[varID].nsbMax);
+            auto &varStatGlob = varsStatGlob[varID];
+            varStatGlob.nsbMin = std::min(varStatGlob.nsbMin, varsStat[varID].nsbMin);
+            varStatGlob.nsbMax = std::max(varStatGlob.nsbMax, varsStat[varID].nsbMax);
           }
 
         if (params.printBits) break;
@@ -467,25 +468,31 @@ public:
 
     if (params.printBits)
       {
-        for (int varID = 0; varID < nvars; ++varID)
-          if (varsStatGlob[varID].nsbMin >= 1 && varsStatGlob[varID].nsbMin <= 23)
-            fprintf(stdout, "%s=%d\n", varList1[varID].name.c_str(), varsStatGlob[varID].nsbMax);
+        for (const auto &var1 : varList1.vars)
+          {
+            const auto &varStatGlob = varsStatGlob[var1.ID];
+            if (varStatGlob.nsbMin >= 1 && varStatGlob.nsbMin <= 23)
+              fprintf(stdout, "%s=%d\n", var1.name.c_str(), varStatGlob.nsbMax);
+          }
       }
     else if (Options::cdoVerbose && params.numBits == -1)
       {
         fprintf(stderr, "NSB: step=all:");
-        for (int varID = 0; varID < nvars; ++varID)
-          if (varsStatGlob[varID].nsbMin >= 1 && varsStatGlob[varID].nsbMin <= 23)
-            {
-              fprintf(stderr, " %s=%d", varList1[varID].name.c_str(), varsStatGlob[varID].nsbMin);
-              if (varsStatGlob[varID].nsbMin != varsStatGlob[varID].nsbMax) fprintf(stderr, "-%d", varsStatGlob[varID].nsbMax);
-            }
-        fprintf(stderr, "\n");
+        for (const auto &var1 : varList1.vars)
+          {
+            const auto &varStatGlob = varsStatGlob[var1.ID];
+            if (varStatGlob.nsbMin >= 1 && varStatGlob.nsbMin <= 23)
+              {
+                fprintf(stderr, " %s=%d", var1.name.c_str(), varStatGlob.nsbMin);
+                if (varStatGlob.nsbMin != varStatGlob.nsbMax) fprintf(stderr, "-%d", varStatGlob.nsbMax);
+              }
+            fprintf(stderr, "\n");
+          }
       }
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID2);
