@@ -9,7 +9,6 @@
 
 #include "cdo_options.h"
 #include "cdo_timer.h"
-#include "cdo_vlist.h"
 #include "param_conversion.h"
 #include "process_int.h"
 #include "util_files.h"
@@ -34,7 +33,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "CDIread",
-    .operators = { { "cdiread"} },
+    .operators = { { "cdiread" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -52,9 +51,8 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     sinfo[0] = 0;
 
     if (Options::cdoVerbose) cdo_print("parameter: <nruns>");
@@ -69,8 +67,9 @@ public:
 
     // vlistDefNtsteps(vlistID, 1);
   }
+
   void
-  run()
+  run() override
   {
     for (int irun = 0; irun < nruns; ++irun)
       {
@@ -81,8 +80,7 @@ public:
         auto streamID = cdo_open_read(0);
         auto vlistID = cdo_stream_inq_vlist(streamID);
 
-        VarList varList;
-        varList_init(varList, vlistID);
+        VarList varList(vlistID);
 
         filetype = cdo_inq_filetype(streamID);
         datatype = vlistInqVarDatatype(vlistID, 0);
@@ -107,7 +105,7 @@ public:
                 int varID, levelID;
                 cdo_inq_record(streamID, &varID, &levelID);
 
-                auto gridsize = varList[varID].gridsize;
+                auto gridsize = varList.vars[varID].gridsize;
                 nvalues += gridsize;
 
                 size_t numMissVals;
@@ -142,8 +140,9 @@ public:
 
     if (nruns > 1) print_stat("(mean)", memtype, datatype, filetype, nvalues, dataSize, fileSize, runTimeSum / nruns);
   }
+
   void
-  close()
+  close() override
   {
   }
 };
