@@ -118,7 +118,7 @@ cmor_check_prep(CmorVar &var, long gridsize, double missval, const double *const
       for (long i = 0; i < gridsize; ++i)
         {
           auto aval = array[i];
-          if (dbl_is_not_equal(aval, missval))
+          if (fp_is_not_equal(aval, missval))
             {
               amean += std::fabs(aval);
               nvals++;
@@ -133,7 +133,7 @@ cmor_check_prep(CmorVar &var, long gridsize, double missval, const double *const
       for (long i = 0; i < gridsize; ++i)
         {
           auto aval = array[i];
-          if (dbl_is_not_equal(aval, missval))
+          if (fp_is_not_equal(aval, missval))
             {
               if (aval < var.valid_min) n_lower_min++;
               if (aval > var.valid_max) n_greater_max++;
@@ -186,7 +186,7 @@ apply_cmor_list(PMList &pmlist, int nvars, int vlistID2, std::vector<CmorVar> &v
       if (hasMissvals)
         {
           auto missvalOld = vlistInqVarMissval(vlistID2, varID);
-          if (dbl_is_not_equal(missval, missvalOld))
+          if (fp_is_not_equal(missval, missvalOld))
             {
               var.changemissval = true;
               var.missvalOld = missvalOld;
@@ -239,7 +239,7 @@ apply_cmor_list(PMList &pmlist, int nvars, int vlistID2, std::vector<CmorVar> &v
                 {
                   missval = parameter_to_double(value);
                   auto missvalOld = vlistInqVarMissval(vlistID2, varID);
-                  if (dbl_is_not_equal(missval, missvalOld))
+                  if (fp_is_not_equal(missval, missvalOld))
                     {
                       if (Options::cdoVerbose) cdo_print("%s - change missval from %g to %g", var.name, missvalOld, missval);
                       var.changemissval = true;
@@ -466,7 +466,7 @@ public:
               {
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (dbl_is_equal(array[i], var.missvalOld)) array[i] = missval;
+                    if (fp_is_equal(array[i], var.missvalOld)) array[i] = missval;
                   }
               }
 
@@ -474,7 +474,7 @@ public:
               {
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (dbl_is_not_equal(array[i], missval)) array[i] *= var.factor;
+                    if (fp_is_not_equal(array[i], missval)) array[i] *= var.factor;
                   }
               }
 
@@ -484,7 +484,7 @@ public:
                 int nerr = 0;
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (dbl_is_not_equal(array[i], missval))
+                    if (fp_is_not_equal(array[i], missval))
                       {
                         array[i] = cv_convert_double((const cv_converter *) var.ut_converter, array[i]);
                         if (ut_get_status() != UT_SUCCESS) nerr++;
