@@ -15,8 +15,6 @@
 
 #include "process_int.h"
 #include "cdo_timer.h"
-#include "cdo_vlist.h"
-#include "timer.h"
 #include "util_files.h"
 #include "progress.h"
 #include "cdo_options.h"
@@ -48,27 +46,27 @@ public:
   CdoStreamID streamID2;
   int vlistID2 = CDI_UNDEFID;
   int taxisID2 = CDI_UNDEFID;
-  int nfiles;
+  int numFiles;
   Field field;
 
 public:
   void
-  init()
+  init() override
   {
     operator_check_argc(0);
 
     dataIsUnchanged = data_is_unchanged();
 
     auto streamCnt = cdo_stream_cnt();
-    nfiles = streamCnt - 1;
-
-    progress::init();
+    numFiles = streamCnt - 1;
   }
 
   void
-  run()
+  run() override
   {
-    for (int indf = 0; indf < nfiles; ++indf)
+    cdo::Progress progress;
+
+    for (int indf = 0; indf < numFiles; ++indf)
       {
         cdo::timer timer;
 
@@ -76,80 +74,80 @@ public:
         auto vlistID1 = cdo_stream_inq_vlist(streamID1);
         auto taxisID1 = vlistInqTaxis(vlistID1);
 
-        VarList varList1;
-        varList_init(varList1, vlistID1);
+        VarList varList1(vlistID1);
 
         if (indf == 0)
           {
-            auto nvars = vlistNvars(vlistID1);
+            auto numVars = varList1.numVars();
+            auto numSteps = varList1.numSteps();
+            if (numSteps == 1 && varList1.numVaryingVars() == 0) numSteps = 0;
 
-            auto ntsteps = vlistNtsteps(vlistID1);
-            if (ntsteps == 1 && varList_numVaryingVars(varList1) == 0) ntsteps = 0;
-
-            std::string ofilename = cdo_get_stream_name(nfiles);
+            std::string ofilename = cdo_get_stream_name(numFiles);
             if (!Options::cdoOverwriteMode && FileUtils::file_exists(ofilename))
               {
-                streamID2 = cdo_open_append(nfiles);
-
+                streamID2 = cdo_open_append(numFiles);
                 vlistID2 = cdo_stream_inq_vlist(streamID2);
                 taxisID2 = vlistInqTaxis(vlistID2);
 
-                vlist_compare(vlistID1, vlistID2, CmpVlist::All);
+                VarList varList2(vlistID2);
+                varList_compare(varList1, varList2);
 
-                tsID2 = vlistNtsteps(vlistID2);
+                tsID2 = varList2.numSteps();
                 if (tsID2 == 0) tsID2 = 1;  // bug fix for time constant data only
 
-                if (ntsteps == 0) hasConstVars = false;
+                if (numSteps == 0) hasConstVars = false;
               }
             else
               {
                 if (Options::cdoVerbose) cdo_print("Output file doesn't exist, creating: %s", ofilename);
 
                 streamMode = StreamMode::CREATE;
-                streamID2 = cdo_open_write(nfiles);
-
+                streamID2 = cdo_open_write(numFiles);
                 vlistID2 = vlistDuplicate(vlistID1);
                 taxisID2 = taxisDuplicate(taxisID1);
                 vlistDefTaxis(vlistID2, taxisID2);
 
-                if (ntsteps == 0 && nfiles > 1)
+                if (numSteps == 0 && numFiles > 1)
                   {
                     hasConstVars = false;
-                    for (int varID = 0; varID < nvars; ++varID) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
+                    for (int varID = 0; varID < numVars; ++varID) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
                   }
 
                 cdo_def_vlist(streamID2, vlistID2);
               }
           }
-        else { vlist_compare(vlistID1, vlistID2, CmpVlist::All); }
+        else
+          {
+            VarList varList2(vlistID2);
+            varList_compare(varList1, varList2);
+          }
 
-        auto ntsteps = vlistNtsteps(vlistID1);
+        auto numSteps = varList1.numSteps();
         int tsID1 = 0;
         while (true)
           {
-            auto nrecs = cdo_stream_inq_timestep(streamID1, tsID1);
-            if (nrecs == 0) break;
+            auto numRecords = cdo_stream_inq_timestep(streamID1, tsID1);
+            if (numRecords == 0) break;
 
-            const double fstatus = (ntsteps > 1) ? indf + (tsID1 + 1.0) / ntsteps : indf + 1.0;
-            if (!Options::cdoVerbose) progress::update(0, 1, fstatus / nfiles);
+            auto fstatus = (numSteps > 1) ? indf + (tsID1 + 1.0) / numSteps : indf + 1.0;
+            progress.update(fstatus / numFiles);
 
             cdo_taxis_copy_timestep(taxisID2, taxisID1);
             cdo_def_timestep(streamID2, tsID2);
 
-            for (int recID = 0; recID < nrecs; ++recID)
+            for (int recID = 0; recID < numRecords; ++recID)
               {
-                int varID, levelID;
-                cdo_inq_record(streamID1, &varID, &levelID);
+                auto [varID, levelID] = cdo_inq_record(streamID1);
 
-                if (hasConstVars && tsID2 > 0 && tsID1 == 0)
-                  if (varList1[varID].isConstant) continue;
+                const auto &var1 = varList1.vars[varID];
+                if (hasConstVars && tsID2 > 0 && tsID1 == 0 && var1.isConstant) continue;
 
                 cdo_def_record(streamID2, varID, levelID);
 
                 if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
                 else
                   {
-                    field.init(varList1[varID]);
+                    field.init(var1);
                     cdo_read_record(streamID1, field);
                     cdo_write_record(streamID2, field);
                   }
@@ -166,14 +164,10 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
 
-    if (streamMode == StreamMode::CREATE)
-      {
-        vlistDestroy(vlistID2);
-        taxisDestroy(taxisID2);
-      }
+    if (streamMode == StreamMode::CREATE) { vlistDestroy(vlistID2); }
   }
 };
