@@ -92,7 +92,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Cloudlayer",
-    .operators = { { "cloudlayer"} },
+    .operators = { { "cloudlayer" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -125,7 +125,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     if (cdo_operator_argc() > 0)
@@ -140,22 +140,20 @@ public:
     streamID1 = cdo_open_read(0);
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-    VarList varList1;
-    varList_init(varList1, vlistID1);
+    VarList varList1(vlistID1);
 
     gridsize = vlist_check_gridsize(vlistID1);
 
     auto aclcac_code = 223;
 
-    auto nvars = vlistNvars(vlistID1);
-    for (int varID = 0; varID < nvars; ++varID)
+    for (const auto &var1 : varList1.vars)
       {
-        zaxisID = varList1[varID].zaxisID;
-        auto code = varList1[varID].code;
+        zaxisID = var1.zaxisID;
+        auto code = var1.code;
 
         if (code <= 0)
           {
-            if (string_to_lower(varList1[varID].name) == "aclcac") code = 223;
+            if (string_to_lower(var1.name) == "aclcac") code = 223;
           }
 
         if (code == aclcac_code)
@@ -163,7 +161,7 @@ public:
             aclcac_code_found = 1;
             if (zaxisInqType(zaxisID) == ZAXIS_PRESSURE || zaxisInqType(zaxisID) == ZAXIS_HYBRID)
               {
-                aclcacID = varID;
+                aclcacID = var1.ID;
                 break;
               }
           }
@@ -177,11 +175,11 @@ public:
           cdo_abort("Cloud cover (parameter 223) not found!");
       }
 
-    missval = varList1[aclcacID].missval;
-    gridID = varList1[aclcacID].gridID;
-    zaxisID = varList1[aclcacID].zaxisID;
-
-    nlevels = varList1[aclcacID].nlevels;
+    const auto &aclcacVar = varList1.vars[aclcacID];
+    missval = aclcacVar.missval;
+    gridID = aclcacVar.gridID;
+    zaxisID = aclcacVar.zaxisID;
+    nlevels = aclcacVar.nlevels;
     auto nhlev = nlevels + 1;
 
     aclcac = std::vector<double>(gridsize * nlevels);
@@ -279,8 +277,9 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
   }
+
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -328,8 +327,9 @@ public:
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
