@@ -147,7 +147,7 @@ gen_coll_grid(int ngrids, int numFiles, std::vector<CollgridInfo> &collgridInfo,
           nx = 1;
           for (int fileID = 1; fileID < numFiles; ++fileID)
             {
-              if (dbl_is_equal(xyinfo[0].y, xyinfo[fileID].y))
+              if (fp_is_equal(xyinfo[0].y, xyinfo[fileID].y))
                 nx++;
               else
                 break;
