@@ -134,7 +134,8 @@ com_stat(const std::string &arg)
 {
   (void) (arg);  // unused
 
-  auto name = varList[gl_varID].name.c_str();
+  const auto &var = varList.vars[gl_varID];
+  auto name = var.name.c_str();
 
   auto tsID2 = gl_tsID2;
   if (tsID2 == -1) tsID2 = (gl_ntsteps != -1) ? gl_ntsteps - 1 : INT_MAX - 1;
@@ -154,19 +155,19 @@ com_stat(const std::string &arg)
         {
           cdo::timer stepTimer;
 
-          auto nlevels = varList[gl_varID].nlevels;
-          auto gridsize = varList[gl_varID].gridsize;
-          auto missval = varList[gl_varID].missval;
+          auto nlevels = var.nlevels;
+          auto gridsize = var.gridsize;
+          auto missval = var.missval;
 
           auto levelID = (nlevels > 1) ? gl_levelID : 0;
 
           size_t numMissVals;
           streamReadVarSlice(gl_streamID, gl_varID, levelID, gl_data.data(), &numMissVals);
 
-          auto mmm = varray_min_max_mean_mv(gridsize, gl_data, missval);
+          auto mmm = varray_min_max_mean_mv(gl_data, gridsize, missval);
 
-          fprintf(stdout, "%s:  z=%d  t=%d  size=%zu numMissVals=%zu  min=%.5g mean=%.5g max=%.5g [%.2fs]\n", name, levelID + 1, tsID + 1,
-                  gridsize, numMissVals, mmm.min, mmm.mean, mmm.max, stepTimer.elapsed());
+          fprintf(stdout, "%s:  z=%d  t=%d  size=%zu numMissVals=%zu  min=%.5g mean=%.5g max=%.5g [%.2fs]\n", name, levelID + 1,
+                  tsID + 1, gridsize, numMissVals, mmm.min, mmm.mean, mmm.max, stepTimer.elapsed());
         }
     }
 
@@ -214,7 +215,7 @@ set_tsID(int tsID1, int tsID2)
 static int
 check_levelID(int levelID)
 {
-  auto nlevels = varList[gl_varID].nlevels;
+  auto nlevels = varList.vars[gl_varID].nlevels;
   if (levelID >= nlevels)
     {
       fprintf(stdout, "z=%d out of range (max=%d)!\n", levelID + 1, nlevels);
@@ -236,9 +237,9 @@ set_levelID(int levelID)
 static int
 check_varID(int varID)
 {
-  if (varID < 0 || varID >= (int) varList.size())
+  if (varID < 0 || varID >= (int) varList.numVars())
     {
-      fprintf(stdout, "varID out of range (max=%d)!\n", (int) varList.size());
+      fprintf(stdout, "varID out of range (max=%d)!\n", (int) varList.numVars());
       return 1;
     }
 
@@ -312,7 +313,7 @@ set_var(const std::vector<std::string> &argv)
   auto lfound = false;
   for (int varID = 0; varID < gl_nvars; ++varID)
     {
-      if (name == varList[varID].name)
+      if (name == varList.vars[varID].name)
         {
           lfound = true;
           set_varID(varID);
@@ -360,10 +361,11 @@ com_vars(const std::string &arg)
 
   for (int varID = 0; varID < gl_nvars; ++varID)
     {
-      cdiParamToString(varList[varID].param, paramstr, sizeof(paramstr));
+      const auto &var = varList.vars[varID];
+      cdiParamToString(var.param, paramstr, sizeof(paramstr));
 
-      fprintf(stdout, "varID=%3d, param=%s, name=%s, longname=\"%s\", units=\"%s\"\n", varID + 1, paramstr,
-              varList[varID].name.c_str(), varList[varID].longname.c_str(), varList[varID].units.c_str());
+      fprintf(stdout, "varID=%3d, param=%s, name=%s, longname=\"%s\", units=\"%s\"\n", varID + 1, paramstr, var.name.c_str(),
+              var.longname.c_str(), var.units.c_str());
     }
 
   return 0;
@@ -477,7 +479,7 @@ command_init()
   gl_data.resize(gridsizemax);
 
   gl_nvars = vlistNvars(gl_vlistID);
-  varList_init(varList, gl_vlistID);
+  varList = VarList(gl_vlistID);
 
   set_varID(0);
 }
@@ -489,12 +491,13 @@ run_demo()
   gl_tsID2 = -1;
   for (int varID = 0; varID < gl_nvars; ++varID)
     {
-      auto nlevels = varList[varID].nlevels;
+      const auto &var = varList.vars[varID];
+      auto nlevels = var.nlevels;
       for (int levelID = 0; levelID < nlevels; ++levelID)
         {
           set_varID(varID);
           set_levelID(levelID);
-          com_stat(varList[varID].name);
+          com_stat(var.name);
         }
     }
 }
@@ -505,7 +508,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Command",
-    .operators = { { "command"}, { "com"}, { "cmd"} },
+    .operators = { { "command" }, { "com" }, { "cmd" } },
     .aliases = {},
     .mode = INTERNAL,    // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -515,7 +518,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     if (cdo_operator_argc() == 1)
@@ -532,8 +535,9 @@ public:
 
     command_init();
   }
+
   void
-  run()
+  run() override
   {
     if (mode_demo) { run_demo(); }
     else
@@ -548,8 +552,9 @@ public:
           }
       }
   }
+
   void
-  close()
+  close() override
   {
     streamClose(gl_streamID);
   }
