@@ -52,14 +52,14 @@ public:
   CdoStreamID streamID4;
   int taxisID4;
 
-  VarList varList1, varList2;
+  VarList varList1;
+  VarList varList2;
   Varray<double> array1, array2, array3, array4;
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_check_argc(0);
 
     streamID1 = cdo_open_read(0);
@@ -80,22 +80,22 @@ public:
     if (ntsteps1 == 0) ntsteps1 = 1;
     if (ntsteps2 == 0) ntsteps2 = 1;
 
-    if (vlistNrecs(vlistID1) == 1 && vlistNrecs(vlistID2) != 1)
+    if (vlistNumRecords(vlistID1) == 1 && vlistNumRecords(vlistID2) != 1)
       {
         filltype = FILL_REC;
         cdo_print("Filling up stream1 >%s< by copying the first record.", cdo_get_stream_name(0));
       }
 
-    if (filltype == FILL_NONE) vlist_compare(vlistID1, vlistID2, CmpVlist::Dim);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
 
-    vlist_compare(vlistID2, vlistID3, CmpVlist::Dim);
+    if (filltype == FILL_NONE) varList_compare(varList1, varList2, CmpVarList::Dim);
+
+    varList_compare(varList2, VarList(vlistID3), CmpVarList::Dim);
 
     streamID4 = cdo_open_write(3);
     cdo_def_vlist(streamID4, vlistID4);
 
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
-
     auto gridsizemax = vlistGridsizeMax(vlistID1);
 
     if (filltype == FILL_REC && gridsizemax != gridInqSize(vlistGrid(vlistID1, 0)))
@@ -122,7 +122,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -162,7 +162,7 @@ public:
 
                 if (filltype == FILL_TS)
                   {
-                    auto gridsize = varList1[varID].gridsize;
+                    auto gridsize = varList1.vars[varID].gridsize;
                     auto offset = gridsize * levelID;
                     array_copy(gridsize, &array1[0], &vardata1[varID][offset]);
                     varnumMissVals1[varID][levelID] = numMissVals1;
@@ -170,20 +170,22 @@ public:
               }
             else if (filltype == FILL_TS)
               {
-                auto gridsize = varList1[varID].gridsize;
+                auto gridsize = varList1.vars[varID].gridsize;
                 auto offset = gridsize * levelID;
                 array_copy(gridsize, &vardata1[varID][offset], &array1[0]);
                 numMissVals1 = varnumMissVals1[varID][levelID];
               }
 
-            auto gridsize = varList2[varID].gridsize;
-            auto missval2 = varList2[varID].missval;
-            if (recID == 0 || filltype != FILL_REC) missval1 = varList1[varID].missval;
+            const auto &var1 = varList1.vars[varID];
+            const auto &var2 = varList2.vars[varID];
+            auto gridsize = var2.gridsize;
+            auto missval2 = var2.missval;
+            if (recID == 0 || filltype != FILL_REC) missval1 = var1.missval;
 
-            if (numMissVals1 > 0) cdo_check_missval(missval1, varList1[varID].name);
+            if (numMissVals1 > 0) cdo_check_missval(missval1, var1.name);
 
             for (size_t i = 0; i < gridsize; ++i)
-              array4[i] = DBL_IS_EQUAL(array1[i], missval1) ? missval2 : !DBL_IS_EQUAL(array1[i], 0.) ? array2[i] : array3[i];
+              array4[i] = fp_is_equal(array1[i], missval1) ? missval2 : !fp_is_equal(array1[i], 0.) ? array2[i] : array3[i];
 
             numMissVals = varray_num_mv(gridsize, array4, missval2);
             cdo_def_record(streamID4, varID, levelID);
@@ -195,7 +197,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID4);
     cdo_stream_close(streamID3);
