@@ -24,7 +24,7 @@ operator_IFTHENC(size_t n, T mv, Varray<T> &v, T cVal)
 {
   constexpr T nullVal{ 0 };
   if (std::isnan(mv))
-    for (size_t i = 0; i < n; ++i) v[i] = (!dbl_is_equal(v[i], mv) && !dbl_is_equal(v[i], nullVal)) ? cVal : mv;
+    for (size_t i = 0; i < n; ++i) v[i] = (fp_is_not_equal(v[i], mv) && fp_is_not_equal(v[i], nullVal)) ? cVal : mv;
   else
     for (size_t i = 0; i < n; ++i) v[i] = (!is_equal(v[i], mv) && !is_equal(v[i], nullVal)) ? cVal : mv;
 }
@@ -35,7 +35,7 @@ operator_IFNOTTHENC(size_t n, T mv, Varray<T> &v, T cVal)
 {
   constexpr T nullVal{ 0 };
   if (std::isnan(mv))
-    for (size_t i = 0; i < n; ++i) v[i] = (!dbl_is_equal(v[i], mv) && dbl_is_equal(v[i], nullVal)) ? cVal : mv;
+    for (size_t i = 0; i < n; ++i) v[i] = (fp_is_not_equal(v[i], mv) && fp_is_equal(v[i], nullVal)) ? cVal : mv;
   else
     for (size_t i = 0; i < n; ++i) v[i] = (!is_equal(v[i], mv) && is_equal(v[i], nullVal)) ? cVal : mv;
 }
@@ -53,6 +53,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Condc> registration = RegisterEntry<Condc>(module);
+
   int IFTHENC, IFNOTTHENC;
   CdoStreamID streamID1;
   int taxisID1;
@@ -63,17 +64,14 @@ public:
   int operatorID;
   double rconst;
 
-  VarList varList;
+  VarList varList1;
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-IFTHENC = module.get_id("ifthenc");
-IFNOTTHENC = module.get_id("ifnotthenc");
-    // clang-format on
+    IFTHENC = module.get_id("ifthenc");
+    IFNOTTHENC = module.get_id("ifnotthenc");
 
     operatorID = cdo_operator_id();
 
@@ -91,14 +89,14 @@ IFNOTTHENC = module.get_id("ifnotthenc");
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    varList_init(varList, vlistID1);
+    varList1 = VarList(vlistID1);
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
   }
 
   void
-  run()
+  run() override
   {
     Field field;
 
@@ -115,14 +113,15 @@ IFNOTTHENC = module.get_id("ifnotthenc");
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field.init(varList[varID]);
+            const auto &var = varList1.vars[varID];
+            field.init(var);
             cdo_read_record(streamID1, field);
 
             auto missval = field.missval;
             auto ngp = field.size;
 
             auto numMissVals = field.numMissVals;
-            if (numMissVals > 0) cdo_check_missval(missval, varList[varID].name);
+            if (numMissVals > 0) cdo_check_missval(missval, var.name);
 
             // clang-format off
             if (field.memType == MemType::Float)
@@ -150,7 +149,7 @@ IFNOTTHENC = module.get_id("ifnotthenc");
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
