@@ -66,14 +66,14 @@ public:
 
   bool dataIsUnchanged;
 
-  int nfiles;
+  int numFiles;
   bool isFdbCopy;
 
   int operatorID;
 
 public:
   void
-  init()
+  init() override
   {
     dataIsUnchanged = data_is_unchanged();
 
@@ -90,18 +90,18 @@ public:
     operator_check_argc(0);
 
     auto streamCnt = cdo_stream_cnt();
-    nfiles = streamCnt - 1;
+    numFiles = streamCnt - 1;
 
-    isFdbCopy = is_fdb_copy(dataIsUnchanged, nfiles);
-
-    progress::init();
+    isFdbCopy = is_fdb_copy(dataIsUnchanged, numFiles);
   }
 
   void
-  run()
+  run() override
   {
+    cdo::Progress progress;
+
     int tsID2 = 0;
-    for (int indf = 0; indf < nfiles; ++indf)
+    for (int indf = 0; indf < numFiles; ++indf)
       {
         if (Options::cdoVerbose) cdo_print("Process file: %s", cdo_get_stream_name(indf));
 
@@ -109,8 +109,7 @@ public:
         auto vlistID1 = cdo_stream_inq_vlist(streamID1);
         auto taxisID1 = vlistInqTaxis(vlistID1);
 
-        VarList varList1;
-        varList_init(varList1, vlistID1);
+        VarList varList1(vlistID1);
 
         if (indf == 0)
           {
@@ -118,46 +117,47 @@ public:
             taxisID2 = taxisDuplicate(taxisID1);
             vlistDefTaxis(vlistID2, taxisID2);
 
-            auto nvars = vlistNvars(vlistID1);
+            auto numVars = varList1.numVars();
+            auto numSteps = varList1.numSteps();
+            if (numSteps == 1 && varList1.numVaryingVars() == 0) numSteps = 0;
 
-            auto ntsteps = vlistNtsteps(vlistID1);
-            if (ntsteps == 1 && varList_numVaryingVars(varList1) == 0) ntsteps = 0;
-
-            if (ntsteps == 0 && nfiles > 1)
+            if (numSteps == 0 && numFiles > 1)
               {
                 hasConstantFields = false;
-                for (int varID = 0; varID < nvars; ++varID) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
+                for (int varID = 0; varID < numVars; ++varID) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
               }
           }
-        else { vlist_compare(vlistID1, vlistID2, CmpVlist::All); }
+        else
+          {
+            VarList varList2(vlistID2);
+            varList_compare(varList1, varList2);
+          }
 
         if (streamID2 == CDO_STREAM_UNDEF)
           {
-            streamID2 = cdo_open_write(nfiles);
+            streamID2 = cdo_open_write(numFiles);
             cdo_def_vlist(streamID2, vlistID2);
           }
 
-        auto ntsteps = vlistNtsteps(vlistID1);
-
+        auto numSteps = varList1.numSteps();
         int tsID1 = 0;
         while (true)
           {
-            auto nrecs = cdo_stream_inq_timestep(streamID1, tsID1);
-            if (nrecs == 0) break;
+            auto numRecords = cdo_stream_inq_timestep(streamID1, tsID1);
+            if (numRecords == 0) break;
 
             cdo_taxis_copy_timestep(taxisID2, taxisID1);
             cdo_def_timestep(streamID2, tsID2);
 
-            for (int recID = 0; recID < nrecs; ++recID)
+            for (int recID = 0; recID < numRecords; ++recID)
               {
-                double fstatus = indf + ((ntsteps >= 0) ? (tsID1 + (recID + 1.0) / nrecs) / ntsteps : 1.0);
-                if (!Options::cdoVerbose) progress::update(0, 1, fstatus / nfiles);
+                double fstatus = indf + ((numSteps >= 0) ? (tsID1 + (recID + 1.0) / numRecords) / numSteps : 1.0);
+                progress.update(fstatus / numFiles);
 
-                int varID, levelID;
-                cdo_inq_record(streamID1, &varID, &levelID);
+                auto [varID, levelID] = cdo_inq_record(streamID1);
 
-                if (hasConstantFields && tsID2 > 0 && tsID1 == 0)
-                  if (varList1[varID].isConstant) continue;
+                const auto &var1 = varList1.vars[varID];
+                if (hasConstantFields && tsID2 > 0 && tsID1 == 0 && var1.isConstant) continue;
 
                 cdo_def_record(streamID2, varID, levelID);
 
@@ -167,7 +167,7 @@ public:
                   }
                 else
                   {
-                    field.init(varList1[varID]);
+                    field.init(var1);
                     cdo_read_record(streamID1, field);
                     cdo_write_record(streamID2, field);
                   }
@@ -182,7 +182,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
 
