@@ -30,7 +30,7 @@ varray_deltat(const size_t len, const Varray<T> &v0, const Varray<T> &v1, Varray
 
   for (size_t i = 0; i < len; ++i)
     {
-      if (DBL_IS_EQUAL(v0[i], mv) || DBL_IS_EQUAL(v1[i], mv))
+      if (fp_is_equal(v0[i], mv) || fp_is_equal(v1[i], mv))
         v2[i] = mv;
       else
         v2[i] = (v1[i] - v0[i]) * factor;
@@ -82,6 +82,8 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Deltat> registration = RegisterEntry<Deltat>(module);
+
+private:
   CdoStreamID streamID1;
   CdoStreamID streamID2;
 
@@ -89,19 +91,15 @@ public:
   int taxisID2;
   int calendar;
   VarList varList1;
-  FieldVector2D vars;
+  FieldVector2D varsData;
 
   Field field1, field2;
   bool ldivdt;
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-    // clang-format on
-
     auto operatorID = cdo_operator_id();
     ldivdt = cdo_operator_f2(operatorID);
 
@@ -118,15 +116,15 @@ public:
 
     calendar = taxisInqCalendar(taxisID1);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    fields_from_vlist(vlistID1, vars, FIELD_VEC | FIELD_NAT);
+    field2D_init(varsData, vlistID1, FIELD_VEC | FIELD_NAT);
   }
   void
-  run()
+  run() override
   {
     int tsID = 0;
     auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
@@ -137,7 +135,7 @@ public:
       {
         int varID, levelID;
         cdo_inq_record(streamID1, &varID, &levelID);
-        cdo_read_record(streamID1, vars[varID][levelID]);
+        cdo_read_record(streamID1, varsData[varID][levelID]);
       }
 
     tsID++;
@@ -158,12 +156,13 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field1.init(varList1[varID]);
+            const auto &var1 = varList1.vars[varID];
+            field1.init(var1);
             cdo_read_record(streamID1, field1);
 
-            auto &field0 = vars[varID][levelID];
+            auto &field0 = varsData[varID][levelID];
 
-            field2.init(varList1[varID]);
+            field2.init(var1);
             field_deltat(field0, field1, field2, idtInSec);
 
             field_copy(field1, field0);
@@ -178,7 +177,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
