@@ -19,13 +19,14 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Deltime",
-    .operators = { { "delday"}, { "del29feb"} },
+    .operators = { { "delday" }, { "del29feb" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Deltime> registration = RegisterEntry<Deltime>(module);
+
   int DELDAY, DEL29FEB;
   int dday, dmon;
 
@@ -39,21 +40,16 @@ public:
   int nfound = 0;
   bool dataIsUnchanged;
 
-  Field field;
-
   VarList varList1;
 
 public:
   void
-  init()
+  init() override
   {
-
     dataIsUnchanged = data_is_unchanged();
 
-    // clang-format off
-DELDAY = module.get_id("delday");
-DEL29FEB = module.get_id("del29feb");
-    // clang-format on
+    DELDAY = module.get_id("delday");
+    DEL29FEB = module.get_id("del29feb");
 
     (void) (DELDAY);  // unused
 
@@ -103,11 +99,14 @@ DEL29FEB = module.get_id("del29feb");
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
+
   void
-  run()
+  run() override
   {
+    Field field;
+
     int tsID = 0;
     int tsID2 = 0;
     while (true)
@@ -141,7 +140,7 @@ DEL29FEB = module.get_id("del29feb");
                 if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
                 else
                   {
-                    field.init(varList1[varID]);
+                    field.init(varList1.vars[varID]);
                     cdo_read_record(streamID1, field);
                     cdo_write_record(streamID2, field);
                   }
@@ -151,8 +150,9 @@ DEL29FEB = module.get_id("del29feb");
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
