@@ -58,8 +58,8 @@ diff_kernel_mv(double v1, double v2, double missval1, double missval2, DiffResul
 {
   auto v1IsNan = std::isnan(v1);
   auto v2IsNan = std::isnan(v2);
-  auto v1IsMissval = dbl_is_equal(v1, missval1);
-  auto v2IsMissval = dbl_is_equal(v2, missval2);
+  auto v1IsMissval = fp_is_equal(v1, missval1);
+  auto v2IsMissval = fp_is_equal(v2, missval2);
   if (v1IsNan != v2IsNan)
     {
       result.ndiff++;
@@ -80,57 +80,31 @@ diff(size_t n, const Field &field1, const Field &field2)
   auto hasMissvals = (field1.numMissVals || field2.numMissVals);
   if (hasMissvals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        {
-          for (size_t i = 0; i < n; ++i)
-            diff_kernel_mv(field1.vec_f[i], field2.vec_f[i], field1.missval, field2.missval, diffParam);
-        }
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        {
-          for (size_t i = 0; i < n; ++i)
-            diff_kernel_mv(field1.vec_f[i], field2.vec_d[i], field1.missval, field2.missval, diffParam);
-        }
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        {
-          for (size_t i = 0; i < n; ++i)
-            diff_kernel_mv(field1.vec_d[i], field2.vec_f[i], field1.missval, field2.missval, diffParam);
-        }
-      else
-        {
-          for (size_t i = 0; i < n; ++i)
-            diff_kernel_mv(field1.vec_d[i], field2.vec_d[i], field1.missval, field2.missval, diffParam);
-        }
+      auto func = [&](auto &v1, auto &v2, double mv1, double mv2) {
+        for (size_t i = 0; i < n; ++i) { diff_kernel_mv(v1[i], v2[i], mv1, mv2, diffParam); }
+      };
+      field_operation2(func, field1, field2, field1.missval, field2.missval);
     }
   else
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        {
-          for (size_t i = 0; i < n; ++i) { diff_kernel(field1.vec_f[i], field2.vec_f[i], diffParam); }
-        }
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        {
-          for (size_t i = 0; i < n; ++i) { diff_kernel(field1.vec_f[i], field2.vec_d[i], diffParam); }
-        }
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        {
-          for (size_t i = 0; i < n; ++i) { diff_kernel(field1.vec_d[i], field2.vec_f[i], diffParam); }
-        }
-      else
-        {
-          for (size_t i = 0; i < n; ++i) { diff_kernel(field1.vec_d[i], field2.vec_d[i], diffParam); }
-        }
+      auto func = [&](auto &v1, auto &v2) {
+        for (size_t i = 0; i < n; ++i) { diff_kernel(v1[i], v2[i], diffParam); }
+      };
+      field_operation2(func, field1, field2);
     }
 
   return diffParam;
 }
 
 static void
-use_real_part(size_t gridsize, Field &field)
+use_real_part(Field &field)
 {
-  if (field.memType == MemType::Float)
-    for (size_t i = 0; i < gridsize; ++i) field.vec_f[i] = field.vec_f[i * 2];
-  else
-    for (size_t i = 0; i < gridsize; ++i) field.vec_d[i] = field.vec_d[i * 2];
+  auto func = [](auto &v) {
+    auto n = v.size() / 2;
+    for (size_t i = 0; i < n; ++i) v[i] = v[i * 2];
+  };
+
+  return field_operation(func, field);
 }
 
 struct DiffParam
@@ -385,11 +359,11 @@ public:
 
             field1.init(var1);
             cdo_read_record(streamID1, field1);
-            if (var1.nwpv == CDI_COMP) use_real_part(var1.gridsize, field1);
+            if (var1.nwpv == CDI_COMP) use_real_part(field1);
 
             field2.init(var2);
             cdo_read_record(streamID2, field2);
-            if (var2.nwpv == CDI_COMP) use_real_part(var1.gridsize, field2);
+            if (var2.nwpv == CDI_COMP) use_real_part(field2);
 
             if (runAsync && numSets > 0)
               {
