@@ -365,7 +365,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     operator_input_arg("nxblocks, [nyblocks]");
     if (cdo_operator_argc() < 1) cdo_abort("Too few arguments!");
@@ -380,7 +380,7 @@ public:
     streamID1 = cdo_open_read(0);
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-    ngrids = vlistNgrids(vlistID1);
+    ngrids = vlistNumGrids(vlistID1);
 
     gridInfo1 = std::vector<GridInfo1>(ngrids);
     for (int index = 0; index < ngrids; ++index)
@@ -443,7 +443,7 @@ public:
 
     cdo::set_numfiles(nsplit + 8);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     vlistIDs = std::vector<int>(nsplit);
     streamIDs = std::vector<CdoStreamID>(nsplit);
@@ -500,7 +500,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -514,7 +514,7 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field1.init(varList1[varID]);
+            field1.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field1);
 
 #ifdef _OPENMP
@@ -522,7 +522,7 @@ public:
 #endif
             for (size_t index = 0; index < nsplit; ++index)
               {
-                auto var = varList1[varID];
+                auto var = varList1.vars[varID];
                 var.gridID = distgridInfo[0][index].gridID;
                 var.gridsize = distgridInfo[0][index].gridsize;
                 field2.init(var);
@@ -544,7 +544,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
 
