@@ -9,7 +9,6 @@
 
 #include "cdo_options.h"
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "param_conversion.h"
 #include "field_functions.h"
 
@@ -26,7 +25,8 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Duplicate> registration = RegisterEntry<Duplicate>(module);
-  FieldVector3D vars;
+
+  FieldVector3D varsData;
   std::vector<CdiDateTime> vDateTimes;
 
   CdoStreamID streamID1;
@@ -39,11 +39,11 @@ public:
   int nvars;
   int ndup;
 
-  VarList varList;
+  VarList varList1;
 
 public:
   void
-  init()
+  init() override
   {
 
     if (cdo_operator_argc() > 1) cdo_abort("Too many arguments!");
@@ -60,12 +60,12 @@ public:
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    varList_init(varList, vlistID1);
+    varList1 = VarList(vlistID1);
 
     nvars = vlistNvars(vlistID1);
     auto ntsteps = vlistNtsteps(vlistID1);
 
-    if (ntsteps == 1 && varList_numVaryingVars(varList) == 0) ntsteps = 0;
+    if (ntsteps == 1 && varList1.numVaryingVars() == 0) ntsteps = 0;
 
     if (ntsteps == 0)
       {
@@ -81,7 +81,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -91,18 +91,18 @@ public:
 
         constexpr size_t NALLOC_INC = 1024;
         if ((size_t) tsID >= vDateTimes.size()) vDateTimes.resize(vDateTimes.size() + NALLOC_INC);
-        if ((size_t) tsID >= vars.size()) vars.resize(vars.size() + NALLOC_INC);
+        if ((size_t) tsID >= varsData.size()) varsData.resize(varsData.size() + NALLOC_INC);
 
         vDateTimes[tsID] = taxisInqVdatetime(taxisID1);
 
-        fields_from_vlist(vlistID1, vars[tsID]);
+        field2D_init(varsData[tsID], varList1);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            auto &field = vars[tsID][varID][levelID];
-            field.init(varList[varID]);
+            auto &field = varsData[tsID][varID][levelID];
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
           }
 
@@ -121,10 +121,11 @@ public:
 
             for (int varID = 0; varID < nvars; ++varID)
               {
-                fieldOut.init(varList[varID]);
-                for (int levelID = 0; levelID < varList[varID].nlevels; ++levelID)
+                const auto &var1 = varList1.vars[varID];
+                fieldOut.init(var1);
+                for (int levelID = 0; levelID < var1.nlevels; ++levelID)
                   {
-                    const auto &field = vars[tsID][varID][levelID];
+                    const auto &field = varsData[tsID][varID][levelID];
                     if (field.hasData())
                       {
                         field_copy(field, fieldOut);
@@ -138,7 +139,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
