@@ -353,18 +353,18 @@ protected:
   }
   std::function<void(Request p_request)> eca_func;
   Request request;
-  virtual void init() = 0;
+  // virtual void init() = 0;
 
 public:
   void
-  run()
+  run() override
   {
     assert(request.compare_type != -1);
     eca_func(request);
   }
 
   void
-  close()
+  close() override
   {
   }
 };
@@ -419,6 +419,8 @@ public:
   };
   inline static RegisterEntry<EcaCfd> registration = RegisterEntry<EcaCfd>(module);
   int ndays = 5;
+  char cfd_name2[1024];
+  char cfd_longname2[1024];
 
 public:
   void
@@ -438,10 +440,8 @@ public:
         if (cdo_operator_argc() > 0) ndays = parameter_to_int(cdo_operator_argv(0));
       }
 
-    char cfd_longname2[1024];
-    char cfd_name2[1024];
-    std::snprintf(cfd_longname2, sizeof(cfd_longname2), CFD_LONGNAME2, ndays);
     std::snprintf(cfd_name2, sizeof(cfd_name2), CFD_NAME2, ndays);
+    std::snprintf(cfd_longname2, sizeof(cfd_longname2), CFD_LONGNAME2, ndays);
 
     request.var1.name = CFD_NAME;
     request.var1.longname = CFD_LONGNAME;
@@ -474,10 +474,12 @@ public:
   inline static RegisterEntry<EcaCsu> registration = RegisterEntry<EcaCsu>(module);
   double argT = 25.0;
   int ndays = 5;
+  char csu_name2[1024];
+  char csu_longname2[1024];
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -494,10 +496,8 @@ public:
         if (cdo_operator_argc() == 2) ndays = parameter_to_int(cdo_operator_argv(1));
       }
 
-    char csu_longname2[1024];
-    char csu_name2[1024];
-    std::snprintf(csu_longname2, sizeof(csu_longname2), CSU_LONGNAME2, ndays);
     std::snprintf(csu_name2, sizeof(csu_name2), CSU_NAME2, ndays);
+    std::snprintf(csu_longname2, sizeof(csu_longname2), CSU_LONGNAME2, ndays);
 
     request.var1.name = CSU_NAME;
     request.var1.longname = CSU_LONGNAME;
@@ -534,7 +534,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -594,7 +594,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     ECA_CWFI = module.get_id("eca_cwfi");
     ETCCDI_CSDI = module.get_id("etccdi_csdi");
@@ -657,7 +657,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -688,7 +688,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     ECA_FD = module.get_id("eca_fd");
     ETCCDI_FD = module.get_id("etccdi_fd");
@@ -750,7 +750,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -794,7 +794,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -837,7 +837,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -895,7 +895,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     ECA_HWFI = module.get_id("eca_hwfi");
     ETCCDI_WSDI = module.get_id("etccdi_wsdi");
@@ -959,7 +959,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     ECA_ID = module.get_id("eca_id");
@@ -1011,7 +1011,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     ECA_SU = module.get_id("eca_su");
@@ -1062,7 +1062,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1093,7 +1093,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1124,7 +1124,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1155,7 +1155,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1189,7 +1189,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -1241,7 +1241,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1272,7 +1272,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -1320,7 +1320,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     ECA_CDD = module.get_id("eca_cdd");
@@ -1396,7 +1396,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     ECA_CWD = module.get_id("eca_cwd");
     ETCCDI_CWD = module.get_id("etccdi_cwd");
@@ -1472,7 +1472,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     ECA_PD = module.get_id("eca_pd");
     ETCCDI_R1MM = module.get_id("etccdi_r1mm");
@@ -1588,7 +1588,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1620,7 +1620,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1652,7 +1652,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1684,7 +1684,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1716,7 +1716,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1736,7 +1736,7 @@ public:
 //{
 // public:
 //   void
-//   init()
+//   init() override
 //   {
 // //
 //     cdo_operator_add("eca_r95p", 0, CMP_DATE, nullptr);
@@ -1779,7 +1779,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1811,7 +1811,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1843,7 +1843,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     set_default_compare_type(request.compare_type);
@@ -1875,7 +1875,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     double threshold = 1;
 
@@ -1924,7 +1924,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     ECA_RX1DAY = module.get_id("eca_rx1day");
@@ -1975,7 +1975,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     double argX = 50.0;
 
@@ -2035,7 +2035,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     ECA_SDII = module.get_id("eca_sdii");
     ETCCDI_SDII = module.get_id("etccdi_sdii");
@@ -2092,7 +2092,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -2127,7 +2127,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -2180,7 +2180,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -2224,7 +2224,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
@@ -2268,7 +2268,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     set_default_compare_type(request.compare_type);
 
