@@ -622,19 +622,19 @@ public:
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto taxisID = vlistInqTaxis(vlistID1);
 
-    VarList varList1;
-    varList_init(varList1, vlistID1);
-    auto nvars = vlistNvars(vlistID1);
+    VarList varList1(vlistID1);
+    auto numVars = varList1.numVars();
 
-    std::vector<VAR> vars(nvars);
+    std::vector<VAR> vars(numVars);
 
     int ntr = 0;
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        auto code = varList1[varID].code;
-        auto &name = varList1[varID].name;
-        auto &longname = varList1[varID].longname;
-        auto &units = varList1[varID].units;
+        const auto &var1 = varList1.vars[varID];
+        auto code = var1.code;
+        auto name = var1.name;
+        auto longname = var1.longname;
+        auto units = var1.units;
 
         if (code < 0) code = 0;
         if (name.substr(0, 3) == "var")
@@ -675,27 +675,18 @@ public:
         else if (name.substr(0, 3) == "LSP")
           code = 152;
 
-        auto gridID = varList1[varID].gridID;
-        auto zaxisID = varList1[varID].zaxisID;
+        if (var1.zaxisType == GRID_SPECTRAL && ntr == 0) ntr = gridInqTrunc(var1.gridID);
 
-        auto gridtype = gridInqType(gridID);
-        auto zaxistype = zaxisInqType(zaxisID);
+        auto zaxisType = var1.zaxisType;
+        if (zaxisType == ZAXIS_HYBRID && var1.nlevels == 1) zaxisType = ZAXIS_SURFACE;
 
-        if (gridtype == GRID_SPECTRAL && ntr == 0) ntr = gridInqTrunc(gridID);
+        inivar(vars[varID], var1.gridType, zaxisType, code, name, longname, units);
 
-        auto gridsize = gridInqSize(gridID);
-        auto nlev = zaxisInqSize(zaxisID);
-
-        if (zaxistype == ZAXIS_HYBRID && nlev == 1) zaxistype = ZAXIS_SURFACE;
-
-        inivar(vars[varID], gridtype, zaxistype, code, name, longname, units);
-
-        vars[varID].gridID = gridID;
-        vars[varID].zaxisID = zaxisID;
-        vars[varID].gridsize = gridsize;
-        vars[varID].nlev = nlev;
-
-        vars[varID].ptr = new double[nlev * gridsize];
+        vars[varID].gridID = var1.gridID;
+        vars[varID].zaxisID = var1.zaxisID;
+        vars[varID].gridsize = var1.gridsize;
+        vars[varID].nlev = var1.nlevels;
+        vars[varID].ptr = new double[var1.nlevels * var1.gridsize];
       }
 
     auto nrecs = cdo_stream_inq_timestep(streamID1, 0);
@@ -714,14 +705,14 @@ public:
         int varID, levelID;
         cdo_inq_record(streamID1, &varID, &levelID);
 
-        auto gridsize = gridInqSize(vlistInqVarGrid(vlistID1, varID));
+        auto gridsize = vars[varID].gridsize;
         size_t numMissVals;
         cdo_read_record(streamID1, vars[varID].ptr + levelID * gridsize, &numMissVals);
       }
 
     cdo_stream_close(streamID1);
 
-    export_e5ml(cdo_get_stream_name(1), vars, nvars, vdate, vtime, ntr);
+    export_e5ml(cdo_get_stream_name(1), vars, numVars, vdate, vtime, ntr);
   }
 
   void
@@ -731,13 +722,13 @@ public:
     iniatts(&atts);
 
     std::vector<VAR> vars;
-    auto nvars = import_e5ml(cdo_get_stream_name(0), vars);
-    if (nvars == 0) cdo_abort("Unsupported file type!");
+    auto numVars = import_e5ml(cdo_get_stream_name(0), vars);
+    if (numVars == 0) cdo_abort("Unsupported file type!");
 
     auto vlistID2 = vlistCreate();
     vlistDefNtsteps(vlistID2, 0);
 
-    for (int iv = 0; iv < nvars; iv++)
+    for (int iv = 0; iv < numVars; iv++)
       {
         int varID = vlistDefVar(vlistID2, vars[iv].gridID, vars[iv].zaxisID, TIME_CONSTANT);
         if (vars[iv].code > 0) vlistDefVarCode(vlistID2, varID, vars[iv].code);
@@ -765,7 +756,7 @@ public:
     int tsID = 0;
     cdo_def_timestep(streamID2, tsID);
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
         auto gridsize = vars[varID].gridsize;
         auto nlev = vars[varID].nlev;
@@ -783,11 +774,11 @@ public:
   }
 
   void
-  init()
+  init() override
   {
   }
   void
-  close()
+  close() override
   {
     // vlistDestroy(vlistID2);
   }
@@ -799,7 +790,7 @@ public:
   using Echam5ini::Echam5ini;
   inline static CdoModule module = {
     .name = "Echam5ini",
-    .operators = { { "import_e5ml"} },
+    .operators = { { "import_e5ml" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -809,7 +800,7 @@ public:
 
 public:
   void
-  run()
+  run() override
   {
     im_e5ml();
   }
@@ -820,7 +811,7 @@ public:
   using Echam5ini::Echam5ini;
   inline static CdoModule module = {
     .name = "Echam5ini",
-    .operators = { { "import_e5ml"}, { "export_e5ml"} },
+    .operators = { { "import_e5ml" }, { "export_e5ml" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -830,7 +821,7 @@ public:
 
 public:
   void
-  run()
+  run() override
   {
     ex_e5ml();
   }
