@@ -30,6 +30,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Enlarge> registration = RegisterEntry<Enlarge>(module);
+
   bool linfo = true;
 
   CdoStreamID streamID1;
@@ -48,11 +49,12 @@ public:
   Varray<double> array1;
   Varray<double> array2;
 
+  VarList varList1;
+
 public:
   void
-  init()
+  init() override
   {
-
     operator_check_argc(1);
 
     auto gridID2 = cdo_define_grid(cdo_operator_argv(0));
@@ -66,6 +68,8 @@ public:
     vlistID1 = cdo_stream_inq_vlist(streamID1);
     vlistID2 = vlistDuplicate(vlistID1);
 
+    varList1 = VarList(vlistID1);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
@@ -73,8 +77,8 @@ public:
     gridsize2 = gridInqSize(gridID2);
     if (gridsize2 < vlistGridsizeMax(vlistID1)) cdo_abort("Gridsize of input stream is greater than new gridsize!");
 
-    auto ngrids = vlistNgrids(vlistID1);
-    for (int index = 0; index < ngrids; ++index) vlistChangeGridIndex(vlistID2, index, gridID2);
+    auto numGrids = vlistNumGrids(vlistID1);
+    for (int index = 0; index < numGrids; ++index) vlistChangeGridIndex(vlistID2, index, gridID2);
 
     streamID2 = cdo_open_write(1);
 
@@ -85,7 +89,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -103,9 +107,9 @@ public:
             size_t numMissVals;
             cdo_read_record(streamID1, array1.data(), &numMissVals);
 
-            auto missval = vlistInqVarMissval(vlistID1, varID);
-            auto gridID1 = vlistInqVarGrid(vlistID1, varID);
-            auto gridsize1 = gridInqSize(gridID1);
+            const auto &var = varList1.vars[varID];
+            auto gridID1 = var.gridID;
+            auto gridsize1 = var.gridsize;
 
             auto xsize1 = gridInqXsize(gridID1);
             auto ysize1 = gridInqYsize(gridID1);
@@ -143,7 +147,7 @@ public:
                 varray_copy(gridsize1, array1, array2);
                 for (size_t i = gridsize1; i < gridsize2; ++i) array2[i] = array1[gridsize1 - 1];
 
-                if (numMissVals && DBL_IS_EQUAL(array1[gridsize1 - 1], missval)) numMissVals += (gridsize2 - gridsize1);
+                if (numMissVals && fp_is_equal(array1[gridsize1 - 1], var.missval)) numMissVals += (gridsize2 - gridsize1);
               }
 
             cdo_def_record(streamID2, varID, levelID);
@@ -155,7 +159,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
 
     cdo_stream_close(streamID2);
