@@ -32,7 +32,7 @@
 #include "cdo_task.h"
 #include "cdo_options.h"
 #include "util_files.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "field_functions.h"
 
 struct EnsstatFile
@@ -76,7 +76,7 @@ ensstat(const std::vector<EnsstatFile> &ef, FieldVector &fieldVector, CdoStreamI
       if (hasMissvals)
         for (int fileID = 0; fileID < numFiles; ++fileID)
           {
-            if (dbl_is_equal(work.vec_d[fileID], ef[fileID].varList.vars[varID].missval))
+            if (fp_is_equal(work.vec_d[fileID], ef[fileID].varList.vars[varID].missval))
               {
                 work.vec_d[fileID] = missval;
                 work.numMissVals++;
@@ -86,7 +86,7 @@ ensstat(const std::vector<EnsstatFile> &ef, FieldVector &fieldVector, CdoStreamI
       auto lpctl = (operfunc == FieldFunc_Pctl);
       array2[i] = lpctl ? field_pctl(work, pn) : field_function(work, operfunc);
 
-      if (dbl_is_equal(array2[i], work.missval)) atomicNumMiss++;
+      if (fp_is_equal(array2[i], work.missval)) atomicNumMiss++;
 
       if (withCountData) count2[i] = numFiles - work.numMissVals;
     }
