@@ -18,7 +18,7 @@
 #include "param_conversion.h"
 #include "cdo_options.h"
 #include "util_files.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "field_functions.h"
 
 // Defines for rank histogram
@@ -338,7 +338,7 @@ public:
                 for (int fileID = 0; fileID < nfiles; ++fileID)
                   {
                     field[ompthID].vec_d[fileID] = ef[fileID].array[i];
-                    if (DBL_IS_EQUAL(field[ompthID].vec_d[fileID], missval))
+                    if (fp_is_equal(field[ompthID].vec_d[fileID], missval))
                       {
                         have_miss = 1;
                         break;
