@@ -305,7 +305,7 @@ public:
                     else
                       val[fileID - 1] = value;  // Ensembles start at 2nd file
 
-                    if (dbl_is_equal(value, missval))
+                    if (fp_is_equal(value, missval))
                       {
                         have_miss = 1;
                         break;
@@ -398,7 +398,7 @@ public:
                   {
                     p = (double) k / (double) nens;
 
-                    if (dbl_is_not_equal(sum_weights, 1.0))
+                    if (fp_is_not_equal(sum_weights, 1.0))
                       {
                         alpha[k] /= sum_weights;
                         beta[k] /= sum_weights;
