@@ -202,13 +202,13 @@ public:
                 out.missval = missval2;
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (!DBL_IS_EQUAL(in.vec_d[i], missval2) && !DBL_IS_EQUAL(eof[varID][levelID][eofID].vec_d[i], missval1))
+                    if (!fp_is_equal(in.vec_d[i], missval2) && !fp_is_equal(eof[varID][levelID][eofID].vec_d[i], missval1))
                       {
                         // out.vec_d[0] += w[i]*in.vec_d[i]*eof[varID][levelID][eofID].vec_d[i];
                         out.vec_d[0] += in.vec_d[i] * eof[varID][levelID][eofID].vec_d[i];
                       }
                   }
-                if (!DBL_IS_EQUAL(out.vec_d[0], 0.))
+                if (!fp_is_equal(out.vec_d[0], 0.))
                   numMissVals = 0;
                 else
                   {
