@@ -46,14 +46,17 @@ public:
   int vlistID1;
   int vlistID2;
 
+  VarList varList1;
+  VarList varList2;
+
   int gridID1;
 
   int taxisID2;
 
   size_t gridsize;
-  int nvars;
+  int numVars;
   int neof;
-  int nlevs;
+  int numLevels;
   int taxisID3;
 
   std::string fileSuffix;
@@ -65,7 +68,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     streamID1 = cdo_open_read(0);
     streamID2 = cdo_open_read(1);
@@ -73,31 +76,34 @@ public:
     vlistID1 = cdo_stream_inq_vlist(streamID1);
     vlistID2 = cdo_stream_inq_vlist(streamID2);
 
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
+
     // taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = vlistInqTaxis(vlistID2);
     taxisID3 = taxisDuplicate(taxisID2);
 
-    gridID1 = vlistInqVarGrid(vlistID1, 0);
-    int gridID2 = vlistInqVarGrid(vlistID2, 0);
+    gridID1 = varList1.vars[0].gridID;
+    int gridID2 = varList2.vars[0].gridID;
 
     gridsize = vlistGridsizeMax(vlistID1);
     if (gridsize != vlistGridsizeMax(vlistID2)) cdo_abort("Gridsize of input files does not match!");
 
-    if (vlistNgrids(vlistID2) > 1 || vlistNgrids(vlistID1) > 1) cdo_abort("Too many different grids in input");
+    if (vlistNumGrids(vlistID2) > 1 || vlistNumGrids(vlistID1) > 1) cdo_abort("Too many different grids in input");
 
-    nvars = (vlistNvars(vlistID1) == vlistNvars(vlistID2)) ? vlistNvars(vlistID1) : -1;
-    nlevs = zaxisInqSize(vlistInqVarZaxis(vlistID1, 0));
+    numVars = (varList1.numVars() == varList2.numVars()) ? varList1.numVars() : -1;
+    numLevels = varList1.vars[0].nlevels;
 
     if (gridID1 != gridID2) cdo_compare_grids(gridID1, gridID2);
 
     fileSuffix = FileUtils::gen_suffix(cdo_inq_filetype(streamID1), vlistID1, cdo_get_stream_name(0));
 
-    eof = FieldVector3D(nvars);
-    for (varID = 0; varID < nvars; ++varID) eof[varID].resize(nlevs);
+    eof = FieldVector3D(numVars);
+    for (varID = 0; varID < numVars; ++varID) eof[varID].resize(numLevels);
   }
 
   void
-  run()
+  run() override
   {
     while (1)
       {
@@ -107,15 +113,15 @@ public:
         for (int recID = 0; recID < nrecs; ++recID)
           {
             cdo_inq_record(streamID1, &varID, &levelID);
-            missval1 = vlistInqVarMissval(vlistID1, varID);
+            missval1 = varList1.vars[varID].missval;
             eof[varID][levelID].resize((eofID == 0) ? 1 : eofID + 1);
             eof[varID][levelID][eofID].grid = gridID1;
             eof[varID][levelID][eofID].missval = missval1;
             eof[varID][levelID][eofID].resize(gridsize);
             ranges::fill(eof[varID][levelID][eofID].vec_d, missval1);
 
-            if (varID >= nvars) cdo_abort("Internal error - varID >= nvars");
-            if (levelID >= nlevs) cdo_abort("Internal error - levelID >= nlevs");
+            if (varID >= numVars) cdo_abort("Internal error - varID >= nvars");
+            if (levelID >= numLevels) cdo_abort("Internal error - levelID >= nlevs");
 
             cdo_read_record(streamID1, eof[varID][levelID][eofID].vec_d.data(), &numMissVals);
             eof[varID][levelID][eofID].numMissVals = numMissVals;
@@ -145,14 +151,14 @@ public:
 
     auto vlistID3 = vlistDuplicate(vlistID2);
 
-    auto ngrids = vlistNgrids(vlistID3);
+    auto ngrids = vlistNumGrids(vlistID3);
     for (int i = 0; i < ngrids; ++i) vlistChangeGridIndex(vlistID3, i, gridID3);
 
-    auto nzaxis = vlistNzaxis(vlistID3);
+    auto nzaxis = vlistNumZaxis(vlistID3);
     for (int i = 0; i < nzaxis; ++i) vlistChangeZaxisIndex(vlistID3, i, zaxisID3);
 
     vlistDefTaxis(vlistID3, taxisID3);
-    for (varID = 0; varID < nvars; ++varID) vlistDefVarTimetype(vlistID3, varID, TIME_VARYING);
+    for (varID = 0; varID < numVars; ++varID) vlistDefVarTimetype(vlistID3, varID, TIME_VARYING);
 
     // open streams for eofcoeff output
 
@@ -174,8 +180,8 @@ public:
     Field in;
     in.resize(gridsize);
     in.grid = gridID1;
-    FieldVector2D out(nvars);
-    for (varID = 0; varID < nvars; ++varID)
+    FieldVector2D out(numVars);
+    for (varID = 0; varID < numVars; ++varID)
       {
         out[varID].resize(neof);
         for (eofID = 0; eofID < neof; eofID++)
@@ -192,7 +198,7 @@ public:
         nrecs = cdo_stream_inq_timestep(streamID2, tsID);
         if (nrecs == 0) break;
 
-        for (varID = 0; varID < nvars; ++varID)
+        for (varID = 0; varID < numVars; ++varID)
           for (eofID = 0; eofID < neof; eofID++)
             {
               out[varID][eofID].vec_d[0] = 0;
@@ -206,7 +212,7 @@ public:
           {
             cdo_inq_record(streamID2, &varID, &levelID);
             cdo_read_record(streamID2, in.vec_d.data(), &in.numMissVals);
-            missval2 = vlistInqVarMissval(vlistID2, varID);
+            missval2 = varList2.vars[varID].missval;
 
             for (eofID = 0; eofID < neof; eofID++)
               {
@@ -215,7 +221,7 @@ public:
                 numMissVals = 0;
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (!DBL_IS_EQUAL(in.vec_d[i], missval2) && !DBL_IS_EQUAL(eof[varID][levelID][eofID].vec_d[i], missval1))
+                    if (!fp_is_equal(in.vec_d[i], missval2) && !fp_is_equal(eof[varID][levelID][eofID].vec_d[i], missval1))
                       {
                         // out[varID][eofID].vec_d[0] += w[i]*in.vec_d[i]*eof[varID][levelID][eofID].vec_d[i];
                         out[varID][eofID].vec_d[0] += in.vec_d[i] * eof[varID][levelID][eofID].vec_d[i];
@@ -231,13 +237,13 @@ public:
                 */
               }
 
-            if (varID >= nvars) cdo_abort("Internal error - varID >= nvars");
-            if (levelID >= nlevs) cdo_abort("Internal error - levelID >= nlevs");
+            if (varID >= numVars) cdo_abort("Internal error - varID >= nvars");
+            if (levelID >= numLevels) cdo_abort("Internal error - levelID >= nlevs");
           }
 
         for (eofID = 0; eofID < neof; eofID++)
           {
-            for (varID = 0; varID < nvars; ++varID)
+            for (varID = 0; varID < numVars; ++varID)
               {
                 cdo_def_record(streamIDs[eofID], varID, 0);
                 cdo_write_record(streamIDs[eofID], out[varID][eofID].vec_d.data(), out[varID][eofID].numMissVals);
@@ -249,7 +255,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     for (eofID = 0; eofID < neof; eofID++) cdo_stream_close(streamIDs[eofID]);
 
