@@ -127,15 +127,15 @@ public:
                  ntsteps, lyear, fyear);
         double covered_years = lyear - fyear + 1.0;
         double freq = ntsteps / covered_years;
-        if (DBL_IS_EQUAL(freq, 1.))
+        if (fp_is_equal(freq, 1.))
           frequency = "yr";
-        else if (DBL_IS_EQUAL(freq, 12.))
+        else if (fp_is_equal(freq, 12.))
           frequency = "mon";
-        else if (IS_EQUAL(freq, 365.) || IS_EQUAL(freq, 365.25) || IS_EQUAL(freq, 366.))
+        else if (is_equal(freq, 365.) || is_equal(freq, 365.25) || is_equal(freq, 366.))
           frequency = "day";
-        else if (IS_EQUAL(freq, 365. * 4) || IS_EQUAL(freq, 365.25 * 4) || IS_EQUAL(freq, 366. * 4))
+        else if (is_equal(freq, 365. * 4) || is_equal(freq, 365.25 * 4) || is_equal(freq, 366. * 4))
           frequency = "6hr";
-        else if (IS_EQUAL(freq, 365. * 8) || IS_EQUAL(freq, 365.25 * 8) || IS_EQUAL(freq, 366. * 8))
+        else if (is_equal(freq, 365. * 8) || is_equal(freq, 365.25 * 8) || is_equal(freq, 366. * 8))
           frequency = "3hr";
         else
           {
