@@ -30,13 +30,13 @@
 #include <mpim_grid.h>
 #include "specspace.h"
 #include "griddes.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 
 static int
 vlistGetFirstReg2DGrid(int vlistID)
 {
   // find first gaussian grid
-  auto ngrids = vlistNgrids(vlistID);
+  auto ngrids = vlistNumGrids(vlistID);
   for (int index = 0; index < ngrids; ++index)
     {
       auto gridID = vlistGrid(vlistID, index);
@@ -53,18 +53,15 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "FC",
-    .operators = { { "fc2sp"},
-                   { "sp2fc"},
-                   { "fc2gp"},
-                   { "gp2fc"},
-                   { "fourier2grid", 1, 0, nullptr},
-                   { "grid2fourier", 1, 0, nullptr} },
+    .operators
+    = { { "fc2sp" }, { "sp2fc" }, { "fc2gp" }, { "gp2fc" }, { "fourier2grid", 1, 0, nullptr }, { "grid2fourier", 1, 0, nullptr } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_BOTH,  // Allowed number type
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<FC> registration = RegisterEntry<FC>(module);
+
   int FC2SP, SP2FC, FC2GP, GP2FC, GRID2FOURIER, FOURIER2GRID;
   int gridID1 = -1, gridID2 = -1;
   size_t nlon = 0, nlat = 0;
@@ -76,6 +73,7 @@ public:
   CdoStreamID streamID2;
 
   int vlistID1;
+  VarList varList1;
 
   int taxisID1;
   int taxisID2;
@@ -92,7 +90,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     operator_check_argc(0);
@@ -114,6 +112,8 @@ public:
     vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
+    varList1 = VarList(vlistID1);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
@@ -276,19 +276,19 @@ public:
 
     // printf("nfc %d, ntr %d, nlat %zu, nlon %zu\n", nfc, ntr, nlat, nlon);
 
-    auto nvars = vlistNvars(vlistID2);
-    vars = std::vector<bool>(nvars);
-    for (int varID = 0; varID < nvars; ++varID) vars[varID] = gridID1 == vlistInqVarGrid(vlistID1, varID);
+    auto numVars = varList1.numVars();
+    vars = std::vector<bool>(numVars);
+    for (const auto &var : varList1.vars) vars[var.ID] = (gridID1 == var.gridID);
 
     if (gridID1 != -1) vlistChangeGrid(vlistID2, gridID1, gridID2);
     if (operatorID == GRID2FOURIER)
       {
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           if (vars[varID]) vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_CPX64);
       }
     else if (operatorID == FOURIER2GRID)
       {
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           if (vars[varID]) vlistDefVarDatatype(vlistID2, varID, CDI_DATATYPE_FLT32);
       }
 
@@ -309,7 +309,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -331,7 +331,7 @@ public:
                 cdo_read_record(streamID1, array1.data(), &numMissVals);
                 if (numMissVals) cdo_abort("Missing values unsupported for spectral/fourier data!");
 
-                gridID1 = vlistInqVarGrid(vlistID1, varID);
+                gridID1 = varList1.vars[varID].gridID;
                 if (operatorID == FC2SP)
                   four2spec(spTrans, gridID1, array1, gridID2, array2);
                 else if (operatorID == SP2FC)
@@ -365,7 +365,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
