@@ -36,15 +36,15 @@ auto correlation_kernel = [](auto v1, auto mv1, auto v2, auto mv2, auto w, auto
 
 template <typename T1, typename T2>
 static double
-correlation(const Varray<T1> &v1, const Varray<T2> &v2, const Varray<double> &weight, double missval1, double missval2,
-            size_t gridsize)
+correlation(const Varray<T1> &v1, const Varray<T2> &v2, double missval1, double missval2, size_t gridsize,
+            const Varray<double> &weight)
 {
   double sum0 = 0.0, sum1 = 0.0, sum00 = 0.0, sum01 = 0.0, sum11 = 0.0, wsum0 = 0.0;
 
   if (std::isnan(missval1) || std::isnan(missval2))
     {
       for (size_t i = 0; i < gridsize; ++i)
-        correlation_kernel(v1[i], missval1, v2[i], missval2, weight[i], sum0, sum1, sum00, sum01, sum11, wsum0, dbl_is_not_equal);
+        correlation_kernel(v1[i], missval1, v2[i], missval2, weight[i], sum0, sum1, sum00, sum01, sum11, wsum0, fp_is_not_equal);
     }
   else
     {
@@ -52,7 +52,7 @@ correlation(const Varray<T1> &v1, const Varray<T2> &v2, const Varray<double> &we
         correlation_kernel(v1[i], missval1, v2[i], missval2, weight[i], sum0, sum1, sum00, sum01, sum11, wsum0, is_not_equal);
     }
 
-  auto is_EQ = dbl_is_equal;
+  auto is_EQ = fp_is_equal;
   auto out = is_not_equal(wsum0, 0.0)
                  ? DIVM((sum01 * wsum0 - sum0 * sum1), SQRTM((sum00 * wsum0 - sum0 * sum0) * (sum11 * wsum0 - sum1 * sum1)))
                  : missval1;
@@ -63,14 +63,10 @@ correlation(const Varray<T1> &v1, const Varray<T2> &v2, const Varray<double> &we
 static double
 correlation(const Field &field1, const Field &field2, const Varray<double> &weight)
 {
-  if (field1.memType == MemType::Float && field2.memType == MemType::Float)
-    return correlation(field1.vec_f, field2.vec_f, weight, field1.missval, field2.missval, field1.size);
-  else if (field1.memType == MemType::Float && field2.memType == MemType::Double)
-    return correlation(field1.vec_f, field2.vec_d, weight, field1.missval, field2.missval, field1.size);
-  else if (field1.memType == MemType::Double && field2.memType == MemType::Float)
-    return correlation(field1.vec_d, field2.vec_f, weight, field1.missval, field2.missval, field1.size);
-  else
-    return correlation(field1.vec_d, field2.vec_d, weight, field1.missval, field2.missval, field1.size);
+  auto func = [&](const auto &v1, const auto &v2, double mv1, double mv2, size_t size) {
+    return correlation(v1, v2, mv1, mv2, size, weight);
+  };
+  return field_operation2(func, field1, field2, field1.missval, field2.missval, field1.size);
 }
 
 // covariance in space
@@ -87,15 +83,15 @@ auto covariance_kernel
 
 template <typename T1, typename T2>
 static double
-covariance(const Varray<T1> &v1, const Varray<T2> &v2, const Varray<double> &weight, double missval1, double missval2,
-           size_t gridsize)
+covariance(const Varray<T1> &v1, const Varray<T2> &v2, double missval1, double missval2, size_t gridsize,
+           const Varray<double> &weight)
 {
   double sum0 = 0.0, sum1 = 0.0, sum01 = 0.0, wsum0 = 0.0;
 
   if (std::isnan(missval1) || std::isnan(missval2))
     {
       for (size_t i = 0; i < gridsize; ++i)
-        covariance_kernel(v1[i], missval1, v2[i], missval2, weight[i], sum0, sum1, sum01, wsum0, dbl_is_not_equal);
+        covariance_kernel(v1[i], missval1, v2[i], missval2, weight[i], sum0, sum1, sum01, wsum0, fp_is_not_equal);
     }
   else
     {
@@ -111,14 +107,10 @@ covariance(const Varray<T1> &v1, const Varray<T2> &v2, const Varray<double> &wei
 static double
 covariance(const Field &field1, const Field &field2, const Varray<double> &weight)
 {
-  if (field1.memType == MemType::Float && field2.memType == MemType::Float)
-    return covariance(field1.vec_f, field2.vec_f, weight, field1.missval, field2.missval, field1.size);
-  else if (field1.memType == MemType::Float && field2.memType == MemType::Double)
-    return covariance(field1.vec_f, field2.vec_d, weight, field1.missval, field2.missval, field1.size);
-  else if (field1.memType == MemType::Double && field2.memType == MemType::Float)
-    return covariance(field1.vec_d, field2.vec_f, weight, field1.missval, field2.missval, field1.size);
-  else
-    return covariance(field1.vec_d, field2.vec_d, weight, field1.missval, field2.missval, field1.size);
+  auto func = [&](const auto &v1, const auto &v2, double mv1, double mv2, size_t size) {
+    return covariance(v1, v2, mv1, mv2, size, weight);
+  };
+  return field_operation2(func, field1, field2, field1.missval, field2.missval, field1.size);
 }
 
 class Fldstat2 : public Process
@@ -240,7 +232,7 @@ public:
             else if (operfunc == FieldFunc_Covar)
               sglval = covariance(field1, field2, weight);
 
-            auto numMissVals3 = DBL_IS_EQUAL(sglval, var1.missval) ? 1 : 0;
+            auto numMissVals3 = fp_is_equal(sglval, var1.missval) ? 1 : 0;
 
             cdo_def_record(streamID3, varID, levelID);
             cdo_write_record(streamID3, &sglval, numMissVals3);
