@@ -18,11 +18,10 @@ static std::mutex fftwMutex;
 #include <cdi.h>
 
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "param_conversion.h"
 #include "cdo_fft.h"
 #include "cdo_options.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "field_functions.h"
 
 struct FourierMemory
@@ -61,7 +60,7 @@ fourier_fftw(int sign, int varID, int levelID, int nts, size_t gridsize, double
           auto imag = vars[tsID][varID][levelID].vec_d[2 * i + 1];
           fm.in_fft[tsID][0] = real;
           fm.in_fft[tsID][1] = imag;
-          if (DBL_IS_EQUAL(real, missval) || DBL_IS_EQUAL(imag, missval)) hasMissvals = true;
+          if (fp_is_equal(real, missval) || fp_is_equal(imag, missval)) hasMissvals = true;
         }
 
       if (hasMissvals)
@@ -107,7 +106,7 @@ fourier_intrinsic(int sign, int varID, int levelID, int nts, size_t gridsize, do
           auto imag = vars[tsID][varID][levelID].vec_d[2 * i + 1];
           fm.real[tsID] = real;
           fm.imag[tsID] = imag;
-          if (DBL_IS_EQUAL(real, missval) || DBL_IS_EQUAL(imag, missval)) hasMissvals = true;
+          if (fp_is_equal(real, missval) || fp_is_equal(imag, missval)) hasMissvals = true;
         }
 
       if (hasMissvals)
@@ -159,16 +158,16 @@ public:
   int vlistID1;
 
   bool use_fftw = false;
-  int nvars;
+  int numVars;
   int sign;
 
   VarList varList;
-  FieldVector3D vars;
+  FieldVector3D varsData;
   std::vector<CdiDateTime> vDateTimes;
 
 public:
   void
-  init()
+  init() override
   {
     if (Options::Use_FFTW)
       {
@@ -197,13 +196,13 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList, vlistID1);
+    varList = VarList(vlistID1);
 
-    nvars = vlistNvars(vlistID1);
+    numVars = vlistNvars(vlistID1);
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -216,22 +215,22 @@ public:
             constexpr size_t NALLOC_INC = 1024;
             nalloc += NALLOC_INC;
             vDateTimes.resize(nalloc);
-            vars.resize(nalloc);
+            varsData.resize(nalloc);
           }
 
         vDateTimes[tsID] = taxisInqVdatetime(taxisID1);
 
-        fields_from_vlist(vlistID1, vars[tsID]);
+        field2D_init(varsData[tsID], varList);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            auto gridsize = varList[varID].gridsize;
-            vars[tsID][varID][levelID].resize(2 * gridsize);
+            auto gridsize = varList.vars[varID].gridsize;
+            varsData[tsID][varID][levelID].resize(2 * gridsize);
             size_t numMissVals;
-            cdo_read_record(streamID1, vars[tsID][varID][levelID].vec_d.data(), &numMissVals);
-            vars[tsID][varID][levelID].numMissVals = numMissVals;
+            cdo_read_record(streamID1, varsData[tsID][varID][levelID].vec_d.data(), &numMissVals);
+            varsData[tsID][varID][levelID].numMissVals = numMissVals;
           }
 
         tsID++;
@@ -266,17 +265,18 @@ public:
           }
       }
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        auto missval = varList[varID].missval;
-        auto gridsize = varList[varID].gridsize;
-        auto nlevels = varList[varID].nlevels;
+        const auto &var = varList.vars[varID];
+        auto missval = var.missval;
+        auto gridsize = var.gridsize;
+        auto nlevels = var.nlevels;
         for (int levelID = 0; levelID < nlevels; ++levelID)
           {
             if (use_fftw)
-              fourier_fftw(sign, varID, levelID, nts, gridsize, missval, vars, fourierMemory);
+              fourier_fftw(sign, varID, levelID, nts, gridsize, missval, varsData, fourierMemory);
             else
-              fourier_intrinsic(sign, varID, levelID, nts, gridsize, missval, vars, fourierMemory);
+              fourier_intrinsic(sign, varID, levelID, nts, gridsize, missval, varsData, fourierMemory);
           }
       }
 
@@ -299,16 +299,16 @@ public:
         taxisDefVdatetime(taxisID2, vDateTimes[tsID]);
         cdo_def_timestep(streamID2, tsID);
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            auto nlevels = varList[varID].nlevels;
+            auto nlevels = varList.vars[varID].nlevels;
             for (int levelID = 0; levelID < nlevels; ++levelID)
               {
-                if (!vars[tsID][varID][levelID].empty())
+                if (!varsData[tsID][varID][levelID].empty())
                   {
-                    auto numMissVals = vars[tsID][varID][levelID].numMissVals;
+                    auto numMissVals = varsData[tsID][varID][levelID].numMissVals;
                     cdo_def_record(streamID2, varID, levelID);
-                    cdo_write_record(streamID2, vars[tsID][varID][levelID].vec_d.data(), numMissVals);
+                    cdo_write_record(streamID2, varsData[tsID][varID][levelID].vec_d.data(), numMissVals);
                   }
               }
           }
@@ -316,7 +316,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
