@@ -40,7 +40,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     operator_check_argc(0);
@@ -124,7 +124,7 @@ public:
     cdo_def_vlist(streamID3, vlistID3);
   }
   void
-  run()
+  run() override
   {
     int tsID = 0;
     cdo_def_timestep(streamID3, tsID);
@@ -135,7 +135,7 @@ public:
     cdo_write_record(streamID3, array3.data(), gridsize);
   }
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID3);
   }
