@@ -138,7 +138,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     gridPoint = get_parameter();
 
@@ -151,14 +151,14 @@ public:
 
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-    auto ngrids = vlistNgrids(vlistID1);
+    auto ngrids = vlistNumGrids(vlistID1);
     if (ngrids != 1) cdo_abort("Too many different grids!");
 
     gridID1 = vlistGrid(vlistID1, 0);
   }
 
   void
-  run()
+  run() override
   {
     int64_t cellIdx = -1;
     if (is_healpix_grid(gridID1))
@@ -172,7 +172,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
   }
