@@ -26,8 +26,7 @@
 #include "param_conversion.h"
 #include <mpim_grid.h>
 #include "cdo_options.h"
-#include "progress.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "field_functions.h"
 
 static void
@@ -273,7 +272,7 @@ gridbox_stat(const Field &field1, Field &field2, size_t xinc, size_t yinc, int s
               auto index = jj * nlon1 + ii;
               if (ii >= nlon1) break;
               field.vec_d[isize] = (field1.memType == MemType::Float) ? (double) field1.vec_f[index] : field1.vec_d[index];
-              if (dbl_is_equal(field.vec_d[isize], field.missval)) field.numMissVals++;
+              if (fp_is_equal(field.vec_d[isize], field.missval)) field.numMissVals++;
               if (useWeight) field.weightv[isize] = field1.weightv[index];
               isize++;
             }
@@ -315,6 +314,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Gridboxstat> registration = RegisterEntry<Gridboxstat>(module);
+
   int lastgrid = -1;
   bool wstatus = false;
 
@@ -327,7 +327,8 @@ public:
   int taxisID2;
 
   Field field1, field2;
-  VarList varList1, varList2;
+  VarList varList1;
+  VarList varList2;
 
   int xinc;
   int yinc;
@@ -336,9 +337,8 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_input_arg("xinc, yinc");
     operator_check_argc(2);
     xinc = parameter_to_int(cdo_operator_argv(0));
@@ -361,7 +361,7 @@ public:
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    auto ngrids = vlistNgrids(vlistID1);
+    auto ngrids = vlistNumGrids(vlistID1);
     if (ngrids > 1) cdo_abort("Too many different grids!");
 
     auto gridID1 = vlistGrid(vlistID1, 0);
@@ -372,8 +372,8 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
 
     auto gridsize1 = gridInqSize(gridID1);
 
@@ -381,7 +381,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -396,7 +396,7 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field1.init(varList1[varID]);
+            field1.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field1);
 
             if (needWeights && field1.grid != lastgrid)
@@ -406,9 +406,9 @@ public:
               }
             if (wstatus != 0 && tsID == 0 && levelID == 0)
               cdo_warning("Grid cell bounds not available, using constant grid cell area weights for variable %s!",
-                          varList1[varID].name);
+                          varList1.vars[varID].name);
 
-            field2.init(varList2[varID]);
+            field2.init(varList2.vars[varID]);
             gridbox_stat(field1, field2, xinc, yinc, operfunc);
 
             cdo_def_record(streamID2, varID, levelID);
@@ -419,7 +419,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
