@@ -237,7 +237,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     TESTPOINTSEARCH = module.get_id("testpointsearch");
@@ -253,13 +253,13 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     if (operatorID == TESTCELLSEARCH) cell_search(gridID1, gridID2);
   }
 
   void
-  close()
+  close() override
   {
   }
 };
