@@ -26,7 +26,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Harmonic",
-    .operators = { { "harmonic"} },
+    .operators = { { "harmonic" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -52,11 +52,12 @@ public:
   Varray3D<double> work;
   Varray<double> array;
 
-  VarList varList1, varList2;
+  VarList varList1;
+  VarList varList2;
 
 public:
   void
-  init()
+  init() override
   {
     operator_input_arg("wave number and wave length of first harmonic in number of timesteps");
 
@@ -75,8 +76,8 @@ public:
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     vlistID2 = vlistDuplicate(vlistID1);
 
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = cdo_taxis_create(TAXIS_ABSOLUTE);
@@ -104,7 +105,8 @@ public:
     for (int j = 0; j < n_out; ++j)
       {
         out[j].resize(nvars);
-        for (int varID = 0; varID < nvars; ++varID) out[j][varID].resize(varList1[varID].nlevels * varList1[varID].gridsize);
+        for (int varID = 0; varID < nvars; ++varID)
+          out[j][varID].resize(varList1.vars[varID].nlevels * varList1.vars[varID].gridsize);
       }
 
     for (int j = 0; j < n_out * 2; ++j)
@@ -112,7 +114,7 @@ public:
         work[j].resize(nvars);
         for (int varID = 0; varID < nvars; ++varID)
           {
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             work[j][varID].resize(var.gridsize * var.nlevels, 0);
           }
       }
@@ -122,7 +124,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -141,7 +143,7 @@ public:
 
             if (numMissVals) cdo_abort("Missing values are not allowed!");
 
-            auto gridsize = varList1[varID].gridsize;
+            auto gridsize = varList1.vars[varID].gridsize;
             auto offset = gridsize * levelID;
 
             for (int j = 0; j < n_out; ++j)
@@ -170,7 +172,7 @@ public:
       {
         for (int varID = 0; varID < nvars; ++varID)
           {
-            const auto &var2 = varList2[varID];
+            const auto &var2 = varList2.vars[varID];
             for (int levelID = 0; levelID < var2.nlevels; ++levelID)
               {
                 auto offset = var2.gridsize * levelID;
@@ -188,7 +190,7 @@ public:
       {
         for (int varID = 0; varID < nvars; ++varID)
           {
-            const auto &var2 = varList2[varID];
+            const auto &var2 = varList2.vars[varID];
             for (int levelID = 0; levelID < var2.nlevels; ++levelID)
               {
                 auto offset = var2.gridsize * levelID;
@@ -208,7 +210,7 @@ public:
 
         for (int varID = 0; varID < nvars; ++varID)
           {
-            const auto &var2 = varList2[varID];
+            const auto &var2 = varList2.vars[varID];
             for (int levelID = 0; levelID < var2.nlevels; ++levelID)
               {
                 auto offset = var2.gridsize * levelID;
@@ -222,7 +224,7 @@ public:
       {
         for (int varID = 0; varID < nvars; ++varID)
           {
-            const auto &var2 = varList2[varID];
+            const auto &var2 = varList2.vars[varID];
             for (int levelID = 0; levelID < var2.nlevels; ++levelID)
               {
                 auto offset = var2.gridsize * levelID;
@@ -249,7 +251,7 @@ public:
 
         for (int varID = 0; varID < nvars; ++varID)
           {
-            const auto &var2 = varList2[varID];
+            const auto &var2 = varList2.vars[varID];
             for (int levelID = 0; levelID < var2.nlevels; ++levelID)
               {
                 auto offset = var2.gridsize * levelID;
@@ -262,7 +264,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     for (int j = 0; j < n_out; ++j) cdo_stream_close(streamIDs[j]);
   }
