@@ -89,7 +89,7 @@ define_level(dsets_t *pfi, int nlev)
 
       get_dim_vals(pfi, zvals.data(), nz, 2);
 
-      if (nz == 1 && IS_EQUAL(zvals[0], 0))
+      if (nz == 1 && is_equal(zvals[0], 0))
         zaxisID = zaxisCreate(ZAXIS_SURFACE, nz);
       else
         {
@@ -153,7 +153,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     operator_check_argc(0);
@@ -301,7 +301,7 @@ public:
     array = Varray<double>(gridsize);
   }
   void
-  run()
+  run() override
   {
     pfi.infile = nullptr;
     int tcur = 0;
@@ -488,16 +488,12 @@ public:
       }  // end of while (1) loop
   }
   void
-  close()
+  close() override
   {
     process_def_var_num(vlistNvars(vlistID));
 
     cdo_stream_close(streamID);
-
     vlistDestroy(vlistID);
-    gridDestroy(gridID);
-    zaxisDestroy(zaxisID);
-    taxisDestroy(taxisID);
 
     if (pfi.infile) std::fclose(pfi.infile);
   }
