@@ -16,10 +16,9 @@
 #endif
 
 #include <cdi.h>
-#include <stdlib.h> // realloc()
+#include <stdlib.h>  // realloc()
 
 #include "cdo_options.h"
-#include "compare.h"
 #include "varray.h"
 #include "process_int.h"
 #include "cdo_default_values.h"
@@ -993,13 +992,13 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
         {
           if (((datasets_t *) opdata)->obj[nset].dtype != dtype) cdo_warning("Data type changes over levels!");
 
-          if (haveAddoffset && !dbl_is_equal(((datasets_t *) opdata)->obj[nset].addoffset, addoffset))
+          if (haveAddoffset && fp_is_not_equal(((datasets_t *) opdata)->obj[nset].addoffset, addoffset))
             cdo_warning("Offset changes over levels!");
 
-          if (haveScalefactor && !dbl_is_equal(((datasets_t *) opdata)->obj[nset].scalefactor, scalefactor))
+          if (haveScalefactor && fp_is_not_equal(((datasets_t *) opdata)->obj[nset].scalefactor, scalefactor))
             cdo_warning("Scalefactor changes over levels!");
 
-          if (haveMissvals && !dbl_is_equal(((datasets_t *) opdata)->obj[nset].missval, missval))
+          if (haveMissvals && fp_is_not_equal(((datasets_t *) opdata)->obj[nset].missval, missval))
             cdo_warning("Missing value changes over levels!");
         }
 
@@ -1032,7 +1031,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
       if (haveAddoffset || haveScalefactor)
         {
           for (size_t i = 0; i < gridsize * nt; ++i)
-            if (!dbl_is_equal(array[i], missval))
+            if (fp_is_not_equal(array[i], missval))
               {
                 mask[i] = false;
 
@@ -1062,7 +1061,7 @@ read_dataset(hid_t loc_id, const char *name, void *opdata)
         {
           if (!(missval < minval || missval > maxval))
             {
-              if (dbl_is_equal(missval, 255.) && dtype == CDI_DATATYPE_UINT8)
+              if (fp_is_equal(missval, 255.) && dtype == CDI_DATATYPE_UINT8)
                 {
                   missval = -255;
                   dtype = CDI_DATATYPE_INT16;
@@ -1284,7 +1283,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     operator_check_argc(0);
@@ -1307,7 +1306,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
 
 #ifdef HAVE_LIBHDF5
@@ -1436,8 +1435,8 @@ public:
                 numMissVals = gridsize - mm.n;
 
                 if (Options::cdoVerbose)
-                  cdo_print(" Write var %d,  level %d, numMissVals %zu, missval %g, minval %g, maxval %g", varID, levelID, numMissVals, missval,
-                            mm.min, mm.max);
+                  cdo_print(" Write var %d,  level %d, numMissVals %zu, missval %g, minval %g, maxval %g", varID, levelID,
+                            numMissVals, missval, mm.min, mm.max);
 
                 cdo_def_record(streamID, varID, levelID);
                 cdo_write_record(streamID, array, numMissVals);
@@ -1450,7 +1449,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
 #ifdef HAVE_LIBHDF5
     // Close file
@@ -1459,11 +1458,7 @@ public:
     process_def_var_num(vlistNvars(vlistID));
 
     cdo_stream_close(streamID);
-
     vlistDestroy(vlistID);
-    gridDestroy(gridID);
-    zaxisDestroy(zaxisID);
-    taxisDestroy(taxisID);
 
     for (ivar = 0; ivar < dsets.numSets; ++ivar) free(dsets.obj[ivar].array);
 
