@@ -15,7 +15,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Importfv3grid",
-    .operators = { { "import_fv3grid"} },
+    .operators = { { "import_fv3grid" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -39,7 +39,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     operator_check_argc(0);
@@ -63,7 +63,7 @@ public:
         if (varname == vars[varID]) cdo_abort("Found variable %s, expected variable %s!", varname, vars[varID]);
       }
 
-    auto ngrids = vlistNgrids(vlistID1);
+    auto ngrids = vlistNumGrids(vlistID1);
     if (ngrids != 2) cdo_abort("Found %d grids, expected 2 grids!", nvars);
 
     auto gridIDi1 = vlistGrid(vlistID1, 0);
@@ -81,7 +81,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     Varray<double> buffer(gridsize1);
     int varID, levelID;
@@ -153,13 +153,10 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
-
     vlistDestroy(vlistID2);
-    gridDestroy(gridIDo);
-    zaxisDestroy(surfaceID);
   }
 };
