@@ -33,26 +33,22 @@ init_vars(int vlistID, int gridID, int zaxisID, int nvars)
 }
 
 static void
-init_data(int vlistID, int nvars, Varray2D<double> &data)
+init_data(const VarList &varList, Varray2D<double> &data)
 {
-  for (int varID = 0; varID < nvars; ++varID)
+  for (const auto &var : varList.vars)
     {
-      auto gridsize = gridInqSize(vlistInqVarGrid(vlistID, varID));
-      auto missval = vlistInqVarMissval(vlistID, varID);
-      for (size_t i = 0; i < gridsize; ++i) data[varID][i] = missval;
+      for (size_t i = 0; i < var.gridsize; ++i) data[var.ID][i] = var.missval;
     }
 }
 
 static void
-write_data(CdoStreamID streamID, int vlistID, int nvars, Varray2D<double> &data)
+write_data(CdoStreamID streamID, const VarList &varList, Varray2D<double> &data)
 {
-  for (int varID = 0; varID < nvars; ++varID)
+  for (const auto &var : varList.vars)
     {
-      auto gridsize = gridInqSize(vlistInqVarGrid(vlistID, varID));
-      auto missval = vlistInqVarMissval(vlistID, varID);
-      auto numMissVals = varray_num_mv(gridsize, data[varID], missval);
-      cdo_def_record(streamID, varID, 0);
-      cdo_write_record(streamID, data[varID].data(), numMissVals);
+      auto numMissVals = varray_num_mv(var.gridsize, data[var.ID], var.missval);
+      cdo_def_record(streamID, var.ID, 0);
+      cdo_write_record(streamID, data[var.ID].data(), numMissVals);
     }
 }
 
@@ -70,7 +66,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Importobs",
-    .operators = { { "import_obs", 0, 0, "grid description file or name"} },
+    .operators = { { "import_obs", 0, 0, "grid description file or name" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -78,7 +74,7 @@ public:
   };
   inline static auto registration = RegisterEntry<Importobs>(module);
 
-  int nvars = 6;
+  int numVars = 6;
   int vtime = 0;
   char dummy[32], station[32], datetime[32];
   float lat, lon, height1, pressure, height2, value;
@@ -94,8 +90,6 @@ public:
 
   int vdate;
 
-  FILE *fp;
-
   Varray2D<double> data;
 
   Varray<double> xvals;
@@ -105,7 +99,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     auto operatorID = cdo_operator_id();
 
@@ -132,24 +126,24 @@ public:
     if (vdate <= 999999) vdate = vdate * 100 + 1;
 
     streamID = cdo_open_write(1);
-
     zaxisID = zaxisCreate(ZAXIS_SURFACE, 1);
-
     vlistID = vlistCreate();
 
     taxisID = cdo_taxis_create(TAXIS_ABSOLUTE);
     vlistDefTaxis(vlistID, taxisID);
-    data = Varray2D<double>(nvars);
-    for (int i = 0; i < nvars; ++i) data[i].resize(gridsize);
+    data.resize(numVars);
+    for (int i = 0; i < numVars; ++i) data[i].resize(gridsize);
 
-    init_vars(vlistID, gridID, zaxisID, nvars);
+    init_vars(vlistID, gridID, zaxisID, numVars);
 
     cdo_def_vlist(streamID, vlistID);
   }
 
   void
-  run()
+  run() override
   {
+    VarList varList(vlistID);
+
     std::ifstream file(cdo_get_stream_name(0));
     if (!file.is_open()) cdo_abort("Open failed on: %s\n", cdo_get_stream_name(0));
 
@@ -168,7 +162,7 @@ public:
 
         if (vdate != vdate0 || vtime != vtime0)
           {
-            if (tsID > 0) write_data(streamID, vlistID, nvars, data);
+            if (tsID > 0) write_data(streamID, varList, data);
 
             vdate0 = vdate;
             vtime0 = vtime;
@@ -179,7 +173,7 @@ public:
             taxisDefVdatetime(taxisID, vDateTime);
             cdo_def_timestep(streamID, tsID);
 
-            init_data(vlistID, nvars, data);
+            init_data(varList, data);
 
             tsID++;
           }
@@ -225,7 +219,7 @@ public:
 
     file.close();
 
-    write_data(streamID, vlistID, nvars, data);
+    write_data(streamID, varList, data);
 
     if (Options::cdoVerbose) printf("lonmin=%g, lonmax=%g, latmin=%g, latmax=%g\n", lonmin, lonmax, latmin, latmax);
 
@@ -233,13 +227,9 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID);
-
     vlistDestroy(vlistID);
-    gridDestroy(gridID);
-    zaxisDestroy(zaxisID);
-    taxisDestroy(taxisID);
   }
 };
