@@ -21,9 +21,9 @@
 #include "griddes.h"
 #include "matrix_view.h"
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-thinout(const Varray<T> &varray1, Varray<T> &varray2, int gridID1, int gridID2, size_t xinc, size_t yinc)
+thinout(const Varray<T1> &varray1, Varray<T2> &varray2, int gridID1, int gridID2, size_t xinc, size_t yinc)
 {
   auto nlon1 = gridInqXsize(gridID1);
   auto nlat1 = gridInqYsize(gridID1);
@@ -31,8 +31,8 @@ thinout(const Varray<T> &varray1, Varray<T> &varray2, int gridID1, int gridID2,
   auto nlon2 = gridInqXsize(gridID2);
   auto nlat2 = gridInqYsize(gridID2);
 
-  MatrixView<const T> xfield1(varray1.data(), nlat1, nlon1);
-  MatrixView<T> xfield2(varray2.data(), nlat2, nlon2);
+  MatrixView<const T1> xfield1(varray1.data(), nlat1, nlon1);
+  MatrixView<T2> xfield2(varray2.data(), nlat2, nlon2);
 
   size_t olat = 0;
   for (size_t ilat = 0; ilat < nlat1; ilat += yinc)
@@ -50,13 +50,8 @@ thinout(const Varray<T> &varray1, Varray<T> &varray2, int gridID1, int gridID2,
 static void
 thinout(const Field &field1, Field &field2, size_t xinc, size_t yinc)
 {
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    thinout(field1.vec_f, field2.vec_f, field1.grid, field2.grid, xinc, yinc);
-  else
-    thinout(field1.vec_d, field2.vec_d, field1.grid, field2.grid, xinc, yinc);
-
+  auto func = [&](auto &v1, auto &v2, auto grid1, auto grid2) { thinout(v1, v2, grid1, grid2, xinc, yinc); };
+  field_operation2(func, field1, field2, field1.grid, field2.grid);
   field_num_mv(field2);
 }
 
@@ -191,9 +186,9 @@ gen_boxavg_grid(int gridID1, size_t xinc, size_t yinc)
   return gridID2;
 }
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-boxavg(const Varray<T> &varray1, Varray<T> &varray2, int gridID1, int gridID2, size_t xinc, size_t yinc)
+boxavg(const Varray<T1> &varray1, Varray<T2> &varray2, int gridID1, int gridID2, size_t xinc, size_t yinc)
 {
   auto nlon1 = gridInqXsize(gridID1);
   auto nlat1 = gridInqYsize(gridID1);
@@ -201,8 +196,8 @@ boxavg(const Varray<T> &varray1, Varray<T> &varray2, int gridID1, int gridID2, s
   auto nlon2 = gridInqXsize(gridID2);
   auto nlat2 = gridInqYsize(gridID2);
 
-  MatrixView<const T> xfield1(varray1.data(), nlat1, nlon1);
-  MatrixView<T> xfield2(varray2.data(), nlat2, nlon2);
+  MatrixView<const T1> xfield1(varray1.data(), nlat1, nlon1);
+  MatrixView<T2> xfield2(varray2.data(), nlat2, nlon2);
 
   for (size_t ilat = 0; ilat < nlat2; ilat++)
     for (size_t ilon = 0; ilon < nlon2; ilon++)
@@ -230,13 +225,8 @@ boxavg(const Varray<T> &varray1, Varray<T> &varray2, int gridID1, int gridID2, s
 static void
 boxavg(const Field &field1, Field &field2, size_t xinc, size_t yinc)
 {
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    boxavg(field1.vec_f, field2.vec_f, field1.grid, field2.grid, xinc, yinc);
-  else
-    boxavg(field1.vec_d, field2.vec_d, field1.grid, field2.grid, xinc, yinc);
-
+  auto func = [&](auto &v1, auto &v2, auto grid1, auto grid2) { boxavg(v1, v2, grid1, grid2, xinc, yinc); };
+  field_operation2(func, field1, field2, field1.grid, field2.grid);
   field_num_mv(field2);
 }
 
