@@ -15,10 +15,9 @@
 
 #include <cdi.h>
 
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "cdo_options.h"
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "cdi_lockedIO.h"
 
 void vert_interp_lev3d(size_t gridsize, int nlev1, double missval, const Field3D &field1, Field3D &field2, int nlev2,
@@ -74,28 +73,26 @@ vert_gen_weights3d(bool expol, size_t gridsize, int nlev1, const Varray<float> &
 }
 
 static void
-vlist_copy_var_attributes(const VarList &varList0, int varID0, int vlistID3, int oz3dvarID)
+vlist_copy_var_attributes(const CdoVar &var0, int vlistID3, int oz3dvarID)
 {
-  const auto &var0 = varList0[varID0];
   cdiDefKeyString(vlistID3, oz3dvarID, CDI_KEY_NAME, var0.name.c_str());
   if (var0.longname.size()) cdiDefKeyString(vlistID3, oz3dvarID, CDI_KEY_LONGNAME, var0.longname.c_str());
   if (var0.units.size()) cdiDefKeyString(vlistID3, oz3dvarID, CDI_KEY_UNITS, var0.units.c_str());
 }
 
-static void
-read_source_coordinate(int streamNumber, VarList &varList2, Varray<float> &zlevelsIn)
+static CdoVar
+read_source_coordinate(int streamNumber, Varray<float> &zlevelsIn)
 {
   auto streamID2 = cdo_open_read(streamNumber);  // 3d vertical source coordinate
   auto vlistID2 = cdo_stream_inq_vlist(streamID2);
 
-  varList_init(varList2, vlistID2);
+  VarList varList(vlistID2);
 
-  if (vlistNvars(vlistID2) != 1) cdo_abort("infile2: Only one single variable is allowed!");
+  if (varList.numVars() != 1) cdo_abort("infile2: Only one single variable is allowed!");
 
-  auto gridsize = varList2[0].gridsize;
-  auto nlevels = varList2[0].nlevels;
+  const auto &var0 = varList.vars[0];
 
-  zlevelsIn.resize(gridsize * nlevels);
+  zlevelsIn.resize(var0.gridsize * var0.nlevels);
 
   auto nrecs = cdo_stream_inq_timestep(streamID2, 0);
   if (Options::cdoVerbose) cdo_print("%d records input 3d vertical height", nrecs);
@@ -104,44 +101,47 @@ read_source_coordinate(int streamNumber, VarList &varList2, Varray<float> &zleve
     {
       int varID, levelID;
       cdo_inq_record(streamID2, &varID, &levelID);
-      auto offset = gridsize * levelID;
+      auto offset = var0.gridsize * levelID;
       size_t numMissVals;
       cdo_read_record_f(streamID2, &zlevelsIn[offset], &numMissVals);
       if (0 != numMissVals) cdo_abort("Input vertical coordinate variables are not allowed to contain missing values.");
     }
 
   cdo_stream_close(streamID2);
+
+  return var0;
 }
 
-static void
-read_target_coordinate(const std::string &fileName, VarList &varList0, Varray<float> &zlevelsOut)
+static CdoVar
+read_target_coordinate(const std::string &fileName, Varray<float> &zlevelsOut)
 {
   auto streamID0 = stream_open_read_locked(fileName.c_str());  // 3d vertical target coordinate
   auto vlistID0 = streamInqVlist(streamID0);
 
-  varList_init(varList0, vlistID0);
+  VarList varList(vlistID0);
 
-  if (vlistNvars(vlistID0) != 1) cdo_abort("tgtcoordinate: Only one single variable is allowed!");
+  if (varList.numVars() != 1) cdo_abort("tgtcoordinate: Only one single variable is allowed!");
 
-  auto gridsize = varList0[0].gridsize;
-  auto nlevels = varList0[0].nlevels;
+  const auto var0 = varList.vars[0];
 
-  zlevelsOut.resize(gridsize * nlevels);
+  zlevelsOut.resize(var0.gridsize * var0.nlevels);
 
   auto nrecs = streamInqTimestep(streamID0, 0);
-  if (Options::cdoVerbose) cdo_print("%d records target 3d vertical height and gridsize %zu", nrecs, gridsize);
+  if (Options::cdoVerbose) cdo_print("%d records target 3d vertical height and gridsize %zu", nrecs, var0.gridsize);
 
   for (int recID = 0; recID < nrecs; ++recID)
     {
       int varID, levelID;
       streamInqRecord(streamID0, &varID, &levelID);
-      auto offset = gridsize * levelID;
+      auto offset = var0.gridsize * levelID;
       size_t numMissVals;
       streamReadRecordF(streamID0, &zlevelsOut[offset], &numMissVals);
       if (0 != numMissVals) cdo_abort("Output vertical coordinate variables are not allowd to contain missing values.");
     }
 
   streamClose(streamID0);
+
+  return var0;
 }
 
 class Intlevel3d : public Process
@@ -167,7 +167,7 @@ public:
   int taxisID3;
   int vlistID3;
 
-  int nvars;
+  int numVars;
 
   int nlevi;
   int nlevo;
@@ -194,13 +194,10 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-INTLEVEL3D = module.get_id("intlevel3d");
-INTLEVELX3D = module.get_id("intlevelx3d");
-    // clang-format on
+    INTLEVEL3D = module.get_id("intlevel3d");
+    INTLEVELX3D = module.get_id("intlevelx3d");
 
     (void) INTLEVEL3D;  // unused
 
@@ -222,28 +219,23 @@ INTLEVELX3D = module.get_id("intlevelx3d");
     taxisID3 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID3, taxisID1);
 
-    varList_init(varList1, vlistID1);
-    varListSetUniqueMemtype(varList1);
-    memType = varList1[0].memType;
+    varList1 = VarList(vlistID1);
+    varList_set_unique_memtype(varList1);
+    memType = varList1.vars[0].memType;
 
     // Read 3d source coordinate (streamID2)
-    VarList varList2;
     Varray<float> zlevelsIn;
-
-    read_source_coordinate(1, varList2, zlevelsIn);
-
-    auto gridsizei = varList2[0].gridsize;  // horizontal gridsize of input z coordinate
-    nlevi = varList2[0].nlevels;            // number of input levels for later use
+    auto zvari = read_source_coordinate(1, zlevelsIn);
+    auto gridsizei = zvari.gridsize;
+    nlevi = zvari.nlevels;
 
     // Read 3d target coordinate (streamID0)
-    VarList varList0;
+    auto zvaro = read_target_coordinate(cdo_operator_argv(0), zlevelsOut);
 
-    read_target_coordinate(cdo_operator_argv(0), varList0, zlevelsOut);
-
-    auto gridsizeo = varList0[0].gridsize;  // horizontal gridsize of output z coordinate
-    nlevo = varList0[0].nlevels;            // number of output levels for later use
-    auto gridID3 = varList0[0].gridID;
-    auto zaxisID3 = varList0[0].zaxisID;
+    auto gridsizeo = zvaro.gridsize;  // horizontal gridsize of output z coordinate
+    nlevo = zvaro.nlevels;            // number of output levels for later use
+    auto gridID3 = zvaro.gridID;
+    auto zaxisID3 = zvaro.zaxisID;
 
     // gridsize of input and output vertical coordinate must be equal (later use of gridsizeo ONLY)
     if (gridsizei != gridsizeo) cdo_abort("Input and output vertical coordinate must have the same gridsize!");
@@ -256,7 +248,7 @@ INTLEVELX3D = module.get_id("intlevelx3d");
      * Variables with a different z-axis should be copied into output.
      */
     int zaxisID1 = -1;
-    auto nzaxis = vlistNzaxis(vlistID1);
+    auto nzaxis = vlistNumZaxis(vlistID1);
     int i;
     for (i = 0; i < nzaxis; ++i)
       {
@@ -270,7 +262,7 @@ INTLEVELX3D = module.get_id("intlevelx3d");
       }
     if (i == nzaxis) cdo_abort("No processable variable found (vertical coordinate differ)!");
 
-    auto ngrids = vlistNgrids(vlistID1);
+    auto ngrids = vlistNumGrids(vlistID1);
     for (i = 0; i < ngrids; ++i)
       {
         auto gridsize = gridInqSize(vlistGrid(vlistID1, i));
@@ -290,30 +282,31 @@ INTLEVELX3D = module.get_id("intlevelx3d");
 
     // add the vertical output field to the output stream
     oz3dvarID = vlistDefVar(vlistID3, gridID3, zaxisID3, TIME_VARYING);
-    vlist_copy_var_attributes(varList0, 0, vlistID3, oz3dvarID);
+    vlist_copy_var_attributes(zvaro, vlistID3, oz3dvarID);
 
     streamID3 = cdo_open_write(2);  // output stream
     cdo_def_vlist(streamID3, vlistID3);
 
-    varList_init(varList3, vlistID3);
-    varListSetMemtype(varList3, memType);
+    varList3 = VarList(vlistID3);
+    varList_set_memtype(varList3, memType);
 
     auto maxlev = std::max(nlevi, nlevo);
-    nvars = vlistNvars(vlistID1);
+    numVars = varList1.numVars();
 
-    processVars = std::vector<bool>(nvars);
-    interpVars = std::vector<bool>(nvars, false);        // marker for variables to be interpolated
-    varnumMissVals = std::vector<std::vector<size_t>>(nvars);  // can for missing values of arbitrary variables
-    vardata1 = Field3DVector(nvars);
-    vardata2 = Field3DVector(nvars);
+    processVars = std::vector<bool>(numVars);
+    interpVars = std::vector<bool>(numVars, false);              // marker for variables to be interpolated
+    varnumMissVals = std::vector<std::vector<size_t>>(numVars);  // can for missing values of arbitrary variables
+    vardata1 = Field3DVector(numVars);
+    vardata2 = Field3DVector(numVars);
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        auto zaxisID = varList1[varID].zaxisID;
-        auto gridsize = varList1[varID].gridsize;
-        auto nlevel = varList1[varID].nlevels;
+        const auto &var1 = varList1.vars[varID];
+        auto zaxisID = var1.zaxisID;
+        auto gridsize = var1.gridsize;
+        auto nlevel = var1.nlevels;
 
-        vardata1[varID].init(varList1[varID]);
+        vardata1[varID].init(var1);
 
         /*  variabls for interpolation:
          *  * have the required vertical axis, i.e. the correct number of levels (nlevi)
@@ -324,25 +317,24 @@ INTLEVELX3D = module.get_id("intlevelx3d");
         if (interpVars[varID])
           {
             varnumMissVals[varID].resize(maxlev, 0);
-            vardata2[varID].init(varList3[varID]);
+            vardata2[varID].init(varList3.vars[varID]);
           }
         else
           {
             varnumMissVals[varID].resize(nlevel);
-            if (Options::cdoVerbose)
-              cdo_print("Ignore variable %s (levels=%d gridsize=%zu)!", varList1[varID].name, nlevel, gridsize);
+            if (Options::cdoVerbose) cdo_print("Ignore variable %s (levels=%d gridsize=%zu)!", var1.name, nlevel, gridsize);
           }
       }
 
     {
       int varID;
-      for (varID = 0; varID < nvars; ++varID)
+      for (varID = 0; varID < numVars; ++varID)
         if (interpVars[varID]) break;
-      if (varID == nvars) cdo_abort("No processable variable found!");
+      if (varID == numVars) cdo_abort("No processable variable found!");
     }
   }
   void
-  run()
+  run() override
   {
 
     int tsID = 0;
@@ -351,7 +343,7 @@ INTLEVELX3D = module.get_id("intlevelx3d");
         auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
-        for (int varID = 0; varID < nvars; ++varID) processVars[varID] = false;
+        for (int varID = 0; varID < numVars; ++varID) processVars[varID] = false;
 
         cdo_taxis_copy_timestep(taxisID3, taxisID1);
         cdo_def_timestep(streamID3, tsID);
@@ -366,12 +358,13 @@ INTLEVELX3D = module.get_id("intlevelx3d");
           }
 
         // Perform the interpolation on all valid data variables
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
+            const auto &var1 = varList1.vars[varID];
             if (processVars[varID] && interpVars[varID])
               {
-                auto gridsize = varList1[varID].gridsize;
-                auto missval = varList1[varID].missval;
+                auto gridsize = var1.gridsize;
+                auto missval = var1.missval;
 
                 vert_interp_lev3d(gridsize, nlevi, missval, vardata1[varID], vardata2[varID], nlevo, lev_idx, lev_wgt);
 
@@ -386,16 +379,16 @@ INTLEVELX3D = module.get_id("intlevelx3d");
               }
             else
               {
-                if (Options::cdoVerbose && tsID <= 1) cdo_print("Perform no interpolation on variable %s", varList1[varID].name);
+                if (Options::cdoVerbose && tsID <= 1) cdo_print("Perform no interpolation on variable %s", var1.name);
               }
           }
 
         // write the output
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
             if (processVars[varID])
               {
-                for (int levelID = 0; levelID < varList3[varID].nlevels; ++levelID)
+                for (int levelID = 0; levelID < varList3.vars[varID].nlevels; ++levelID)
                   {
                     cdo_def_record(streamID3, varID, levelID);
                     cdo_write_record(streamID3, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
@@ -405,9 +398,9 @@ INTLEVELX3D = module.get_id("intlevelx3d");
           }
 
         // copy output z coordinate to output stream
-        for (int levelID = 0; levelID < varList3[oz3dvarID].nlevels; ++levelID)
+        for (int levelID = 0; levelID < varList3.vars[oz3dvarID].nlevels; ++levelID)
           {
-            auto offset = varList3[oz3dvarID].gridsize * levelID;
+            auto offset = varList3.vars[oz3dvarID].gridsize * levelID;
             cdo_def_record(streamID3, oz3dvarID, levelID);
             cdo_write_record_f(streamID3, &zlevelsOut[offset], 0);
           }
@@ -416,7 +409,7 @@ INTLEVELX3D = module.get_id("intlevelx3d");
       }
   }
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID3);
