@@ -15,7 +15,6 @@
 
 #include "cdo_rlimit.h"
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "param_conversion.h"
 #include "util_files.h"
 #include "util_string.h"
@@ -30,7 +29,7 @@ intlin_year(double fac1, double fac2, size_t gridsize, const Varray<double> &arr
     {
       for (size_t i = 0; i < gridsize; ++i)
         {
-          if (!dbl_is_equal(array1[i], missval1) && !dbl_is_equal(array2[i], missval2))
+          if (fp_is_not_equal(array1[i], missval1) && fp_is_not_equal(array2[i], missval2))
             {
               array3[i] = array1[i] * fac1 + array2[i] * fac2;
             }
@@ -72,7 +71,8 @@ public:
   std::vector<int> iyears;
   int nyears;
 
-  VarList varList1, varList2;
+  VarList varList1;
+  VarList varList2;
 
   std::vector<CdoStreamID> streamIDs;
 
@@ -82,7 +82,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     operator_input_arg("years");
@@ -101,7 +101,9 @@ public:
     auto vlistID2 = cdo_stream_inq_vlist(streamID2);
     auto vlistID3 = vlistDuplicate(vlistID1);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
+    varList_compare(varList1, varList2);
 
     auto gridsizemax = vlistGridsizeMax(vlistID1);
 
@@ -125,13 +127,10 @@ public:
         streamIDs[iy] = cdo_open_write(fileName.c_str());
         cdo_def_vlist(streamIDs[iy], vlistID3);
       }
-
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -167,9 +166,9 @@ public:
             cdo_read_record(streamID1, array1.data(), &numMissVals1);
             cdo_read_record(streamID2, array2.data(), &numMissVals2);
 
-            auto gridsize = varList1[varID].gridsize;
-            auto missval1 = varList1[varID].missval;
-            auto missval2 = varList2[varID].missval;
+            auto gridsize = varList1.vars[varID].gridsize;
+            auto missval1 = varList1.vars[varID].missval;
+            auto missval2 = varList2.vars[varID].missval;
             auto withMissval = (numMissVals1 || numMissVals2);
 
             for (int iy = 0; iy < nyears; iy++)
@@ -189,7 +188,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     for (int iy = 0; iy < nyears; iy++) cdo_stream_close(streamIDs[iy]);
 
