@@ -44,8 +44,8 @@ invert_lon_data(Varray<T> &v, size_t nlon, size_t nlat)
 static void
 invert_lon_data(Field &field)
 {
-  const auto nlon = gridInqXsize(field.grid);
-  const auto nlat = gridInqYsize(field.grid);
+  auto nlon = gridInqXsize(field.grid);
+  auto nlat = gridInqYsize(field.grid);
 
   if (field.memType == MemType::Float)
     invert_lon_data(field.vec_f, nlon, nlat);
@@ -74,8 +74,8 @@ invert_lat_data(Varray<T> &v, size_t nlon, size_t nlat)
 static void
 invert_lat_data(Field &field)
 {
-  const auto nlon = gridInqXsize(field.grid);
-  const auto nlat = gridInqYsize(field.grid);
+  auto nlon = gridInqXsize(field.grid);
+  auto nlat = gridInqYsize(field.grid);
 
   if (field.memType == MemType::Float)
     invert_lat_data(field.vec_f, nlon, nlat);
@@ -86,13 +86,13 @@ invert_lat_data(Field &field)
 static void
 invert_lon_des(int vlistID)
 {
-  const auto ngrids = vlistNgrids(vlistID);
+  auto ngrids = vlistNumGrids(vlistID);
   for (int index = 0; index < ngrids; ++index)
     {
-      const auto gridID1 = vlistGrid(vlistID, index);
-      const auto gridID2 = gridDuplicate(gridID1);
+      auto gridID1 = vlistGrid(vlistID, index);
+      auto gridID2 = gridDuplicate(gridID1);
 
-      const auto gridtype = gridInqType(gridID1);
+      auto gridtype = gridInqType(gridID1);
 
       if (!(gridtype == GRID_GENERIC || gridtype == GRID_GAUSSIAN || gridtype == GRID_PROJECTION || gridtype == GRID_LONLAT
             || gridtype == GRID_CURVILINEAR))
@@ -100,9 +100,9 @@ invert_lon_des(int vlistID)
 
       if (gridInqXvals(gridID1, nullptr))
         {
-          const auto nlon = gridInqXsize(gridID1);
-          const auto nlat = gridInqYsize(gridID1);
-          const auto size = (gridtype == GRID_CURVILINEAR) ? nlon * nlat : nlon;
+          auto nlon = gridInqXsize(gridID1);
+          auto nlat = gridInqYsize(gridID1);
+          auto size = (gridtype == GRID_CURVILINEAR) ? nlon * nlat : nlon;
 
           Varray<double> coords(size);
 
@@ -129,10 +129,10 @@ invert_lon_des(int vlistID)
 
       if (gridInqXbounds(gridID1, nullptr))
         {
-          const auto nlon = gridInqXsize(gridID1);
-          const auto nlat = gridInqYsize(gridID1);
-          const auto nv = gridInqNvertex(gridID1);
-          const auto size = (gridtype == GRID_CURVILINEAR) ? nv * nlon * nlat : nv * nlon;
+          auto nlon = gridInqXsize(gridID1);
+          auto nlat = gridInqYsize(gridID1);
+          auto nv = gridInqNvertex(gridID1);
+          auto size = (gridtype == GRID_CURVILINEAR) ? nv * nlon * nlat : nv * nlon;
 
           Varray<double> bounds(size);
 
@@ -168,13 +168,13 @@ invert_lon_des(int vlistID)
 static void
 invert_lat_coord(int gridID)
 {
-  const auto gridtype = gridInqType(gridID);
+  auto gridtype = gridInqType(gridID);
 
   if (gridInqYvals(gridID, nullptr))
     {
-      const auto nlon = gridInqXsize(gridID);
-      const auto nlat = gridInqYsize(gridID);
-      const auto size = (gridtype == GRID_CURVILINEAR) ? nlon * nlat : nlat;
+      auto nlon = gridInqXsize(gridID);
+      auto nlat = gridInqYsize(gridID);
+      auto size = (gridtype == GRID_CURVILINEAR) ? nlon * nlat : nlat;
 
       Varray<double> coords(size);
 
@@ -201,10 +201,10 @@ invert_lat_coord(int gridID)
 
   if (gridInqYbounds(gridID, nullptr))
     {
-      const auto nlon = gridInqXsize(gridID);
-      const auto nlat = gridInqYsize(gridID);
-      const auto nv = gridInqNvertex(gridID);
-      const auto size = (gridtype == GRID_CURVILINEAR) ? nv * nlon * nlat : nv * nlat;
+      auto nlon = gridInqXsize(gridID);
+      auto nlat = gridInqYsize(gridID);
+      auto nv = gridInqNvertex(gridID);
+      auto size = (gridtype == GRID_CURVILINEAR) ? nv * nlon * nlat : nv * nlat;
 
       Varray<double> bounds(size);
 
@@ -237,13 +237,13 @@ invert_lat_coord(int gridID)
 static void
 invert_lat_des(int vlistID)
 {
-  const auto ngrids = vlistNgrids(vlistID);
+  auto ngrids = vlistNumGrids(vlistID);
   for (int index = 0; index < ngrids; ++index)
     {
-      const auto gridID1 = vlistGrid(vlistID, index);
-      const auto gridID2 = gridDuplicate(gridID1);
+      auto gridID1 = vlistGrid(vlistID, index);
+      auto gridID2 = gridDuplicate(gridID1);
 
-      const auto gridtype = gridInqType(gridID1);
+      auto gridtype = gridInqType(gridID1);
 
       if (!(gridtype == GRID_GENERIC || gridtype == GRID_GAUSSIAN || gridtype == GRID_PROJECTION || gridtype == GRID_LONLAT
             || gridtype == GRID_CURVILINEAR))
@@ -251,7 +251,7 @@ invert_lat_des(int vlistID)
 
       invert_lat_coord(gridID2);
 
-      const auto projID = gridInqProj(gridID2);
+      auto projID = gridInqProj(gridID2);
       if (projID != CDI_UNDEFID) invert_lat_coord(projID);
 
       vlistChangeGrid(vlistID, gridID1, gridID2);
@@ -296,17 +296,12 @@ public:
   int operfunc2;
 
   VarList varList1;
-  Field field;
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-    // clang-format on
-
-    const auto operatorID = cdo_operator_id();
+    auto operatorID = cdo_operator_id();
     operfunc1 = cdo_operator_f1(operatorID);
     operfunc2 = cdo_operator_f2(operatorID);
 
@@ -314,8 +309,8 @@ public:
 
     streamID1 = cdo_open_read(0);
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = vlistDuplicate(vlistID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
@@ -333,15 +328,18 @@ public:
 
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
+
   void
-  run()
+  run() override
   {
+    Field field;
+
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -352,7 +350,7 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field.init(varList1[varID]);
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
 
             cdo_def_record(streamID2, varID, levelID);
@@ -374,7 +372,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
