@@ -1003,7 +1003,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
 #ifdef HAVE_LIBMAGICS
@@ -1069,13 +1069,13 @@ public:
 #endif
   }
   void
-  run()
+  run() override
   {
 #ifdef HAVE_LIBMAGICS
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID, tsID);
         if (nrecs == 0) break;
 
         if (ANIM_FLAG)
@@ -1179,7 +1179,7 @@ public:
 #endif
   }
   void
-  close()
+  close() override
   {
 #ifdef HAVE_LIBMAGICS
 
