@@ -33,7 +33,7 @@ countMask(const double *maskField, size_t gridSize, double falseVal)
 
   for (size_t i = 0; i < gridSize; ++i)
     {
-      if (!DBL_IS_EQUAL(maskField[i], falseVal)) counter++;
+      if (!fp_is_equal(maskField[i], falseVal)) counter++;
     }
 
   return counter;
@@ -70,7 +70,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     if (cdo_operator_argc() < 1) cdo_abort("Too few arguments!");
@@ -96,7 +96,7 @@ public:
       size_t k = 0;
       for (size_t i = 0; i < inputGridSize; ++i)
         {
-          if (!DBL_IS_EQUAL(inputMaskField[i], 0.0)) maskIndexList[k++] = i;
+          if (!fp_is_equal(inputMaskField[i], 0.0)) maskIndexList[k++] = i;
         }
 
       if (k == inputGridSize) cdo_warning("Number of mask values and gridsize is the same, no reduction!");
@@ -122,21 +122,20 @@ public:
     auto nvars = vlistNvars(vlistID1);
     vars = std::vector<bool>(nvars, false);
 
-    VarList varList1;
-    varList_init(varList1, vlistID1);
+    VarList varList1(vlistID1);
 
     // use vlist flags for marking the corresponding variables
     vlistClearFlag(vlistID1);
     for (int varID = 0; varID < nvars; ++varID)
       {
-        auto gridID = varList1[varID].gridID;
-        if (inputGridType == gridInqType(gridID) && inputGridSize == gridInqSize(gridID))
+        const auto &var = varList1.vars[varID];
+        if (inputGridType == var.gridType && inputGridSize == var.gridsize)
           {
             vars[varID] = true;
-            auto nlevels = varList1[varID].nlevels;
+            auto nlevels = var.nlevels;
             for (int levID = 0; levID < nlevels; levID++) vlistDefFlag(vlistID1, varID, levID, true);
           }
-        else { cdo_warning("Gridtype or gridsize differ, skipped variable %s!", varList1[varID].name); }
+        else { cdo_warning("Gridtype or gridsize differ, skipped variable %s!", var.name); }
       }
 
     vlistID2 = vlistCreate();
@@ -149,7 +148,7 @@ public:
     vlistDefTaxis(vlistID2, taxisID2);
 
     // use the new selection grid for all output variables
-    auto ngrids = vlistNgrids(vlistID2);
+    auto ngrids = vlistNumGrids(vlistID2);
     for (int index = 0; index < ngrids; ++index) vlistChangeGridIndex(vlistID2, index, outputGridID);
 
     // loop over input fields and mask the data values {{{
@@ -159,8 +158,9 @@ public:
     arrayIn = Varray<double>(inputGridSize);
     arrayOut = Varray<double>(maskSize);
   }
+
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -191,10 +191,10 @@ public:
           }
         tsID++;
       }
-    // }}}
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
