@@ -15,6 +15,7 @@
 
 #include "cdo_options.h"
 #include "cdo_rlimit.h"
+#include "cdo_varlist.h"
 #include "process_int.h"
 #include "cdo_zaxis.h"
 #include "util_files.h"
@@ -25,29 +26,23 @@ check_dup_entry(int vlistID1, int vlistID2, const std::string &filename)
 {
   Varray<double> lev1, lev2;
 
-  auto nvars1 = vlistNvars(vlistID1);
-  auto nvars2 = vlistNvars(vlistID2);
+  VarList varList1(vlistID1);
+  VarList varList2(vlistID2);
 
-  VarList varList1, varList2;
-  varList_init(varList1, vlistID1);
-  varList_init(varList2, vlistID2);
-
-  for (int varID1 = 0; varID1 < nvars1; ++varID1)
+  for (const auto &var1 : varList1.vars)
     {
-      const auto &var1 = varList1[varID1];
-      auto gtype1 = gridInqType(var1.gridID);
+      auto gtype1 = var1.gridType;
       auto gsize1 = var1.gridsize;
-      auto ztype1 = zaxisInqType(var1.zaxisID);
+      auto ztype1 = var1.zaxisType;
       size_t nlev1 = var1.nlevels;
       if (nlev1 > lev1.size()) lev1.resize(nlev1);
       cdo_zaxis_inq_levels(var1.zaxisID, lev1.data());
 
-      for (int varID2 = 0; varID2 < nvars2; ++varID2)
+      for (const auto &var2 : varList2.vars)
         {
-          const auto &var2 = varList2[varID2];
-          auto gtype2 = gridInqType(var2.gridID);
+          auto gtype2 = var2.gridType;
           auto gsize2 = var2.gridsize;
-          auto ztype2 = zaxisInqType(var2.zaxisID);
+          auto ztype2 = var2.zaxisType;
           size_t nlev2 = var2.nlevels;
           if (gtype1 == gtype2 && gsize1 == gsize2 && ztype1 == ztype2 && nlev1 == nlev2)
             {
@@ -84,7 +79,7 @@ get_taxis_index(const std::vector<int> &vlistIDs)
 {
   if (vlistNtsteps(vlistIDs[0]) == 0)
     {
-      const int nmerge = vlistIDs.size();
+      int nmerge = vlistIDs.size();
       for (int im = 1; im < nmerge; ++im)
         {
           if (vlistNtsteps(vlistIDs[im]) != 0) return im;
@@ -128,8 +123,8 @@ public:
   inline static RegisterEntry<Merge> registration = RegisterEntry<Merge>(module);
 
   CdoStreamID streamID2;
-  int nmerge;
-  int taxisindex;
+  int numMerge;
+  int taxisIndex;
 
   int taxisID1;
   int taxisID2;
@@ -140,39 +135,37 @@ public:
 
   std::vector<CdoStreamID> streamIDs;
   std::vector<int> vlistIDs;
-  std::vector<int> numRecords;
-  std::vector<int> numTimeSteps;
+  std::vector<int> numRecordsList;
+  std::vector<int> numStepsList;
 
-  VarList varList2;
   Field field;
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_check_argc(0);
 
     dataIsUnchanged = data_is_unchanged();
 
     auto streamCnt = cdo_stream_cnt();
-    nmerge = streamCnt - 1;
+    numMerge = streamCnt - 1;
 
-    cdo::set_numfiles(nmerge + 8);
+    cdo::set_numfiles(numMerge + 8);
 
     std::string ofilename = cdo_get_stream_name(streamCnt - 1);
 
     if (!Options::cdoOverwriteMode && FileUtils::file_exists(ofilename) && !FileUtils::user_file_overwrite(ofilename))
       cdo_abort("Outputfile %s already exists!", ofilename);
 
-    streamIDs = std::vector<CdoStreamID>(nmerge);
-    vlistIDs = std::vector<int>(nmerge);
-    numRecords = std::vector<int>(nmerge);
-    numTimeSteps = std::vector<int>(nmerge);
+    streamIDs = std::vector<CdoStreamID>(numMerge);
+    vlistIDs = std::vector<int>(numMerge);
+    numRecordsList = std::vector<int>(numMerge);
+    numStepsList = std::vector<int>(numMerge);
 
     auto setFileType = (CdoDefault::FileType == CDI_UNDEFID);
     auto baseFiletype = -1;
-    for (int im = 0; im < nmerge; ++im)
+    for (int im = 0; im < numMerge; ++im)
       {
         streamIDs[im] = cdo_open_read(im);
         vlistIDs[im] = cdo_stream_inq_vlist(streamIDs[im]);
@@ -183,14 +176,13 @@ public:
     if (setFileType) CdoDefault::FileType = cdo_inq_filetype(streamIDs[0]);
     // printf("setFileType=%d  filetype=%d\n", setFileType, CdoDefault::FileType);
 
-    taxisindex = get_taxis_index(vlistIDs);
+    taxisIndex = get_taxis_index(vlistIDs);
 
-    taxisID1 = vlistInqTaxis(vlistIDs[taxisindex]);
+    taxisID1 = vlistInqTaxis(vlistIDs[taxisIndex]);
     taxisID2 = taxisDuplicate(taxisID1);
 
-    vlistID2 = vlistCreate();
-    vlistCopy(vlistID2, vlistIDs[0]);
-    for (int im = 1; im < nmerge; ++im)
+    vlistID2 = vlistDuplicate(vlistIDs[0]);
+    for (int im = 1; im < numMerge; ++im)
       {
         std::string commandString = cdo_get_command_from_in_stream(im);
         check_dup_entry(vlistID2, vlistIDs[im], commandString);
@@ -198,28 +190,28 @@ public:
       }
 
     int numConstVars = 0;
-    for (int im = 0; im < nmerge; ++im)
+    for (int im = 0; im < numMerge; ++im)
       {
-        numTimeSteps[im] = vlistNtsteps(vlistIDs[im]);
-        if (numTimeSteps[im] == 0) numTimeSteps[im] = 1;
-        if (numTimeSteps[im] == 1) numConstVars++;
+        numStepsList[im] = vlistNtsteps(vlistIDs[im]);
+        if (numStepsList[im] == 0) numStepsList[im] = 1;
+        if (numStepsList[im] == 1) numConstVars++;
       }
 
-    if (numConstVars > 0 && numConstVars < nmerge)
-      for (int im = 0; im < nmerge; ++im)
+    if (numConstVars > 0 && numConstVars < numMerge)
+      for (int im = 0; im < numMerge; ++im)
         {
-          if (numTimeSteps[im] == 1)
+          if (numStepsList[im] == 1)
             {
               auto vlistID1 = vlistIDs[im];
-              auto nvars = vlistNvars(vlistID1);
-              for (int varID = 0; varID < nvars; ++varID)
+              auto numVars = vlistNvars(vlistID1);
+              for (int varID = 0; varID < numVars; ++varID)
                 vlistDefVarTimetype(vlistID2, vlistMergedVar(vlistID1, varID), TIME_CONSTANT);
             }
         }
 
     if (Options::cdoVerbose)
       {
-        for (int im = 0; im < nmerge; ++im) vlistPrint(vlistIDs[im]);
+        for (int im = 0; im < numMerge; ++im) vlistPrint(vlistIDs[im]);
         vlistPrint(vlistID2);
       }
 
@@ -227,50 +219,51 @@ public:
 
     vlistDefTaxis(vlistID2, taxisID2);
     cdo_def_vlist(streamID2, vlistID2);
-
-    varList_init(varList2, vlistID2);
   }
+
   void
-  run()
+  run() override
   {
+    VarList varList2(vlistID2);
+
     int tsID = 0;
     while (true)
       {
-        for (int im = 0; im < nmerge; ++im)
+        for (int im = 0; im < numMerge; ++im)
           {
             if (vlistIDs[im] == -1) continue;
-            numRecords[im] = cdo_stream_inq_timestep(streamIDs[im], tsID);
+            numRecordsList[im] = cdo_stream_inq_timestep(streamIDs[im], tsID);
           }
 
         {
           int im;
-          for (im = 0; im < nmerge; ++im)
-            if (numRecords[im] != 0) break;
-          if (im == nmerge) break;  // EOF on all input streams
+          for (im = 0; im < numMerge; ++im)
+            if (numRecordsList[im] != 0) break;
+          if (im == numMerge) break;  // EOF on all input streams
         }
 
         if (tsID == 1)
           {
-            for (int im = 0; im < nmerge; ++im)
-              if (numRecords[im] == 0 && numTimeSteps[im] == 1) vlistIDs[im] = -1;
+            for (int im = 0; im < numMerge; ++im)
+              if (numRecordsList[im] == 0 && numStepsList[im] == 1) vlistIDs[im] = -1;
           }
 
-        if (numRecords[taxisindex] == 0)
+        if (numRecordsList[taxisIndex] == 0)
           {
-            for (int im = 1; im < nmerge; ++im)
-              if (vlistIDs[im] != -1 && numRecords[im] != 0)
-                cdo_warning("Input stream %d has %d timestep%s. Stream %d has more timesteps, skipped!", taxisindex + 1, tsID,
+            for (int im = 1; im < numMerge; ++im)
+              if (vlistIDs[im] != -1 && numRecordsList[im] != 0)
+                cdo_warning("Input stream %d has %d timestep%s. Stream %d has more timesteps, skipped!", taxisIndex + 1, tsID,
                             (tsID == 1) ? "" : "s", im + 1);
             break;
           }
         else
           {
             auto lstop = false;
-            for (int im = 1; im < nmerge; ++im)
-              if (vlistIDs[im] != -1 && numRecords[im] == 0)
+            for (int im = 1; im < numMerge; ++im)
+              if (vlistIDs[im] != -1 && numRecordsList[im] == 0)
                 {
                   cdo_warning("Input stream %d has %d timestep%s. Stream %d has more timesteps, skipped!", im + 1, tsID,
-                              (tsID == 1) ? "" : "s", taxisindex + 1);
+                              (tsID == 1) ? "" : "s", taxisIndex + 1);
                   lstop = true;
                   break;
                 }
@@ -280,17 +273,16 @@ public:
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
         cdo_def_timestep(streamID2, tsID);
 
-        for (int im = 0; im < nmerge; ++im)
+        for (int im = 0; im < numMerge; ++im)
           {
             auto streamID1 = streamIDs[im];
             auto vlistID1 = vlistIDs[im];
             if (vlistID1 == -1) continue;
 
-            auto nrecs = numRecords[im];
-            for (int recID = 0; recID < nrecs; ++recID)
+            auto numRecords = numRecordsList[im];
+            for (int recID = 0; recID < numRecords; ++recID)
               {
-                int varID, levelID;
-                cdo_inq_record(streamID1, &varID, &levelID);
+                auto [varID, levelID] = cdo_inq_record(streamID1);
 
                 auto varID2 = vlistMergedVar(vlistID1, varID);
                 auto levelID2 = vlistMergedLevel(vlistID1, varID, levelID);
@@ -302,7 +294,7 @@ public:
                 if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
                 else
                   {
-                    field.init(varList2[varID2]);
+                    field.init(varList2.vars[varID2]);
                     cdo_read_record(streamID1, field);
                     cdo_write_record(streamID2, field);
                   }
@@ -312,8 +304,9 @@ public:
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     for (auto &streamID : streamIDs) cdo_stream_close(streamID);
 
