@@ -56,7 +56,6 @@ public:
   inline static RegisterEntry<Merstat> registration = RegisterEntry<Merstat>(module);
 
   int gridID1, gridID2 = -1, lastgrid = -1;
-  int index;
 
   CdoStreamID streamID1;
   CdoStreamID streamID2;
@@ -74,9 +73,8 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);
 
@@ -97,18 +95,20 @@ public:
 
     if (!lminmax) vlist_unpack(vlistID2);
 
+    varList1 = VarList(vlistID1);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    auto ngrids = vlistNgrids(vlistID1);
-    int ndiffgrids = 0;
-    for (index = 1; index < ngrids; ++index)
-      if (vlistGrid(vlistID1, 0) != vlistGrid(vlistID1, index)) ndiffgrids++;
+    auto numGrids = vlistNumGrids(vlistID1);
+    int numDiffGrids = 0;
+    for (int index = 1; index < numGrids; ++index)
+      if (vlistGrid(vlistID1, 0) != vlistGrid(vlistID1, index)) numDiffGrids++;
 
-    if (ndiffgrids > 0) cdo_abort("Too many different grids!");
+    if (numDiffGrids > 0) cdo_abort("Too many different grids!");
 
-    index = 0;
+    int index = 0;
     gridID1 = vlistGrid(vlistID1, index);
 
     if (gridInqType(gridID1) == GRID_LONLAT || gridInqType(gridID1) == GRID_GAUSSIAN || gridInqType(gridID1) == GRID_GENERIC)
@@ -122,8 +122,8 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    gridID1 = vlistInqVarGrid(vlistID1, 0);
-    const int nlonmax = gridInqXsize(gridID1);  // max nlon?
+    gridID1 = varList1.vars[0].gridID;
+    int nlonmax = gridInqXsize(gridID1);  // max nlon?
     auto gridsizemax = vlistGridsizeMax(vlistID1);
 
     if (needWeights) field1.weightv.resize(gridsizemax);
@@ -131,12 +131,10 @@ public:
     field2.resize(nlonmax);
     field2.grid = gridID2;
     field2.memType = MemType::Double;
-
-    varList_init(varList1, vlistID1);
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -151,12 +149,13 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field1.init(varList1[varID]);
+            const auto &var = varList1.vars[varID];
+            field1.init(var);
             cdo_read_record(streamID1, field1);
 
             field2.missval = field1.missval;
 
-            bool wstatus = false;
+            auto wstatus = false;
             if (needWeights && field1.grid != lastgrid)
               {
                 lastgrid = field1.grid;
@@ -164,8 +163,7 @@ public:
               }
 
             if (wstatus != 0 && tsID == 0 && levelID == 0)
-              cdo_warning("Grid cell bounds not available, using constant grid cell area weights for variable %s!",
-                          varList1[varID].name);
+              cdo_warning("Grid cell bounds not available, using constant grid cell area weights for variable %s!", var.name);
 
             (operfunc == FieldFunc_Pctl) ? meridional_pctl(field1, field2, pn) : meridional_function(field1, field2, operfunc);
 
@@ -178,7 +176,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
