@@ -182,7 +182,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Mrotuv",
-    .operators = { { "mrotuv"} },
+    .operators = { { "mrotuv" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -224,25 +224,26 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     operator_check_argc(0);
 
     streamID1 = cdo_open_read(0);
 
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    VarList varList1(vlistID1);
 
-    auto nvars = vlistNvars(vlistID1);
-    for (int varid = 0; varid < nvars; varid++)
+    auto numVars = vlistNvars(vlistID1);
+    for (int varid = 0; varid < numVars; varid++)
       {
-        auto code = vlistInqVarCode(vlistID1, varid);
+        auto code = varList1.vars[varid].code;
         if (code == 3 || code == 131) uid = varid;
         if (code == 4 || code == 132) vid = varid;
       }
 
     if (uid == -1 || vid == -1)
       {
-        if (nvars == 2)
+        if (numVars == 2)
           {
             uid = 0;
             vid = 1;
@@ -251,18 +252,19 @@ public:
           cdo_abort("U and V not found in %s", cdo_get_stream_name(0));
       }
 
-    nlevs = zaxisInqSize(vlistInqVarZaxis(vlistID1, uid));
-    if (nlevs != zaxisInqSize(vlistInqVarZaxis(vlistID1, vid))) cdo_abort("U and V have different number of levels!");
+    const auto &varU = varList1.vars[uid];
+    const auto &varV = varList1.vars[vid];
+    if (varU.nlevels != varV.nlevels) cdo_abort("U and V have different number of levels!");
 
-    auto gridID1 = vlistInqVarGrid(vlistID1, uid);
-    auto gridID2 = vlistInqVarGrid(vlistID1, vid);
-    gridsize = gridInqSize(gridID1);
-    if (gridID1 != gridID2) cdo_abort("Input grids differ!");
+    auto gridID1 = varU.gridID;
+    gridsize = varU.gridsize;
+    if (varU.gridID != varV.gridID) cdo_abort("Input grids differ!");
 
-    if (gridInqType(gridID1) != GRID_LONLAT && gridInqType(gridID1) != GRID_GAUSSIAN && gridInqType(gridID1) != GRID_CURVILINEAR)
-      cdo_abort("Grid %s unsupported!", gridNamePtr(gridInqType(gridID1)));
+    auto gridType = varU.gridType;
+    if (gridType != GRID_LONLAT && gridType != GRID_GAUSSIAN && gridType != GRID_CURVILINEAR)
+      cdo_abort("Grid %s unsupported!", gridNamePtr(gridType));
 
-    if (gridInqType(gridID1) != GRID_CURVILINEAR) gridID1 = gridToCurvilinear(gridID1);
+    if (gridType != GRID_CURVILINEAR) gridID1 = gridToCurvilinear(gridID1);
 
     if (gridsize != gridInqSize(gridID1)) cdo_abort("Internal problem: gridsize changed!");
 
@@ -329,12 +331,12 @@ public:
     cdo_def_vlist(streamID2, vlistID2);
     cdo_def_vlist(streamID3, vlistID3);
 
-    missval1 = vlistInqVarMissval(vlistID1, uid);
-    missval2 = vlistInqVarMissval(vlistID1, vid);
+    missval1 = varU.missval;
+    missval2 = varV.missval;
   }
 
   void
-  run()
+  run() override
   {
     ufield_v = Varray<double>(gridsize);
     vfield_v = Varray<double>(gridsize);
@@ -378,8 +380,8 @@ public:
               {
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (DBL_IS_EQUAL(urfield[levelID][i], missval1)) urfield[levelID][i] = 0.0;
-                    if (DBL_IS_EQUAL(vrfield[levelID][i], missval2)) vrfield[levelID][i] = 0.0;
+                    if (fp_is_equal(urfield[levelID][i], missval1)) urfield[levelID][i] = 0.0;
+                    if (fp_is_equal(vrfield[levelID][i], missval2)) vrfield[levelID][i] = 0.0;
                   }
               }
 
@@ -423,7 +425,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID3);
     cdo_stream_close(streamID2);
