@@ -238,6 +238,7 @@ public:
     .constraints = { 2, 1, NoRestriction },
   };
   inline static RegisterEntry<Mrotuvb> registration = RegisterEntry<Mrotuvb>(module);
+
   CdoStreamID streamID1;
   CdoStreamID streamID2;
   CdoStreamID streamID3;
@@ -265,9 +266,8 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     gpint = !(cdo_operator_argc() == 1 && cdo_operator_argv(0) == "noint");
 
     streamID1 = cdo_open_read(0);
@@ -276,26 +276,31 @@ public:
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = cdo_stream_inq_vlist(streamID2);
 
-    auto nvars = vlistNvars(vlistID1);
-    if (nvars > 1) cdo_abort("More than one variable found in %s", cdo_get_stream_name(0));
-    nvars = vlistNvars(vlistID2);
-    if (nvars > 1) cdo_abort("More than one variable found in %s", cdo_get_stream_name(1));
+    VarList varList1(vlistID1);
+    VarList varList2(vlistID2);
 
-    auto gridID1 = vlistGrid(vlistID1, 0);
-    auto gridID2 = vlistGrid(vlistID2, 0);
-    gridsize = gridInqSize(gridID1);
+    const auto &varU = varList1.vars[0];
+    const auto &varV = varList2.vars[0];
+
+    if (varList1.numVars() > 1) cdo_abort("More than one variable found in %s", cdo_get_stream_name(0));
+    if (varList2.numVars() > 1) cdo_abort("More than one variable found in %s", cdo_get_stream_name(1));
+
+    auto gridID1 = varU.gridID;
+    auto gridID2 = varV.gridID;
+    gridsize = varU.gridsize;
     if (gpint && gridID1 == gridID2) cdo_abort("Input grids are the same, use parameter >noint< to disable interpolation!");
     if (!gpint && gridID1 != gridID2) cdo_abort("Input grids are not the same!");
-    if (gridsize != gridInqSize(gridID2)) cdo_abort("Grids have different size!");
+    if (gridsize != varV.gridsize) cdo_abort("Grids have different size!");
 
-    if (gridInqType(gridID1) != GRID_LONLAT && gridInqType(gridID1) != GRID_GAUSSIAN && gridInqType(gridID1) != GRID_CURVILINEAR)
-      cdo_abort("Grid %s unsupported!", gridNamePtr(gridInqType(gridID1)));
+    auto gridType = varU.gridType;
+    if (gridType != GRID_LONLAT && gridType != GRID_GAUSSIAN && gridType != GRID_CURVILINEAR)
+      cdo_abort("Grid %s unsupported!", gridNamePtr(gridType));
 
-    if (gridInqType(gridID1) != GRID_CURVILINEAR) gridID1 = gridToCurvilinear(gridID1, NeedCorners::Yes);
+    if (gridType != GRID_CURVILINEAR) gridID1 = gridToCurvilinear(gridID1, NeedCorners::Yes);
 
     if (gridsize != gridInqSize(gridID1)) cdo_abort("Internal problem: gridsize changed!");
 
-    if (gridInqType(gridID2) != GRID_CURVILINEAR) gridID2 = gridToCurvilinear(gridID2, NeedCorners::Yes);
+    if (varV.gridType != GRID_CURVILINEAR) gridID2 = gridToCurvilinear(gridID2, NeedCorners::Yes);
 
     if (gridsize != gridInqSize(gridID2)) cdo_abort("Internal problem: gridsize changed!");
 
@@ -341,14 +346,10 @@ public:
         grid3y[i] *= DEG2RAD;
       }
 
-    auto vlistID3 = vlistCreate();
-    vlistCopy(vlistID3, vlistID1);
+    auto vlistID3 = vlistDuplicate(vlistID1);
     vlistCat(vlistID3, vlistID2);
 
-    auto code1 = vlistInqVarCode(vlistID1, 0);
-    auto code2 = vlistInqVarCode(vlistID2, 0);
-
-    if (code1 == code2) vlistDefVarCode(vlistID3, 1, code1 + 1);
+    if (varU.code == varV.code) vlistDefVarCode(vlistID3, 1, varU.code + 1);
 
     vlistChangeGrid(vlistID3, gridID1, gridID3);
     vlistChangeGrid(vlistID3, gridID2, gridID3);
@@ -362,8 +363,8 @@ public:
     streamID3 = cdo_open_write(2);
     cdo_def_vlist(streamID3, vlistID3);
 
-    missval1 = vlistInqVarMissval(vlistID1, 0);
-    missval2 = vlistInqVarMissval(vlistID2, 0);
+    missval1 = varU.missval;
+    missval2 = varV.missval;
 
     urfield = Varray<double>(gridsize);
     vrfield = Varray<double>(gridsize);
@@ -372,7 +373,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     MatrixView<double> ufield(ufield_v.data(), nlat, nlon);
     MatrixView<double> vfield(vfield_v.data(), nlat, nlon);
@@ -415,8 +416,8 @@ public:
               {
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (DBL_IS_EQUAL(ufield_v[i], missval1)) ufield_v[i] = 0.0;
-                    if (DBL_IS_EQUAL(vfield_v[i], missval2)) vfield_v[i] = 0.0;
+                    if (fp_is_equal(ufield_v[i], missval1)) ufield_v[i] = 0.0;
+                    if (fp_is_equal(vfield_v[i], missval2)) vfield_v[i] = 0.0;
                   }
               }
 
@@ -488,7 +489,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID3);
     cdo_stream_close(streamID2);
