@@ -60,14 +60,13 @@ public:
   int ntsteps;
   CdoStreamID streamID;
   int taxisID;
-  int nvars;
   int ngrids;
 
   VarList varList;
 
 public:
   void
-  init()
+  init() override
   {
 
     auto operatorID = cdo_operator_id();
@@ -78,16 +77,17 @@ public:
     streamID = cdo_open_read(0);
     auto vlistID = cdo_stream_inq_vlist(streamID);
 
-    nvars = vlistNvars(vlistID);
     taxisID = vlistInqTaxis(vlistID);
     ntsteps = vlistNtsteps(vlistID);
-    ngrids = vlistNgrids(vlistID);
+    ngrids = vlistNumGrids(vlistID);
 
-    varList_init(varList, vlistID);
+    varList = VarList(vlistID);
   }
+
   void
-  run()
+  run() override
   {
+    auto numVars = varList.numVars();
     switch (operfunc)
       {
       case NYEAR:
@@ -159,12 +159,12 @@ public:
           fprintf(stdout, "%d\n", tsID);
           break;
         }
-      case NPAR: fprintf(stdout, "%d\n", nvars); break;
+      case NPAR: fprintf(stdout, "%d\n", numVars); break;
       case NLEVEL:
-        for (int varID = 0; varID < nvars; ++varID) { fprintf(stdout, "%d\n", varList[varID].nlevels); }
+        for (int varID = 0; varID < numVars; ++varID) { fprintf(stdout, "%d\n", varList.vars[varID].nlevels); }
         break;
       case NGRIDPOINTS:
-        for (int varID = 0; varID < nvars; ++varID) { fprintf(stdout, "%zu\n", varList[varID].gridsize); }
+        for (int varID = 0; varID < numVars; ++varID) { fprintf(stdout, "%zu\n", varList.vars[varID].gridsize); }
         break;
       case NGRIDS: fprintf(stdout, "%d\n", ngrids); break;
       default: cdo_abort("operator not implemented!"); break;
@@ -172,7 +172,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID);
   }
