@@ -18,8 +18,6 @@
 
 #include <cdi.h>
 
-#include <unordered_map>
-
 #include "cdo_options.h"
 #include "process_int.h"
 #include "param_conversion.h"
@@ -76,7 +74,7 @@ outputxyz(size_t gridsize, const Varray<double> &array, double missval, size_t n
   double fmin = 0.0;
   double x, y, z;
   for (size_t i = 0; i < gridsize; ++i)
-    if (!dbl_is_equal(array[i], missval))
+    if (fp_is_not_equal(array[i], missval))
       {
         if (array[i] < fmin) fmin = array[i];
         fprintf(stdout, "%g\t%g\t%g\t%g\n", lon[i], lat[i], array[i], array[i]);
@@ -308,14 +306,13 @@ public:
     { "year",     kyear,      5 },
     { "month",    kmonth,     2 },
     { "day",      kday,       2 },
-    // clang-format on
   };
+  // clang-format on
 
 public:
   void
-  init()
+  init() override
   {
-
     OUTPUT = module.get_id("output");
     OUTPUTINT = module.get_id("outputint");
     OUTPUTSRV = module.get_id("outputsrv");
@@ -396,18 +393,18 @@ public:
       }
     else { operator_check_argc(0); }
   }
+
   void
-  run()
+  run() override
   {
     for (int indf = 0; indf < cdo_stream_cnt(); indf++)
       {
         auto streamID = cdo_open_read(indf);
         auto vlistID = cdo_stream_inq_vlist(streamID);
 
-        VarList varList;
-        varList_init(varList, vlistID);
+        VarList varList(vlistID);
 
-        auto ngrids = vlistNgrids(vlistID);
+        auto ngrids = vlistNumGrids(vlistID);
         int ndiffgrids = 0;
         for (index = 1; index < ngrids; ++index)
           if (vlistGrid(vlistID, 0) != vlistGrid(vlistID, index)) ndiffgrids++;
@@ -448,11 +445,11 @@ public:
               {
                 int varID, levelID;
                 cdo_inq_record(streamID, &varID, &levelID);
-                const auto &var = varList[varID];
+                const auto &var = varList.vars[varID];
 
                 auto code = var.code;
                 auto gridID = var.gridID;
-                auto dig = (var.datatype == CDI_DATATYPE_FLT64) ? Options::CDO_dbl_digits : Options::CDO_flt_digits;
+                auto dig = (var.dataType == CDI_DATATYPE_FLT64) ? Options::CDO_dbl_digits : Options::CDO_flt_digits;
                 gridsize = var.nwpv * var.gridsize;
                 auto nlon = gridInqXsize(gridID);
                 auto nlat = gridInqYsize(gridID);
@@ -491,7 +488,7 @@ public:
                     cdiTime_decode(vDateTime.time, &hour, &minute, &second, &ms);
                     double xdate = vdate - (vdate / 100) * 100 + (hour * 3600 + minute * 60 + second) / 86400.0;
                     for (size_t i = 0; i < gridsize; ++i)
-                      if (!dbl_is_equal(array[i], missval))
+                      if (fp_is_not_equal(array[i], missval))
                         fprintf(stdout, "%g\t%g\t%g\t%.*g\n", xdate, grid_center_lat[i], grid_center_lon[i], dig, array[i]);
                   }
                 else if (operatorID == OUTPUTTAB)
@@ -562,8 +559,9 @@ public:
         cdo_stream_close(streamID);
       }
   }
+
   void
-  close()
+  close() override
   {
   }
 };
