@@ -113,7 +113,7 @@ output_mer(double levmin, double levmax, const double *cell_corner_lon)
 static const int *
 get_rgb(double value, double missval, const CPT &cpt)
 {
-  if (dbl_is_not_equal(value, missval))
+  if (fp_is_not_equal(value, missval))
     {
       int n;
       for (n = 0; n < cpt.ncolors; ++n)
@@ -173,7 +173,7 @@ output_vrml(long nlon, long nlat, long ngp, const Varray<double> &array, double
         int r = 0, g = 0, b = 0;
         auto val = array[j * nlon + i];
 
-        if (!DBL_IS_EQUAL(val, missval))
+        if (!fp_is_equal(val, missval))
           {
             int n;
             for (n = 0; n < cpt.ncolors; ++n)
@@ -765,7 +765,7 @@ public:
                   {
                     if (grid_mask.size() && grid_mask[i] == 0) continue;
 
-                    if (!DBL_IS_EQUAL(array[i], missval))
+                    if (!fp_is_equal(array[i], missval))
                       fprintf(stdout, "> -Z%g", array[i]);
                     else
                       fprintf(stdout, "> -ZNaN");
