@@ -17,7 +17,6 @@
 #include <cdi.h>
 
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "datetime.h"
 #include "cdo_default_values.h"
 #include "field_functions.h"
@@ -123,19 +122,6 @@ compute_scale_and_offset(int datatype, double fmin, double fmax, double &scaleFa
   return 0;
 }
 
-static MinMax
-field_min_max(Field &field)
-{
-  auto numMissVals = field.numMissVals;
-  auto missval = field.missval;
-  auto len = field.size;
-
-  if (field.memType == MemType::Float)
-    return numMissVals ? varray_min_max_mv(len, field.vec_f, (float) missval) : varray_min_max(len, field.vec_f);
-  else
-    return numMissVals ? varray_min_max_mv(len, field.vec_d, missval) : varray_min_max(len, field.vec_d);
-}
-
 static void
 field_change_missval(Field &field, double missval1, double missval2)
 {
@@ -145,13 +131,13 @@ field_change_missval(Field &field, double missval1, double missval2)
     {
       auto &v = field.vec_f;
       for (size_t i = 0; i < len; ++i)
-        if (dbl_is_equal(v[i], (float) missval1)) v[i] = missval2;
+        if (fp_is_equal(v[i], (float) missval1)) v[i] = missval2;
     }
   else
     {
       auto &v = field.vec_d;
       for (size_t i = 0; i < len; ++i)
-        if (dbl_is_equal(v[i], missval1)) v[i] = missval2;
+        if (fp_is_equal(v[i], missval1)) v[i] = missval2;
     }
 }
 
@@ -169,7 +155,7 @@ print_parameter(const PackParams &params)
 }
 
 static void
-print_pack_params(const std::string& name, double addOffset, double scaleFactor)
+print_pack_params(const std::string &name, double addOffset, double scaleFactor)
 {
   fprintf(stdout, "name=%s  add_offset=%.9g  scale_factor=%.9g\n", name.c_str(), addOffset, scaleFactor);
 }
@@ -235,15 +221,14 @@ public:
   PackParams params;
 
   int datatype = CDI_DATATYPE_INT16;
-  int nvars;
 
-  VarList varList;
+  VarList varList1;
 
 private:
   void
   run_method1()
   {
-    FieldVector3D vars;
+    FieldVector3D varsData;
     DateTimeList dtlist;
 
     int tsID = 0;
@@ -253,18 +238,18 @@ private:
         if (nrecs == 0) break;
 
         constexpr size_t NALLOC_INC = 1024;
-        if ((size_t) tsID >= vars.size()) vars.resize(vars.size() + NALLOC_INC);
+        if ((size_t) tsID >= varsData.size()) varsData.resize(varsData.size() + NALLOC_INC);
 
         dtlist.taxis_inq_timestep(taxisID1, tsID);
 
-        fields_from_vlist(vlistID1, vars[tsID]);
+        field2D_init(varsData[tsID], varList1);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            auto &field = vars[tsID][varID][levelID];
-            field.init(varList[varID]);
+            auto &field = varsData[tsID][varID][levelID];
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
           }
 
@@ -275,9 +260,10 @@ private:
 
     constexpr double undefValue = 1.0e300;
 
-    for (int varID = 0; varID < nvars; ++varID)
+    auto numVars = varList1.numVars();
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        const auto &var = varList[varID];
+        const auto &var = varList1.vars[varID];
 
         double fmin = undefValue, fmax = -undefValue;
         size_t numMissValspv = 0;
@@ -288,7 +274,7 @@ private:
               {
                 if (t > 0 && var.isConstant) continue;
 
-                auto &field = vars[t][varID][levelID];
+                auto &field = varsData[t][varID][levelID];
                 auto numMissVals = field.numMissVals;
 
                 if (numMissVals) numMissValspv += numMissVals;
@@ -322,7 +308,7 @@ private:
                       {
                         if (t > 0 && var.isConstant) continue;
 
-                        auto &field = vars[t][varID][levelID];
+                        auto &field = varsData[t][varID][levelID];
                         if (field.numMissVals) field_change_missval(field, var.missval, missval2);
                       }
                   }
@@ -350,13 +336,13 @@ private:
         dtlist.taxis_def_timestep(taxisID2, tsID);
         cdo_def_timestep(streamID2, tsID);
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            const auto &var = varList[varID];
+            const auto &var = varList1.vars[varID];
             if (tsID > 0 && var.isConstant) continue;
             for (int levelID = 0; levelID < var.nlevels; ++levelID)
               {
-                auto &field = vars[tsID][varID][levelID];
+                auto &field = varsData[tsID][varID][levelID];
                 if (field.hasData())
                   {
                     cdo_def_record(streamID2, varID, levelID);
@@ -372,11 +358,12 @@ private:
   {
     const auto packList = read_params_from_file(params.filename);
 
-    for (int varID = 0; varID < nvars; ++varID)
+    auto numVars = varList1.numVars();
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        const auto &var = varList[varID];
+        const auto &var = varList1.vars[varID];
 
-        for (auto &packEntry: packList)
+        for (auto &packEntry : packList)
           {
             if (var.name == packEntry.name)
               {
@@ -412,7 +399,7 @@ private:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field.init(varList[varID]);
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
 
             cdo_def_record(streamID2, varID, levelID);
@@ -425,7 +412,7 @@ private:
 
 public:
   void
-  init()
+  init() override
   {
     params = get_parameter();
     if (Options::cdoVerbose) print_parameter(params);
@@ -441,9 +428,7 @@ public:
 
     streamID2 = cdo_open_write(1);
 
-    varList_init(varList, vlistID1);
-
-    nvars = vlistNvars(vlistID1);
+    varList1 = VarList(vlistID1);
 
     if (CdoDefault::DataType != CDI_UNDEFID)
       {
@@ -459,7 +444,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     if (params.filename.empty())
       run_method1();
@@ -468,7 +453,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
