@@ -67,7 +67,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     PRESSURE_FULL = module.get_id("pressure");
     PRESSURE_HALF = module.get_id("pressure_half");
@@ -80,10 +80,9 @@ public:
     streamID1 = cdo_open_read(0);
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-    VarList varList1;
-    varList_init(varList1, vlistID1);
-    // varListSetUniqueMemtype(varList1);
-    // auto memType = varList1[0].memType;
+    VarList varList1(vlistID1);
+    // varList_setUniqueMemtype(varList1);
+    // auto memType = varList1.vars[0].memType;
 
     gridsize = vlist_check_gridsize(vlistID1);
 
@@ -132,22 +131,22 @@ public:
         zaxisDefVct(zaxisID_PL, 2 * numHalfLevels, vct.data());
       }
 
-    varIDs = search_varIDs(varList1, vlistID1, numFullLevels);
+    varIDs = varList_search_varIDs(varList1, numFullLevels);
 
     if (Options::cdoVerbose)
       {
         cdo_print("Found:");
         // clang-format off
-        if (-1 != varIDs.psID)   cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1[varIDs.psID].name);
-        if (-1 != varIDs.lnpsID) cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), varList1[varIDs.lnpsID].name);
+        if (-1 != varIDs.psID)   cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1.vars[varIDs.psID].name);
+        if (-1 != varIDs.lnpsID) cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), varList1.vars[varIDs.lnpsID].name);
         // clang-format on
       }
 
     pvarID = varIDs.lnpsID;
     if (zaxisID_ML != -1 && varIDs.lnpsID != -1)
       {
-        auto gridID = varList1[varIDs.lnpsID].gridID;
-        if (gridInqType(gridID) == GRID_SPECTRAL)
+        auto gridType = varList1.vars[varIDs.lnpsID].gridType;
+        if (gridType == GRID_SPECTRAL)
           {
             varIDs.lnpsID = -1;
             cdo_warning("Spectral LOG(%s) not supported - using %s!", var_stdname(surface_air_pressure),
@@ -161,7 +160,7 @@ public:
         if (varIDs.psID == -1) cdo_abort("%s not found!", var_stdname(surface_air_pressure));
       }
 
-    auto gridID = varList1[pvarID].gridID;
+    auto gridID = varList1.vars[pvarID].gridID;
     if (gridInqType(gridID) == GRID_SPECTRAL)
       cdo_abort("%s on spectral representation not supported!", var_stdname(surface_air_pressure));
 
@@ -185,7 +184,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -257,7 +256,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
 
     cdo_stream_close(streamID2);
