@@ -261,7 +261,7 @@ public:
             auto offset = gridsize * levelID;
             auto single2 = &t2[offset];
 
-            auto mm = array_min_max_mask(gridsize, single2, imiss);
+            auto mm = array_min_max_mask(single2, gridsize, imiss);
             if (mm.min < MIN_T || mm.max > MAX_T)
               cdo_warning("Output temperature at level %d out of range (min=%g max=%g)!", levelID + 1, mm.min, mm.max);
 
@@ -285,7 +285,7 @@ public:
             if (levelID < nctop)
               for (size_t i = 0; i < gridsize; ++i) single2[i] = cconst;
 
-            auto mm = array_min_max_mask(gridsize, single2, imiss);
+            auto mm = array_min_max_mask(single2, gridsize, imiss);
             if (mm.min < MIN_Q || mm.max > MAX_Q)
               cdo_warning("Output humidity at level %d out of range (min=%g max=%g)!", levelID + 1, mm.min, mm.max);
 
@@ -372,13 +372,13 @@ public:
     if (numMissVals)
       {
         imiss.resize(nfis2gp);
-        for (size_t i = 0; i < nfis2gp; ++i) imiss[i] = dbl_is_equal(fis2[i], var.missval);
+        for (size_t i = 0; i < nfis2gp; ++i) imiss[i] = fp_is_equal(fis2[i], var.missval);
 
         numMissValsout = numMissVals;
       }
 
     // check range of surface_geopotential
-    auto mm = array_min_max_mask(nfis2gp, fis2.data(), imiss);
+    auto mm = array_min_max_mask(fis2.data(), nfis2gp, imiss);
     if (mm.min < MIN_FIS || mm.max > MAX_FIS)
       cdo_warning("%s out of range (min=%g max=%g)!", var_stdname(surface_geopotential), mm.min, mm.max);
 
@@ -681,11 +681,11 @@ public:
         if (zaxisID_ML != -1)
           {
             // check range of psProg
-            auto mm = array_min_max_mask(gridsize, ps1.data(), imiss);
+            auto mm = array_min_max_mask(ps1.data(), gridsize, imiss);
             if (mm.min < MIN_PS || mm.max > MAX_PS) cdo_warning("Surface pressure out of range (min=%g max=%g)!", mm.min, mm.max);
 
             // check range of geop
-            mm = array_min_max_mask(gridsize, fis1.data(), imiss);
+            mm = array_min_max_mask(fis1.data(), gridsize, imiss);
             if (mm.min < MIN_FIS || mm.max > MAX_FIS) cdo_warning("Orography out of range (min=%g max=%g)!", mm.min, mm.max);
           }
 
@@ -700,8 +700,8 @@ public:
               {
                 auto offset = gridsize * levelID;
                 auto mm = [&]() {
-                  if (memType == MemType::Float) { return array_min_max_mask(gridsize, &f_t1[offset], imiss); }
-                  else { return array_min_max_mask(gridsize, &d_t1[offset], imiss); }
+                  if (memType == MemType::Float) { return array_min_max_mask(&f_t1[offset], gridsize, imiss); }
+                  else { return array_min_max_mask(&d_t1[offset], gridsize, imiss); }
                 }();
 
                 if (mm.min < MIN_T || mm.max > MAX_T)
@@ -719,8 +719,8 @@ public:
                   corr_hum(gridsize, &d_q1[offset], MIN_Q);
 
                 auto mm = [&]() {
-                  if (memType == MemType::Float) { return array_min_max_mask(gridsize, &f_q1[offset], imiss); }
-                  else { return array_min_max_mask(gridsize, &d_q1[offset], imiss); }
+                  if (memType == MemType::Float) { return array_min_max_mask(&f_q1[offset], gridsize, imiss); }
+                  else { return array_min_max_mask(&d_q1[offset], gridsize, imiss); }
                 }();
                 if (mm.min < MIN_Q || mm.max > MAX_Q)
                   cdo_warning("Input humidity at level %d out of range (min=%g max=%g)!", levelID + 1, mm.min, mm.max);
