@@ -129,7 +129,7 @@ remap_normalize_field(NormOpt normOpt, size_t gridsize, Varray<T> &array, T miss
     {
       for (size_t i = 0; i < gridsize; ++i)
         {
-          if (dbl_is_not_equal(array[i], missval))
+          if (fp_is_not_equal(array[i], missval))
             {
               auto gridError = tgtGrid.cell_frac[i] * tgtGrid.cell_area[i];
               array[i] = (std::fabs(gridError) > 0.0) ? (array[i] / gridError) : missval;
@@ -140,7 +140,7 @@ remap_normalize_field(NormOpt normOpt, size_t gridsize, Varray<T> &array, T miss
     {
       for (size_t i = 0; i < gridsize; ++i)
         {
-          if (dbl_is_not_equal(array[i], missval))
+          if (fp_is_not_equal(array[i], missval))
             {
               array[i] = (std::fabs(tgtGrid.cell_frac[i]) > 0.0) ? (array[i] / tgtGrid.cell_frac[i]) : missval;
             }
@@ -503,7 +503,7 @@ public:
 
                 if (gridIsCircular(var.gridID) && !extrapolateIsSet) remapExtrapolate = true;
 
-                remap_set_mask(var.gridsize, field1, numMissVals1, var.missval, imask);
+                remap_set_mask(field1, var.gridsize, numMissVals1, var.missval, imask);
 
                 int remapIndex = -1;
                 for (remapIndex = numRemaps - 1; remapIndex >= 0; remapIndex--)
@@ -620,7 +620,7 @@ public:
                         if (remap.srcGrid.rank != 2 && remapOrder == 2)
                           cdo_abort("Second order remapping is not available for unstructured grids!");
 
-                        remap_gradients(remap.srcGrid, field1, gradients);
+                        remap_gradients(field1, remap.srcGrid, gradients);
                       }
 
                     if (Options::cdoVerbose && operfunc == REMAPNN && gridsize2 == 1)
