@@ -33,6 +33,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Replacevalues> registration = RegisterEntry<Replacevalues>(module);
+
   int SETVALS, SETRTOC, SETRTOC2;
   int nvals = 0;
   std::vector<double> fltarr;
@@ -52,9 +53,8 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     SETVALS = module.get_id("setvals");
     SETRTOC = module.get_id("setrtoc");
     SETRTOC2 = module.get_id("setrtoc2");
@@ -89,8 +89,8 @@ public:
 
     streamID1 = cdo_open_read(0);
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = vlistDuplicate(vlistID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
@@ -100,18 +100,18 @@ public:
 
     cdo_def_vlist(streamID2, vlistID2);
 
-    const auto gridsizemax = vlistGridsizeMax(vlistID1);
+    auto gridsizemax = vlistGridsizeMax(vlistID1);
     array = Varray<double>(gridsizemax);
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -123,18 +123,19 @@ public:
             cdo_inq_record(streamID1, &varID, &levelID);
             size_t numMissVals;
             cdo_read_record(streamID1, array.data(), &numMissVals);
+            const auto &var = varList1.vars[varID];
 
-            const auto gridsize = varList1[varID].gridsize;
-            const auto missval = varList1[varID].missval;
+            auto gridsize = var.gridsize;
+            auto missval = var.missval;
 
             if (operatorID == SETVALS)
               {
                 for (size_t i = 0; i < gridsize; ++i)
-                  if (!DBL_IS_EQUAL(array[i], missval))
+                  if (fp_is_not_equal(array[i], missval))
                     {
                       for (int j = 0; j < nvals; ++j)
                         {
-                          if (DBL_IS_EQUAL(array[i], fltarr[j * 2]))
+                          if (fp_is_equal(array[i], fltarr[j * 2]))
                             {
                               array[i] = fltarr[j * 2 + 1];
                               break;
@@ -145,7 +146,7 @@ public:
             else if (operatorID == SETRTOC)
               {
                 for (size_t i = 0; i < gridsize; ++i)
-                  if (!DBL_IS_EQUAL(array[i], missval))
+                  if (fp_is_not_equal(array[i], missval))
                     {
                       if (array[i] >= rmin && array[i] <= rmax) array[i] = newval;
                     }
@@ -153,7 +154,7 @@ public:
             else if (operatorID == SETRTOC2)
               {
                 for (size_t i = 0; i < gridsize; ++i)
-                  if (!DBL_IS_EQUAL(array[i], missval)) { array[i] = (array[i] >= rmin && array[i] <= rmax) ? newval : newval2; }
+                  if (fp_is_not_equal(array[i], missval)) { array[i] = (array[i] >= rmin && array[i] <= rmax) ? newval : newval2; }
               }
 
             cdo_def_record(streamID2, varID, levelID);
@@ -163,8 +164,9 @@ public:
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
