@@ -27,13 +27,14 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Seascount",
-    .operators = { { "seascount"} },
+    .operators = { { "seascount" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_BOTH,  // Allowed number type
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Seascount> registration = RegisterEntry<Seascount>(module);
+
   CdiDateTime vDateTime0{};
   int seas0 = 0;
   int oldmon = 0;
@@ -44,18 +45,13 @@ public:
   int taxisID1;
   int taxisID2;
 
-  int maxrecs;
-
   VarList varList1;
-  Field field;
-  std::vector<RecordInfo> recList;
-  FieldVector2D vars1;
+  FieldVector2D varsData1;
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_check_argc(0);
 
     streamID1 = cdo_open_read(0);
@@ -70,16 +66,18 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
+    varList1 = VarList(vlistID1);
 
-    varList_init(varList1, vlistID1);
-
-    fields_from_vlist(vlistID1, vars1, FIELD_VEC);
+    field2D_init(varsData1, varList1, FIELD_VEC);
   }
+
   void
-  run()
+  run() override
   {
+    auto maxRecords = varList1.numRecords();
+    std::vector<RecordInfo> recordList(maxRecords);
+    Field field;
+
     auto seasonStart = get_season_start();
 
     int tsID = 0;
@@ -122,22 +120,22 @@ public:
               {
                 int varID, levelID;
                 cdo_inq_record(streamID1, &varID, &levelID);
-                const auto &var = varList1[varID];
+                const auto &var = varList1.vars[varID];
 
-                if (tsID == 0) recList[recID].set(varID, levelID);
+                if (tsID == 0) recordList[recID].set(varID, levelID);
 
-                auto fieldsize = vars1[varID][levelID].size;
+                auto fieldsize = varsData1[varID][levelID].size;
 
                 if (numSets == 0)
                   {
-                    for (size_t i = 0; i < fieldsize; ++i) vars1[varID][levelID].vec_d[i] = vars1[varID][levelID].missval;
-                    vars1[varID][levelID].numMissVals = fieldsize;
+                    for (size_t i = 0; i < fieldsize; ++i) varsData1[varID][levelID].vec_d[i] = varsData1[varID][levelID].missval;
+                    varsData1[varID][levelID].numMissVals = fieldsize;
                   }
 
                 field.init(var);
                 cdo_read_record(streamID1, field);
 
-                field2_count(vars1[varID][levelID], field);
+                field2_count(varsData1[varID][levelID], field);
               }
 
             vDateTime0 = vDateTime;
@@ -150,21 +148,22 @@ public:
         taxisDefVdatetime(taxisID2, vDateTime0);
         cdo_def_timestep(streamID2, otsID);
 
-        for (int recID = 0; recID < maxrecs; ++recID)
+        for (int recID = 0; recID < maxRecords; ++recID)
           {
-            auto [varID, levelID] = recList[recID].get();
-            if (otsID && varList1[varID].isConstant) continue;
+            auto [varID, levelID] = recordList[recID].get();
+            if (otsID && varList1.vars[varID].isConstant) continue;
 
             cdo_def_record(streamID2, varID, levelID);
-            cdo_write_record(streamID2, vars1[varID][levelID].vec_d.data(), vars1[varID][levelID].numMissVals);
+            cdo_write_record(streamID2, varsData1[varID][levelID].vec_d.data(), varsData1[varID][levelID].numMissVals);
           }
 
         if (nrecs == 0) break;
         otsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
