@@ -37,6 +37,7 @@ public:
     .constraints = { 3, 1, NoRestriction },
   };
   inline static RegisterEntry<Seaspctl> registration = RegisterEntry<Seaspctl>(module);
+
   TimeStat timestatDate{ TimeStat::MEAN };
   int seas0 = 0;
   int oldmon = 0;
@@ -51,21 +52,16 @@ public:
   int taxisID3;
   int taxisID4;
 
-  Field field1, field2;
   DateTimeList dtlist;
   VarList varList1;
-  int maxrecs;
   double pn;
 
-  std::vector<RecordInfo> recList;
   HistogramSet hset;
-  FieldVector constFields;
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_input_arg("percentile number");
     pn = parameter_to_double(cdo_operator_argv(0));
 
@@ -80,8 +76,12 @@ public:
 
     vlist_unpack(vlistID4);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
-    vlist_compare(vlistID1, vlistID3, CmpVlist::All);
+    varList1 = VarList(vlistID1);
+    VarList varList2(vlistID2);
+    VarList varList3(vlistID3);
+
+    varList_compare(varList1, varList2);
+    varList_compare(varList1, varList3);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = vlistInqTaxis(vlistID2);
@@ -95,30 +95,26 @@ public:
     streamID4 = cdo_open_write(3);
     cdo_def_vlist(streamID4, vlistID4);
 
-    auto ntsteps = vlistNtsteps(vlistID1);
-    auto nvars = vlistNvars(vlistID1);
-
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
-    constFields = FieldVector(maxrecs);
+    auto numVars = varList1.numVars();
+    auto numSteps = varList1.numSteps();
 
     dtlist.set_stat(timestatDate);
     dtlist.set_calendar(taxisInqCalendar(taxisID1));
 
-    varList_init(varList1, vlistID1);
+    hset = HistogramSet(numVars, numSteps);
 
-    hset = HistogramSet(nvars, ntsteps);
-
-    for (int varID = 0; varID < nvars; ++varID)
-      {
-        const auto &var = varList1[varID];
-        hset.createVarLevels(varID, var.nlevels, var.gridsize);
-      }
+    for (const auto &var : varList1.vars) hset.createVarLevels(var.ID, var.nlevels, var.gridsize);
   }
 
   void
-  run()
+  run() override
   {
+    auto maxRecords = varList1.numRecords();
+    std::vector<RecordInfo> recordList(maxRecords);
+    FieldVector constFields(maxRecords);
+
+    Field field1, field2;
+
     auto seasonStart = get_season_start();
 
     int tsID = 0;
@@ -140,7 +136,7 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID2, &varID, &levelID);
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             field1.init(var);
             cdo_read_record(streamID2, field1);
 
@@ -184,9 +180,9 @@ public:
               {
                 int varID, levelID;
                 cdo_inq_record(streamID1, &varID, &levelID);
-                const auto &var = varList1[varID];
+                const auto &var = varList1.vars[varID];
 
-                if (tsID == 0) recList[recID].set(varID, levelID);
+                if (tsID == 0) recordList[recID].set(varID, levelID);
 
                 if (tsID == 0 && var.isConstant)
                   {
@@ -211,17 +207,17 @@ public:
         dtlist.stat_taxis_def_timestep(taxisID4, numSets);
         cdo_def_timestep(streamID4, otsID);
 
-        for (int recID = 0; recID < maxrecs; ++recID)
+        for (int recID = 0; recID < maxRecords; ++recID)
           {
-            auto [varID, levelID] = recList[recID].get();
-            if (otsID && varList1[varID].isConstant) continue;
+            auto [varID, levelID] = recordList[recID].get();
+            const auto &var = varList1.vars[varID];
+            if (otsID && var.isConstant) continue;
 
             cdo_def_record(streamID4, varID, levelID);
 
-            if (varList1[varID].isConstant) { cdo_write_record(streamID4, constFields[recID]); }
+            if (var.isConstant) { cdo_write_record(streamID4, constFields[recID]); }
             else
               {
-                const auto &var = varList1[varID];
                 field1.init(var);
                 hset.getVarLevelPercentiles(field1, varID, levelID, pn);
                 cdo_write_record(streamID4, field1);
@@ -234,7 +230,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID4);
     cdo_stream_close(streamID3);
