@@ -127,15 +127,13 @@ public:
   VarList varList1;
   VarList varList2;
 
-  Field field1, field2;
-
   std::vector<long> cellidx;
   std::vector<sindex_t> sindex;
   std::vector<bool> processVars;
 
 public:
   void
-  init()
+  init() override
   {
     int nind = 0;
     std::vector<int> indarr;
@@ -216,12 +214,12 @@ public:
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     auto nvars = vlistNvars(vlistID1);
     processVars = std::vector<bool>(nvars, false);
 
-    auto ngrids = vlistNgrids(vlistID1);
+    auto ngrids = vlistNumGrids(vlistID1);
     sindex = std::vector<sindex_t>(ngrids);
 
     ncells = nind;
@@ -270,7 +268,7 @@ public:
         vlistChangeGridIndex(vlistID2, index, gridID2);
 
         for (int varID = 0; varID < nvars; ++varID)
-          if (gridID1 == varList1[varID].gridID) processVars[varID] = true;
+          if (gridID1 == varList1.vars[varID].gridID) processVars[varID] = true;
       }
 
     {
@@ -281,15 +279,17 @@ public:
       if (varID >= nvars) cdo_abort("No variables selected!");
     }
 
-    varList_init(varList2, vlistID2);
+    varList2 = VarList(vlistID2);
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
   }
 
   void
-  run()
+  run() override
   {
+    Field field1, field2;
+
     int tsID = 0;
     while (true)
       {
@@ -303,14 +303,14 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field1.init(varList1[varID]);
+            field1.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field1);
 
             cdo_def_record(streamID2, varID, levelID);
 
             if (processVars[varID])
               {
-                field2.init(varList2[varID]);
+                field2.init(varList1.vars[varID]);
                 select_index(field1, field2, ncells, cellidx);
 
                 if (field1.numMissVals) field2.numMissVals = field_num_mv(field2);
@@ -325,7 +325,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
