@@ -177,7 +177,7 @@ public:
   int vlistID2;
 
   int operatorID;
-  int nvars;
+  int numVars;
   size_t gridsizemax;
 
   bool lcopy = false;
@@ -187,7 +187,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     SELMULTI = module.get_id("selmulti");
     DELMULTI = module.get_id("delmulti");
@@ -230,17 +230,17 @@ public:
 
     vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     vlistClearFlag(vlistID1);
-    nvars = vlistNvars(vlistID1);
+    numVars = varList1.numVars();
 
-    Debug(cdoDebugExt, " Total number of variables: %d", nvars);
+    Debug(cdoDebugExt, " Total number of variables: %d", numVars);
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        const auto &var = varList1[varID];
-        const auto ltype = zaxis_to_ltype(var.zaxisID);
+        const auto &var = varList1.vars[varID];
+        auto ltype = zaxis_to_ltype(var.zaxisID);
 
         for (int levelID = 0; levelID < var.nlevels; ++levelID)
           {
@@ -262,9 +262,9 @@ public:
                 // (int)level, nvars, varID);
                 // Note: When the list is Empty then function
                 // checkListContainsInt() also returns true !
-                const auto selcode = checkListContainsInt(var.code, tuplerec->codeLST, tuplerec->ncodes);
-                const auto selltype = checkListContainsInt(ltype, tuplerec->levelTypeLST, tuplerec->nlevelTypes);
-                const auto sellevel = checkListContainsInt((int) level, tuplerec->levelLST, tuplerec->nlevels);
+                auto selcode = checkListContainsInt(var.code, tuplerec->codeLST, tuplerec->ncodes);
+                auto selltype = checkListContainsInt(ltype, tuplerec->levelTypeLST, tuplerec->nlevelTypes);
+                auto sellevel = checkListContainsInt((int) level, tuplerec->levelLST, tuplerec->nlevels);
                 if (selcode && selltype && sellevel)
                   {
                     if (operatorID == SELMULTI)
@@ -370,11 +370,11 @@ public:
     vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
 
     {
-      nvars = vlistNvars(vlistID2);
+      numVars = vlistNvars(vlistID2);
       int varID;
-      for (varID = 0; varID < nvars; ++varID)
+      for (varID = 0; varID < numVars; ++varID)
         if (vlistInqVarTimetype(vlistID2, varID) != TIME_CONSTANT) break;
-      if (varID == nvars) vlistDefNtsteps(vlistID2, 0);
+      if (varID == numVars) vlistDefNtsteps(vlistID2, 0);
     }
 
     taxisID1 = vlistInqTaxis(vlistID1);
@@ -388,13 +388,14 @@ public:
     if (vlistNumber(vlistID1) != CDI_REAL) gridsizemax *= 2;
     array = Varray<double>(gridsizemax);
   }
+
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -404,24 +405,24 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
 
             if (vlistInqFlag(vlistID1, varID, levelID) == true)
               {
                 int simpleMath = 0;  // 1:  simple array arithmetics ( *,+), 0: do nothing
                 double scale = 1.0;
                 double offset = 0.0;
-                const auto code = var.code;
-                const auto level = zaxisInqLevel(var.zaxisID, levelID);
-                const auto ltype = zaxis_to_ltype(var.zaxisID);
+                auto code = var.code;
+                auto level = zaxisInqLevel(var.zaxisID, levelID);
+                auto ltype = zaxis_to_ltype(var.zaxisID);
                 for (int ii = 0; ii < NUMTUPLES; ++ii)
                   {
                     TUPLEREC *tuplerec = getSelTuple(ii);
                     // Note: When the list is Empty then function
                     // checkListContainsInt() also returns true !
-                    const auto selcode = checkListContainsInt(code, tuplerec->codeLST, tuplerec->ncodes);
-                    const auto selltype = checkListContainsInt(ltype, tuplerec->levelTypeLST, tuplerec->nlevelTypes);
-                    const auto sellevel = checkListContainsInt((int) level, tuplerec->levelLST, tuplerec->nlevels);
+                    auto selcode = checkListContainsInt(code, tuplerec->codeLST, tuplerec->ncodes);
+                    auto selltype = checkListContainsInt(ltype, tuplerec->levelTypeLST, tuplerec->nlevelTypes);
+                    auto sellevel = checkListContainsInt((int) level, tuplerec->levelLST, tuplerec->nlevels);
                     lcopy = true;
                     if (selcode && selltype && sellevel)
                       {
@@ -430,8 +431,8 @@ public:
                             if (cdoDebugExt)
                               cdo_print(" Processing: (code %d, ltype %d, level %d);  nvars=%d, varID=%d => (selcode %d, selltype "
                                         "%d, sellevel %d) => change (%d,%d,%d)",
-                                        code, ltype, (int) level, nvars, varID, selcode, selltype, sellevel, tuplerec->changedCode,
-                                        tuplerec->changedLevelType, tuplerec->changedLevel);
+                                        code, ltype, (int) level, numVars, varID, selcode, selltype, sellevel,
+                                        tuplerec->changedCode, tuplerec->changedLevelType, tuplerec->changedLevel);
                             if ((tuplerec->changedCode == -1) && (tuplerec->changedLevelType == -1)
                                 && (tuplerec->changedLevel == -1))
                               cdo_print(" WARNING: Cannot CHANGE identification!");
@@ -450,7 +451,7 @@ public:
                             if (cdoDebugExt)
                               cdo_print(" Processing: (code %d, ltype %d, level %d);  nvars=%d, varID=%d => (selcode %d, "
                                         "selltype %d, sellevel %d)",
-                                        code, ltype, (int) level, nvars, varID, selcode, selltype, sellevel);
+                                        code, ltype, (int) level, numVars, varID, selcode, selltype, sellevel);
                           }
                         simpleMath = tuplerec->simpleMath;  // 1:  simple array arithmetics ( *,+),
                                                             // 0: do nothing
@@ -464,8 +465,8 @@ public:
                       }
                   }  // end of for (ii=0; ii<NUMTUPLES ..
 
-                const auto varID2 = vlistFindVar(vlistID2, varID);
-                const auto levelID2 = vlistFindLevel(vlistID2, varID, levelID);
+                auto varID2 = vlistFindVar(vlistID2, varID);
+                auto levelID2 = vlistFindLevel(vlistID2, varID, levelID);
 
                 // tijdelijk PATCH M.K.
                 if ((varID2 == -1) || (levelID2 == -1))
@@ -502,7 +503,7 @@ public:
                                     "SCALE=%f; OFFSET=%f",
                                     recID, code, ltype, (int) (level), varID, levelID, scale, offset);
                         for (size_t li = 0; li < gridsizemax; ++li)
-                          if (!DBL_IS_EQUAL(array[li], var.missval))
+                          if (!fp_is_equal(array[li], var.missval))
                             {
                               array[li] = scale * (array[li] - offset);
                               // If SCALE and/or OFFSET are defined, then the data
@@ -518,8 +519,9 @@ public:
         tsID++;
       }  // end while
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID2);
