@@ -18,7 +18,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Seloperator",
-    .operators = { { "seloperator"} },
+    .operators = { { "seloperator" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -35,16 +35,13 @@ public:
   int taxisID1;
   int taxisID2;
 
-  int varID;
-
-  Field field;
   VarList varList1;
 
   bool dataIsUnchanged;
 
 public:
   void
-  init()
+  init() override
   {
     bool selfound = false;
 
@@ -61,7 +58,7 @@ public:
     vlistID1 = cdo_stream_inq_vlist(streamID1);
 
     auto nvars = vlistNvars(vlistID1);
-    for (varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < nvars; ++varID)
       {
         auto code = vlistInqVarCode(vlistID1, varID);
         auto zaxisID = vlistInqVarZaxis(vlistID1, varID);
@@ -71,7 +68,7 @@ public:
         for (int levID = 0; levID < nlevels; levID++)
           {
             auto level = cdo_zaxis_inq_level(zaxisID, levID);
-            auto sellevel = (cdo_operator_argc() == 3) ? IS_EQUAL(level, slevel) : true;
+            auto sellevel = (cdo_operator_argc() == 3) ? is_equal(level, slevel) : true;
             auto selcode = (scode == -1 || scode == code);
             auto selltype = (sltype == -1 || sltype == ltype);
 
@@ -96,14 +93,15 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
 
   void
-  run()
+  run() override
   {
+    Field field;
+
     int tsID = 0;
-    int levelID;
     while (true)
       {
         auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
@@ -114,7 +112,7 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            cdo_inq_record(streamID1, &varID, &levelID);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
             if (vlistInqFlag(vlistID1, varID, levelID) == true)
               {
                 auto varID2 = vlistFindVar(vlistID2, varID);
@@ -124,7 +122,7 @@ public:
                 if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
                 else
                   {
-                    field.init(varList1[varID]);
+                    field.init(varList1.vars[varID]);
                     cdo_read_record(streamID1, field);
                     cdo_write_record(streamID2, field);
                   }
@@ -136,7 +134,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID2);
