@@ -41,7 +41,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     operator_input_arg("records");
@@ -62,8 +62,8 @@ public:
         || filetype == CDI_FILETYPE_NC5 || filetype == CDI_FILETYPE_NCZARR)
       cdo_abort("This operator does not work on NetCDF data!");
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = vlistDuplicate(vlistID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
@@ -74,13 +74,13 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int recordID = 0;
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -108,7 +108,7 @@ public:
       }
   }
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
