@@ -249,16 +249,16 @@ public:
   int taxisID1;
   int taxisID2;
 
-  int ngrids;
+  int numGrids;
 
-  Field field1, field2;
-  VarList varList1, varList2;
+  VarList varList1;
+  VarList varList2;
   std::vector<bool> varIDs;
   std::vector<RegionInfo> regions;
 
 public:
   void
-  init()
+  init() override
   {
     SELREGION = module.get_id("selregion");
     SELCIRCLE = module.get_id("selcircle");
@@ -272,15 +272,17 @@ public:
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
+    varList1 = VarList(vlistID1);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    auto nvars = vlistNvars(vlistID1);
-    varIDs = std::vector<bool>(nvars, false);
+    auto numVars = varList1.numVars();
+    varIDs = std::vector<bool>(numVars, false);
 
-    ngrids = vlistNgrids(vlistID1);
-    regions = std::vector<RegionInfo>(ngrids);
+    numGrids = vlistNumGrids(vlistID1);
+    regions = std::vector<RegionInfo>(numGrids);
 
     int numFiles = 0;
     CirclePoint cpoint;
@@ -306,7 +308,7 @@ public:
         cpoint.lat *= DEG2RAD;
       }
 
-    for (int index = 0; index < ngrids; ++index)
+    for (int index = 0; index < numGrids; ++index)
       {
         auto &region = regions[index];
         auto gridID1 = vlistGrid(vlistID1, index);
@@ -334,23 +336,24 @@ public:
 
                 vlistChangeGridIndex(vlistID2, index, gridID2);
 
-                for (int varID = 0; varID < nvars; ++varID)
-                  if (gridID1 == vlistInqVarGrid(vlistID1, varID)) varIDs[varID] = true;
+                for (const auto &var : varList1.vars)
+                  if (gridID1 == var.gridID) varIDs[var.ID] = true;
               }
           }
         else { cdo_abort("Unsupported grid type: %s", gridNamePtr(gridtype)); }
       }
 
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
+    varList2 = VarList(vlistID2);
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
   }
 
   void
-  run()
+  run() override
   {
+    Field field1, field2;
+
     int tsID = 0;
     while (true)
       {
@@ -364,7 +367,7 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             field1.init(var);
             cdo_read_record(streamID1, field1);
 
@@ -374,11 +377,11 @@ public:
               {
                 auto gridID1 = var.gridID;
                 int index;
-                for (index = 0; index < ngrids; ++index)
+                for (index = 0; index < numGrids; ++index)
                   if (gridID1 == regions[index].gridID1) break;
-                if (index == ngrids) cdo_abort("Internal problem, grid not found!");
+                if (index == numGrids) cdo_abort("Internal problem, grid not found!");
 
-                field2.init(varList2[varID]);
+                field2.init(varList2.vars[varID]);
                 window_cell(field1, field2, regions[index].cellidx);
 
                 if (field1.numMissVals) field_num_mv(field2);
@@ -393,7 +396,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
