@@ -33,8 +33,8 @@ isosurface_kernel(double isoval, size_t numMissVals, const Varray<double> &level
 
           if (numMissVals)
             {
-              auto hasMissvals1 = dbl_is_equal(val1, missval);
-              auto hasMissvals2 = dbl_is_equal(val2, missval);
+              auto hasMissvals1 = fp_is_equal(val1, missval);
+              auto hasMissvals2 = fp_is_equal(val2, missval);
               if (hasMissvals1 && hasMissvals2) continue;
               if (hasMissvals1 && is_equal(isoval, val2)) data2D[i] = levels[k + 1];
               if (hasMissvals2 && is_equal(isoval, val1)) data2D[i] = levels[k];
@@ -89,7 +89,7 @@ layer_value_min_kernel(int nlevels, size_t gridsize, T missval, const Varray<con
       for (int k = 0; k < nlevels; ++k)
         {
           auto val = data3D[k][i];
-          if (!dbl_is_equal(val, missval))
+          if (fp_is_not_equal(val, missval))
             {
               data2D[i] = val;
               break;
@@ -134,7 +134,7 @@ layer_value_max_kernel(int nlevels, size_t gridsize, T missval, const Varray<con
       for (int k = nlevels - 1; k >= 0; --k)
         {
           auto val = data3D[k][i];
-          if (!dbl_is_equal(val, missval))
+          if (fp_is_not_equal(val, missval))
             {
               data2D[i] = val;
               break;
@@ -171,9 +171,11 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Selsurface",
+    // clang-format off
     .operators = { { "isosurface", SelsurfaceHelp },
                    { "bottomvalue", SelsurfaceHelp },
                    { "topvalue", SelsurfaceHelp } },
+    // clang-format on
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -200,7 +202,7 @@ public:
 
   VarList varList1;
   Field field2;
-  FieldVector2D vars1;
+  FieldVector2D varsData1;
 
   int nlevels;
   Varray<double> levels;
@@ -210,14 +212,11 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-ISOSURFACE = module.get_id("isosurface");
-BOTTOMVALUE = module.get_id("bottomvalue");
-TOPVALUE = module.get_id("topvalue");
-    // clang-format on
+    ISOSURFACE = module.get_id("isosurface");
+    BOTTOMVALUE = module.get_id("bottomvalue");
+    TOPVALUE = module.get_id("topvalue");
 
     operatorID = cdo_operator_id();
 
@@ -239,7 +238,7 @@ TOPVALUE = module.get_id("topvalue");
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    auto nzaxis = vlistNzaxis(vlistID1);
+    auto nzaxis = vlistNumZaxis(vlistID1);
     for (int i = 0; i < nzaxis; ++i)
       {
         auto zaxisID = vlistZaxis(vlistID1, i);
@@ -267,32 +266,31 @@ TOPVALUE = module.get_id("topvalue");
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     nvars = vlistNvars(vlistID1);
     isVar3D = std::vector<bool>(nvars);
     foundVar = std::vector<bool>(nvars);
 
-    fields_from_vlist(vlistID1, vars1);
+    field2D_init(varsData1, varList1);
 
     for (int varID = 0; varID < nvars; ++varID)
       {
-        const auto &var = varList1[varID];
+        const auto &var = varList1.vars[varID];
         isVar3D[varID] = (var.zaxisID == zaxisID1);
       }
   }
 
   void
-  run()
+  run() override
   {
-
     auto bottom_value_func = isReverse ? layer_value_max : layer_value_min;
     auto top_value_func = isReverse ? layer_value_min : layer_value_max;
     if (isPositive && positive_is_down(zaxisID1)) std::swap(bottom_value_func, top_value_func);
+
     int tsID = 0;
     while (true)
       {
-
         auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
@@ -305,8 +303,8 @@ TOPVALUE = module.get_id("topvalue");
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            const auto &var = varList1[varID];
-            auto &field1 = vars1[varID][levelID];
+            const auto &var = varList1.vars[varID];
+            auto &field1 = varsData1[varID][levelID];
             field1.init(var);
             cdo_read_record(streamID1, field1);
             foundVar[varID] = true;
@@ -316,14 +314,14 @@ TOPVALUE = module.get_id("topvalue");
           {
             if (foundVar[varID])
               {
-                const auto &var = varList1[varID];
+                const auto &var = varList1.vars[varID];
                 if (isVar3D[varID])
                   {
                     field2.init(var);
                     // clang-format off
-                  if      (operatorID == ISOSURFACE)  isosurface(isoval, nlevels, levels, vars1[varID], field2);
-                  else if (operatorID == BOTTOMVALUE) bottom_value_func(nlevels, vars1[varID], field2);
-                  else if (operatorID == TOPVALUE)    top_value_func(nlevels, vars1[varID], field2);
+                    if      (operatorID == ISOSURFACE)  isosurface(isoval, nlevels, levels, varsData1[varID], field2);
+                    else if (operatorID == BOTTOMVALUE) bottom_value_func(nlevels, varsData1[varID], field2);
+                    else if (operatorID == TOPVALUE)    top_value_func(nlevels, varsData1[varID], field2);
                     // clang-format on
 
                     cdo_def_record(streamID2, varID, 0);
@@ -334,7 +332,7 @@ TOPVALUE = module.get_id("topvalue");
                     for (int levelID = 0; levelID < var.nlevels; ++levelID)
                       {
                         cdo_def_record(streamID2, varID, levelID);
-                        cdo_write_record(streamID2, vars1[varID][levelID]);
+                        cdo_write_record(streamID2, varsData1[varID][levelID]);
                       }
                   }
               }
@@ -343,10 +341,10 @@ TOPVALUE = module.get_id("topvalue");
         tsID++;
       }
   }
-  void
-  close()
-  {
 
+  void
+  close() override
+  {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
 
