@@ -27,7 +27,6 @@
 
 #include "cdo_options.h"
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "cdo_zaxis.h"
 #include "util_wildcards.h"
 #include "cdi_lockedIO.h"
@@ -72,14 +71,13 @@ public:
   int taxisID1;
   int taxisID2;
 
-  Field field;
   VarList varList1;
 
   bool dataIsUnchanged;
 
 public:
   void
-  init()
+  init() override
   {
     int nsel = 0;
     char paramstr[32];
@@ -156,7 +154,7 @@ public:
     auto nvars = vlistNvars(vlistID1);
     std::vector<bool> vars(nvars);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     if (operatorID == SELGRID && !args_are_numeric && nsel == 1 && argnames[0].starts_with("var="))
       {
@@ -166,7 +164,7 @@ public:
 
         for (int varID = 0; varID < nvars; ++varID)
           {
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             if (var.name == gridvarname)
               {
                 gridnum = 1 + vlistGridIndex(vlistID1, var.gridID);
@@ -184,7 +182,7 @@ public:
       {
         vars[varID] = doDelete;
 
-        const auto &var = varList1[varID];
+        const auto &var = varList1.vars[varID];
         auto stdname = cdo::inq_key_string(vlistID1, varID, CDI_KEY_STDNAME);
         auto tabnum = tableInqNum(vlistInqVarTable(vlistID1, varID));
         auto grididx = vlistGridIndex(vlistID1, var.gridID);
@@ -256,7 +254,7 @@ public:
       {
         if (vars[varID])
           {
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             if (zaxisInqType(var.zaxisID) == ZAXIS_HYBRID)
               {
                 auto psvarid = varList_get_psvarid(varList1, var.zaxisID);
@@ -326,8 +324,10 @@ public:
   }
 
   void
-  run()
+  run() override
   {
+    Field field;
+
     int tsID = 0;
     while (true)
       {
@@ -350,7 +350,7 @@ public:
                 if (dataIsUnchanged) { cdo_copy_record(streamID2, streamID1); }
                 else
                   {
-                    const auto &var = varList1[varID];
+                    const auto &var = varList1.vars[varID];
                     field.init(var);
                     cdo_read_record(streamID1, field);
                     cdo_write_record(streamID2, field);
@@ -363,7 +363,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
