@@ -14,7 +14,6 @@
 #include <cdi.h>
 
 #include "process_int.h"
-#include "cdo_vlist.h"
 #include "field_functions.h"
 
 class Selyearidx : public Process
@@ -23,47 +22,52 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Selyearidx",
-    .operators = { { "selyearidx", SelyearidxHelp }, { "seltimeidx", 1, 0, SelyearidxHelp } },
+    // clang-format off
+    .operators = { { "selyearidx", 0, 0, SelyearidxHelp },
+                   { "seltimeidx", 1, 0, SeltimeidxHelp } },
+    // clang-format on
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
     .constraints = { 2, 1, NoRestriction },
   };
   inline static RegisterEntry<Selyearidx> registration = RegisterEntry<Selyearidx>(module);
+
   CdoStreamID streamID1;
   CdoStreamID streamID2;
   CdoStreamID streamID3;
+  int vlistID1;
+  int vlistID2;
 
   int taxisID1;
   int taxisID2;
   int taxisID3;
 
-  bool ltime;
-  int maxrecs;
+  bool allSteps;
   size_t gridsizemax;
 
-  FieldVector2D vars1, vars2;
-  std::vector<RecordInfo> recList;
-  VarList varList1, varList2;
+  VarList varList1;
+  VarList varList2;
   Varray<double> array;
 
 public:
   void
-  init()
+  init() override
   {
-
-    ltime = cdo_operator_f1(cdo_operator_id());
+    allSteps = cdo_operator_f1(cdo_operator_id());
 
     streamID1 = cdo_open_read(0);
-    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    vlistID1 = cdo_stream_inq_vlist(streamID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
 
     streamID2 = cdo_open_read(1);
-    auto vlistID2 = cdo_stream_inq_vlist(streamID2);
+    vlistID2 = cdo_stream_inq_vlist(streamID2);
     taxisID2 = vlistInqTaxis(vlistID2);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
+    varList_compare(varList1, varList2);
 
     auto vlistID3 = vlistDuplicate(vlistID2);
     taxisID3 = taxisDuplicate(taxisID1);
@@ -72,35 +76,32 @@ public:
     streamID3 = cdo_open_write(2);
     cdo_def_vlist(streamID3, vlistID3);
 
-    varList_init(varList1, vlistID1);
-    varList_init(varList2, vlistID2);
-
-    maxrecs = vlistNrecs(vlistID1);
-
-    recList = std::vector<RecordInfo>(maxrecs);
-
     gridsizemax = vlistGridsizeMax(vlistID1);
 
     array = Varray<double>(gridsizemax);
-
-    fields_from_vlist(vlistID1, vars1, FIELD_VEC);
-    fields_from_vlist(vlistID2, vars2, FIELD_VEC);
-
-    const int nvars = vlistNvars(vlistID1);
-    for (int varID = 0; varID < nvars; ++varID)
-      {
-        const auto &var = varList1[varID];
-        auto missval = varList2[varID].missval;
-        for (int levelID = 0; levelID < var.nlevels; ++levelID)
-          {
-            for (size_t i = 0; i < var.gridsize; ++i) vars2[varID][levelID].vec_d[i] = missval;
-          }
-      }
   }
 
   void
-  run()
+  run() override
   {
+    auto maxRecords = varList1.numRecords();
+    std::vector<RecordInfo> recordList(maxRecords);
+
+    FieldVector2D varsData1, varsData2;
+    field2D_init(varsData1, varList1, FIELD_VEC);
+    field2D_init(varsData2, varList2, FIELD_VEC);
+
+    auto numVars = varList1.numVars();
+    for (int varID = 0; varID < numVars; ++varID)
+      {
+        const auto &var = varList1.vars[varID];
+        auto missval = varList2.vars[varID].missval;
+        for (int levelID = 0; levelID < var.nlevels; ++levelID)
+          {
+            for (size_t i = 0; i < var.gridsize; ++i) varsData2[varID][levelID].vec_d[i] = missval;
+          }
+      }
+
     int tsID = 0;
     int tsID2 = 0;
     int tsID3 = 0;
@@ -111,17 +112,16 @@ public:
 
         auto year1 = taxisInqVdatetime(taxisID1).date.year;
 
-        auto lexactdate = (gridsizemax == 1 && nrecs == 1);
+        auto useExactDate = (gridsizemax == 1 && nrecs == 1);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            size_t numMissVals;
-            cdo_read_record(streamID1, vars1[varID][levelID].vec_d.data(), &numMissVals);
-            vars1[varID][levelID].numMissVals = numMissVals;
+            auto &var1 = varsData1[varID][levelID];
+            cdo_read_record(streamID1, var1.vec_d.data(), &var1.numMissVals);
 
-            if (tsID == 0) recList[recID].set(varID, levelID);
+            if (tsID == 0) recordList[recID].set(varID, levelID);
           }
 
         int nrecs2;
@@ -130,7 +130,7 @@ public:
           {
             auto year = taxisInqVdatetime(taxisID2).date.year;
 
-            if (ltime == false && year1 != year) break;
+            if (allSteps == false && year1 != year) break;
 
             for (int recID = 0; recID < nrecs2; ++recID)
               {
@@ -139,12 +139,14 @@ public:
                 size_t numMissVals;
                 cdo_read_record(streamID2, array.data(), &numMissVals);
 
-                const auto &var = varList2[varID];
+                const auto &var = varList2.vars[varID];
+                const auto &var1 = varsData1[varID][levelID];
+                auto &var2 = varsData2[varID][levelID];
                 for (size_t i = 0; i < var.gridsize; ++i)
-                  if (numSets == (int) std::lround(vars1[varID][levelID].vec_d[i]))
+                  if (numSets == (int) std::lround(var1.vec_d[i]))
                     {
-                      if (lexactdate) cdo_taxis_copy_timestep(taxisID3, taxisID2);
-                      vars2[varID][levelID].vec_d[i] = array[i];
+                      if (useExactDate) cdo_taxis_copy_timestep(taxisID3, taxisID2);
+                      var2.vec_d[i] = array[i];
                     }
               }
 
@@ -154,15 +156,15 @@ public:
 
         if (numSets)
           {
-            if (!lexactdate) cdo_taxis_copy_timestep(taxisID3, taxisID1);
+            if (!useExactDate) cdo_taxis_copy_timestep(taxisID3, taxisID1);
             cdo_def_timestep(streamID3, tsID3);
 
-            for (int recID = 0; recID < maxrecs; ++recID)
+            for (int recID = 0; recID < maxRecords; ++recID)
               {
-                auto [varID, levelID] = recList[recID].get();
-                if (tsID && varList1[varID].isConstant) continue;
+                auto [varID, levelID] = recordList[recID].get();
+                if (tsID && varList1.vars[varID].isConstant) continue;
 
-                auto &var2 = vars2[varID][levelID];
+                auto &var2 = varsData2[varID][levelID];
                 cdo_def_record(streamID3, varID, levelID);
                 cdo_write_record(streamID3, var2.vec_d.data(), field_num_miss(var2));
               }
@@ -183,7 +185,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID3);
     cdo_stream_close(streamID2);
