@@ -44,7 +44,7 @@ get_gridID(int vlistID1, bool operIndexBox)
 {
   std::vector<int> gridsFound;
 
-  auto ngrids = vlistNgrids(vlistID1);
+  auto ngrids = vlistNumGrids(vlistID1);
   for (int index = 0; index < ngrids; ++index)
     {
       auto gridID1 = vlistGrid(vlistID1, index);
@@ -74,20 +74,20 @@ get_gridID(int vlistID1, bool operIndexBox)
 }
 
 static std::vector<bool>
-get_processVars(int vlistID1, int gridID)
+get_processVars(const VarList &varList, int gridID)
 {
-  auto nvars = vlistNvars(vlistID1);
+  auto numVars = varList.numVars();
 
-  std::vector<bool> processVars(nvars, false);
+  std::vector<bool> processVars(numVars, false);
 
   int varID;
-  for (varID = 0; varID < nvars; ++varID)
-    if (gridID == vlistInqVarGrid(vlistID1, varID)) processVars[varID] = true;
+  for (varID = 0; varID < numVars; ++varID)
+    if (gridID == varList.vars[varID].gridID) processVars[varID] = true;
 
-  for (varID = 0; varID < nvars; ++varID)
+  for (varID = 0; varID < numVars; ++varID)
     if (processVars[varID]) break;
 
-  if (varID >= nvars) cdo_abort("No processable variable found!");
+  if (varID >= numVars) cdo_abort("No processable variable found!");
 
   return processVars;
 }
@@ -98,8 +98,9 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Setbox",
-    .operators = { { "setclonlatbox", 0, 0, "constant, western and eastern longitude and southern and northern latitude", SetboxHelp },
-                   { "setcindexbox", 0, 0, "constant, index of first and last longitude and index of first and last latitude", SetboxHelp } },
+    .operators
+    = { { "setclonlatbox", 0, 0, "constant, western and eastern longitude and southern and northern latitude", SetboxHelp },
+        { "setcindexbox", 0, 0, "constant, index of first and last longitude and index of first and last latitude", SetboxHelp } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -115,6 +116,7 @@ public:
   int taxisID2;
 
   int vlistID1;
+  VarList varList1;
 
   int gridID;
 
@@ -127,7 +129,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     SETCLONLATBOX = module.get_id("setclonlatbox");
     SETCINDEXBOX = module.get_id("setcindexbox");
@@ -144,9 +146,11 @@ public:
     streamID1 = cdo_open_read(0);
     vlistID1 = cdo_stream_inq_vlist(streamID1);
 
+    varList1 = VarList(vlistID1);
+
     gridID = get_gridID(vlistID1, operIndexBox);
 
-    processVars = get_processVars(vlistID1, gridID);
+    processVars = get_processVars(varList1, gridID);
 
     operator_input_arg(cdo_operator_enter(operatorID));
 
@@ -167,7 +171,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -190,7 +194,7 @@ public:
 
                 setcbox(constant, array.data(), gridID, selboxInfo);
 
-                auto missval = vlistInqVarMissval(vlistID1, varID);
+                auto missval = varList1.vars[varID].missval;
                 numMissVals = varray_num_mv(gridsize, array, missval);
                 cdo_def_record(streamID2, varID, levelID);
                 cdo_write_record(streamID2, array.data(), numMissVals);
@@ -202,7 +206,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
