@@ -149,7 +149,7 @@ public:
   int taxisID2;
 
   int numVars;
-  VarList varList;
+  VarList varList1;
   Varray<bool> selectVars;
 
   std::vector<std::string> varnames;
@@ -160,9 +160,8 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_input_arg(cdo_operator_enter(0));
 
     const auto nparam = cdo_operator_argc();
@@ -170,7 +169,7 @@ public:
 
     std::string maskfile;
     setgridcell_get_parameter(value, cells, varnames, maskfile);
-    if (DBL_IS_EQUAL(value, DBL_MAX)) cdo_abort("Parameter <values> not set!");
+    if (fp_is_equal(value, DBL_MAX)) cdo_abort("Parameter <values> not set!");
 
     if (cells.size() && maskfile.size()) cdo_abort("Too many parameter, choose either cell or mask!");
 
@@ -188,16 +187,16 @@ public:
 
     streamID1 = cdo_open_read(0);
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = vlistDuplicate(vlistID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    varList_init(varList, vlistID1);
+    varList1 = VarList(vlistID1);
 
-    numVars = varList.size();
+    numVars = varList1.numVars();
     selectVars = Varray<bool>(numVars, !varnames.size());
     if (varnames.size())
       {
@@ -206,7 +205,7 @@ public:
             auto varFound = false;
             for (int varID = 0; varID < numVars; ++varID)
               {
-                if (varname == varList[varID].name)
+                if (varname == varList1.vars[varID].name)
                   {
                     selectVars[varID] = true;
                     varFound = true;
@@ -222,12 +221,12 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -237,7 +236,7 @@ public:
           {
             int varID, levelID;
             cdo_inq_record(streamID1, &varID, &levelID);
-            field.init(varList[varID]);
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
 
             if (selectVars[varID])
@@ -257,8 +256,9 @@ public:
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
