@@ -20,17 +20,20 @@
 
 #include "process_int.h"
 #include "param_conversion.h"
+#include "progress.h"
 
 template <typename T>
 static size_t
-set_missval(size_t gridsize, Varray<T> &array, T missval, T new_missval)
+set_missval(size_t gridsize, Varray<T> &array, double mv, double mvNew)
 {
+  T missval = mv;
+  T missvalNew = mvNew;
   size_t numMissVals = 0;
   for (size_t i = 0; i < gridsize; ++i)
-    if (DBL_IS_EQUAL(array[i], missval) || DBL_IS_EQUAL(array[i], (float) missval) || DBL_IS_EQUAL(array[i], new_missval)
-        || DBL_IS_EQUAL(array[i], (float) new_missval))
+    if (fp_is_equal(array[i], missval) || fp_is_equal(array[i], (float) missval) || fp_is_equal(array[i], missvalNew)
+        || fp_is_equal(array[i], (float) missvalNew))
       {
-        array[i] = new_missval;
+        array[i] = missvalNew;
         numMissVals++;
       }
 
@@ -38,18 +41,18 @@ set_missval(size_t gridsize, Varray<T> &array, T missval, T new_missval)
 }
 
 static void
-set_missval(Field &field, double new_missval)
+set_missval(Field &field, double missvalNew)
 {
-  if (field.memType == MemType::Float)
-    field.numMissVals = set_missval(field.size, field.vec_f, (float) field.missval, (float) new_missval);
-  else
-    field.numMissVals = set_missval(field.size, field.vec_d, field.missval, new_missval);
+  auto func = [&](auto &v, auto size, double mv) { return set_missval(size, v, mv, missvalNew); };
+  field.numMissVals = field_operation(func, field, field.size, field.missval);
 }
 
 template <typename T>
 static size_t
-set_const_to_miss(size_t gridsize, Varray<T> &array, T missval, T rconst)
+set_const_to_miss(size_t gridsize, Varray<T> &array, double _missval, double _rconst)
 {
+  T missval = _missval;
+  T rconst = _rconst;
   size_t numMissVals = 0;
   if (std::isnan(rconst))
     {
@@ -63,7 +66,7 @@ set_const_to_miss(size_t gridsize, Varray<T> &array, T missval, T rconst)
   else
     {
       for (size_t i = 0; i < gridsize; ++i)
-        if (DBL_IS_EQUAL(array[i], rconst) || DBL_IS_EQUAL(array[i], (float) rconst))
+        if (fp_is_equal(array[i], rconst) || fp_is_equal(array[i], (float) rconst))
           {
             array[i] = missval;
             numMissVals++;
@@ -76,18 +79,18 @@ set_const_to_miss(size_t gridsize, Varray<T> &array, T missval, T rconst)
 static void
 set_const_to_miss(Field &field, double rconst)
 {
-  if (field.memType == MemType::Float)
-    field.numMissVals += set_const_to_miss(field.size, field.vec_f, (float) field.missval, (float) rconst);
-  else
-    field.numMissVals += set_const_to_miss(field.size, field.vec_d, field.missval, rconst);
+  auto func = [&](auto &v, auto size, double mv) { return set_const_to_miss(size, v, mv, rconst); };
+  field.numMissVals += field_operation(func, field, field.size, field.missval);
 }
 
 template <typename T>
 static size_t
-set_miss_to_const(size_t gridsize, Varray<T> &array, T missval, T rconst)
+set_miss_to_const(size_t gridsize, Varray<T> &array, double _missval, double _rconst)
 {
+  T missval = _missval;
+  T rconst = _rconst;
   for (size_t i = 0; i < gridsize; ++i)
-    if (DBL_IS_EQUAL(array[i], missval) || DBL_IS_EQUAL(array[i], (float) missval)) { array[i] = rconst; }
+    if (fp_is_equal(array[i], missval) || fp_is_equal(array[i], (float) missval)) { array[i] = rconst; }
 
   return 0;
 }
@@ -95,16 +98,17 @@ set_miss_to_const(size_t gridsize, Varray<T> &array, T missval, T rconst)
 static void
 set_miss_to_const(Field &field, double rconst)
 {
-  if (field.memType == MemType::Float)
-    field.numMissVals = set_miss_to_const(field.size, field.vec_f, (float) field.missval, (float) rconst);
-  else
-    field.numMissVals = set_miss_to_const(field.size, field.vec_d, field.missval, rconst);
+  auto func = [&](auto &v, auto size, double mv) { return set_miss_to_const(size, v, mv, rconst); };
+  field.numMissVals = field_operation(func, field, field.size, field.missval);
 }
 
 template <typename T>
 static size_t
-set_range_to_miss(size_t gridsize, Varray<T> &array, T missval, T rmin, T rmax)
+set_range_to_miss(size_t gridsize, Varray<T> &array, double _missval, double _rmin, double _rmax)
 {
+  T missval = _missval;
+  T rmin = _rmin;
+  T rmax = _rmax;
   size_t numMissVals = 0;
   for (size_t i = 0; i < gridsize; ++i)
     if (array[i] >= rmin && array[i] <= rmax)
@@ -119,20 +123,21 @@ set_range_to_miss(size_t gridsize, Varray<T> &array, T missval, T rmin, T rmax)
 static void
 set_range_to_miss(Field &field, double rmin, double rmax)
 {
-  if (field.memType == MemType::Float)
-    field.numMissVals += set_range_to_miss(field.size, field.vec_f, (float) field.missval, (float) rmin, (float) rmax);
-  else
-    field.numMissVals += set_range_to_miss(field.size, field.vec_d, field.missval, rmin, rmax);
+  auto func = [&](auto &v, auto size, double mv) { return set_range_to_miss(size, v, mv, rmin, rmax); };
+  field.numMissVals += field_operation(func, field, field.size, field.missval);
 }
 
 template <typename T>
 static size_t
-set_valid_range(size_t gridsize, Varray<T> &array, T missval, T rmin, T rmax)
+set_valid_range(size_t gridsize, Varray<T> &array, double _missval, double _rmin, double _rmax)
 {
+  T missval = _missval;
+  T rmin = _rmin;
+  T rmax = _rmax;
   for (size_t i = 0; i < gridsize; ++i)
     if (array[i] < rmin || array[i] > rmax) array[i] = missval;
 
-  const auto numMissVals = varray_num_mv(gridsize, array, missval);
+  auto numMissVals = varray_num_mv(gridsize, array, missval);
 
   return numMissVals;
 }
@@ -140,10 +145,8 @@ set_valid_range(size_t gridsize, Varray<T> &array, T missval, T rmin, T rmax)
 static void
 set_valid_range(Field &field, double rmin, double rmax)
 {
-  if (field.memType == MemType::Float)
-    field.numMissVals = set_valid_range(field.size, field.vec_f, (float) field.missval, (float) rmin, (float) rmax);
-  else
-    field.numMissVals = set_valid_range(field.size, field.vec_d, field.missval, rmin, rmax);
+  auto func = [&](auto &v, auto size, double mv) { return set_valid_range(size, v, mv, rmin, rmax); };
+  field.numMissVals = field_operation(func, field, field.size, field.missval);
 }
 
 class Setmiss : public Process
@@ -163,6 +166,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Setmiss> registration = RegisterEntry<Setmiss>(module);
+
   int SETMISSVAL, SETCTOMISS, SETMISSTOC, SETRTOMISS, SETVRANGE;
 
   CdoStreamID streamID1;
@@ -170,7 +174,7 @@ public:
   int taxisID1;
   int taxisID2;
 
-  VarList varList;
+  VarList varList1;
   Field field;
   int operatorID;
 
@@ -181,16 +185,13 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-SETMISSVAL = module.get_id("setmissval");
-SETCTOMISS = module.get_id("setctomiss");
-SETMISSTOC = module.get_id("setmisstoc");
-SETRTOMISS = module.get_id("setrtomiss");
-SETVRANGE = module.get_id("setvrange");
-    // clang-format on
+    SETMISSVAL = module.get_id("setmissval");
+    SETCTOMISS = module.get_id("setctomiss");
+    SETMISSTOC = module.get_id("setmisstoc");
+    SETRTOMISS = module.get_id("setrtomiss");
+    SETVRANGE = module.get_id("setvrange");
 
     operatorID = cdo_operator_id();
 
@@ -213,18 +214,18 @@ SETVRANGE = module.get_id("setvrange");
 
     streamID1 = cdo_open_read(0);
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = vlistDuplicate(vlistID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    varList_init(varList, vlistID1);
+    varList1 = VarList(vlistID1);
 
     if (operatorID == SETMISSVAL)
       {
-        const auto nvars = vlistNvars(vlistID2);
+        auto nvars = vlistNvars(vlistID2);
         for (int varID = 0; varID < nvars; ++varID) vlistDefVarMissval(vlistID2, varID, new_missval);
       }
     else if (operatorID == SETMISSTOC)
@@ -232,8 +233,8 @@ SETVRANGE = module.get_id("setvrange");
         auto nvars = vlistNvars(vlistID2);
         for (int varID = 0; varID < nvars; ++varID)
           {
-            const auto &var = varList[varID];
-            if (DBL_IS_EQUAL(rconst, var.missval))
+            const auto &var = varList1.vars[varID];
+            if (fp_is_equal(rconst, var.missval))
               {
                 cdo_warning("Missing value and constant have the same value!");
                 break;
@@ -253,32 +254,37 @@ SETVRANGE = module.get_id("setvrange");
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
   }
+
   void
-  run()
+  run() override
   {
+    auto numSteps = varList1.numSteps();
+    cdo::Progress progress;
+
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
+        if (numSteps > 1) progress.update((tsID + 1.0) / numSteps);
+
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
         cdo_def_timestep(streamID2, tsID);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            const auto &var = varList[varID];
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            const auto &var = varList1.vars[varID];
             field.init(var);
             cdo_read_record(streamID1, field);
 
             // clang-format off
-          if      (operatorID == SETMISSVAL) set_missval(field, new_missval);
-          else if (operatorID == SETCTOMISS) set_const_to_miss(field, rconst);
-          else if (operatorID == SETMISSTOC) set_miss_to_const(field, rconst);
-          else if (operatorID == SETRTOMISS) set_range_to_miss(field, rmin, rmax);
-          else if (operatorID == SETVRANGE)  set_valid_range(field, rmin, rmax);
+            if      (operatorID == SETMISSVAL) set_missval(field, new_missval);
+            else if (operatorID == SETCTOMISS) set_const_to_miss(field, rconst);
+            else if (operatorID == SETMISSTOC) set_miss_to_const(field, rconst);
+            else if (operatorID == SETRTOMISS) set_range_to_miss(field, rmin, rmax);
+            else if (operatorID == SETVRANGE)  set_valid_range(field, rmin, rmax);
             // clang-format on
 
             cdo_def_record(streamID2, varID, levelID);
@@ -288,8 +294,9 @@ SETVRANGE = module.get_id("setvrange");
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
