@@ -33,7 +33,7 @@ enum pt_mode_t
 };
 
 static void
-apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int nvars, int vlistID2, std::vector<CmorVar> &vars)
+apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int vlistID2, std::vector<CmorVar> &vars)
 {
   const std::vector<std::string> hentry = { "Header" };
   const std::vector<std::string> ventry = { "variable_entry", "parameter" };
@@ -41,6 +41,8 @@ apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int nvars, int vlistID2, s
   char paramstr[32];
   int codenum = 0;
 
+  VarList varList2(vlistID2);
+
   // search for global missing value
   auto hasMissvals = false;
   double missval = 0.0;
@@ -59,18 +61,19 @@ apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int nvars, int vlistID2, s
   }
 
   int numVarsFound = 0;
-  for (int varID = 0; varID < nvars; ++varID)
+  int numVars = vars.size();
+  for (int varID = 0; varID < numVars; ++varID)
     {
       auto &var = vars[varID];
       var.name = cdo::inq_var_name(vlistID2, varID);
 
+      const auto &var2 = varList2.vars[varID];
       if (hasMissvals)
         {
-          auto missval_old = vlistInqVarMissval(vlistID2, varID);
-          if (!dbl_is_equal(missval, missval_old))
+          if (fp_is_not_equal(missval, var2.missval))
             {
               var.changemissval = true;
-              var.missval_old = missval_old;
+              var.missvalOld = var2.missval;
               vlistDefVarMissval(vlistID2, varID, missval);
             }
         }
@@ -78,7 +81,7 @@ apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int nvars, int vlistID2, s
       const KVList *kvlist = nullptr;
       if (ptmode == CODE_NUMBER)
         {
-          codenum = vlistInqVarCode(vlistID2, varID);
+          codenum = var2.code;
           std::snprintf(valstr, sizeof(valstr), "%d", codenum);
           kvlist = pmlist.searchKVListVentry("code", valstr, ventry);
           if (kvlist)
@@ -86,7 +89,7 @@ apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int nvars, int vlistID2, s
               auto tableID = vlistInqVarTable(vlistID2, varID);
               auto tabnum = tableInqNum(tableID);
               int levtype = 0;
-              cdiInqKeyInt(vlistInqVarZaxis(vlistID2, varID), CDI_GLOBAL, CDI_KEY_TYPEOFFIRSTFIXEDSURFACE, &levtype);
+              cdiInqKeyInt(var2.zaxisID, CDI_GLOBAL, CDI_KEY_TYPEOFFIRSTFIXEDSURFACE, &levtype);
               auto table = tabnum;
               auto ltype = levtype;
               {
@@ -102,14 +105,14 @@ apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int nvars, int vlistID2, s
         }
       else if (ptmode == PARAMETER_ID)
         {
-          auto param = vlistInqVarParam(vlistID2, varID);
+          auto param = var2.param;
           cdiParamToString(param, paramstr, sizeof(paramstr));
           std::snprintf(valstr, sizeof(valstr), "%s", paramstr);
           kvlist = pmlist.searchKVListVentry("param", valstr, ventry);
           if (kvlist)
             {
               int levtype = 0;
-              cdiInqKeyInt(vlistInqVarZaxis(vlistID2, varID), CDI_GLOBAL, CDI_KEY_TYPEOFFIRSTFIXEDSURFACE, &levtype);
+              cdiInqKeyInt(var2.zaxisID, CDI_GLOBAL, CDI_KEY_TYPEOFFIRSTFIXEDSURFACE, &levtype);
               auto kv = kvlist->search("ltype");
               auto ltype = (kv && kv->nvalues == 1) ? parameter_to_int(kv->values[0]) : levtype;
               if (levtype != ltype) kvlist = nullptr;
@@ -121,7 +124,7 @@ apply_parameterList(pt_mode_t ptmode, PMList &pmlist, int nvars, int vlistID2, s
         {
           numVarsFound++;
           int pnum, ptab, pdum;
-          cdiDecodeParam(vlistInqVarParam(vlistID2, varID), &pnum, &ptab, &pdum);
+          cdiDecodeParam(var2.param, &pnum, &ptab, &pdum);
           auto hasValidMin = false, hasValidMax = false;
 
           for (const auto &kv : *kvlist)
@@ -183,14 +186,14 @@ public:
   int vlistID2;
 
   std::vector<CmorVar> vars;
-  int nvars;
+  int numVars;
 
   Varray<double> array;
   VarList varList2;
 
 public:
   void
-  init()
+  init() override
   {
     SETCODETAB = module.get_id("setcodetab");
     SETPARTABC = module.get_id("setpartabc");
@@ -216,10 +219,10 @@ public:
 
     pt_mode_t ptmode = CODE_NUMBER;
     // clang-format off
-  if      (operatorID == SETCODETAB) ptmode = CODE_NUMBER;
-  else if (operatorID == SETPARTABC) ptmode = CODE_NUMBER;
-  else if (operatorID == SETPARTABP) ptmode = PARAMETER_ID;
-  else if (operatorID == SETPARTABN) ptmode = VARIABLE_NAME;
+    if      (operatorID == SETCODETAB) ptmode = CODE_NUMBER;
+    else if (operatorID == SETPARTABC) ptmode = CODE_NUMBER;
+    else if (operatorID == SETPARTABP) ptmode = PARAMETER_ID;
+    else if (operatorID == SETPARTABN) ptmode = VARIABLE_NAME;
     // clang-format on
 
     if (ptmode == CODE_NUMBER)
@@ -254,17 +257,17 @@ public:
     vlistID2 = vlistDuplicate(vlistID1);
     // vlistPrint(vlistID2);
 
-    nvars = vlistNvars(vlistID2);
-    vars = std::vector<CmorVar>(nvars);
+    numVars = vlistNvars(vlistID2);
+    vars.resize(numVars);
 
     if (convertData)
-      for (int varID = 0; varID < nvars; ++varID) vars[varID].convert = true;
+      for (int varID = 0; varID < numVars; ++varID) vars[varID].convert = true;
 
     if (tableformat == 0)
       {
-        // for (int varID = 0; varID < nvars; ++varID) vlistDefVarTable(vlistID2, varID, tableID);
+        // for (int varID = 0; varID < numVars; ++varID) vlistDefVarTable(vlistID2, varID, tableID);
         char name[CDI_MAX_NAME], longname[CDI_MAX_NAME], units[CDI_MAX_NAME];
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
             auto param = vlistInqVarParam(vlistID2, varID);
             int pdis, pcat, pnum;
@@ -299,10 +302,10 @@ public:
           pmlist.read_namelist(fp, filename);
           std::fclose(fp);
 
-          apply_parameterList(ptmode, pmlist, nvars, vlistID2, vars);
+          apply_parameterList(ptmode, pmlist, vlistID2, vars);
         }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           if (vars[varID].remove)
             {
               deleteVars = true;
@@ -314,18 +317,18 @@ public:
             vlistClearFlag(vlistID1);
             vlistClearFlag(vlistID2);
 
-            for (int varID = 0; varID < nvars; ++varID)
+            for (int varID = 0; varID < numVars; ++varID)
               {
                 auto zaxisID = vlistInqVarZaxis(vlistID2, varID);
-                auto nlevs = zaxisInqSize(zaxisID);
-                for (int levID = 0; levID < nlevs; levID++)
+                auto numLevels = zaxisInqSize(zaxisID);
+                for (int levelID = 0; levelID < numLevels; levelID++)
                   {
-                    vlistDefFlag(vlistID1, varID, levID, true);
-                    vlistDefFlag(vlistID2, varID, levID, true);
+                    vlistDefFlag(vlistID1, varID, levelID, true);
+                    vlistDefFlag(vlistID2, varID, levelID, true);
                     if (vars[varID].remove)
                       {
-                        vlistDefFlag(vlistID1, varID, levID, false);
-                        vlistDefFlag(vlistID2, varID, levID, false);
+                        vlistDefFlag(vlistID1, varID, levelID, false);
+                        vlistDefFlag(vlistID2, varID, levelID, false);
                       }
                   }
               }
@@ -339,7 +342,7 @@ public:
             if (vlistNvars(vlistID2) == 0) cdo_abort("No variable selected!");
           }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
             auto &var = vars[varID];
             if (!var.convert) var.changeunits = false;
@@ -361,11 +364,11 @@ public:
     if (vlistNumber(vlistID1) != CDI_REAL) gridsizemax *= 2;
     array = Varray<double>(gridsizemax);
 
-    varList_init(varList2, vlistID2);
+    varList2 = VarList(vlistID2);
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -376,7 +379,7 @@ public:
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
         cdo_def_timestep(streamID2, tsID);
 
-        cmor_check_init(nvars, vars);
+        cmor_check_init(numVars, vars);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
@@ -403,14 +406,15 @@ public:
             size_t numMissVals;
             cdo_read_record(streamID1, array.data(), &numMissVals);
 
-            auto missval = varList2[varID2].missval;
-            auto gridsize = varList2[varID2].nwpv * varList2[varID2].gridsize;
+            const auto &var2 = varList2.vars[varID2];
+            auto missval = var2.missval;
+            auto gridsize = var2.nwpv * var2.gridsize;
 
             if (numMissVals && var.changemissval)
               {
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (dbl_is_equal(array[i], var.missval_old)) array[i] = missval;
+                    if (fp_is_equal(array[i], var.missvalOld)) array[i] = missval;
                   }
               }
 
@@ -418,7 +422,7 @@ public:
               {
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (!dbl_is_equal(array[i], missval)) array[i] *= var.factor;
+                    if (fp_is_not_equal(array[i], missval)) array[i] *= var.factor;
                   }
               }
 
@@ -428,7 +432,7 @@ public:
                 int nerr = 0;
                 for (size_t i = 0; i < gridsize; ++i)
                   {
-                    if (!dbl_is_equal(array[i], missval))
+                    if (fp_is_not_equal(array[i], missval))
                       {
                         array[i] = cv_convert_double((const cv_converter *) var.ut_converter, array[i]);
                         if (ut_get_status() != UT_SUCCESS) nerr++;
@@ -448,20 +452,21 @@ public:
             cmor_check_prep(var, gridsize, missval, array.data());
           }
 
-        cmor_check_eval(vlistID2, nvars, vars);
+        cmor_check_eval(vlistID2, numVars, vars);
 
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
 
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
 
 #ifdef HAVE_UDUNITS2
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       if (vars[varID].changeunits) cdo_convert_free(vars[varID].ut_converter);
 
     cdo_convert_destroy();
