@@ -166,6 +166,9 @@ public:
   int vlistID1;
   int vlistID2;
 
+  VarList varList1;
+  VarList varList2;
+
   Varray<double> array1;
   Varray<double> array2;
 
@@ -178,7 +181,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     SHIFTX = module.get_id("shiftx");
     SHIFTY = module.get_id("shifty");
@@ -204,14 +207,17 @@ public:
     vlistID1 = cdo_stream_inq_vlist(streamID1);
     vlistID2 = vlistDuplicate(vlistID1);
 
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    auto nvars = vlistNvars(vlistID1);
-    vars = std::vector<bool>(nvars, false);
+    auto numVars = varList1.numVars();
+    vars = std::vector<bool>(numVars, false);
 
-    auto ngrids = vlistNgrids(vlistID1);
+    auto ngrids = vlistNumGrids(vlistID1);
     for (int index = 0; index < ngrids; ++index)
       {
         auto gridID1 = vlistGrid(vlistID1, index);
@@ -232,8 +238,8 @@ public:
                 vlistChangeGridIndex(vlistID2, index, gridID2);
               }
 
-            for (int varID = 0; varID < nvars; ++varID)
-              if (gridID1 == vlistInqVarGrid(vlistID1, varID)) vars[varID] = true;
+            for (const auto &var : varList1.vars)
+              if (gridID1 == var.gridID) vars[var.ID] = true;
           }
         else if (gridtype == GRID_GENERIC && gridInqXsize(gridID1) <= 1 && gridInqYsize(gridID1) <= 1) {}
         else { cdo_abort("Unsupported grid type: %s", gridNamePtr(gridtype)); }
@@ -241,9 +247,9 @@ public:
 
     {
       int varID;
-      for (varID = 0; varID < nvars; ++varID)
+      for (varID = 0; varID < numVars; ++varID)
         if (vars[varID]) break;
-      if (varID >= nvars) cdo_warning("No variables selected!");
+      if (varID >= numVars) cdo_warning("No variables selected!");
     }
 
     streamID2 = cdo_open_write(1);
@@ -255,7 +261,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -277,9 +283,9 @@ public:
 
             if (vars[varID])
               {
-                auto gridID1 = vlistInqVarGrid(vlistID1, varID);
-                auto gridsize = gridInqSize(gridID1);
-                auto missval = vlistInqVarMissval(vlistID2, varID);
+                auto gridID1 = varList1.vars[varID].gridID;
+                auto gridsize = varList1.vars[varID].gridsize;
+                auto missval = varList2.vars[varID].missval;
 
                 auto nx = gridInqXsize(gridID1);
                 auto ny = gridInqYsize(gridID1);
@@ -299,7 +305,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
