@@ -25,7 +25,7 @@
 #include "pmlist.h"
 #include "cdo_options.h"
 #include "progress.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "grid_point_search.h"
 
 enum class CurveForm
@@ -48,15 +48,16 @@ struct SmoothPoint
 
 template <typename T>
 static size_t
-smooth(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2, const SmoothPoint &spoint)
+smooth(int gridID, double mv, const Varray<T> &array1, Varray<T> &array2, const SmoothPoint &spoint)
 {
+  T missval = mv;
   auto gridID0 = gridID;
   auto gridsize = gridInqSize(gridID);
   auto numNeighbors = spoint.maxpoints;
   if (numNeighbors > gridsize) numNeighbors = gridsize;
 
   Varray<uint8_t> mask(gridsize);
-  for (size_t i = 0; i < gridsize; ++i) mask[i] = dbl_is_not_equal(array1[i], missval);
+  for (size_t i = 0; i < gridsize; ++i) mask[i] = fp_is_not_equal(array1[i], missval);
 
   gridID = generate_full_point_grid(gridID);
   if (!gridHasCoordinates(gridID)) cdo_abort("Cell center coordinates missing!");
@@ -161,7 +162,7 @@ smooth9(int gridID, T missval, const Varray<T> &array1, Varray<T> &array2)
 
   std::vector<uint8_t> mask(gridsize);
 
-  for (size_t i = 0; i < gridsize; ++i) mask[i] = dbl_is_not_equal(missval, array1[i]);
+  for (size_t i = 0; i < gridsize; ++i) mask[i] = fp_is_not_equal(missval, array1[i]);
 
   size_t numMissVals = 0;
   for (size_t i = 0; i < nlat; ++i)
