@@ -130,6 +130,7 @@ public:
   int taxisID2;
 
   int vlistID1;
+  VarList varList1;
 
   std::vector<bool> processVars;
   Varray<double> array1;
@@ -141,19 +142,16 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     dataIsUnchanged = data_is_unchanged();
 
-    // clang-format off
-GP2SP = module.get_id("gp2sp");
-GP2SPL = module.get_id("gp2spl");
-SP2GP = module.get_id("sp2gp");
-SP2GPL = module.get_id("sp2gpl");
-SP2SP = module.get_id("sp2sp");
-SPCUT = module.get_id("spcut");
-    // clang-format on
+    GP2SP = module.get_id("gp2sp");
+    GP2SPL = module.get_id("gp2spl");
+    SP2GP = module.get_id("sp2gp");
+    SP2GPL = module.get_id("sp2gpl");
+    SP2SP = module.get_id("sp2sp");
+    SPCUT = module.get_id("spcut");
 
     operatorID = cdo_operator_id();
 
@@ -195,6 +193,8 @@ SPCUT = module.get_id("spcut");
     vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
+    varList1 = VarList(vlistID1);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
@@ -261,9 +261,9 @@ SPCUT = module.get_id("spcut");
         gridID2 = gridIDsp;
       }
 
-    auto nvars = vlistNvars(vlistID2);
-    processVars = std::vector<bool>(nvars);
-    for (int varID = 0; varID < nvars; ++varID) processVars[varID] = (gridID1 == vlistInqVarGrid(vlistID1, varID));
+    auto numVars = varList1.numVars();
+    processVars = std::vector<bool>(numVars);
+    for (const auto &var : varList1.vars) processVars[var.ID] = (gridID1 == var.gridID);
 
     if (gridID1 != -1) vlistChangeGrid(vlistID2, gridID1, gridID2);
 
@@ -276,7 +276,7 @@ SPCUT = module.get_id("spcut");
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -298,7 +298,7 @@ SPCUT = module.get_id("spcut");
                 cdo_read_record(streamID1, array1.data(), &numMissVals);
                 if (numMissVals) cdo_abort("Missing values unsupported for spectral data!");
 
-                gridID1 = vlistInqVarGrid(vlistID1, varID);
+                gridID1 = varList1.vars[varID].gridID;
                 // clang-format off
                 if      (lgp2sp) grid2spec(spTrans, gridID1, array1, gridID2, array2);
                 else if (lsp2gp) spec2grid(spTrans, gridID1, array1, gridID2, array2);
@@ -327,7 +327,7 @@ SPCUT = module.get_id("spcut");
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
