@@ -36,19 +36,19 @@ gen_filename(std::string &fileName, bool swapObase, const std::string &obase, co
 }
 
 static int
-split_code(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList1,
+split_code(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList,
            std::vector<CdoStreamID> &streamIDs, std::vector<int> &vlistIDs)
 {
-  auto nvars = vlistNvars(vlistID1);
-  std::vector<int> codes(nvars);
+  auto numVars = varList.numVars();
+  std::vector<int> codes(numVars);
 
   int nsplit = 0;
-  for (int varID = 0; varID < nvars; ++varID)
+  for (int varID = 0; varID < numVars; ++varID)
     {
-      const auto &var = varList1[varID];
+      const auto &var = varList.vars[varID];
       int index;
       for (index = 0; index < varID; ++index)
-        if (var.code == varList1[index].code) break;
+        if (var.code == varList.vars[index].code) break;
 
       if (index == varID) codes[nsplit++] = var.code;
     }
@@ -59,9 +59,9 @@ split_code(bool swapObase, const std::string &fileSuffix, std::string &fileName,
   for (int index = 0; index < nsplit; ++index)
     {
       vlistClearFlag(vlistID1);
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
-          const auto &var = varList1[varID];
+          const auto &var = varList.vars[varID];
           if (codes[index] == var.code)
             {
               for (int levelID = 0; levelID < var.nlevels; ++levelID)
@@ -87,20 +87,20 @@ split_code(bool swapObase, const std::string &fileSuffix, std::string &fileName,
 }
 
 static int
-split_param(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList1,
+split_param(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList,
             std::vector<CdoStreamID> &streamIDs, std::vector<int> &vlistIDs)
 {
   char paramstr[32];
-  auto nvars = vlistNvars(vlistID1);
-  std::vector<int> params(nvars);
+  auto numVars = varList.numVars();
+  std::vector<int> params(numVars);
 
   int nsplit = 0;
-  for (int varID = 0; varID < nvars; ++varID)
+  for (int varID = 0; varID < numVars; ++varID)
     {
-      const auto &var = varList1[varID];
+      const auto &var = varList.vars[varID];
       int index;
       for (index = 0; index < varID; ++index)
-        if (var.param == varList1[index].param) break;
+        if (var.param == varList.vars[index].param) break;
 
       if (index == varID) params[nsplit++] = var.param;
     }
@@ -111,9 +111,9 @@ split_param(bool swapObase, const std::string &fileSuffix, std::string &fileName
   for (int index = 0; index < nsplit; ++index)
     {
       vlistClearFlag(vlistID1);
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
-          const auto &var = varList1[varID];
+          const auto &var = varList.vars[varID];
           if (params[index] == var.param)
             {
               for (int levelID = 0; levelID < var.nlevels; ++levelID)
@@ -140,11 +140,11 @@ split_param(bool swapObase, const std::string &fileSuffix, std::string &fileName
 }
 
 static int
-split_name(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList1,
+split_name(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList,
            std::vector<CdoStreamID> &streamIDs, std::vector<int> &vlistIDs)
 {
-  auto nvars = vlistNvars(vlistID1);
-  auto nsplit = nvars;
+  auto numVars = varList.numVars();
+  auto nsplit = numVars;
 
   vlistIDs.resize(nsplit);
   streamIDs.resize(nsplit);
@@ -153,7 +153,7 @@ split_name(bool swapObase, const std::string &fileSuffix, std::string &fileName,
     {
       vlistClearFlag(vlistID1);
       int varID = index;
-      const auto &var = varList1[varID];
+      const auto &var = varList.vars[varID];
       for (int levelID = 0; levelID < var.nlevels; ++levelID)
         {
           vlistDefIndex(vlistID1, varID, levelID, index);
@@ -174,11 +174,11 @@ split_name(bool swapObase, const std::string &fileSuffix, std::string &fileName,
 }
 
 static int
-split_level(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList1,
+split_level(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList,
             std::vector<CdoStreamID> &streamIDs, std::vector<int> &vlistIDs)
 {
-  auto nvars = vlistNvars(vlistID1);
-  auto nzaxis = vlistNzaxis(vlistID1);
+  auto numVars = varList.numVars();
+  auto nzaxis = vlistNumZaxis(vlistID1);
   Varray<double> ftmp(999, 0.0);
 
   int nsplit = 0;
@@ -204,9 +204,9 @@ split_level(bool swapObase, const std::string &fileSuffix, std::string &fileName
   for (int index = 0; index < nsplit; ++index)
     {
       vlistClearFlag(vlistID1);
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
-          const auto &var = varList1[varID];
+          const auto &var = varList.vars[varID];
           for (int levelID = 0; levelID < var.nlevels; ++levelID)
             {
               auto level = cdo_zaxis_inq_level(var.zaxisID, levelID);
@@ -232,11 +232,11 @@ split_level(bool swapObase, const std::string &fileSuffix, std::string &fileName
 }
 
 static int
-split_grid(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList1,
+split_grid(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList,
            std::vector<CdoStreamID> &streamIDs, std::vector<int> &vlistIDs)
 {
-  auto nsplit = vlistNgrids(vlistID1);
-  auto nvars = vlistNvars(vlistID1);
+  auto nsplit = vlistNumGrids(vlistID1);
+  auto numVars = varList.numVars();
 
   vlistIDs.resize(nsplit);
   streamIDs.resize(nsplit);
@@ -246,9 +246,9 @@ split_grid(bool swapObase, const std::string &fileSuffix, std::string &fileName,
   for (int index = 0; index < nsplit; ++index)
     {
       vlistClearFlag(vlistID1);
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
-          const auto &var = varList1[varID];
+          const auto &var = varList.vars[varID];
           if (gridIDs[index] == var.gridID)
             {
               for (int levelID = 0; levelID < var.nlevels; ++levelID)
@@ -273,11 +273,11 @@ split_grid(bool swapObase, const std::string &fileSuffix, std::string &fileName,
 }
 
 static int
-split_zaxis(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList1,
+split_zaxis(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList,
             std::vector<CdoStreamID> &streamIDs, std::vector<int> &vlistIDs)
 {
-  auto nsplit = vlistNzaxis(vlistID1);
-  auto nvars = vlistNvars(vlistID1);
+  auto nsplit = vlistNumZaxis(vlistID1);
+  auto numVars = varList.numVars();
 
   vlistIDs.resize(nsplit);
   streamIDs.resize(nsplit);
@@ -287,9 +287,9 @@ split_zaxis(bool swapObase, const std::string &fileSuffix, std::string &fileName
   for (int index = 0; index < nsplit; ++index)
     {
       vlistClearFlag(vlistID1);
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
-          const auto &var = varList1[varID];
+          const auto &var = varList.vars[varID];
           if (zaxisIDs[index] == var.zaxisID)
             {
               for (int levelID = 0; levelID < var.nlevels; ++levelID)
@@ -314,14 +314,14 @@ split_zaxis(bool swapObase, const std::string &fileSuffix, std::string &fileName
 }
 
 static int
-split_tabnum(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList1,
+split_tabnum(bool swapObase, const std::string &fileSuffix, std::string &fileName, int vlistID1, const VarList &varList,
              std::vector<CdoStreamID> &streamIDs, std::vector<int> &vlistIDs)
 {
-  auto nvars = vlistNvars(vlistID1);
-  std::vector<int> tabnums(nvars);
+  auto numVars = varList.numVars();
+  std::vector<int> tabnums(numVars);
 
   int nsplit = 0;
-  for (int varID = 0; varID < nvars; ++varID)
+  for (int varID = 0; varID < numVars; ++varID)
     {
       auto tabnum = tableInqNum(vlistInqVarTable(vlistID1, varID));
       int index;
@@ -337,12 +337,12 @@ split_tabnum(bool swapObase, const std::string &fileSuffix, std::string &fileNam
   for (int index = 0; index < nsplit; ++index)
     {
       vlistClearFlag(vlistID1);
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
           auto tabnum = tableInqNum(vlistInqVarTable(vlistID1, varID));
           if (tabnums[index] == tabnum)
             {
-              const auto &var = varList1[varID];
+              const auto &var = varList.vars[varID];
               for (int levelID = 0; levelID < var.nlevels; ++levelID)
                 {
                   vlistDefIndex(vlistID1, varID, levelID, index);
@@ -382,7 +382,6 @@ public:
     .number = CDI_BOTH,  // Allowed number type
     .constraints = { 1, OBASE, OnlyFirst },
   };
-
   inline static RegisterEntry<Split> registration = RegisterEntry<Split>(module);
 
   int SPLITCODE, SPLITPARAM, SPLITNAME, SPLITLEVEL, SPLITGRID, SPLITZAXIS, SPLITTABNUM;
@@ -399,20 +398,17 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     dataIsUnchanged = data_is_unchanged();
 
-    // clang-format off
-SPLITCODE = module.get_id("splitcode");
-SPLITPARAM = module.get_id("splitparam");
-SPLITNAME = module.get_id("splitname");
-SPLITLEVEL = module.get_id("splitlevel");
-SPLITGRID = module.get_id("splitgrid");
-SPLITZAXIS = module.get_id("splitzaxis");
-SPLITTABNUM = module.get_id("splittabnum");
-    // clang-format on
+    SPLITCODE = module.get_id("splitcode");
+    SPLITPARAM = module.get_id("splitparam");
+    SPLITNAME = module.get_id("splitname");
+    SPLITLEVEL = module.get_id("splitlevel");
+    SPLITGRID = module.get_id("splitgrid");
+    SPLITZAXIS = module.get_id("splitzaxis");
+    SPLITTABNUM = module.get_id("splittabnum");
 
     auto operatorID = cdo_operator_id();
 
@@ -431,7 +427,7 @@ SPLITTABNUM = module.get_id("splittabnum");
     streamID1 = cdo_open_read(0);
     vlistID1 = cdo_stream_inq_vlist(streamID1);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     std::string fileName;
     if (!swapObase) fileName = cdo_get_obase();
@@ -476,7 +472,7 @@ SPLITTABNUM = module.get_id("splittabnum");
   }
 
   void
-  run()
+  run() override
   {
     Field field;
     int tsID = 0;
@@ -502,7 +498,7 @@ SPLITTABNUM = module.get_id("splittabnum");
             if (dataIsUnchanged) { cdo_copy_record(streamIDs[index], streamID1); }
             else
               {
-                const auto &var = varList1[varID];
+                const auto &var = varList1.vars[varID];
                 field.init(var);
                 cdo_read_record(streamID1, field);
                 cdo_write_record(streamIDs[index], field);
@@ -514,7 +510,7 @@ SPLITTABNUM = module.get_id("splittabnum");
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
 
