@@ -15,7 +15,6 @@
 
 #include "cdo_options.h"
 #include "process_int.h"
-#include "param_conversion.h"
 #include "util_files.h"
 #include "util_string.h"
 
@@ -32,6 +31,7 @@ public:
     .constraints = { 1, OBASE, OnlyFirst },
   };
   inline static RegisterEntry<Splitdate> registration = RegisterEntry<Splitdate>(module);
+
   int SPLITDATE;
   CdoStreamID streamID1;
   int taxisID1;
@@ -52,7 +52,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
 
     dataIsUnchanged = data_is_unchanged();
@@ -71,7 +71,7 @@ public:
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
 
     fileSuffix = FileUtils::gen_suffix(cdo_inq_filetype(streamID1), vlistID1, cdo_get_stream_name(0));
 
@@ -82,16 +82,15 @@ public:
       array.resize(gridsizemax);
     }
 
-    haveConstVars = (varList_numConstVars(varList1) > 0);
-
+    haveConstVars = (varList1.numConstVars() > 0);
     if (haveConstVars)
       {
-        int numVars = varList1.size();
+        int numVars = varList1.numVars();
         vars.resize(numVars);
 
         for (int varID = 0; varID < numVars; ++varID)
           {
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             if (var.isConstant)
               {
                 vars[varID].resize(var.nlevels);
@@ -107,7 +106,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int64_t vDate0 = -1;
 
@@ -169,10 +168,10 @@ public:
 
         if (tsID > 0 && tsID2 == 0 && haveConstVars)
           {
-            int numVars = varList1.size();
+            int numVars = varList1.numVars();
             for (int varID = 0; varID < numVars; ++varID)
               {
-                const auto &var = varList1[varID];
+                const auto &var = varList1.vars[varID];
                 if (var.isConstant)
                   {
                     for (int levelID = 0; levelID < var.nlevels; ++levelID)
@@ -200,7 +199,7 @@ public:
 
                 if (tsID == 0 && haveConstVars)
                   {
-                    const auto &var = varList1[varID];
+                    const auto &var = varList1.vars[varID];
                     if (var.isConstant)
                       {
                         varray_copy(var.gridsize, array, vars[varID][levelID].vec_d);
@@ -216,7 +215,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     if (streamID2 != CDO_STREAM_UNDEF) cdo_stream_close(streamID2);
 
