@@ -22,6 +22,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Tee> registration = RegisterEntry<Tee>(module);
+
   Field field;
   CdoStreamID streamID1;
   CdoStreamID streamID2;
@@ -33,7 +34,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     operator_check_argc(1);
 
@@ -58,11 +59,11 @@ public:
     cdo_def_vlist(streamID2, vlistID2);
     streamDefVlist(streamID3, vlistID3);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -78,9 +79,8 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            field.init(varList1[varID]);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
 
             cdo_def_record(streamID2, varID, levelID);
@@ -98,7 +98,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID2);
