@@ -46,7 +46,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     NORMAL = module.get_id("normal");
     STUDENTT = module.get_id("studentt");
@@ -103,11 +103,11 @@ public:
     array1 = Varray<double>(gridsizemax);
     array2 = Varray<double>(gridsizemax);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -120,28 +120,27 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
+            auto [varID, levelID] = cdo_inq_record(streamID1);
             size_t numMissVals;
-            cdo_inq_record(streamID1, &varID, &levelID);
             cdo_read_record(streamID1, array1.data(), &numMissVals);
 
-            auto gridsize = varList1[varID].gridsize;
-            auto missval = varList1[varID].missval;
+            auto gridsize = varList1.vars[varID].gridsize;
+            auto missval = varList1.vars[varID].missval;
 
             if (operatorID == NORMAL)
               {
                 for (size_t i = 0; i < gridsize; ++i)
-                  array2[i] = dbl_is_equal(array1[i], missval) ? missval : cdo::normal(array1[i]);
+                  array2[i] = fp_is_equal(array1[i], missval) ? missval : cdo::normal(array1[i]);
               }
             else if (operatorID == STUDENTT)
               {
                 for (size_t i = 0; i < gridsize; ++i)
-                  array2[i] = dbl_is_equal(array1[i], missval) ? missval : cdo::student_t(degreeOfFreedom, array1[i]);
+                  array2[i] = fp_is_equal(array1[i], missval) ? missval : cdo::student_t(degreeOfFreedom, array1[i]);
               }
             else if (operatorID == CHISQUARE)
               {
                 for (size_t i = 0; i < gridsize; ++i)
-                  array2[i] = dbl_is_equal(array1[i], missval) ? missval : cdo::chi_square(degreeOfFreedom, array1[i]);
+                  array2[i] = fp_is_equal(array1[i], missval) ? missval : cdo::chi_square(degreeOfFreedom, array1[i]);
               }
             else if (operatorID == BETA)
               {
@@ -149,13 +148,13 @@ public:
                   {
                     if (array1[i] < 0 || array1[i] > 1) cdo_abort("Value out of range (0-1)!");
 
-                    array2[i] = dbl_is_equal(array1[i], missval) ? missval : cdo::beta_distr(p, q, array1[i]);
+                    array2[i] = fp_is_equal(array1[i], missval) ? missval : cdo::beta_distr(p, q, array1[i]);
                   }
               }
             else if (operatorID == FISHER)
               {
                 for (size_t i = 0; i < gridsize; ++i)
-                  array2[i] = dbl_is_equal(array1[i], missval) ? missval : cdo::fisher(n, d, array1[i]);
+                  array2[i] = fp_is_equal(array1[i], missval) ? missval : cdo::fisher(n, d, array1[i]);
               }
             else { cdo_abort("Internal problem, operator not implemented!"); }
 
@@ -168,7 +167,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID2);
