@@ -30,11 +30,11 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Timcount",
-    .operators = { { "timcount", 0, CMP_DATE, nullptr},
-                   { "yearcount", 0, CMP_YEAR, nullptr},
-                   { "moncount", 0, CMP_MONTH, nullptr},
-                   { "daycount", 0, CMP_DAY, nullptr},
-                   { "hourcount", 0, CMP_HOUR, nullptr} },
+    .operators = { { "timcount", 0, CMP_DATE, nullptr },
+                   { "yearcount", 0, CMP_YEAR, nullptr },
+                   { "moncount", 0, CMP_MONTH, nullptr },
+                   { "daycount", 0, CMP_DAY, nullptr },
+                   { "hourcount", 0, CMP_HOUR, nullptr } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_BOTH,  // Allowed number type
@@ -48,24 +48,17 @@ public:
   int taxisID2;
 
   int compareDate;
-  int maxrecs;
 
   CdiDateTime vDateTime0{};
   CdiDateTime vDateTimeN{};
 
   VarList varList1;
-  Field field;
-  FieldVector2D vars1;
-  std::vector<RecordInfo> recList;
+  FieldVector2D varsData1;
 
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-    // clang-format on
-
     auto operatorID = cdo_operator_id();
     compareDate = cdo_operator_f2(operatorID);
 
@@ -88,16 +81,18 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
+    varList1 = VarList(vlistID1);
 
-    varList_init(varList1, vlistID1);
-
-    fields_from_vlist(vlistID1, vars1, FIELD_VEC);
+    field2D_init(varsData1, varList1, FIELD_VEC);
   }
+
   void
-  run()
+  run() override
   {
+    Field field;
+    auto maxRecords = varList1.numRecords();
+    std::vector<RecordInfo> recordList(maxRecords);
+
     int tsID = 0;
     int otsID = 0;
     while (true)
@@ -121,23 +116,22 @@ public:
 
             for (int recID = 0; recID < nrecs; ++recID)
               {
-                int varID, levelID;
-                cdo_inq_record(streamID1, &varID, &levelID);
+                auto [varID, levelID] = cdo_inq_record(streamID1);
 
-                if (tsID == 0) recList[recID].set(varID, levelID);
+                if (tsID == 0) recordList[recID].set(varID, levelID);
 
-                const size_t fieldsize = vars1[varID][levelID].size;
+                size_t fieldsize = varsData1[varID][levelID].size;
 
                 if (numSets == 0)
                   {
-                    for (size_t i = 0; i < fieldsize; ++i) vars1[varID][levelID].vec_d[i] = vars1[varID][levelID].missval;
-                    vars1[varID][levelID].numMissVals = fieldsize;
+                    for (size_t i = 0; i < fieldsize; ++i) varsData1[varID][levelID].vec_d[i] = varsData1[varID][levelID].missval;
+                    varsData1[varID][levelID].numMissVals = fieldsize;
                   }
 
-                field.init(varList1[varID]);
+                field.init(varList1.vars[varID]);
                 cdo_read_record(streamID1, field);
 
-                field2_count(vars1[varID][levelID], field);
+                field2_count(varsData1[varID][levelID], field);
               }
 
             vDateTimeN = vDateTime;
@@ -150,13 +144,13 @@ public:
         taxisDefVdatetime(taxisID2, vDateTimeN);
         cdo_def_timestep(streamID2, otsID);
 
-        for (int recID = 0; recID < maxrecs; ++recID)
+        for (int recID = 0; recID < maxRecords; ++recID)
           {
-            auto [varID, levelID] = recList[recID].get();
-            if (otsID && varList1[varID].isConstant) continue;
+            auto [varID, levelID] = recordList[recID].get();
+            if (otsID && varList1.vars[varID].isConstant) continue;
 
             cdo_def_record(streamID2, varID, levelID);
-            cdo_write_record(streamID2, vars1[varID][levelID].vec_d.data(), vars1[varID][levelID].numMissVals);
+            cdo_write_record(streamID2, varsData1[varID][levelID].vec_d.data(), varsData1[varID][levelID].numMissVals);
           }
 
         if (nrecs == 0) break;
@@ -165,7 +159,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
