@@ -29,6 +29,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Timcumsum> registration = RegisterEntry<Timcumsum>(module);
+
   CdoStreamID streamID1;
   int taxisID1;
   CdoStreamID streamID2;
@@ -37,13 +38,12 @@ public:
   int varID, levelID;
 
   Field field;
-  FieldVector2D vars1;
+  FieldVector2D varsData1;
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_check_argc(0);
 
     streamID1 = cdo_open_read(0);
@@ -63,10 +63,11 @@ public:
 
     field.resize(gridsizemax);
 
-    fields_from_vlist(vlistID1, vars1, FIELD_VEC);
+    VarList varList1(vlistID1);
+    field2D_init(varsData1, varList1, FIELD_VEC);
   }
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -81,7 +82,7 @@ public:
           {
             cdo_inq_record(streamID1, &varID, &levelID);
 
-            auto &rvars1 = vars1[varID][levelID];
+            auto &rvars1 = varsData1[varID][levelID];
 
             auto fieldsize = rvars1.size;
 
@@ -90,7 +91,7 @@ public:
                 cdo_read_record(streamID1, rvars1.vec_d.data(), &rvars1.numMissVals);
                 if (rvars1.numMissVals)
                   for (size_t i = 0; i < fieldsize; ++i)
-                    if (DBL_IS_EQUAL(rvars1.vec_d[i], rvars1.missval)) rvars1.vec_d[i] = 0;
+                    if (fp_is_equal(rvars1.vec_d[i], rvars1.missval)) rvars1.vec_d[i] = 0;
               }
             else
               {
@@ -101,7 +102,7 @@ public:
 
                 if (field.numMissVals)
                   for (size_t i = 0; i < fieldsize; ++i)
-                    if (DBL_IS_EQUAL(field.vec_d[i], rvars1.missval)) field.vec_d[i] = 0;
+                    if (fp_is_equal(field.vec_d[i], rvars1.missval)) field.vec_d[i] = 0;
 
                 field2_sum(rvars1, field);
               }
@@ -113,8 +114,9 @@ public:
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
