@@ -62,15 +62,19 @@
 
 #include <cdi.h>
 
+#include <unordered_map>
+
 #include "cdo_options.h"
-#include "cdo_vlist.h"
+#include "cdo_stepstat.h"
+#include "cdo_task.h"
 #include "process_int.h"
 #include "datetime.h"
 #include "printinfo.h"
 #include "util_date.h"
-#include "param_conversion.h"
 #include "progress.h"
 #include "field_functions.h"
+#include "param_conversion.h"
+#include "pmlist.h"
 
 static void
 vlist_set_frequency(int vlistID, const std::string &frequency)
@@ -89,22 +93,32 @@ vlist_set_frequency(int vlistID, int compareDate)
 }
 
 static void
-set_missval(Field &field, const Field &samp, int numSets, double vfrac)
+get_parameter(double &vfraction, bool &completeOnly)
 {
-  auto fieldsize = field.size;
-  auto missval = field.missval;
-
-  size_t irun = 0;
-  for (size_t i = 0; i < fieldsize; ++i)
+  auto pargc = cdo_operator_argc();
+  if (pargc)
     {
-      if ((samp.vec_d[i] / numSets) < vfrac)
+      const auto &pargv = cdo_get_oper_argv();
+
+      KVList kvlist;
+      kvlist.name = cdo_module_name();
+      if (kvlist.parse_arguments(pargv) != 0) cdo_abort("Parse error!");
+      if (Options::cdoVerbose) kvlist.print();
+
+      for (const auto &kv : kvlist)
         {
-          field.vec_d[i] = missval;
-          irun++;
+          const auto &key = kv.key;
+          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
+          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
+          const auto &value = kv.values[0];
+
+          // clang-format off
+          if      (key == "vfraction")       vfraction = parameter_to_double(value);
+          else if (key == "complete_only")   completeOnly = parameter_to_bool(value);
+          else cdo_abort("Invalid parameter key >%s<!", key);
+          // clang-format on
         }
     }
-
-  if (irun) field.numMissVals = field_num_miss(field);
 }
 
 class Timstat : public Process
@@ -176,85 +190,100 @@ public:
   };
   inline static RegisterEntry<Timstat> registration = RegisterEntry<Timstat>(module);
 
+private:
   static const TimeStat timestatDate{ TimeStat::MEAN };
-  CdiDateTime vDateTime0{};
-  CdiDateTime vDateTimeN{};
 
   CdoStreamID streamID1;
-  int taxisID1;
-
   CdoStreamID streamID2;
+  CdoStreamID streamID3;
+  int taxisID1;
   int taxisID2;
 
-  CdoStreamID streamID3;
-  int vlistID3, taxisID3{ -1 };
-
-  int ntsteps1;
-
-  bool lstd{ false };
-  bool lminidx{ false };
-  bool lmaxidx{ false };
-  bool lrange{ false };
-  bool lvarstd{ false };
-  bool lmean{ false };
-  double divisor;
-
-  int operfunc;
+  int vlistID3;
+  int taxisID3{ -1 };
 
   int compareDate;
-  int maxrecs;
+  int maxRecords;
 
-  bool lvfrac{ false };
-  double vfrac{ 1.0 };
+  bool completeOnly{ false };
+  bool handleVfraction{ false };
+  double vfraction{ -1.0 };
 
+  cdo::StepStat2D stepStat;
+
+  std::vector<RecordInfo> recordList;
   DateTimeList dtlist;
-  std::vector<RecordInfo> recList;
+  VarList varList1;
 
-  VarList varList;
-  Field field;
-  Varray<double> samp;
-  FieldVector2D samp1, vars1, vars2;
+  void
+  create_diag_stream(int operatorID, int vlistID1, int numVars)
+  {
+    char filename[8192];
+    std::strcpy(filename, cdo_operator_name(operatorID));
+    strcat(filename, "_");
+    strcat(filename, cdo_get_stream_name(1));
+    streamID3 = cdo_open_write(filename);
+
+    vlistID3 = vlistDuplicate(vlistID1);
+
+    for (int varID = 0; varID < numVars; ++varID)
+      {
+        vlistDefVarDatatype(vlistID3, varID, CDI_DATATYPE_INT32);
+        vlistDefVarMissval(vlistID3, varID, -1);
+        cdiDefKeyString(vlistID3, varID, CDI_KEY_UNITS, "");
+        cdiDeleteKey(vlistID3, varID, CDI_KEY_ADDOFFSET);
+        cdiDeleteKey(vlistID3, varID, CDI_KEY_SCALEFACTOR);
+      }
+
+    taxisID3 = taxisDuplicate(taxisID1);
+    taxisWithBounds(taxisID3);
+    vlistDefTaxis(vlistID3, taxisID3);
+
+    cdo_def_vlist(streamID3, vlistID3);
+  }
+
+  bool
+  check_numSets(std::vector<int> &numSetsList)
+  {
+    std::unordered_map<int, std::pair<double, std::string>> periodNameMap
+        = { { CMP_DAY, { 23.0 / 24.0, "day" } }, { CMP_MONTH, { 28 / 31.0, "month" } }, { CMP_YEAR, { 365 / 366.0, "year" } } };
+
+    if (numSetsList.size() > 1)
+      {
+        auto start = (numSetsList.size() > 2) ? 1 : 0;
+        auto numSetsMin = std::min_element(numSetsList.begin() + start, numSetsList.end() - 1);
+        auto [periodFactor, periodName] = periodNameMap[compareDate];
+        if ((double) numSetsList.back() < *numSetsMin * periodFactor)
+          {
+            if (Options::cdoVerbose)
+              cdo_warning("Last %s has less steps (%d) than all previous %ss (%d)!", periodName, numSetsList.back(), periodName,
+                          *numSetsMin);
+            return true;
+          }
+      }
+
+    return false;
+  }
 
 public:
   void
-  init()
+  init() override
   {
-
     auto operatorID = cdo_operator_id();
-    operfunc = cdo_operator_f1(operatorID);
+    auto operfunc = cdo_operator_f1(operatorID);
     compareDate = cdo_operator_f2(operatorID);
 
-    auto lminmax = (operfunc == FieldFunc_Min || operfunc == FieldFunc_Max);
-    lminidx = (operfunc == FieldFunc_Minidx);
-    lmaxidx = (operfunc == FieldFunc_Maxidx);
-    lrange = (operfunc == FieldFunc_Range);
-    lmean = (operfunc == FieldFunc_Mean || operfunc == FieldFunc_Avg);
-    lstd = (operfunc == FieldFunc_Std || operfunc == FieldFunc_Std1);
-    lvarstd = (lstd || operfunc == FieldFunc_Var || operfunc == FieldFunc_Var1);
-    auto lvars2 = (lvarstd || lrange || lminidx || lmaxidx);
-    divisor = (operfunc == FieldFunc_Std1 || operfunc == FieldFunc_Var1);
+    stepStat.init(operfunc);
 
-    if (operfunc == FieldFunc_Mean)
-      {
-        auto oargc = cdo_operator_argc();
-        if (oargc == 1)
-          {
-            lvfrac = true;
-            vfrac = parameter_to_double(cdo_operator_argv(0));
-            if (Options::cdoVerbose) cdo_print("Set vfrac to %g", vfrac);
-            if (vfrac < 0 || vfrac > 1) cdo_abort("vfrac out of range!");
-          }
-        else if (oargc > 1)
-          cdo_abort("Too many arguments!");
-      }
-    else { operator_check_argc(0); }
+    get_parameter(vfraction, completeOnly);
+    handleVfraction = (vfraction >= 0.0 && vfraction <= 1.0);
 
     streamID1 = cdo_open_read(0);
 
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
-    if (!lminmax) vlist_unpack(vlistID2);
+    if (!stepStat.lminmax) vlist_unpack(vlistID2);
 
     vlist_define_timestep_type(vlistID2, operfunc);
 
@@ -266,70 +295,41 @@ public:
     if (taxisInqType(taxisID2) == TAXIS_FORECAST) taxisDefType(taxisID2, TAXIS_RELATIVE);
     vlistDefTaxis(vlistID2, taxisID2);
 
-    auto nvars = vlistNvars(vlistID1);
+    varList1 = VarList(vlistID1);
 
     vlist_set_frequency(vlistID2, compareDate);
 
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    if (Options::cdoDiag)
-      {
-        char filename[8192];
-        std::strcpy(filename, cdo_operator_name(operatorID));
-        strcat(filename, "_");
-        strcat(filename, cdo_get_stream_name(1));
-        streamID3 = cdo_open_write(filename);
+    if (Options::cdoDiag) create_diag_stream(operatorID, vlistID1, varList1.numVars());
 
-        vlistID3 = vlistDuplicate(vlistID1);
-
-        for (int varID = 0; varID < nvars; ++varID)
-          {
-            vlistDefVarDatatype(vlistID3, varID, CDI_DATATYPE_INT32);
-            vlistDefVarMissval(vlistID3, varID, -1);
-            cdiDefKeyString(vlistID3, varID, CDI_KEY_UNITS, "");
-            cdiDeleteKey(vlistID3, varID, CDI_KEY_ADDOFFSET);
-            cdiDeleteKey(vlistID3, varID, CDI_KEY_SCALEFACTOR);
-          }
-
-        taxisID3 = taxisDuplicate(taxisID1);
-        taxisWithBounds(taxisID3);
-        vlistDefTaxis(vlistID3, taxisID3);
-
-        cdo_def_vlist(streamID3, vlistID3);
-      }
-
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
+    maxRecords = varList1.numRecords();
+    recordList = std::vector<RecordInfo>(maxRecords);
 
     dtlist.set_stat(timestatDate);
     dtlist.set_calendar(taxisInqCalendar(taxisID1));
 
-    varList_init(varList, vlistID1);
-
-    int VARS_MEMTYPE = lminmax ? FIELD_NAT : 0;
-    // if ((Options::CDO_???(--single) == MemType::Float) && (operfunc == FieldFunc_Mean)) VARS_MEMTYPE = FIELD_NAT;
+    int VARS_MEMTYPE = stepStat.lminmax ? FIELD_NAT : 0;
+    // if ((Options::CDO_???(--single) == MemType::Float) && stepStat.lmean) VARS_MEMTYPE = FIELD_NAT;
     // if (Options::CDO_Memtype == MemType::Float) VARS_MEMTYPE = FIELD_FLT;
-    if (Options::cdoDiag || (lvfrac && operfunc == FieldFunc_Mean)) VARS_MEMTYPE = FIELD_DBL;
+    if (Options::cdoDiag || (handleVfraction && stepStat.lmean)) VARS_MEMTYPE = FIELD_DBL;
 
-    fields_from_vlist(vlistID1, samp1);
-    fields_from_vlist(vlistID1, vars1, FIELD_VEC | VARS_MEMTYPE);
-    if (lvars2) fields_from_vlist(vlistID1, vars2, FIELD_VEC);
+    stepStat.alloc(varList1, VARS_MEMTYPE);
 
-    auto numVars = varList.size();
-    for (size_t varID = 0; varID < numVars; ++varID) varList[varID].memType = vars1[varID][0].memType;
-
-    ntsteps1 = vlistNtsteps(vlistID1);
-
-    if (!Options::cdoVerbose && ntsteps1 > 1) progress::init();
+    // for (auto &var1 : varList1.vars) var1.memType = stepStat.var1(var1.ID, 0).memType;
   }
 
   void
-  run()
+  run_sync()
   {
+    std::vector<int> numSetsList;
+    CdiDateTime vDateTime0{};
+    CdiDateTime vDateTimeN{};
+    Field field;
 
-    auto field2_stdvar_func = lstd ? field2_std : field2_var;
-    auto fieldc_stdvar_func = lstd ? fieldc_std : fieldc_var;
+    auto numSteps1 = varList1.numSteps();
+    cdo::Progress progress;
 
     int tsID = 0;
     int otsID = 0;
@@ -342,7 +342,7 @@ public:
             nrecs = cdo_stream_inq_timestep(streamID1, tsID);
             if (nrecs == 0) break;
 
-            if (!Options::cdoVerbose && ntsteps1 > 1) progress::update(0, 1, (tsID + 1.0) / ntsteps1);
+            if (numSteps1 > 1) progress.update((tsID + 1.0) / numSteps1);
 
             dtlist.taxis_inq_timestep(taxisID1, numSets);
             auto vDateTime = dtlist.get_vDateTime(numSets);
@@ -357,61 +357,13 @@ public:
 
             for (int recID = 0; recID < nrecs; ++recID)
               {
-                int varID, levelID;
-                cdo_inq_record(streamID1, &varID, &levelID);
-
-                if (tsID == 0) recList[recID].set(varID, levelID);
-
-                auto &rsamp1 = samp1[varID][levelID];
-                auto &rvars1 = vars1[varID][levelID];
-
-                if (numSets == 0)
-                  {
-                    cdo_read_record(streamID1, rvars1);
-                    if (lrange || lminidx || lmaxidx)
-                      {
-                        vars2[varID][levelID].numMissVals = rvars1.numMissVals;
-                        vars2[varID][levelID].vec_d = rvars1.vec_d;
-                      }
-
-                    if (lminidx || lmaxidx) field_fill(rvars1, 0.0);
-
-                    if (rvars1.numMissVals || !rsamp1.empty())
-                      {
-                        if (rsamp1.empty()) rsamp1.resize(rvars1.size);
-                        field2_vinit(rsamp1, rvars1);
-                      }
-                  }
-                else
-                  {
-                    field.init(varList[varID]);
-                    cdo_read_record(streamID1, field);
-
-                    if (field.numMissVals || !rsamp1.empty())
-                      {
-                        if (rsamp1.empty()) rsamp1.resize(rvars1.size, numSets);
-                        field2_vincr(rsamp1, field);
-                      }
-
-                    // clang-format off
-                    if      (lvarstd) field2_sumsumq(rvars1, vars2[varID][levelID], field);
-                    else if (lrange)  field2_maxmin(rvars1, vars2[varID][levelID], field);
-                    else if (lminidx) field2_minidx(rvars1, vars2[varID][levelID], field, numSets);
-                    else if (lmaxidx) field2_maxidx(rvars1, vars2[varID][levelID], field, numSets);
-                    else              field2_function(rvars1, field, operfunc);
-                    // clang-format on
-                  }
+                auto [varID, levelID] = cdo_inq_record(streamID1);
+                if (tsID == 0) recordList[recID].set(varID, levelID);
+                field.init(varList1.vars[varID]);
+                cdo_read_record(streamID1, field);
+                stepStat.add_field(field, varID, levelID, numSets);
               }
 
-            if (numSets == 0 && lvarstd)
-              for (int recID = 0; recID < maxrecs; ++recID)
-                {
-                  auto [varID, levelID] = recList[recID].get();
-                  if (varList[varID].isConstant) continue;
-
-                  field2_moq(vars2[varID][levelID], vars1[varID][levelID]);
-                }
-
             vDateTimeN = vDateTime;
             numSets++;
             tsID++;
@@ -419,86 +371,147 @@ public:
 
         if (nrecs == 0 && numSets == 0) break;
 
-        for (int recID = 0; recID < maxrecs; ++recID)
+        if (compareDate == CMP_DAY || compareDate == CMP_MONTH || compareDate == CMP_YEAR)
           {
-            auto [varID, levelID] = recList[recID].get();
-            if (varList[varID].isConstant) continue;
-
-            const auto &rsamp1 = samp1[varID][levelID];
-            auto &rvars1 = vars1[varID][levelID];
-
-            if (lmean)
-              {
-                if (!rsamp1.empty())
-                  field2_div(rvars1, rsamp1);
-                else
-                  fieldc_div(rvars1, (double) numSets);
-              }
-            else if (lvarstd)
-              {
-                if (!rsamp1.empty())
-                  field2_stdvar_func(rvars1, vars2[varID][levelID], rsamp1, divisor);
-                else
-                  fieldc_stdvar_func(rvars1, vars2[varID][levelID], numSets, divisor);
-              }
-            else if (lrange) { field2_sub(rvars1, vars2[varID][levelID]); }
+            numSetsList.push_back(numSets);
+            if (nrecs == 0 && check_numSets(numSetsList) && completeOnly) break;
           }
 
-        if (Options::cdoVerbose) cdo_print("%s  vfrac = %g, numSets = %d", datetime_to_string(vDateTimeN), vfrac, numSets);
+        cdo::records_process(recordList, varList1, stepStat, numSets);
 
-        if (lvfrac && operfunc == FieldFunc_Mean)
-          for (int recID = 0; recID < maxrecs; ++recID)
-            {
-              auto [varID, levelID] = recList[recID].get();
-              if (varList[varID].isConstant) continue;
+        if (Options::cdoVerbose) cdo_print("%s  numSteps = %d", datetime_to_string(vDateTimeN), numSets);
 
-              const auto &rsamp1 = samp1[varID][levelID];
-
-              if (!rsamp1.empty()) set_missval(vars1[varID][levelID], rsamp1, numSets, vfrac);
-            }
+        if (handleVfraction && stepStat.lmean) cdo::records_set_missval(recordList, varList1, stepStat, numSets, vfraction);
 
         dtlist.stat_taxis_def_timestep(taxisID2, numSets);
-        cdo_def_timestep(streamID2, otsID);
+        cdo::write_out_stream(streamID2, recordList, varList1, stepStat, otsID);
 
         if (Options::cdoDiag)
           {
             dtlist.stat_taxis_def_timestep(taxisID3, numSets);
-            cdo_def_timestep(streamID3, otsID);
-          }
-
-        for (int recID = 0; recID < maxrecs; ++recID)
-          {
-            auto [varID, levelID] = recList[recID].get();
-            if (otsID && varList[varID].isConstant) continue;
-
-            auto &rvars1 = vars1[varID][levelID];
-
-            cdo_def_record(streamID2, varID, levelID);
-            cdo_write_record(streamID2, rvars1);
-
-            if (Options::cdoDiag)
-              {
-                auto &rsamp1 = samp1[varID][levelID];
-                samp.resize(field.size);
-                if (!rsamp1.empty())
-                  samp = rsamp1.vec_d;
-                else
-                  ranges::fill(samp, (double) numSets);
-
-                cdo_def_record(streamID3, varID, levelID);
-                cdo_write_record(streamID3, samp.data(), 0);
-              }
+            cdo::write_diag_stream(streamID3, recordList, varList1, stepStat, otsID, numSets);
           }
 
         if (nrecs == 0) break;
         otsID++;
       }
+  }
 
-    if (!Options::cdoVerbose && ntsteps1 > 1) progress::update(0, 1, 1);
+  static void
+  records_add_fields2D(const FieldVector2D &fields2D, const std::vector<RecordInfo> &recordList, const VarList &varList1,
+                       cdo::StepStat2D &stepStat, int numSets) noexcept
+  {
+    for (const auto &record : recordList)
+      {
+        auto [varID, levelID] = record.get();
+        if (varList1.vars[varID].isConstant) continue;
+
+        stepStat.add_field(fields2D[varID][levelID], varID, levelID, numSets);
+      }
   }
 
   void
-  close()
+  run_async()
+  {
+    std::vector<int> numSetsList;
+    CdiDateTime vDateTime0{};
+    CdiDateTime vDateTimeN{};
+    auto numSteps = varList1.numSteps();
+    cdo::Progress progress;
+
+    FieldVector3D fields3D(2);
+    field2D_init(fields3D[0], varList1, FIELD_VEC | FIELD_NAT);
+    field2D_init(fields3D[1], varList1, FIELD_VEC | FIELD_NAT);
+
+    auto useTask = true;
+    auto task = useTask ? std::make_unique<cdo::Task>() : nullptr;
+
+    int tsID = 0;
+    int otsID = 0;
+    while (true)
+      {
+        int numSets = 0;
+        int nrecs = 0;
+        while (true)
+          {
+            nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+            if (nrecs == 0) break;
+
+            if (numSteps > 1) progress.update((tsID + 1.0) / numSteps);
+
+            dtlist.taxis_inq_timestep(taxisID1, numSets);
+            auto vDateTime = dtlist.get_vDateTime(numSets);
+
+            if (numSets == 0) vDateTime0 = vDateTime;
+
+            if (date_is_neq(vDateTime, vDateTime0, compareDate))
+              {
+                cdo_add_steps(-1);
+                break;
+              }
+
+            for (int recID = 0; recID < nrecs; ++recID)
+              {
+                auto [varID, levelID] = cdo_inq_record(streamID1);
+                if (tsID == 0) recordList[recID].set(varID, levelID);
+                cdo_read_record(streamID1, fields3D[numSets % 2][varID][levelID]);
+              }
+
+            if (useTask && numSets > 0) task->wait();
+
+            std::function<void()> records_add_fields2D_func
+                = std::bind(records_add_fields2D, std::cref(fields3D[numSets % 2]), std::cref(recordList), std::cref(varList1),
+                            std::ref(stepStat), numSets);
+
+            useTask ? task->doAsync(records_add_fields2D_func) : records_add_fields2D_func();
+
+            vDateTimeN = vDateTime;
+            numSets++;
+            tsID++;
+          }
+
+        if (nrecs == 0 && numSets == 0) break;
+
+        if (useTask) task->wait();
+
+        if (compareDate == CMP_DAY || compareDate == CMP_MONTH || compareDate == CMP_YEAR)
+          {
+            numSetsList.push_back(numSets);
+            if (nrecs == 0 && check_numSets(numSetsList) && completeOnly) break;
+          }
+
+        cdo::records_process(recordList, varList1, stepStat, numSets);
+
+        if (Options::cdoVerbose) cdo_print("%s  numSteps = %d", datetime_to_string(vDateTimeN), numSets);
+
+        if (handleVfraction && stepStat.lmean) cdo::records_set_missval(recordList, varList1, stepStat, numSets, vfraction);
+
+        dtlist.stat_taxis_def_timestep(taxisID2, numSets);
+        cdo::write_out_stream(streamID2, recordList, varList1, stepStat, otsID);
+
+        if (Options::cdoDiag)
+          {
+            dtlist.stat_taxis_def_timestep(taxisID3, numSets);
+            cdo::write_diag_stream(streamID3, recordList, varList1, stepStat, otsID, numSets);
+          }
+
+        if (nrecs == 0) break;
+        otsID++;
+      }
+  }
+
+  void
+  run() override
+  {
+    auto runAsync = (Options::CDO_Parallel_Read > 0);
+    if (runAsync)
+      run_async();
+    else
+      run_sync();
+  }
+
+  void
+  close() override
   {
     if (Options::cdoDiag) cdo_stream_close(streamID3);
     cdo_stream_close(streamID2);
