@@ -14,8 +14,9 @@
 #include <cdi.h>
 
 #include "arithmetic.h"
+#include "field.h"
 #include "process_int.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "field_functions.h"
 
 double
@@ -30,9 +31,12 @@ calc_pvalue(double cor, size_t n)
 // correlation in time
 template <typename T1, typename T2>
 void
-correlation_init(bool hasMissValues, size_t gridsize, const Varray<T1> &x, const Varray<T2> &y, T1 xmv, T2 ymv,
+correlation_init(const Varray<T1> &x, const Varray<T2> &y, double missval1, double missval2, bool hasMissValues, size_t gridsize,
                  Varray<size_t> &nofvals, Varray2D<double> &work)
 {
+  T1 xmv = missval1;
+  T2 ymv = missval2;
+
   auto correlation_sum = [&](auto i) {
     double xx = x[i];
     double yy = y[i];
@@ -53,7 +57,7 @@ correlation_init(bool hasMissValues, size_t gridsize, const Varray<T1> &x, const
 #endif
       for (size_t i = 0; i < gridsize; ++i)
         {
-          if ((dbl_is_not_equal(x[i], xmv)) && (dbl_is_not_equal(y[i], ymv))) correlation_sum(i);
+          if ((fp_is_not_equal(x[i], xmv)) && (fp_is_not_equal(y[i], ymv))) correlation_sum(i);
         }
     }
   else
@@ -72,21 +76,16 @@ correlation_init(size_t gridsize, const Field &field1, const Field &field2, Varr
 {
   auto hasMissValues = (field1.numMissVals > 0 || field2.numMissVals > 0);
 
-  if (field1.memType == MemType::Float && field2.memType == MemType::Float)
-    correlation_init(hasMissValues, gridsize, field1.vec_f, field2.vec_f, (float) field1.missval, (float) field2.missval, nofvals,
-                     work);
-  else if (field1.memType == MemType::Float && field2.memType == MemType::Double)
-    correlation_init(hasMissValues, gridsize, field1.vec_f, field2.vec_d, (float) field1.missval, field2.missval, nofvals, work);
-  else if (field1.memType == MemType::Double && field2.memType == MemType::Float)
-    correlation_init(hasMissValues, gridsize, field1.vec_d, field2.vec_f, field1.missval, (float) field2.missval, nofvals, work);
-  else
-    correlation_init(hasMissValues, gridsize, field1.vec_d, field2.vec_d, field1.missval, field2.missval, nofvals, work);
+  auto func = [&](const auto &v1, const auto &v2, double mv1, double mv2) {
+    correlation_init(v1, v2, mv1, mv2, hasMissValues, gridsize, nofvals, work);
+  };
+  field_operation2(func, field1, field2, field1.missval, field2.missval);
 }
 
 static size_t
 correlation(size_t gridsize, double missval, const Varray<size_t> &nofvals, Varray2D<double> &work)
 {
-  auto is_EQ = dbl_is_equal;
+  auto is_EQ = fp_is_equal;
   auto missval1 = missval;
   auto missval2 = missval;
 
@@ -110,7 +109,7 @@ correlation(size_t gridsize, double missval, const Varray<size_t> &nofvals, Varr
           cor = DIVM(temp1, SQRTM(temp6));
           cor = std::clamp(cor, -1.0, 1.0);
 
-          if (dbl_is_equal(cor, missval)) numMissVals++;
+          if (fp_is_equal(cor, missval)) numMissVals++;
 
           pvalue = (nvals <= 2) ? missval : ((fabs(cor) < 1) ? calc_pvalue(cor, nvals) : 1);
         }
@@ -131,9 +130,12 @@ correlation(size_t gridsize, double missval, const Varray<size_t> &nofvals, Varr
 // covariance in time
 template <typename T1, typename T2>
 static void
-covariance_init(bool hasMissValues, size_t gridsize, const Varray<T1> &x, const Varray<T2> &y, T1 xmv, T2 ymv,
+covariance_init(const Varray<T1> &x, const Varray<T2> &y, double missval1, double missval2, bool hasMissValues, size_t gridsize,
                 Varray<size_t> &nofvals, Varray2D<double> &work)
 {
+  T1 xmv = missval1;
+  T2 ymv = missval2;
+
   auto covariance_sum = [&](auto i) {
     double xx = x[i];
     double yy = y[i];
@@ -152,7 +154,7 @@ covariance_init(bool hasMissValues, size_t gridsize, const Varray<T1> &x, const
 #endif
       for (size_t i = 0; i < gridsize; ++i)
         {
-          if ((dbl_is_not_equal(x[i], xmv)) && (dbl_is_not_equal(y[i], ymv))) covariance_sum(i);
+          if ((fp_is_not_equal(x[i], xmv)) && (fp_is_not_equal(y[i], ymv))) covariance_sum(i);
         }
     }
   else
@@ -171,21 +173,16 @@ covariance_init(size_t gridsize, const Field &field1, const Field &field2, Varra
 {
   auto hasMissValues = (field1.numMissVals > 0 || field2.numMissVals > 0);
 
-  if (field1.memType == MemType::Float && field2.memType == MemType::Float)
-    covariance_init(hasMissValues, gridsize, field1.vec_f, field2.vec_f, (float) field1.missval, (float) field2.missval, nofvals,
-                    work);
-  else if (field1.memType == MemType::Float && field2.memType == MemType::Double)
-    covariance_init(hasMissValues, gridsize, field1.vec_f, field2.vec_d, (float) field1.missval, field2.missval, nofvals, work);
-  else if (field1.memType == MemType::Double && field2.memType == MemType::Float)
-    covariance_init(hasMissValues, gridsize, field1.vec_d, field2.vec_f, field1.missval, (float) field2.missval, nofvals, work);
-  else
-    covariance_init(hasMissValues, gridsize, field1.vec_d, field2.vec_d, field1.missval, field2.missval, nofvals, work);
+  auto func = [&](const auto &v1, const auto &v2, double mv1, double mv2) {
+    covariance_init(v1, v2, mv1, mv2, hasMissValues, gridsize, nofvals, work);
+  };
+  field_operation2(func, field1, field2, field1.missval, field2.missval);
 }
 
 static size_t
 covariance(size_t gridsize, double missval, const Varray<size_t> &nofvals, Varray2D<double> &work)
 {
-  auto is_EQ = dbl_is_equal;
+  auto is_EQ = fp_is_equal;
   auto missval1 = missval;
   auto missval2 = missval;
 
@@ -199,7 +196,7 @@ covariance(size_t gridsize, double missval, const Varray<size_t> &nofvals, Varra
           double dnvals = nvals;
           auto temp = DIVM(MULM(work[0][i], work[1][i]), dnvals * dnvals);
           covar = SUBM(DIVM(work[2][i], dnvals), temp);
-          if (dbl_is_equal(covar, missval)) numMissVals++;
+          if (fp_is_equal(covar, missval)) numMissVals++;
         }
       else
         {
@@ -216,11 +213,15 @@ covariance(size_t gridsize, double missval, const Varray<size_t> &nofvals, Varra
 // rms in time
 template <typename T1, typename T2>
 static void
-rmsd_init(size_t gridsize, const Varray<T1> &x, const Varray<T2> &y, T1 xmv, T2 ymv, Varray<size_t> &nofvals, Varray<double> &rmsd)
+rmsd_init(const Varray<T1> &x, const Varray<T2> &y, double missval1, double missval2, size_t gridsize, Varray<size_t> &nofvals,
+          Varray<double> &rmsd)
 {
+  T1 xmv = missval1;
+  T2 ymv = missval2;
+
   for (size_t i = 0; i < gridsize; ++i)
     {
-      if ((dbl_is_not_equal(x[i], xmv)) && (dbl_is_not_equal(y[i], ymv)))
+      if ((fp_is_not_equal(x[i], xmv)) && (fp_is_not_equal(y[i], ymv)))
         {
           double xx = x[i];
           double yy = y[i];
@@ -233,14 +234,8 @@ rmsd_init(size_t gridsize, const Varray<T1> &x, const Varray<T2> &y, T1 xmv, T2
 static void
 rmsd_init(size_t gridsize, const Field &field1, const Field &field2, Varray<size_t> &nofvals, Varray<double> &rmsd)
 {
-  if (field1.memType == MemType::Float && field2.memType == MemType::Float)
-    rmsd_init(gridsize, field1.vec_f, field2.vec_f, (float) field1.missval, (float) field2.missval, nofvals, rmsd);
-  else if (field1.memType == MemType::Float && field2.memType == MemType::Double)
-    rmsd_init(gridsize, field1.vec_f, field2.vec_d, (float) field1.missval, field2.missval, nofvals, rmsd);
-  else if (field1.memType == MemType::Double && field2.memType == MemType::Float)
-    rmsd_init(gridsize, field1.vec_d, field2.vec_f, field1.missval, (float) field2.missval, nofvals, rmsd);
-  else
-    rmsd_init(gridsize, field1.vec_d, field2.vec_d, field1.missval, field2.missval, nofvals, rmsd);
+  auto func = [&](const auto &v1, const auto &v2, double mv1, double mv2) { rmsd_init(v1, v2, mv1, mv2, gridsize, nofvals, rmsd); };
+  field_operation2(func, field1, field2, field1.missval, field2.missval);
 }
 
 static size_t
@@ -266,9 +261,11 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Timstat2",
+    // clang-format off
     .operators = { { "timcor", FieldFunc_Cor, 5, TimcorHelp },
                    { "timcovar", FieldFunc_Covar, 3, TimcovarHelp },
                    { "timrmsd", FieldFunc_Rmsd, 1, nullptr } },
+    // clang-format on
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
