@@ -13,8 +13,15 @@
 
 #include <cdi.h>
 
-#include "process_int.h"
+#include "cpp_lib.h"
+/*
+#ifdef HAVE_LIB_MDSPAN
+#include <mdspan>
+#else
+*/
 #include "matrix_view.h"
+// #endif
+#include "process_int.h"
 
 void
 transxy(int gridID, const Varray<double> &v1, Varray<double> &v2)
@@ -25,11 +32,20 @@ transxy(int gridID, const Varray<double> &v1, Varray<double> &v2)
 
   if (gridsize == (nx * ny))
     {
+      /*
+#ifdef HAVE_LIB_MDSPAN
+    printf("using mdspan\n");
+    auto mV1 = std::mdspan(v1.data(), ny, nx);
+    auto mV2 = std::mdspan(v2.data(), nx, ny);
+    for (size_t j = 0; j < ny; ++j)
+      for (size_t i = 0; i < nx; ++i) mV2[i, j] = mV1[j, i];
+#else
+*/
       MatrixView<const double> mV1(v1.data(), ny, nx);
       MatrixView<double> mV2(v2.data(), nx, ny);
-
       for (size_t j = 0; j < ny; ++j)
         for (size_t i = 0; i < nx; ++i) mV2[i][j] = mV1[j][i];
+      // #endif
     }
   else
     {
@@ -43,7 +59,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Transpose",
-    .operators = { { "transxy"} },
+    .operators = { { "transxy" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -59,13 +75,14 @@ private:
   int taxisID2;
 
   int vlistID1;
+  VarList varList1;
 
   Varray<double> array1;
   Varray<double> array2;
 
 public:
   void
-  init()
+  init() override
   {
     operator_check_argc(0);
 
@@ -74,7 +91,9 @@ public:
     vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
-    auto ngrids = vlistNgrids(vlistID1);
+    varList1 = VarList(vlistID1);
+
+    auto ngrids = vlistNumGrids(vlistID1);
     for (int index = 0; index < ngrids; ++index)
       {
         auto gridID1 = vlistGrid(vlistID1, index);
@@ -103,7 +122,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -121,7 +140,7 @@ public:
             cdo_inq_record(streamID1, &varID, &levelID);
             cdo_read_record(streamID1, array1.data(), &numMissVals);
 
-            auto gridID = vlistInqVarGrid(vlistID1, varID);
+            auto gridID = varList1.vars[varID].gridID;
             transxy(gridID, array1, array2);
 
             cdo_def_record(streamID2, varID, levelID);
@@ -133,7 +152,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
