@@ -19,12 +19,13 @@
 #include "datetime.h"
 #include "pmlist.h"
 #include "param_conversion.h"
+#include "progress.h"
 #include "field_functions.h"
 #include "arithmetic.h"
 
 template <typename T>
 static void
-add_trend(double zj, const Varray<T> &v1, const Varray<double> &v2, const Varray<double> &v3, Varray<T> &v4, size_t n, double mv)
+add_trend(double zj, Varray<T> &v1, const Varray<double> &v2, const Varray<double> &v3, size_t n, double mv)
 {
   auto missval1 = mv;
   auto missval2 = mv;
@@ -32,25 +33,21 @@ add_trend(double zj, const Varray<T> &v1, const Varray<double> &v2, const Varray
   auto add_kernel = [&](auto i, auto is_EQ) { return ADDM(v1[i], ADDM(v2[i], MULM(v3[i], zj))); };
 
   if (std::isnan(missval1))
-    for (size_t i = 0; i < n; ++i) v4[i] = add_kernel(i, dbl_is_equal);
+    for (size_t i = 0; i < n; ++i) v1[i] = add_kernel(i, fp_is_equal);
   else
-    for (size_t i = 0; i < n; ++i) v4[i] = add_kernel(i, is_equal);
+    for (size_t i = 0; i < n; ++i) v1[i] = add_kernel(i, is_equal);
 }
 
 static void
-add_trend(double zj, const Field &field1, const Field &field2, const Field &field3, Field &field4)
+add_trend(double zj, Field &field1, const Field &field2, const Field &field3)
 {
-  if (field1.memType != field4.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    add_trend(zj, field1.vec_f, field2.vec_d, field3.vec_d, field4.vec_f, field1.size, field1.missval);
-  else
-    add_trend(zj, field1.vec_d, field2.vec_d, field3.vec_d, field4.vec_d, field1.size, field1.missval);
+  auto func = [&](auto &v1) { add_trend(zj, v1, field2.vec_d, field3.vec_d, field1.size, field1.missval); };
+  field_operation(func, field1);
 }
 
 template <typename T>
 static void
-sub_trend(double zj, const Varray<T> &v1, const Varray<double> &v2, const Varray<double> &v3, Varray<T> &v4, size_t n, double mv)
+sub_trend(double zj, Varray<T> &v1, const Varray<double> &v2, const Varray<double> &v3, size_t n, double mv)
 {
   auto missval1 = mv;
   auto missval2 = mv;
@@ -58,20 +55,16 @@ sub_trend(double zj, const Varray<T> &v1, const Varray<double> &v2, const Varray
   auto sub_kernel = [&](auto i, auto is_EQ) { return SUBM(v1[i], ADDM(v2[i], MULM(v3[i], zj))); };
 
   if (std::isnan(missval1))
-    for (size_t i = 0; i < n; ++i) v4[i] = sub_kernel(i, dbl_is_equal);
+    for (size_t i = 0; i < n; ++i) v1[i] = sub_kernel(i, fp_is_equal);
   else
-    for (size_t i = 0; i < n; ++i) v4[i] = sub_kernel(i, is_equal);
+    for (size_t i = 0; i < n; ++i) v1[i] = sub_kernel(i, is_equal);
 }
 
 static void
-sub_trend(double zj, const Field &field1, const Field &field2, const Field &field3, Field &field4)
+sub_trend(double zj, Field &field1, const Field &field2, const Field &field3)
 {
-  if (field1.memType != field4.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    sub_trend(zj, field1.vec_f, field2.vec_d, field3.vec_d, field4.vec_f, field1.size, field1.missval);
-  else
-    sub_trend(zj, field1.vec_d, field2.vec_d, field3.vec_d, field4.vec_d, field1.size, field1.missval);
+  auto func = [&](auto &v1) { sub_trend(zj, v1, field2.vec_d, field3.vec_d, field1.size, field1.missval); };
+  field_operation(func, field1);
 }
 
 static void
@@ -120,28 +113,23 @@ public:
   inline static RegisterEntry<Trendarith> registration = RegisterEntry<Trendarith>(module);
 
   CdoStreamID streamID1;
-  int taxisID1;
-
   CdoStreamID streamID2;
-
   CdoStreamID streamID3;
-
   CdoStreamID streamID4;
+
+  int taxisID1;
   int taxisID4;
 
   int operfunc;
 
   bool tstepIsEqual;
 
-  int calendar;
-
-  VarList varList;
+  VarList varList1;
   FieldVector2D vars2, vars3;
-  Field field1, field4;
 
 public:
   void
-  init()
+  init() override
   {
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);
@@ -160,28 +148,29 @@ public:
 
     vlist_unpack(vlistID4);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::Dim);
-    vlist_compare(vlistID1, vlistID3, CmpVlist::Dim);
+    varList1 = VarList(vlistID1);
+    VarList varList2(vlistID2);
+    VarList varList3(vlistID3);
+
+    varList_compare(varList1, varList2);
+    varList_compare(varList1, varList3);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID4 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID4, taxisID4);
 
-    varList_init(varList, vlistID1);
-
     streamID4 = cdo_open_write(3);
     cdo_def_vlist(streamID4, vlistID4);
 
-    fields_from_vlist(vlistID1, vars2, FIELD_VEC);
-    fields_from_vlist(vlistID1, vars3, FIELD_VEC);
+    field2D_init(vars2, varList1, FIELD_VEC);
+    field2D_init(vars3, varList1, FIELD_VEC);
 
     {
       auto nrecs = cdo_stream_inq_timestep(streamID2, 0);
       for (int recID = 0; recID < nrecs; ++recID)
         {
-          int varID, levelID;
-          cdo_inq_record(streamID2, &varID, &levelID);
-          cdo_read_record(streamID2, vars2[varID][levelID].vec_d.data(), &vars2[varID][levelID].numMissVals);
+          auto [varID, levelID] = cdo_inq_record(streamID2);
+          cdo_read_record(streamID2, vars2[varID][levelID]);
         }
     }
 
@@ -189,21 +178,23 @@ public:
       auto nrecs = cdo_stream_inq_timestep(streamID3, 0);
       for (int recID = 0; recID < nrecs; ++recID)
         {
-          int varID, levelID;
-          cdo_inq_record(streamID3, &varID, &levelID);
-          cdo_read_record(streamID3, vars3[varID][levelID].vec_d.data(), &vars3[varID][levelID].numMissVals);
+          auto [varID, levelID] = cdo_inq_record(streamID3);
+          cdo_read_record(streamID3, vars3[varID][levelID]);
         }
     }
-
-    calendar = taxisInqCalendar(taxisID1);
   }
 
   void
-  run()
+  run() override
   {
+    auto calendar = taxisInqCalendar(taxisID1);
     CheckTimeIncr checkTimeIncr;
     JulianDate julianDate0;
     double deltat1 = 0.0;
+    auto numSteps = varList1.numSteps();
+    cdo::Progress progress;
+    Field field;
+
     int tsID = 0;
     while (true)
       {
@@ -220,21 +211,21 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            field1.init(varList[varID]);
-            cdo_read_record(streamID1, field1);
+            auto fstatus = (tsID + (recID + 1.0) / nrecs) / numSteps;
+            if (numSteps > 0) progress.update(fstatus);
 
-            field4.init(varList[varID]);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            const auto &var1 = varList1.vars[varID];
+            field.init(var1);
+            cdo_read_record(streamID1, field);
 
             if (operfunc == FieldFunc_Add)
-              add_trend(zj, field1, vars2[varID][levelID], vars3[varID][levelID], field4);
+              add_trend(zj, field, vars2[varID][levelID], vars3[varID][levelID]);
             else
-              sub_trend(zj, field1, vars2[varID][levelID], vars3[varID][levelID], field4);
+              sub_trend(zj, field, vars2[varID][levelID], vars3[varID][levelID]);
 
-            field4.numMissVals = field1.numMissVals;
             cdo_def_record(streamID4, varID, levelID);
-            cdo_write_record(streamID4, field4);
+            cdo_write_record(streamID4, field);
           }
 
         tsID++;
@@ -242,7 +233,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID4);
     cdo_stream_close(streamID3);
