@@ -16,21 +16,21 @@
 #include "process_int.h"
 #include "param_conversion.h"
 #include "cdo_options.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "field_functions.h"
 
 template <typename T>
 static T
 tstepcount(long nts, T missval, const Varray<T> &v, T refval)
 {
-  if (DBL_IS_EQUAL(refval, missval)) return missval;
+  if (fp_is_equal(refval, missval)) return missval;
 
   long j;
   long n = 0;
   for (j = 0; j < nts; ++j)
     {
       n++;
-      if (DBL_IS_EQUAL(v[j], refval)) break;
+      if (fp_is_equal(v[j], refval)) break;
     }
 
   return (j == nts) ? missval : (T) n;
@@ -42,7 +42,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Tstepcount",
-    .operators = { { "tstepcount"} },
+    .operators = { { "tstepcount" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -53,21 +53,21 @@ public:
   CdiDateTime vDateTime{};
 
   CdoStreamID streamID1;
-  int taxisID1;
-  int vlistID1;
-
   CdoStreamID streamID2;
+
+  int vlistID1;
+  int taxisID1;
   int taxisID2;
 
-  int nvars;
+  int numVars;
   double refval;
 
   VarList varList1;
-  FieldVector3D vars;
+  FieldVector3D varsData;
 
 public:
   void
-  init()
+  init() override
   {
     refval = (cdo_operator_argc() == 1) ? parameter_to_double(cdo_operator_argv(0)) : 0.0;
 
@@ -78,8 +78,8 @@ public:
 
     vlistDefNtsteps(vlistID2, 1);
 
-    nvars = vlistNvars(vlistID1);
-    for (int varID = 0; varID < nvars; ++varID) cdiDefKeyString(vlistID2, varID, CDI_KEY_UNITS, "steps");
+    numVars = vlistNvars(vlistID1);
+    for (int varID = 0; varID < numVars; ++varID) cdiDefKeyString(vlistID2, varID, CDI_KEY_UNITS, "steps");
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
@@ -88,11 +88,11 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
-  
+
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -101,18 +101,17 @@ public:
         if (nrecs == 0) break;
 
         constexpr size_t NALLOC_INC = 1024;
-        if ((size_t) tsID >= vars.size()) vars.resize(vars.size() + NALLOC_INC);
+        if ((size_t) tsID >= varsData.size()) varsData.resize(varsData.size() + NALLOC_INC);
 
         vDateTime = taxisInqVdatetime(taxisID1);
 
-        fields_from_vlist(vlistID1, vars[tsID]);
+        field2D_init(varsData[tsID], varList1);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            auto &field = vars[tsID][varID][levelID];
-            field.init(varList1[varID]);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            auto &field = varsData[tsID][varID][levelID];
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
           }
 
@@ -123,12 +122,13 @@ public:
 
     std::vector<Field> fields(Threading::ompNumThreads);
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        auto memType = varList1[varID].memType;
-        auto missval = varList1[varID].missval;
-        auto gridsize = varList1[varID].gridsize;
-        for (int levelID = 0; levelID < varList1[varID].nlevels; ++levelID)
+        const auto &var1 = varList1.vars[varID];
+        auto memType = var1.memType;
+        auto missval = var1.missval;
+        auto gridsize = var1.gridsize;
+        for (int levelID = 0; levelID < var1.nlevels; ++levelID)
           {
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(dynamic, 1)
@@ -141,21 +141,21 @@ public:
                   {
                     auto &v = fields[ompthID].vec_f;
                     v.resize(nts);
-                    for (int t = 0; t < nts; ++t) v[t] = vars[t][varID][levelID].vec_f[i];
+                    for (int t = 0; t < nts; ++t) v[t] = varsData[t][varID][levelID].vec_f[i];
 
                     auto count = tstepcount(nts, (float) missval, v, (float) refval);
 
-                    vars[0][varID][levelID].vec_f[i] = count;
+                    varsData[0][varID][levelID].vec_f[i] = count;
                   }
                 else
                   {
                     auto &v = fields[ompthID].vec_d;
                     v.resize(nts);
-                    for (int t = 0; t < nts; ++t) v[t] = vars[t][varID][levelID].vec_d[i];
+                    for (int t = 0; t < nts; ++t) v[t] = varsData[t][varID][levelID].vec_d[i];
 
                     auto count = tstepcount(nts, missval, v, refval);
 
-                    vars[0][varID][levelID].vec_d[i] = count;
+                    varsData[0][varID][levelID].vec_d[i] = count;
                   }
               }
           }
@@ -164,12 +164,12 @@ public:
     taxisDefVdatetime(taxisID2, vDateTime);
     cdo_def_timestep(streamID2, 0);
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        for (int levelID = 0; levelID < varList1[varID].nlevels; ++levelID)
+        for (int levelID = 0; levelID < varList1.vars[varID].nlevels; ++levelID)
           {
             cdo_def_record(streamID2, varID, levelID);
-            auto &field1 = vars[0][varID][levelID];
+            auto &field1 = varsData[0][varID][levelID];
             field_num_mv(field1);
             cdo_write_record(streamID2, field1);
           }
@@ -177,7 +177,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
