@@ -24,16 +24,16 @@ public:
   inline static RegisterEntry<Unpack> registration = RegisterEntry<Unpack>(module);
 
   CdoStreamID streamID1;
-  int taxisID1;
-
   CdoStreamID streamID2;
+
+  int taxisID1;
   int taxisID2;
 
   VarList varList1;
 
 public:
   void
-  init()
+  init() override
   {
     operator_check_argc(0);
 
@@ -65,11 +65,11 @@ public:
     cdo_def_vlist(streamID2, vlistID2);
     vlistDestroy(vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
 
   void
-  run()
+  run() override
   {
     Field field;
 
@@ -84,9 +84,8 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            field.init(varList1[varID]);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
 
             cdo_def_record(streamID2, varID, levelID);
@@ -98,7 +97,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID1);
     cdo_stream_close(streamID2);
