@@ -18,7 +18,6 @@
 #include "stdnametable.h"
 #include "util_string.h"
 #include "const.h"
-#include "cdo_zaxis.h"
 #include "param_conversion.h"
 #include "vertint_util.h"
 
@@ -110,7 +109,7 @@ public:
   size_t gridsize;
 
   int numPL;
-  int nvars;
+  int numVars;
   int zaxisID_FL;
   int zaxisID_HL;
   int numFullLevels;
@@ -136,7 +135,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     AP2PLX = module.get_id("ap2plx");
     AP2HLX = module.get_id("ap2hlx");
@@ -176,12 +175,12 @@ public:
     auto zaxisIDp = zaxisCreate(zaxistype, numPL);
     zaxisDefLevels(zaxisIDp, levels.data());
 
-    varList_init(varList1, vlistID1);
-    varListSetUniqueMemtype(varList1);
-    auto memtype = varList1[0].memType;
+    varList1 = VarList(vlistID1);
+    varList_set_unique_memtype(varList1);
+    auto memtype = varList1.vars[0].memType;
 
-    nvars = vlistNvars(vlistID1);
-    for (int varID = 0; varID < nvars; ++varID)
+    numVars = varList1.numVars();
+    for (int varID = 0; varID < numVars; ++varID)
       {
         auto stdname = string_to_lower(cdo::inq_key_string(vlistID1, varID, CDI_KEY_STDNAME));
 
@@ -195,28 +194,28 @@ public:
 
     if (-1 != apressID_FL && -1 != apressID_HL)
       {
-        if (varList1[apressID_FL].nlevels == (varList1[apressID_HL].nlevels + 1)) std::swap(apressID_FL, apressID_HL);
+        if (varList1.vars[apressID_FL].nlevels == (varList1.vars[apressID_HL].nlevels + 1)) std::swap(apressID_FL, apressID_HL);
       }
 
     if (Options::cdoVerbose)
       {
         cdo_print("Found:");
         // clang-format off
-        if (-1 != psID)        cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1[psID].name);
-        if (-1 != dpressID)    cdo_print("  %s -> %s", var_stdname(pressure_thickness), varList1[dpressID].name);
-        if (-1 != apressID_FL) cdo_print("  %s (full) -> %s", var_stdname(air_pressure), varList1[apressID_FL].name);
-        if (-1 != apressID_HL) cdo_print("  %s (half) -> %s", var_stdname(air_pressure), varList1[apressID_HL].name);
+        if (-1 != psID)        cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1.vars[psID].name);
+        if (-1 != dpressID)    cdo_print("  %s -> %s", var_stdname(pressure_thickness), varList1.vars[dpressID].name);
+        if (-1 != apressID_FL) cdo_print("  %s (full) -> %s", var_stdname(air_pressure), varList1.vars[apressID_FL].name);
+        if (-1 != apressID_HL) cdo_print("  %s (half) -> %s", var_stdname(air_pressure), varList1.vars[apressID_HL].name);
         // clang-format on
       }
 
     if (-1 == apressID_FL) cdo_abort("%s not found!", var_stdname(air_pressure));
 
-    zaxisID_FL = (-1 == apressID_FL) ? -1 : varList1[apressID_FL].zaxisID;
-    zaxisID_HL = (-1 == apressID_HL) ? -1 : varList1[apressID_HL].zaxisID;
-    numFullLevels = (-1 == zaxisID_FL) ? 0 : varList1[apressID_FL].nlevels;
-    numHalfLevels = (-1 == zaxisID_HL) ? numFullLevels + 1 : varList1[apressID_HL].nlevels;
+    zaxisID_FL = (-1 == apressID_FL) ? -1 : varList1.vars[apressID_FL].zaxisID;
+    zaxisID_HL = (-1 == apressID_HL) ? -1 : varList1.vars[apressID_HL].zaxisID;
+    numFullLevels = (-1 == zaxisID_FL) ? 0 : varList1.vars[apressID_FL].nlevels;
+    numHalfLevels = (-1 == zaxisID_HL) ? numFullLevels + 1 : varList1.vars[apressID_HL].nlevels;
 
-    auto nzaxis = vlistNzaxis(vlistID1);
+    auto nzaxis = vlistNumZaxis(vlistID1);
     for (int index = 0; index < nzaxis; ++index)
       {
         auto zaxisID = vlistZaxis(vlistID1, index);
@@ -226,13 +225,13 @@ public:
           vlistChangeZaxis(vlistID2, zaxisID, zaxisIDp);
       }
 
-    varList_init(varList2, vlistID2);
-    varListSetMemtype(varList2, memtype);
+    varList2 = VarList(vlistID2);
+    varList_set_memtype(varList2, memtype);
 
-    processVars = std::vector<bool>(nvars);
-    interpVars = std::vector<bool>(nvars);
-    varnumMissVals = Varray2D<size_t>(nvars);
-    vardata1 = Field3DVector(nvars), vardata2 = Field3DVector(nvars);
+    processVars = std::vector<bool>(numVars);
+    interpVars = std::vector<bool>(numVars);
+    varnumMissVals = Varray2D<size_t>(numVars);
+    vardata1 = Field3DVector(numVars), vardata2 = Field3DVector(numVars);
 
     auto maxLevels = std::max(std::max(numFullLevels, numHalfLevels), numPL);
 
@@ -263,9 +262,9 @@ public:
         levels = phlev;
       }
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        const auto &var = varList1[varID];
+        const auto &var = varList1.vars[varID];
         auto isHeightAxis = is_height_axis(var.zaxisID);
 
         if (gridInqType(var.gridID) == GRID_SPECTRAL) cdo_abort("Spectral data unsupported!");
@@ -279,7 +278,7 @@ public:
         if (interpVars[varID])
           {
             varnumMissVals[varID].resize(maxLevels, 0);
-            vardata2[varID].init(varList2[varID]);
+            vardata2[varID].init(varList2.vars[varID]);
           }
         else
           {
@@ -299,9 +298,9 @@ public:
           cdo_warning("Surface pressure not found - set to lower bound of %s!", var_stdname(air_pressure));
       }
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        if (interpVars[varID] && varList1[varID].isConstant) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
+        if (interpVars[varID] && varList1.vars[varID].isConstant) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
       }
 
     streamID2 = cdo_open_write(1);
@@ -310,7 +309,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -318,10 +317,10 @@ public:
         auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
             processVars[varID] = false;
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             for (int levelID = 0; levelID < var.nlevels; ++levelID) varnumMissVals[varID][levelID] = 0;
           }
 
@@ -330,34 +329,33 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
             cdo_read_record(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
             processVars[varID] = true;
           }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           if (interpVars[varID]) processVars[varID] = true;
 
         if (zaxisID_FL != -1)
           {
-            if (tsID == 1 && varList1[apressID_FL].timetype == TIME_CONSTANT)
+            if (tsID == 1 && varList1.vars[apressID_FL].timeType == TIME_CONSTANT)
               cdo_warning("%s does not vary in time!", var_stdname(air_pressure));
 
             if (psID != -1)
               {
-                psProg.init(varList1[psID]);
+                psProg.init(varList1.vars[psID]);
                 field_copy(vardata1[psID], psProg);
               }
             else if (dpressID != -1)
               {
-                psProg.init(varList1[dpressID]);
+                psProg.init(varList1.vars[dpressID]);
                 field_fill(psProg, 0);
                 for (int k = 0; k < numFullLevels; ++k) field_add(psProg, vardata1[dpressID], k);
               }
             else
               {
-                psProg.init(varList1[apressID_FL]);
+                psProg.init(varList1.vars[apressID_FL]);
                 field_copy(vardata1[apressID_FL], numFullLevels - 1, psProg);
               }
 
@@ -378,11 +376,11 @@ public:
             if (!extrapolate) gen_vert_index_mv(vertIndex_HL, levels, gridsize, psProg, numMiss_HL);
           }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
             if (processVars[varID])
               {
-                const auto &var = varList1[varID];
+                const auto &var = varList1.vars[varID];
 
                 if (tsID > 0 && !interpVars[varID] && var.isConstant) continue;
 
@@ -407,7 +405,7 @@ public:
                       }
                   }
 
-                for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
+                for (int levelID = 0; levelID < varList2.vars[varID].nlevels; ++levelID)
                   {
                     cdo_def_record(streamID2, varID, levelID);
                     cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
@@ -421,7 +419,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
