@@ -19,7 +19,6 @@
 #include "field_vinterp.h"
 #include "stdnametable.h"
 #include "util_string.h"
-#include "const.h"
 #include "cdo_zaxis.h"
 #include "param_conversion.h"
 #include "vertint_util.h"
@@ -97,7 +96,7 @@ public:
   int taxisID2;
 
   size_t gridsize;
-  int nvars;
+  int numVars;
   int numFullLevels;
   int numHalfLevels;
 
@@ -121,7 +120,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     GH2HLX = module.get_id("gh2hlx");
 
@@ -145,15 +144,15 @@ public:
 
     gridsize = vlist_check_gridsize(vlistID1);
 
-    varList_init(varList1, vlistID1);
-    varListSetUniqueMemtype(varList1);
-    auto memtype = varList1[0].memType;
+    varList1 = VarList(vlistID1);
+    varList_set_unique_memtype(varList1);
+    auto memtype = varList1.vars[0].memType;
 
     auto stdnameHeight_FL = var_stdname(geometric_height_at_full_level_center);
     auto stdnameHeight_HL = var_stdname(geometric_height_at_half_level_center);
 
-    nvars = vlistNvars(vlistID1);
-    for (int varID = 0; varID < nvars; ++varID)
+    numVars = varList1.numVars();
+    for (int varID = 0; varID < numVars; ++varID)
       {
         auto stdname = string_to_lower(cdo::inq_key_string(vlistID1, varID, CDI_KEY_STDNAME));
         if (stdname == stdnameHeight_FL) heightID_FL = varID;
@@ -162,9 +161,9 @@ public:
 
     if (-1 == heightID_FL && -1 == heightID_HL)
       {
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             auto stdname = string_to_lower(cdo::inq_key_string(vlistID1, varID, CDI_KEY_STDNAME));
             if (stdname == "height" && var.units == "m")
               {
@@ -179,18 +178,18 @@ public:
     if (Options::cdoVerbose)
       {
         cdo_print("Found:");
-        if (-1 != heightID_FL) cdo_print("  %s -> %s", stdnameHeight_FL, varList1[heightID_FL].name);
-        if (-1 != heightID_HL) cdo_print("  %s -> %s", stdnameHeight_HL, varList1[heightID_HL].name);
+        if (-1 != heightID_FL) cdo_print("  %s -> %s", stdnameHeight_FL, varList1.vars[heightID_FL].name);
+        if (-1 != heightID_HL) cdo_print("  %s -> %s", stdnameHeight_HL, varList1.vars[heightID_HL].name);
       }
 
     if (-1 == heightID_FL && -1 == heightID_HL) cdo_abort("%s not found!", stdnameHeight_FL);
 
-    auto zaxisID_FL = (-1 == heightID_FL) ? -1 : varList1[heightID_FL].zaxisID;
-    auto zaxisID_HL = (-1 == heightID_HL) ? -1 : varList1[heightID_HL].zaxisID;
-    numFullLevels = (-1 == zaxisID_FL) ? 0 : varList1[heightID_FL].nlevels;
-    numHalfLevels = (-1 == zaxisID_HL) ? 0 : varList1[heightID_HL].nlevels;
+    auto zaxisID_FL = (-1 == heightID_FL) ? -1 : varList1.vars[heightID_FL].zaxisID;
+    auto zaxisID_HL = (-1 == heightID_HL) ? -1 : varList1.vars[heightID_HL].zaxisID;
+    numFullLevels = (-1 == zaxisID_FL) ? 0 : varList1.vars[heightID_FL].nlevels;
+    numHalfLevels = (-1 == zaxisID_HL) ? 0 : varList1.vars[heightID_HL].nlevels;
 
-    auto nzaxis = vlistNzaxis(vlistID1);
+    auto nzaxis = vlistNumZaxis(vlistID1);
     for (int index = 0; index < nzaxis; ++index)
       {
         auto zaxisID = vlistZaxis(vlistID1, index);
@@ -200,8 +199,8 @@ public:
           vlistChangeZaxis(vlistID2, zaxisID, zaxisID2);
       }
 
-    varList_init(varList2, vlistID2);
-    varListSetMemtype(varList2, memtype);
+    varList2 = VarList(vlistID2);
+    varList_set_memtype(varList2, memtype);
 
     if (!extrapolate) numMiss_FL.resize(heightLevels.size());
     if (!extrapolate) numMiss_HL.resize(heightLevels.size());
@@ -209,17 +208,17 @@ public:
     if (-1 != heightID_FL) vertIndex_FL.resize(gridsize * heightLevels.size());
     if (-1 != heightID_HL) vertIndex_HL.resize(gridsize * heightLevels.size());
 
-    processVars = std::vector<bool>(nvars);
-    interpVars = std::vector<bool>(nvars);
-    varnumMissVals = Varray2D<size_t>(nvars);
-    vardata1 = Field3DVector(nvars);
-    vardata2 = Field3DVector(nvars);
+    processVars = std::vector<bool>(numVars);
+    interpVars = std::vector<bool>(numVars);
+    varnumMissVals = Varray2D<size_t>(numVars);
+    vardata1 = Field3DVector(numVars);
+    vardata2 = Field3DVector(numVars);
 
     auto maxLevels = std::max(std::max(numFullLevels, numHalfLevels), (int) heightLevels.size());
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        const auto &var = varList1[varID];
+        const auto &var = varList1.vars[varID];
         auto isHeightAxis = is_height_axis(var.zaxisID);
 
         if (gridInqType(var.gridID) == GRID_SPECTRAL) cdo_abort("Spectral data unsupported!");
@@ -232,7 +231,7 @@ public:
         if (interpVars[varID])
           {
             varnumMissVals[varID].resize(maxLevels, 0);
-            vardata2[varID].init(varList2[varID]);
+            vardata2[varID].init(varList2.vars[varID]);
           }
         else
           {
@@ -250,9 +249,9 @@ public:
           }
       }
 
-    for (int varID = 0; varID < nvars; ++varID)
+    for (int varID = 0; varID < numVars; ++varID)
       {
-        const auto &var = varList1[varID];
+        const auto &var = varList1.vars[varID];
         if (interpVars[varID] && var.isConstant) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
       }
 
@@ -261,7 +260,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     Field heightBottom;
 
@@ -271,10 +270,10 @@ public:
         auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
             processVars[varID] = false;
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             for (int levelID = 0; levelID < var.nlevels; ++levelID) varnumMissVals[varID][levelID] = 0;
           }
 
@@ -283,43 +282,42 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
             cdo_read_record(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
             processVars[varID] = true;
           }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           if (interpVars[varID]) processVars[varID] = true;
 
         auto lreverse = true;
-        if (-1 != heightID_FL && (tsID == 0 || !varList1[heightID_FL].isConstant))
+        if (-1 != heightID_FL && (tsID == 0 || !varList1.vars[heightID_FL].isConstant))
           {
             gen_vert_index(vertIndex_FL, heightLevels, vardata1[heightID_FL], gridsize, lreverse);
             if (!extrapolate)
               {
-                heightBottom.init(varList1[heightID_FL]);
+                heightBottom.init(varList1.vars[heightID_FL]);
                 field_copy(vardata1[heightID_FL], numFullLevels - 1, heightBottom);
                 gen_vert_index_mv(vertIndex_FL, heightLevels, gridsize, heightBottom, numMiss_FL, lreverse);
               }
           }
 
-        if (-1 != heightID_HL && (tsID == 0 || !varList1[heightID_HL].isConstant))
+        if (-1 != heightID_HL && (tsID == 0 || !varList1.vars[heightID_HL].isConstant))
           {
             gen_vert_index(vertIndex_HL, heightLevels, vardata1[heightID_HL], gridsize, lreverse);
             if (!extrapolate)
               {
-                heightBottom.init(varList1[heightID_HL]);
+                heightBottom.init(varList1.vars[heightID_HL]);
                 field_copy(vardata1[heightID_HL], numHalfLevels - 1, heightBottom);
                 gen_vert_index_mv(vertIndex_HL, heightLevels, gridsize, heightBottom, numMiss_HL, lreverse);
               }
           }
 
-        for (int varID = 0; varID < nvars; ++varID)
+        for (int varID = 0; varID < numVars; ++varID)
           {
             if (processVars[varID])
               {
-                const auto &var = varList1[varID];
+                const auto &var = varList1.vars[varID];
                 if (tsID > 0 && !interpVars[varID] && var.isConstant) continue;
 
                 if (interpVars[varID])
@@ -343,7 +341,7 @@ public:
                       }
                   }
 
-                for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
+                for (int levelID = 0; levelID < varList2.vars[varID].nlevels; ++levelID)
                   {
                     cdo_def_record(streamID2, varID, levelID);
                     cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
@@ -357,7 +355,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
