@@ -21,7 +21,6 @@
 #include "stdnametable.h"
 #include "constants.h"
 #include "const.h"
-#include "cdo_zaxis.h"
 #include "param_conversion.h"
 #include "vertint_util.h"
 
@@ -113,7 +112,7 @@ zaxis_is_hybrid(int zaxisType)
 static void
 change_hybrid_zaxis(int vlistID1, int vlistID2, int vctSize, double *vct, int zaxisID2, int numFullLevels, int numHalfLevels)
 {
-  auto nzaxis = vlistNzaxis(vlistID1);
+  auto nzaxis = vlistNumZaxis(vlistID1);
   for (int iz = 0; iz < nzaxis; ++iz)
     {
       auto zaxisID = vlistZaxis(vlistID1, iz);
@@ -129,6 +128,20 @@ change_hybrid_zaxis(int vlistID1, int vlistID2, int vctSize, double *vct, int za
     }
 }
 
+static void
+print_vars_found(const VarIDs &varIDs, const CdoVars &vars)
+{
+  cdo_print("Found:");
+  // clang-format off
+  if (-1 != varIDs.tempID)    cdo_print("  %s -> %s", var_stdname(air_temperature), vars[varIDs.tempID].name);
+  if (-1 != varIDs.psID)      cdo_print("  %s -> %s", var_stdname(surface_air_pressure), vars[varIDs.psID].name);
+  if (-1 != varIDs.lnpsID)    cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), vars[varIDs.lnpsID].name);
+  if (-1 != varIDs.sgeopotID) cdo_print("  %s -> %s", var_stdname(surface_geopotential), vars[varIDs.sgeopotID].name);
+  if (-1 != varIDs.geopotID)  cdo_print("  %s -> %s", var_stdname(geopotential), vars[varIDs.geopotID].name);
+  if (-1 != varIDs.gheightID) cdo_print("  %s -> %s", var_stdname(geopotential_height), vars[varIDs.gheightID].name);
+  // clang-format on
+}
+
 static void
 pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel, bool extrapolate)
 {
@@ -139,10 +152,9 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
   auto vlistID1 = cdo_stream_inq_vlist(streamID1);
   auto vlistID2 = vlistDuplicate(vlistID1);
 
-  VarList varList1;
-  varList_init(varList1, vlistID1);
-  varListSetUniqueMemtype(varList1);
-  auto memType = varList1[0].memType;
+  VarList varList1(vlistID1);
+  varList_set_unique_memtype(varList1);
+  auto memType = varList1.vars[0].memType;
 
   auto taxisID1 = vlistInqTaxis(vlistID1);
   auto taxisID2 = taxisDuplicate(taxisID1);
@@ -163,9 +175,8 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
 
   change_hybrid_zaxis(vlistID1, vlistID2, vctSize, vct.data(), zaxisID_PL, numFullLevels, numHalfLevels);
 
-  VarList varList2;
-  varList_init(varList2, vlistID2);
-  varListSetMemtype(varList2, memType);
+  VarList varList2(vlistID2);
+  varList_set_memtype(varList2, memType);
 
   int psvarID = -1;
   auto vctIsInverted = false;
@@ -183,11 +194,11 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
 
   if (vctIsInverted) invert_vct(vct);
 
-  auto nvars = vlistNvars(vlistID1);
+  auto numVars = varList1.numVars();
 
-  std::vector<bool> processVars(nvars), interpVars(nvars);
-  Varray2D<size_t> varnumMissVals(nvars);
-  Field3DVector vardata1(nvars), vardata2(nvars);
+  std::vector<bool> processVars(numVars), interpVars(numVars);
+  Varray2D<size_t> varnumMissVals(numVars);
+  Field3DVector vardata1(numVars), vardata2(numVars);
 
   auto maxLevels = std::max(numHalfLevels, numPL);
 
@@ -228,32 +239,21 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
       pressureLevels = phlev;
     }
 
-  VarIDs varIDs = search_varIDs(varList1, vlistID1, numFullLevels);
+  auto varIDs = varList_search_varIDs(varList1, numFullLevels);
 
   // vertical_interp_Z() is implemented for gheight on model half levels only
-  if (-1 != varIDs.gheightID && varList1[varIDs.gheightID].nlevels == numFullLevels)
+  if (-1 != varIDs.gheightID && varList1.vars[varIDs.gheightID].nlevels == numFullLevels)
     {
       if (Options::cdoVerbose)
-        cdo_print("%s(%s) on model full levels found!", var_stdname(geopotential_height), varList1[varIDs.gheightID].name);
+        cdo_print("%s(%s) on model full levels found!", var_stdname(geopotential_height), varList1.vars[varIDs.gheightID].name);
       varIDs.gheightID = -1;
     }
 
-  if (Options::cdoVerbose)
-    {
-      cdo_print("Found:");
-      // clang-format off
-      if (-1 != varIDs.tempID)    cdo_print("  %s -> %s", var_stdname(air_temperature), varList1[varIDs.tempID].name);
-      if (-1 != varIDs.psID)      cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1[varIDs.psID].name);
-      if (-1 != varIDs.lnpsID)    cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), varList1[varIDs.lnpsID].name);
-      if (-1 != varIDs.sgeopotID) cdo_print("  %s -> %s", var_stdname(surface_geopotential), varList1[varIDs.sgeopotID].name);
-      if (-1 != varIDs.geopotID)  cdo_print("  %s -> %s", var_stdname(geopotential), varList1[varIDs.geopotID].name);
-      if (-1 != varIDs.gheightID) cdo_print("  %s -> %s", var_stdname(geopotential_height), varList1[varIDs.gheightID].name);
-      // clang-format on
-    }
+  if (Options::cdoVerbose) print_vars_found(varIDs, varList1.vars);
 
-  for (int varID = 0; varID < nvars; ++varID)
+  for (int varID = 0; varID < numVars; ++varID)
     {
-      auto &var1 = varList1[varID];
+      auto &var1 = varList1.vars[varID];
       auto nlevels = var1.nlevels;
 
       if (var1.gridType == GRID_SPECTRAL && zaxis_is_hybrid(var1.zaxisType)) cdo_abort("Spectral data on model level unsupported!");
@@ -272,7 +272,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
       if (interpVars[varID])
         {
           varnumMissVals[varID].resize(maxLevels, 0);
-          vardata2[varID].init(varList2[varID]);
+          vardata2[varID].init(varList2.vars[varID]);
         }
       else
         {
@@ -283,11 +283,11 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
     }
 
   auto needVertIndexHalf{ false };
-  for (int varID = 0; varID < nvars; ++varID)
+  for (int varID = 0; varID < numVars; ++varID)
     {
       if (interpVars[varID])
         {
-          auto &var1 = varList1[varID];
+          auto &var1 = varList1.vars[varID];
           if (var1.nlevels == numHalfLevels && varID != varIDs.gheightID) needVertIndexHalf = true;
         }
     }
@@ -315,20 +315,20 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
   if (Options::cdoVerbose && presID != -1)
     {
       if (presID == varIDs.lnpsID)
-        cdo_print("Using LOG(%s) from %s", var_stdname(surface_air_pressure), varList1[presID].name);
+        cdo_print("Using LOG(%s) from %s", var_stdname(surface_air_pressure), varList1.vars[presID].name);
       else
-        cdo_print("Using %s from %s", var_stdname(surface_air_pressure), varList1[presID].name);
+        cdo_print("Using %s from %s", var_stdname(surface_air_pressure), varList1.vars[presID].name);
     }
 
   Field psProg;
-  if (zaxisID_ML != -1 && presID != -1) psProg.init(varList1[presID]);
+  if (zaxisID_ML != -1 && presID != -1) psProg.init(varList1.vars[presID]);
 
   auto sgeopotNeeded = (varIDs.tempID != -1 || varIDs.gheightID != -1);
 
   Field sgeopot;
   if (zaxisID_ML != -1 && sgeopotNeeded)
     {
-      sgeopot.init(varList1[presID]);
+      sgeopot.init(varList1.vars[presID]);
       if (varIDs.sgeopotID == -1)
         {
           if (extrapolate)
@@ -351,16 +351,15 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
       auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
-      for (int varID = 0; varID < nvars; ++varID) processVars[varID] = false;
+      for (int varID = 0; varID < numVars; ++varID) processVars[varID] = false;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
       cdo_def_timestep(streamID2, tsID);
 
       for (int recID = 0; recID < nrecs; ++recID)
         {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
-          const auto &var = varList1[varID];
+          auto [varID, levelID] = cdo_inq_record(streamID1);
+          const auto &var = varList1.vars[varID];
 
           if (vctIsInverted && zaxisID_ML != -1 && var.zaxisID == zaxisID_ML) levelID = var.nlevels - 1 - levelID;
 
@@ -402,11 +401,11 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
             }
         }
 
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
           if (processVars[varID])
             {
-              const auto &var = varList1[varID];
+              const auto &var = varList1.vars[varID];
 
               if (tsID > 0 && var.isConstant) continue;
 
@@ -445,7 +444,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
                   if (!extrapolate) varray_copy(numPL, pnumMissVals, varnumMissVals[varID]);
                 }
 
-              for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
+              for (int levelID = 0; levelID < varList2.vars[varID].nlevels; ++levelID)
                 {
                   cdo_def_record(streamID2, varID, levelID);
                   cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
@@ -461,7 +460,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
   cdo_stream_close(streamID1);
 }
 
-//#define ENABLE_HEIGHT_LEVEL_INTERPOLATION
+// #define ENABLE_HEIGHT_LEVEL_INTERPOLATION
 
 #ifdef ENABLE_HEIGHT_LEVEL_INTERPOLATION
 // obsolete, use intlevel!!!
@@ -475,10 +474,9 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
   auto vlistID1 = cdo_stream_inq_vlist(streamID1);
   auto vlistID2 = vlistDuplicate(vlistID1);
 
-  VarList varList1;
-  varList_init(varList1, vlistID1);
-  varListSetUniqueMemtype(varList1);
-  auto memType = varList1[0].memType;
+  VarList varList1(vlistID1);
+  varList_setUniqueMemtype(varList1);
+  auto memType = varList1.vars[0].memType;
 
   auto taxisID1 = vlistInqTaxis(vlistID1);
   auto taxisID2 = taxisDuplicate(taxisID1);
@@ -499,14 +497,13 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
 
   change_hybrid_zaxis(vlistID1, vlistID2, vctSize, vct.data(), zaxisID_HL, numFullLevels, numHalfLevels);
 
-  VarList varList2;
-  varList_init(varList2, vlistID2);
-  varListSetMemtype(varList2, memType);
+  VarList varList2(vlistID2);
+  varList_setMemtype(varList2, memType);
   /*
   auto vctIsInverted = false;
   if (vctSize && vctSize % 2 == 0)
     {
-      (void) varList_get_psvarid(varList1, zaxisID_ML);
+      (void) cdoVars_get_psvarid(varList1.vars, zaxisID_ML);
 
       int i;
       for (i = vctSize / 2 + 1; i < vctSize; ++i)
@@ -518,11 +515,11 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
 
   if (vctIsInverted) invert_vct(vct);
   */
-  auto nvars = vlistNvars(vlistID1);
+  auto numVars = varList1.numVars();
 
-  std::vector<bool> processVars(nvars), interpVars(nvars);
-  Varray2D<size_t> varnumMissVals(nvars);
-  Field3DVector vardata1(nvars), vardata2(nvars);
+  std::vector<bool> processVars(numVars), interpVars(numVars);
+  Varray2D<size_t> varnumMissVals(numVars);
+  Field3DVector vardata1(numVars), vardata2(numVars);
 
   auto maxLevels = std::max(numHalfLevels, numHeightLevels);
 
@@ -541,24 +538,13 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
   else
     cdo_warning("No 3D variable with hybrid sigma pressure coordinate found!");
 
-  VarIDs varIDs = search_varIDs(varList1, vlistID1, numFullLevels);
+  VarIDs varIDs = search_varIDs(varList1.vars, vlistID1, numFullLevels);
 
-  if (Options::cdoVerbose)
-    {
-      cdo_print("Found:");
-      // clang-format off
-      if (-1 != varIDs.tempID)    cdo_print("  %s -> %s", var_stdname(air_temperature), varList1[varIDs.tempID].name);
-      if (-1 != varIDs.psID)      cdo_print("  %s -> %s", var_stdname(surface_air_pressure), varList1[varIDs.psID].name);
-      if (-1 != varIDs.lnpsID)    cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), varList1[varIDs.lnpsID].name);
-      if (-1 != varIDs.sgeopotID) cdo_print("  %s -> %s", var_stdname(surface_geopotential), varList1[varIDs.sgeopotID].name);
-      if (-1 != varIDs.geopotID)  cdo_print("  %s -> %s", var_stdname(geopotential), varList1[varIDs.geopotID].name);
-      if (-1 != varIDs.gheightID) cdo_print("  %s -> %s", var_stdname(geopotential_height), varList1[varIDs.gheightID].name);
-      // clang-format on
-    }
+  if (Options::cdoVerbose) print_vars_found(varIDs, varList1.vars);
 
-  for (int varID = 0; varID < nvars; ++varID)
+  for (int varID = 0; varID < numVars; ++varID)
     {
-      const auto &var1 = varList1[varID];
+      const auto &var1 = varList1.vars[varID];
       auto nlevels = var1.nlevels;
 
       if (var1.gridType == GRID_SPECTRAL && zaxis_is_hybrid(var1.zaxisType)) cdo_abort("Spectral data on model level unsupported!");
@@ -575,7 +561,7 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
       if (interpVars[varID])
         {
           varnumMissVals[varID].resize(maxLevels, 0);
-          vardata2[varID].init(varList2[varID]);
+          vardata2[varID].init(varList2.vars[varID]);
         }
       else
         {
@@ -602,7 +588,7 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
 
           if (extrapolate) cdo_warning("%s not found - set to zero!", var_stdname(surface_geopotential));
         }
-      else { sgeopot.init(varList1[varIDs.sgeopotID]); }
+      else { sgeopot.init(varList1.vars[varIDs.sgeopotID]); }
 
       field_fill(sgeopot, 0.0);
     }
@@ -618,15 +604,14 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
       auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
       if (nrecs == 0) break;
 
-      for (int varID = 0; varID < nvars; ++varID) processVars[varID] = false;
+      for (int varID = 0; varID < numVars; ++varID) processVars[varID] = false;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
       cdo_def_timestep(streamID2, tsID);
 
       for (int recID = 0; recID < nrecs; ++recID)
         {
-          int varID, levelID;
-          cdo_inq_record(streamID1, &varID, &levelID);
+          auto [varID, levelID] = cdo_inq_record(streamID1);
           cdo_read_record(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
 
           processVars[varID] = true;
@@ -638,17 +623,17 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
           gen_vert_index(vertIndex, heightLevels, vardata1[varIDs.gheightID], gridsize, lreverse);
           if (!extrapolate)
             {
-              heightBottom.init(varList1[varIDs.gheightID]);
+              heightBottom.init(varList1.vars[varIDs.gheightID]);
               field_copy(vardata1[varIDs.gheightID], numFullLevels - 1, heightBottom);
               gen_vert_index_mv(vertIndex, heightLevels, gridsize, heightBottom, pnumMissVals, lreverse);
             }
         }
 
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < numVars; ++varID)
         {
           if (processVars[varID])
             {
-              const auto &var = varList1[varID];
+              const auto &var = varList1.vars[varID];
               if (tsID > 0 && var.isConstant) continue;
 
               if (interpVars[varID])
@@ -667,7 +652,7 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
                   if (!extrapolate) varray_copy(numHeightLevels, pnumMissVals, varnumMissVals[varID]);
                 }
 
-              for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
+              for (int levelID = 0; levelID < varList2.vars[varID].nlevels; ++levelID)
                 {
                   cdo_def_record(streamID2, varID, levelID);
                   cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
@@ -724,7 +709,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     ML2PLX = module.get_id("ml2plx");
     ML2HLX = module.get_id("ml2hlx");
@@ -753,7 +738,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
 #ifdef ENABLE_HEIGHT_LEVEL_INTERPOLATION
     if (doHeightInterpolation)
@@ -764,7 +749,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
   }
 };
