@@ -17,9 +17,7 @@
 #include "process_int.h"
 #include "cdo_vlist.h"
 #include "field_vinterp.h"
-#include "stdnametable.h"
 #include "util_string.h"
-#include "const.h"
 #include "cdo_zaxis.h"
 #include "param_conversion.h"
 
@@ -69,7 +67,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Vertintzs",
-    .operators = { { "zs2zl", 0, 0, "depth levels in meter"}, { "zs2zlx"} },
+    .operators = { { "zs2zl", 0, 0, "depth levels in meter" }, { "zs2zlx" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -112,7 +110,7 @@ private:
 
 public:
   void
-  init()
+  init() override
   {
 
     auto operatorID = cdo_operator_id();
@@ -132,31 +130,30 @@ public:
 
     gridsize = vlist_check_gridsize(vlistID1);
 
-    varList_init(varList1, vlistID1);
-    varListSetUniqueMemtype(varList1);
-    auto memType = varList1[0].memType;
-
-    nvars = vlistNvars(vlistID1);
+    varList1 = VarList(vlistID1);
+    varList_set_unique_memtype(varList1);
+    auto memType = varList1.vars[0].memType;
 
+    nvars = varList1.numVars();
     for (int varID = 0; varID < nvars; ++varID)
       {
-        if (string_to_lower(varList1[varID].name) == "depth_c") depthID = varID;
+        if (string_to_lower(varList1.vars[varID].name) == "depth_c") depthID = varID;
       }
 
     if (Options::cdoVerbose)
       {
         cdo_print("Found:");
         // clang-format off
-        if (-1 != depthID)   cdo_print("  %s -> %s", "zstar depth at cell center", varList1[depthID].name);
+        if (-1 != depthID)   cdo_print("  %s -> %s", "zstar depth at cell center", varList1.vars[depthID].name);
         // clang-format on
       }
 
     if (-1 == depthID) cdo_abort("depth_c not found!");
 
-    auto zaxisIDfull = (-1 == depthID) ? -1 : varList1[depthID].zaxisID;
+    auto zaxisIDfull = (-1 == depthID) ? -1 : varList1.vars[depthID].zaxisID;
     numFullLevels = (-1 == zaxisIDfull) ? 0 : zaxisInqSize(zaxisIDfull);
 
-    auto nzaxis = vlistNzaxis(vlistID1);
+    auto nzaxis = vlistNumZaxis(vlistID1);
     for (int index = 0; index < nzaxis; ++index)
       {
         auto zaxisID = vlistZaxis(vlistID1, index);
@@ -165,8 +162,8 @@ public:
           vlistChangeZaxis(vlistID2, zaxisID, zaxisID2);
       }
 
-    varList_init(varList2, vlistID2);
-    varListSetMemtype(varList2, memType);
+    varList2 = VarList(vlistID2);
+    varList_set_memtype(varList2, memType);
 
     if (!extrapolate) pnumMissVals.resize(depthLevels.size());
 
@@ -182,7 +179,7 @@ public:
 
     for (int varID = 0; varID < nvars; ++varID)
       {
-        const auto &var = varList1[varID];
+        const auto &var = varList1.vars[varID];
 
         if (gridInqType(var.gridID) == GRID_SPECTRAL) cdo_abort("Spectral data unsupported!");
 
@@ -191,7 +188,7 @@ public:
 
         interpVars[varID] = (var.zaxisID == zaxisIDfull || (is_depth_axis(var.zaxisID) && (var.nlevels == numFullLevels)));
 
-        if (interpVars[varID]) { vardata2[varID].init(varList2[varID]); }
+        if (interpVars[varID]) { vardata2[varID].init(varList2.vars[varID]); }
         else if (is_depth_axis(var.zaxisID) && var.nlevels > 1)
           {
 
@@ -199,11 +196,11 @@ public:
           }
       }
 
-    fullDepth.init(varList1[depthID]);
+    fullDepth.init(varList1.vars[depthID]);
 
     for (int varID = 0; varID < nvars; ++varID)
       {
-        if (interpVars[varID] && varList1[varID].isConstant) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
+        if (interpVars[varID] && varList1.vars[varID].isConstant) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
       }
 
     streamID2 = cdo_open_write(1);
@@ -212,7 +209,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -223,7 +220,7 @@ public:
         for (int varID = 0; varID < nvars; ++varID)
           {
             processVars[varID] = false;
-            const auto &var = varList1[varID];
+            const auto &var = varList1.vars[varID];
             for (int levelID = 0; levelID < var.nlevels; ++levelID) varnumMissVals[varID][levelID] = 0;
           }
 
@@ -232,8 +229,7 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
             cdo_read_record(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
             processVars[varID] = true;
           }
@@ -241,14 +237,14 @@ public:
         for (int varID = 0; varID < nvars; ++varID)
           if (interpVars[varID]) processVars[varID] = true;
 
-        if (tsID == 0 || !varList1[depthID].isConstant)
+        if (tsID == 0 || !varList1.vars[depthID].isConstant)
           {
             constexpr auto lreverse = false;
             field_copy(vardata1[depthID], fullDepth);
             gen_vert_index(vertIndexFull, depthLevels, fullDepth, gridsize, lreverse);
             if (!extrapolate)
               {
-                depthBottom.init(varList1[depthID]);
+                depthBottom.init(varList1.vars[depthID]);
                 field_copy(fullDepth, numFullLevels - 1, depthBottom);
                 gen_vert_index_mv(vertIndexFull, depthLevels, gridsize, depthBottom, pnumMissVals, lreverse);
               }
@@ -258,7 +254,7 @@ public:
           {
             if (processVars[varID])
               {
-                const auto &var = varList1[varID];
+                const auto &var = varList1.vars[varID];
 
                 if (tsID > 0 && !interpVars[varID] && var.isConstant) continue;
 
@@ -277,7 +273,7 @@ public:
                     if (!extrapolate) varray_copy(depthLevels.size(), pnumMissVals, varnumMissVals[varID]);
                   }
 
-                for (int levelID = 0; levelID < varList2[varID].nlevels; ++levelID)
+                for (int levelID = 0; levelID < varList2.vars[varID].nlevels; ++levelID)
                   {
                     cdo_def_record(streamID2, varID, levelID);
                     auto varout = (interpVars[varID] ? vardata2[varID] : vardata1[varID]);
@@ -291,7 +287,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
