@@ -52,7 +52,7 @@ farexpr(Field &field1, Field &field2, double (*expression)(double, double, doubl
   if (field1.numMissVals || field2.numMissVals)
     {
       for (size_t i = 0; i < len; ++i)
-        if (DBL_IS_EQUAL(field1.vec_d[i], missval1) || DBL_IS_EQUAL(field2.vec_d[i], missval2))
+        if (fp_is_equal(field1.vec_d[i], missval1) || fp_is_equal(field2.vec_d[i], missval2))
           field1.vec_d[i] = missval1;
         else
           field1.vec_d[i] = expression(field1.vec_d[i], field2.vec_d[i], missval1);
