@@ -72,11 +72,8 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Wind",
-    .operators = { { "uv2dv", WindHelp },
-                   { "uv2dvl", WindHelp },
-                   { "dv2uv", WindHelp },
-                   { "dv2uvl", WindHelp },
-                   { "dv2ps", Wind2Help } },
+    .operators
+    = { { "uv2dv", WindHelp }, { "uv2dvl", WindHelp }, { "dv2uv", WindHelp }, { "dv2uvl", WindHelp }, { "dv2ps", Wind2Help } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -113,7 +110,7 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
     dataIsUnchanged = data_is_unchanged();
 
@@ -148,6 +145,8 @@ public:
     auto vlistID1 = cdo_stream_inq_vlist(streamID1);
     auto vlistID2 = vlistDuplicate(vlistID1);
 
+    VarList varList1(vlistID1);
+
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
     vlistDefTaxis(vlistID2, taxisID2);
@@ -156,10 +155,10 @@ public:
     auto nvars = vlistNvars(vlistID2);
     for (int varID = 0; varID < nvars; ++varID)
       {
-        auto varname = string_to_lower(cdo::inq_var_name(vlistID1, varID));
-        auto param = vlistInqVarParam(vlistID2, varID);
+        const auto &var = varList1.vars[varID];
+        auto varname = string_to_lower(var.name);
         int pnum, pcat, pdis;
-        cdiDecodeParam(param, &pnum, &pcat, &pdis);
+        cdiDecodeParam(var.param, &pnum, &pcat, &pdis);
         int code = pnum;
         if (operatorID == UV2DV || operatorID == UV2DVL)
           {
@@ -205,10 +204,12 @@ public:
 
         if (varID1 != -1 && varID2 != -1)
           {
-            gridID1 = vlistInqVarGrid(vlistID1, varID1);
+            const auto &var1 = varList1.vars[varID1];
+            const auto &var2 = varList1.vars[varID2];
+            gridID1 = var1.gridID;
 
-            if (gridInqType(gridID1) != GRID_GAUSSIAN) cdo_abort("U-wind is not on Gaussian grid!");
-            if (gridID1 != vlistInqVarGrid(vlistID1, varID2)) cdo_abort("U and V wind must have the same grid represention!");
+            if (var1.gridType != GRID_GAUSSIAN) cdo_abort("U-wind is not on Gaussian grid!");
+            if (var1.gridID != var2.gridID) cdo_abort("U and V wind must have the same grid represention!");
 
             auto numLPE = gridInqNP(gridID1);
             long nlon = gridInqXsize(gridID1);
@@ -234,7 +235,7 @@ public:
             defineAttributesDV(vlistID2, gridID2, varID1, varID2);
 
             ntr = gridInqTrunc(gridID2);
-            nlev = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID1));
+            nlev = var1.nlevels;
 
             spTrans.init(nlon, nlat, ntr, PolFlag::UV2DV, nlev);
           }
@@ -246,12 +247,13 @@ public:
 
         if (varID1 != -1 && varID2 != -1)
           {
-            gridID1 = vlistInqVarGrid(vlistID1, varID2);
+            const auto &var1 = varList1.vars[varID1];
+            const auto &var2 = varList1.vars[varID2];
+            gridID1 = var2.gridID;
 
-            if (gridInqType(gridID1) != GRID_SPECTRAL) cdo_abort("Vorticity is not on spectral grid!");
+            if (var2.gridType != GRID_SPECTRAL) cdo_abort("Vorticity is not on spectral grid!");
 
-            if (gridID1 != vlistInqVarGrid(vlistID1, varID1))
-              cdo_abort("Divergence and vorticity must have the same grid represention!");
+            if (gridID1 != var1.gridID) cdo_abort("Divergence and vorticity must have the same grid represention!");
 
             if (gridIDgp != -1)
               {
@@ -274,7 +276,7 @@ public:
             long nlon = gridInqXsize(gridID2);
             long nlat = gridInqYsize(gridID2);
             ntr = gridInqTrunc(gridID1);
-            nlev = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID1));
+            nlev = var1.nlevels;
 
             spTrans.init(nlon, nlat, ntr, PolFlag::SP2FC, nlev);
             dvTrans.init(ntr);
@@ -287,12 +289,13 @@ public:
 
         if (varID1 != -1 && varID2 != -1)
           {
-            gridID1 = vlistInqVarGrid(vlistID1, varID2);
+            const auto &var1 = varList1.vars[varID1];
+            const auto &var2 = varList1.vars[varID2];
+            gridID1 = var2.gridID;
 
-            if (gridInqType(gridID1) != GRID_SPECTRAL) cdo_abort("Vorticity is not on spectral grid!");
+            if (var2.gridType != GRID_SPECTRAL) cdo_abort("Vorticity is not on spectral grid!");
 
-            if (gridID1 != vlistInqVarGrid(vlistID1, varID1))
-              cdo_abort("Divergence and vorticity must have the same grid represention!");
+            if (gridID1 != var1.gridID) cdo_abort("Divergence and vorticity must have the same grid represention!");
 
             defineAttributesPS(vlistID2, varID1, varID2);
 
@@ -309,7 +312,8 @@ public:
 
     if (varID1 != -1 && varID2 != -1)
       {
-        nlev = zaxisInqSize(vlistInqVarZaxis(vlistID1, varID1));
+        const auto &var1 = varList1.vars[varID1];
+        nlev = var1.nlevels;
 
         auto gridsize = gridInqSize(gridID1);
         ivar1.resize(nlev * gridsize);
@@ -322,7 +326,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
@@ -366,9 +370,9 @@ public:
         if (varID1 != -1 && varID2 != -1)
           {
             if (luv2dv)
-              trans_uv2dv(spTrans, nlev, gridID1, ivar1.data(), ivar2.data(), gridID2, ovar1.data(), ovar2.data());
+              trans_uv2dv(spTrans, nlev, gridID1, ivar1, ivar2, gridID2, ovar1, ovar2);
             else if (ldv2uv)
-              trans_dv2uv(spTrans, dvTrans, nlev, gridID1, ivar1.data(), ivar2.data(), gridID2, ovar1.data(), ovar2.data());
+              trans_dv2uv(spTrans, dvTrans, nlev, gridID1, ivar1, ivar2, gridID2, ovar1, ovar2);
             else if (operatorID == DV2PS)
               {
                 dv2ps(ivar1.data(), ovar1.data(), nlev, ntr);
@@ -413,7 +417,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
