@@ -29,6 +29,7 @@ public:
     .constraints = { 1, 1, NoRestriction },
   };
   inline static RegisterEntry<Writerandom> registration = RegisterEntry<Writerandom>(module);
+
   CdoStreamID streamID1;
   CdoStreamID streamID2;
 
@@ -39,15 +40,14 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_check_argc(0);
 
     streamID1 = cdo_open_read(0);
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = vlistDuplicate(vlistID1);
+    auto vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = vlistDuplicate(vlistID1);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = taxisDuplicate(taxisID1);
@@ -57,15 +57,16 @@ public:
 
     cdo_def_vlist(streamID2, vlistID2);
 
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
   }
+
   void
-  run()
+  run() override
   {
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
@@ -77,11 +78,10 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
+            auto[varID, levelID] = cdo_inq_record(streamID1);
             recvarID[recID] = varID;
             reclevelID[recID] = levelID;
-            recdata[recID].resize(varList1[varID].gridsize);
+            recdata[recID].resize(varList1.vars[varID].gridsize);
             cdo_read_record(streamID1, recdata[recID].data(), &recnumMissVals[recID]);
           }
 
@@ -89,7 +89,7 @@ public:
 
         for (int rindex = nrecs - 1; rindex >= 0; rindex--)
           {
-            const auto index = (int) (rindex * ((double) std::rand()) / ((double) RAND_MAX));
+            auto index = (int) (rindex * ((double) std::rand()) / ((double) RAND_MAX));
             //	printf("rindex %d %d\n", rindex, index);
             int ipos = -1;
             for (int recID = 0; recID < nrecs; ++recID)
@@ -110,9 +110,9 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            const auto rindex = recindex[recID];
-            const auto varID = recvarID[rindex];
-            const auto levelID = reclevelID[rindex];
+            auto rindex = recindex[recID];
+            auto varID = recvarID[rindex];
+            auto levelID = reclevelID[rindex];
             cdo_def_record(streamID2, varID, levelID);
             cdo_write_record(streamID2, recdata[rindex].data(), recnumMissVals[rindex]);
           }
@@ -120,8 +120,9 @@ public:
         tsID++;
       }
   }
+
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
