@@ -16,7 +16,6 @@
 
 #include <cdi.h>
 
-#include "cdo_options.h"
 #include "cdo_vlist.h"
 #include "datetime.h"
 #include "process_int.h"
@@ -37,42 +36,28 @@ public:
     .constraints = { 3, 1, NoRestriction },
   };
   inline static RegisterEntry<Ydaypctl> registration = RegisterEntry<Ydaypctl>(module);
+
   static const int MaxDays = 373;
-  CdiDateTime vDateTimes1[MaxDays]{};
-  CdiDateTime vDateTimes2[MaxDays]{};
-  long numSets[MaxDays] = { 0 };
-  std::vector<bool> vars1;
-  HistogramSet hsets[MaxDays];
 
   CdoStreamID streamID1;
-  int taxisID1;
-
   CdoStreamID streamID2;
-  int taxisID2;
-
   CdoStreamID streamID3;
-  int taxisID3;
-
   CdoStreamID streamID4;
-  int taxisID4;
 
-  int nvars;
-  int ntsteps;
-  int maxrecs;
+  int vlistID1;
+  int taxisID1;
+  int taxisID2;
+  int taxisID3;
+  int taxisID4;
 
   double pn;
 
-  Field field1, field2;
-
   VarList varList1;
-  FieldVector constFields;
-  std::vector<RecordInfo> recList;
 
 public:
   void
-  init()
+  init() override
   {
-
     operator_input_arg("percentile number");
     pn = parameter_to_double(cdo_operator_argv(0));
 
@@ -80,15 +65,19 @@ public:
     streamID2 = cdo_open_read(1);
     streamID3 = cdo_open_read(2);
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = cdo_stream_inq_vlist(streamID2);
-    const auto vlistID3 = cdo_stream_inq_vlist(streamID3);
-    const auto vlistID4 = vlistDuplicate(vlistID1);
+    vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = cdo_stream_inq_vlist(streamID2);
+    auto vlistID3 = cdo_stream_inq_vlist(streamID3);
+    auto vlistID4 = vlistDuplicate(vlistID1);
 
     vlist_unpack(vlistID4);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
-    vlist_compare(vlistID1, vlistID3, CmpVlist::All);
+    varList1 = VarList(vlistID1);
+    VarList varList2(vlistID2);
+    VarList varList3(vlistID3);
+
+    varList_compare(varList1, varList2);
+    varList_compare(varList1, varList3);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = vlistInqTaxis(vlistID2);
@@ -101,28 +90,29 @@ public:
 
     streamID4 = cdo_open_write(3);
     cdo_def_vlist(streamID4, vlistID4);
-
-    ntsteps = vlistNtsteps(vlistID1);
-    nvars = vlistNvars(vlistID1);
-
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
-
-    constFields = FieldVector(maxrecs);
-
-    varList_init(varList1, vlistID1);
-
-    vars1 = std::vector<bool>(MaxDays, false);
   }
 
   void
-  run()
+  run() override
   {
+    Field field1, field2;
+    std::vector<bool> vars1(MaxDays, false);
+    CdiDateTime vDateTimes1[MaxDays]{};
+    CdiDateTime vDateTimes2[MaxDays]{};
+    HistogramSet hsets[MaxDays];
+    long numSets[MaxDays] = { 0 };
+
+    auto numVars = varList1.numVars();
+    auto numSteps = varList1.numSteps();
+    auto maxRecords = varList1.numRecords();
+    std::vector<RecordInfo> recordList(maxRecords);
+
+    FieldVector constFields(maxRecords);
 
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID2, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID2, tsID);
         if (nrecs == 0) break;
 
         if (nrecs != cdo_stream_inq_timestep(streamID3, tsID))
@@ -145,24 +135,19 @@ public:
         if (!vars1[dayOfYear])
           {
             vars1[dayOfYear] = true;
-            hsets[dayOfYear].create(nvars, ntsteps);
+            hsets[dayOfYear].create(numVars, numSteps);
 
-            for (int varID = 0; varID < nvars; ++varID)
-              {
-                const auto &var = varList1[varID];
-                hsets[dayOfYear].createVarLevels(varID, var.nlevels, var.gridsize);
-              }
+            for (const auto &var : varList1.vars) hsets[dayOfYear].createVarLevels(var.ID, var.nlevels, var.gridsize);
           }
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID2, &varID, &levelID);
-            const auto &var = varList1[varID];
+            auto [varID, levelID] = cdo_inq_record(streamID2);
+            const auto &var = varList1.vars[varID];
             field1.init(var);
             cdo_read_record(streamID2, field1);
 
-            cdo_inq_record(streamID3, &varID, &levelID);
+            (void) cdo_inq_record(streamID3);
             field2.init(var);
             cdo_read_record(streamID3, field2);
 
@@ -175,7 +160,7 @@ public:
     tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
+        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
         const auto vDateTime = taxisInqVdatetime(taxisID1);
@@ -192,11 +177,10 @@ public:
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            const auto &var = varList1[varID];
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            const auto &var = varList1.vars[varID];
 
-            if (tsID == 0) recList[recID].set(varID, levelID);
+            if (tsID == 0) recordList[recID].set(varID, levelID);
 
             if (tsID == 0 && var.isConstant)
               {
@@ -227,17 +211,18 @@ public:
           taxisDefVdatetime(taxisID4, vDateTimes1[dayOfYear]);
           cdo_def_timestep(streamID4, otsID);
 
-          for (int recID = 0; recID < maxrecs; ++recID)
+          for (int recID = 0; recID < maxRecords; ++recID)
             {
-              auto [varID, levelID] = recList[recID].get();
-              if (otsID && varList1[varID].isConstant) continue;
+              auto [varID, levelID] = recordList[recID].get();
+              const auto &var = varList1.vars[varID];
+              if (otsID && var.isConstant) continue;
 
               cdo_def_record(streamID4, varID, levelID);
 
-              if (varList1[varID].isConstant) { cdo_write_record(streamID4, constFields[recID]); }
+              if (var.isConstant) { cdo_write_record(streamID4, constFields[recID]); }
               else
                 {
-                  field1.init(varList1[varID]);
+                  field1.init(var);
                   hsets[dayOfYear].getVarLevelPercentiles(field1, varID, levelID, pn);
                   cdo_write_record(streamID4, field1);
                 }
@@ -248,7 +233,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID4);
     cdo_stream_close(streamID3);
