@@ -16,7 +16,7 @@
 #include "calendar.h"
 
 #include "cdo_options.h"
-#include "cdo_vlist.h"
+#include "cdo_stepstat.h"
 #include "process_int.h"
 #include "datetime.h"
 #include "printinfo.h"
@@ -28,8 +28,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Yearmonstat",
-    .operators = { { "yearmonmean", FieldFunc_Mean, 0, YearmonstatHelp },
-                   { "yearmonavg", FieldFunc_Avg, 0, YearmonstatHelp } },
+    .operators = { { "yearmonmean", FieldFunc_Mean, 0, YearmonstatHelp }, { "yearmonavg", FieldFunc_Avg, 0, YearmonstatHelp } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -40,40 +39,26 @@ public:
 private:
   CdoStreamID streamID1;
   CdoStreamID streamID2;
+  int taxisID1;
+  int taxisID2;
 
   int vlistID1;
   int vlistID2;
 
-  int taxisID1;
-  int taxisID2;
-
   int year0 = 0, month0 = 0;
   int year, month, day;
 
   DateTimeList dtlist;
 
-  VarList varList;
-  Field field;
-
-  FieldVector2D samp1, vars1;
   CdiDateTime vDateTime0{};
 
   int calendar;
-
-  std::vector<RecordInfo> recList;
   int operfunc;
 
-  int nvars;
-  int maxrecs;
-
 public:
   void
-  init()
+  init() override
   {
-
-    // clang-format off
-    // clang-format on
-
     auto operatorID = cdo_operator_id();
 
     operfunc = cdo_operator_f1(operatorID);
@@ -95,31 +80,31 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    nvars = vlistNvars(vlistID1);
-
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
-
     calendar = taxisInqCalendar(taxisID1);
     constexpr auto timestatDate{ TimeStat::MEAN };
     dtlist.set_stat(timestatDate);
     dtlist.set_calendar(calendar);
-
-    varList_init(varList, vlistID1);
-
-    fields_from_vlist(vlistID1, samp1);
-    fields_from_vlist(vlistID1, vars1, FIELD_VEC);
   }
 
   void
-  run()
+  run() override
   {
+    Field field;
+    VarList varList1(vlistID1);
+
+    auto maxRecords = varList1.numRecords();
+    std::vector<RecordInfo> recordList(maxRecords);
+
+    FieldVector2D samp1, varsData1;
+    field2D_init(samp1, varList1);
+    field2D_init(varsData1, varList1, FIELD_VEC);
+
     int tsID = 0;
     int otsID = 0;
     while (true)
       {
         int nrecs = 0;
-        long numSets = 0;
+        int numSets = 0;
         double dsets = 0.0;
         while (true)
           {
@@ -149,14 +134,13 @@ public:
 
             for (int recID = 0; recID < nrecs; ++recID)
               {
-                int varID, levelID;
-                cdo_inq_record(streamID1, &varID, &levelID);
-                const auto &var = varList[varID];
+                auto [varID, levelID] = cdo_inq_record(streamID1);
+                const auto &var = varList1.vars[varID];
 
-                if (tsID == 0) recList[recID].set(varID, levelID);
+                if (tsID == 0) recordList[recID].set(varID, levelID);
 
                 auto &rsamp1 = samp1[varID][levelID];
-                auto &rvars1 = vars1[varID][levelID];
+                auto &rvars1 = varsData1[varID][levelID];
 
                 if (numSets == 0)
                   {
@@ -196,14 +180,15 @@ public:
 
         if (nrecs == 0 && numSets == 0) break;
 
-        for (int varID = 0; varID < nvars; ++varID)
+        const auto numVars = varList1.numVars();
+        for (int varID = 0; varID < numVars; ++varID)
           {
-            const auto &var = varList[varID];
+            const auto &var = varList1.vars[varID];
             if (var.isConstant) continue;
             for (int levelID = 0; levelID < var.nlevels; ++levelID)
               {
                 const auto &rsamp1 = samp1[varID][levelID];
-                auto &rvars1 = vars1[varID][levelID];
+                auto &rvars1 = varsData1[varID][levelID];
                 if (!rsamp1.empty())
                   field2_div(rvars1, rsamp1);
                 else
@@ -216,12 +201,12 @@ public:
         dtlist.stat_taxis_def_timestep(taxisID2, numSets);
         cdo_def_timestep(streamID2, otsID);
 
-        for (int recID = 0; recID < maxrecs; ++recID)
+        for (int recID = 0; recID < maxRecords; ++recID)
           {
-            auto [varID, levelID] = recList[recID].get();
-            if (otsID && varList[varID].isConstant) continue;
+            auto [varID, levelID] = recordList[recID].get();
+            if (otsID && varList1.vars[varID].isConstant) continue;
 
-            auto &rvars1 = vars1[varID][levelID];
+            auto &rvars1 = varsData1[varID][levelID];
             cdo_def_record(streamID2, varID, levelID);
             cdo_write_record(streamID2, rvars1);
           }
@@ -232,7 +217,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
