@@ -18,23 +18,12 @@
 
 #include "cdo_vlist.h"
 #include "datetime.h"
-#include "field.h"
 #include "process_int.h"
 #include "printinfo.h"
 #include "field_functions.h"
 
 constexpr int MaxHours = 9301;  // 31*12*25 + 1
 
-static int
-getHourOfYearIndex(const CdiDateTime &vDateTime)
-{
-  auto houroy = decode_hour_of_year(vDateTime);
-
-  if (houroy < 0 || houroy >= MaxHours) cdo_abort("Hour of year %d out of range (%s)!", houroy, datetime_to_string(vDateTime));
-
-  return houroy;
-}
-
 class Yhourarith : public Process
 {
 public:
@@ -51,6 +40,7 @@ public:
     .constraints = { 2, 1, NoRestriction },
   };
   inline static RegisterEntry<Yhourarith> registration = RegisterEntry<Yhourarith>(module);
+
   int operfunc;
   CdoStreamID streamID1;
   CdoStreamID streamID2;
@@ -62,15 +52,13 @@ public:
 
   int vlistID2;
 
-  Field field;
-  FieldVector2D vars2[MaxHours];
   VarList varList1;
+  VarList varList2;
 
 public:
   void
-  init()
+  init() override
   {
-
     auto operatorID = cdo_operator_id();
     operfunc = cdo_operator_f1(operatorID);
 
@@ -85,9 +73,9 @@ public:
 
     vlist_unpack(vlistID3);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
-
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
+    varList_compare(varList1, varList2);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = vlistInqTaxis(vlistID2);
@@ -99,24 +87,26 @@ public:
   }
 
   void
-  run()
+  run() override
   {
+    Field field;
+    FieldVector2D varsData2[MaxHours];
+
     int tsID = 0;
     while (true)
       {
         auto nrecs = cdo_stream_inq_timestep(streamID2, tsID);
         if (nrecs == 0) break;
 
-        auto houroy = getHourOfYearIndex(taxisInqVdatetime(taxisID2));
-        if (vars2[houroy].size() > 0) cdo_abort("Hour of year index %d already allocated!", houroy);
+        auto hourOfYear = decode_hour_of_year(taxisInqVdatetime(taxisID2), MaxHours);
+        if (varsData2[hourOfYear].size() > 0) cdo_abort("Hour of year index %d already allocated!", hourOfYear);
 
-        fields_from_vlist(vlistID2, vars2[houroy], FIELD_VEC | FIELD_NAT);
+        field2D_init(varsData2[hourOfYear], varList2, FIELD_VEC | FIELD_NAT);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID2, &varID, &levelID);
-            cdo_read_record(streamID2, vars2[houroy][varID][levelID]);
+            auto [varID, levelID] = cdo_inq_record(streamID2);
+            cdo_read_record(streamID2, varsData2[hourOfYear][varID][levelID]);
           }
 
         tsID++;
@@ -130,20 +120,19 @@ public:
         auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
         if (nrecs == 0) break;
 
-        auto houroy = getHourOfYearIndex(taxisInqVdatetime(taxisID1));
-        if (vars2[houroy].size() == 0) cdo_abort("Hour of year index %d not found!", houroy);
+        auto hourOfYear = decode_hour_of_year(taxisInqVdatetime(taxisID1), MaxHours);
+        if (varsData2[hourOfYear].size() == 0) cdo_abort("Hour of year index %d not found!", hourOfYear);
 
         cdo_taxis_copy_timestep(taxisID3, taxisID1);
         cdo_def_timestep(streamID3, tsID);
 
         for (int recID = 0; recID < nrecs; ++recID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            field.init(varList1[varID]);
+            auto [varID, levelID] = cdo_inq_record(streamID1);
+            field.init(varList1.vars[varID]);
             cdo_read_record(streamID1, field);
 
-            field2_function(field, vars2[houroy][varID][levelID], operfunc);
+            field2_function(field, varsData2[hourOfYear][varID][levelID], operfunc);
 
             cdo_def_record(streamID3, varID, levelID);
             cdo_write_record(streamID3, field);
@@ -154,9 +143,8 @@ public:
   }
 
   void
-  close()
+  close() override
   {
-
     cdo_stream_close(streamID3);
     cdo_stream_close(streamID1);
   }
