@@ -65,6 +65,7 @@ public:
     .constraints = { 2, 1, NoRestriction },
   };
   inline static RegisterEntry<Ymonarith> registration = RegisterEntry<Ymonarith>(module);
+
   int operfunc;
   int opertype;
 
@@ -79,8 +80,9 @@ public:
   int vlistID2;
 
   VarList varList1;
+  VarList varList2;
   Field field;
-  FieldVector2D vars2[MaxMonths];
+  FieldVector2D varsData2[MaxMonths];
 
   void
   process_data(int tsID, int nrecs, int mon)
@@ -90,12 +92,11 @@ public:
 
     for (int recID = 0; recID < nrecs; ++recID)
       {
-        int varID, levelID;
-        cdo_inq_record(streamID1, &varID, &levelID);
-        field.init(varList1[varID]);
+        auto [varID, levelID] = cdo_inq_record(streamID1);
+        field.init(varList1.vars[varID]);
         cdo_read_record(streamID1, field);
 
-        field2_function(field, vars2[mon][varID][levelID], operfunc);
+        field2_function(field, varsData2[mon][varID][levelID], operfunc);
 
         cdo_def_record(streamID3, varID, levelID);
         cdo_write_record(streamID3, field);
@@ -105,13 +106,12 @@ public:
   void
   load_data_from_stream(int mon, int nrecs)
   {
-    fields_from_vlist(vlistID2, vars2[mon], FIELD_VEC | FIELD_NAT);
+    field2D_init(varsData2[mon], varList2, FIELD_VEC | FIELD_NAT);
 
     for (int recID = 0; recID < nrecs; ++recID)
       {
-        int varID, levelID;
-        cdo_inq_record(streamID2, &varID, &levelID);
-        cdo_read_record(streamID2, vars2[mon][varID][levelID]);
+        auto [varID, levelID] = cdo_inq_record(streamID2);
+        cdo_read_record(streamID2, varsData2[mon][varID][levelID]);
       }
   }
 
@@ -121,7 +121,7 @@ public:
     for (int nrecs, tsID = 0; (nrecs = cdo_stream_inq_timestep(streamID2, tsID)) != 0; tsID++)
       {
         auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
-        if (vars2[mon].size())
+        if (varsData2[mon].size())
           cdo_abort("%s already allocated! The second input file must contain monthly mean values for a maximum of one year.",
                     monthNames[mon]);
 
@@ -131,7 +131,7 @@ public:
     for (int nrecs, tsID = 0; (nrecs = cdo_stream_inq_timestep(streamID1, tsID)) != 0; tsID++)
       {
         auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
-        if (vars2[mon].size() == 0)
+        if (varsData2[mon].size() == 0)
           cdo_abort("%s not found! The second input file must contain monthly mean values for a maximum of one year.",
                     monthNames[mon]);
 
@@ -147,16 +147,16 @@ public:
       {
         auto mon = get_month_index(taxisInqVdatetime(taxisID2).date);
         auto season = month_to_season(mon + 1);
-        if (vars2[season].size()) cdo_abort("Season %s already allocated!", seasonNames[season]);
+        if (varsData2[season].size()) cdo_abort("Season %s already allocated!", seasonNames[season]);
 
-        load_data_from_stream(mon, nrecs);
+        load_data_from_stream(season, nrecs);
       }
 
     for (int nrecs, tsID = 0; (nrecs = cdo_stream_inq_timestep(streamID1, tsID)) != 0; tsID++)
       {
         auto mon = get_month_index(taxisInqVdatetime(taxisID1).date);
         auto season = month_to_season(mon + 1);
-        if (vars2[season].size() == 0) cdo_abort("Season %s not found!", seasonNames[season]);
+        if (varsData2[season].size() == 0) cdo_abort("Season %s not found!", seasonNames[season]);
 
         process_data(tsID, nrecs, season);
       }
@@ -164,9 +164,8 @@ public:
 
 public:
   void
-  init()
+  init() override
   {
-
     auto operatorID = cdo_operator_id();
     opertype = cdo_operator_f2(operatorID);
     operfunc = cdo_operator_f1(operatorID);
@@ -182,9 +181,9 @@ public:
 
     vlist_unpack(vlistID3);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
-
-    varList_init(varList1, vlistID1);
+    varList1 = VarList(vlistID1);
+    varList2 = VarList(vlistID2);
+    varList_compare(varList1, varList2);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = vlistInqTaxis(vlistID2);
@@ -196,7 +195,7 @@ public:
   }
 
   void
-  run()
+  run() override
   {
     if (opertype == SEASONAL)
       run_seasonal();
@@ -205,7 +204,7 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID3);
