@@ -34,7 +34,7 @@ static auto func_comp = [](auto hasMissvals, auto n, auto mv1, auto mv2, auto &v
     {
       if (std::isnan(mv1) || std::isnan(mv2))
         for (size_t i = 0; i < n; ++i)
-          v1[i] = (dbl_is_equal(v1[i], mv1) || dbl_is_equal(v2[i], mv2)) ? mv1 : binary_operator(v1[i], v2[i]);
+          v1[i] = (fp_is_equal(v1[i], mv1) || fp_is_equal(v2[i], mv2)) ? mv1 : binary_operator(v1[i], v2[i]);
       else
         for (size_t i = 0; i < n; ++i) v1[i] = (is_equal(v1[i], mv1) || is_equal(v2[i], mv2)) ? mv1 : binary_operator(v1[i], v2[i]);
     }
@@ -46,15 +46,17 @@ static auto func_comp = [](auto hasMissvals, auto n, auto mv1, auto mv2, auto &v
 
 template <typename T1, typename T2>
 static void
-comp_function(int operFunc, bool hasMissvals, size_t ngp, T1 missval1, T2 missval2, Varray<T1> &v1, const Varray<T2> &v2)
+comp_function(Varray<T1> &v1, const Varray<T2> &v2, double missval1, double missval2, size_t ngp, int operFunc, bool hasMissvals)
 {
+  T1 mv1 = missval1;
+  T2 mv2 = missval2;
   // clang-format off
-  if      (operFunc == FieldFunc_EQ) func_comp(hasMissvals, ngp, missval1, missval2, v1, v2, binary_op_EQ);
-  else if (operFunc == FieldFunc_NE) func_comp(hasMissvals, ngp, missval1, missval2, v1, v2, binary_op_NE);
-  else if (operFunc == FieldFunc_LE) func_comp(hasMissvals, ngp, missval1, missval2, v1, v2, binary_op_LE);
-  else if (operFunc == FieldFunc_LT) func_comp(hasMissvals, ngp, missval1, missval2, v1, v2, binary_op_LT);
-  else if (operFunc == FieldFunc_GE) func_comp(hasMissvals, ngp, missval1, missval2, v1, v2, binary_op_GE);
-  else if (operFunc == FieldFunc_GT) func_comp(hasMissvals, ngp, missval1, missval2, v1, v2, binary_op_GT);
+  if      (operFunc == FieldFunc_EQ) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_EQ);
+  else if (operFunc == FieldFunc_NE) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_NE);
+  else if (operFunc == FieldFunc_LE) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_LE);
+  else if (operFunc == FieldFunc_LT) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_LT);
+  else if (operFunc == FieldFunc_GE) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_GE);
+  else if (operFunc == FieldFunc_GT) func_comp(hasMissvals, ngp, mv1, mv2, v1, v2, binary_op_GT);
   else cdo_abort("Operator not implemented!");
   // clang-format on
 }
@@ -63,14 +65,11 @@ static void
 comp_function(Field &f1, const Field &f2, int operFunc)
 {
   auto hasMissvals = (f1.numMissVals > 0 || f2.numMissVals > 0);
-  if (f1.memType == MemType::Float && f2.memType == MemType::Float)
-    comp_function(operFunc, hasMissvals, f1.size, (float) f1.missval, (float) f2.missval, f1.vec_f, f2.vec_f);
-  else if (f1.memType == MemType::Float && f2.memType == MemType::Double)
-    comp_function(operFunc, hasMissvals, f1.size, (float) f1.missval, f2.missval, f1.vec_f, f2.vec_d);
-  else if (f1.memType == MemType::Double && f2.memType == MemType::Float)
-    comp_function(operFunc, hasMissvals, f1.size, f1.missval, (float) f2.missval, f1.vec_d, f2.vec_f);
-  else
-    comp_function(operFunc, hasMissvals, f1.size, f1.missval, f2.missval, f1.vec_d, f2.vec_d);
+
+  auto func = [&](auto &v1, const auto &v2, double mv1, double mv2, size_t size) {
+    comp_function(v1, v2, mv1, mv2, size, operFunc, hasMissvals);
+  };
+  field_operation2(func, f1, f2, f1.missval, f2.missval, f1.size);
 }
 
 constexpr int MaxMonths = 12;
