@@ -128,7 +128,7 @@ MultVectorScalar(double *dest, const double *restrict src, double factor, size_t
 {
   if (numMissVals)
     {
-      for (size_t i = 0; i < len; ++i) dest[i] = (IS_EQUAL(src[i], missval)) ? missval : src[i] * factor;
+      for (size_t i = 0; i < len; ++i) dest[i] = (is_equal(src[i], missval)) ? missval : src[i] * factor;
     }
   else
     {
@@ -143,7 +143,7 @@ DivVectorIvector(double *dest, const double *restrict src, const int *samp, size
 
   for (size_t i = 0; i < len; ++i)
     {
-      if (IS_EQUAL(src[i], missval) || samp[i] == 0)
+      if (is_equal(src[i], missval) || samp[i] == 0)
         {
           dest[i] = missval;
           *numMissVals = *numMissVals + 1;
