@@ -16,9 +16,9 @@
 #include <iostream>
 #include <algorithm>
 #include <vector>
-#include <limits>
 
-#ifdef HAVE_EXECINFO_H
+#if __has_include(<execinfo.h>)
+#define HAVE_EXECINFO_H 1
 #include <execinfo.h>
 #endif
 
@@ -29,12 +29,19 @@
 #endif
 #include <cfenv>
 #include <sys/stat.h>
-#include <unistd.h> /* sysconf */
+#if __has_include(<sys/resource.h>)
+#define HAVE_SYS_RESOURCE_H 1
+#include <sys/resource.h>  // getrlimit
+#endif
+#include <unistd.h>  // sysconf
 #include <cstring>
+#include <cstdlib>
 #include <csignal>
 
 #include <cdi.h>
 
+#include "cpp_lib.h"
+#include "cdo_timer.h"
 #include "cdo_getopt.h"
 #include "cdo_rlimit.h"
 #include <mpim_grid.h>
@@ -42,41 +49,37 @@
 #include "cdo_default_values.h"
 #include "param_conversion.h"
 #include "progress.h"
-
-#include "module_list.h"
 #include "module_info.h"
 #include "percentiles.h"
 #include "util_wildcards.h"
 #include "util_string.h"
 #include "process_int.h"
+#include "processManager.h"
 #include "cdo_options.h"
-#include "timer.h"
 #include "commandline.h"
 #include "mpmo_color.h"
 #include "cdo_output.h"
 #include "cdo_features.h"
 #include "cdo_zaxis.h"
-#include "compare.h"
-#include "dmemory.h"
 #include "table.h"
 #include "datetime.h"
 #include "remap_grid_cell_search.h"
 #include "cdo_pthread.h"
 #include "institution.h"
-#include "cdo_apply.h"
 #include "parser.h"
+#include "factory.h"
 
 static ProcessManager g_processManager;
 
 void
-cdo_exit()
+cdo_exit(std::string msg = "")
 {
+  (void) msg;
   g_processManager.kill_processes();
   exit(EXIT_FAILURE);
 }
 
 static int CDO_numThreads = 0;
-static int timer_total;
 static int CDO_netcdf_hdr_pad = 0;
 static int CDO_Rusage = 0;
 static bool applyDryRun = false;
@@ -85,6 +88,7 @@ static bool applyDryRun = false;
 extern "C" void streamGrbDefDataScanningMode(int scanmode);
 #endif
 
+void expand_filter_names(std::string &filterSpec);
 void set_point_search_method(const std::string &methodstr);
 
 static void
@@ -177,6 +181,17 @@ cdo_version()
 #ifdef CXX_VERSION
   fprintf(fp, "CXX version : %s\n", CXX_VERSION);
 #endif
+  fprintf(fp, "CXX library :");
+#ifdef HAVE_LIB_RANGES
+  fprintf(fp, " ranges");
+#endif
+#ifdef HAVE_LIB_RANGES_ZIP
+  fprintf(fp, " ranges_zip");
+#endif
+#ifdef HAVE_LIB_MDSPAN
+  fprintf(fp, " mdspan");
+#endif
+  fprintf(fp, "\n");
 #endif
 #ifdef C_COMPILER
   fprintf(fp, "C Compiler: %s\n", C_COMPILER);
@@ -201,7 +216,7 @@ cdo_version()
 #endif
   fprintf(fp, "CDI file types: ");
   set_text_color(fp, BRIGHT, GREEN);
-  for (size_t i = 0; i < sizeof(filetypes) / sizeof(int); ++i)
+  for (size_t i = 0, n = sizeof(filetypes) / sizeof(int); i < n; ++i)
     if (cdiHaveFiletype(filetypes[i])) fprintf(fp, "%s ", typenames[i]);
   reset_text_color(fp);
   fprintf(fp, "\n");
@@ -224,7 +239,7 @@ cdo_display_syntax_help(const std::string &help, FILE *p_target)
   reset_text_color(p_target);
 }
 static void
-print_category(const std::string p_category, FILE *p_target)
+print_category(const std::string &p_category, FILE *p_target)
 {
   std::string options = CLIOptions::print_options_help(p_category).c_str();
   if (!options.empty())
@@ -238,11 +253,9 @@ print_category(const std::string p_category, FILE *p_target)
 }
 
 static void
-cdo_usage()
+cdo_usage(FILE *target)
 {
-
-  FILE *target = stderr;
-  std::string pad = CLIOptions::pad_size_terminal('-');
+  auto pad = CLIOptions::pad_size_terminal('-');
   fprintf(target, "%s", pad.c_str());
   fprintf(target, "  Usage : cdo  [Options]  Operator1  [-Operator2  [-OperatorN]]\n");
   pad = CLIOptions::pad_size_terminal('-');
@@ -279,7 +292,7 @@ cdo_usage()
   */
   pad = CLIOptions::pad_size_terminal('=');
   fprintf(target, "%s\n", pad.c_str());
-  fprintf(target, "    CDO version %s, Copyright (C) 2002-2023 MPI für Meteorologie\n", VERSION);
+  fprintf(target, "    CDO version %s, Copyright (C) 2002-2024 MPI für Meteorologie\n", VERSION);
   fprintf(target, "    This is free software and comes with ABSOLUTELY NO WARRANTY\n");
   fprintf(target, "    Report bugs to <https://mpimet.mpg.de/cdo>\n\n");
   pad = CLIOptions::pad_size_terminal('=');
@@ -293,54 +306,16 @@ cdo_init_is_tty()
   fstat(0, &statbuf);
   if (S_ISCHR(statbuf.st_mode)) cdo::stdinIsTerminal = true;
   fstat(1, &statbuf);
-  if (S_ISCHR(statbuf.st_mode))
-    {
-      cdo::stdoutIsTerminal = true;
-      progress::stdoutIsTerminal = true;
-    }
+  if (S_ISCHR(statbuf.st_mode)) { cdo::stdoutIsTerminal = true; }
   fstat(2, &statbuf);
   if (S_ISCHR(statbuf.st_mode)) cdo::stderrIsTerminal = true;
 }
 
-static void
-cdo_print_help(const char **help)
-{
-  if (!help)
-    fprintf(stderr, "No help available for this operator!\n");
-  else
-    {
-      size_t help_size = 0;
-      while (help[help_size]) help_size++;
-      for (size_t i = 0; i < help_size; ++i)
-        {
-          auto doPrint = !(help[i][0] == '\0' && help[i + 1][0] == ' ');
-          if (doPrint)
-            {
-              if (color_enabled())
-                {
-                  if (cdo_cmpstr(help[i], "NAME") || cdo_cmpstr(help[i], "SYNOPSIS") || cdo_cmpstr(help[i], "DESCRIPTION")
-                      || cdo_cmpstr(help[i], "OPERATORS") || cdo_cmpstr(help[i], "NAMELIST") || cdo_cmpstr(help[i], "PARAMETER")
-                      || cdo_cmpstr(help[i], "ENVIRONMENT") || cdo_cmpstr(help[i], "NOTE") || cdo_cmpstr(help[i], "EXAMPLES"))
-                    {
-                      set_text_color(stdout, BRIGHT);
-                      fprintf(stdout, "%s", help[i]);
-                      reset_text_color(stdout);
-                      fprintf(stdout, "\n");
-                    }
-                  else
-                    fprintf(stdout, "%s\n", help[i]);
-                }
-              else { fprintf(stdout, "%s\n", help[i]); }
-            }
-        }
-    }
-}
-
 #undef IsBigendian
 #define IsBigendian() (u_byteorder.c[sizeof(long) - 1])
 
 static void
-set_default_datatype(const char *datatypestr)
+set_default_datatype(const std::string &datatypeString)
 {
   static const union
   {
@@ -356,6 +331,7 @@ set_default_datatype(const char *datatypestr)
   };
   int dtype = -1;
 
+  auto datatypestr = datatypeString.c_str();
   auto datatype = tolower(*datatypestr);
   // clang-format off
   if      (datatype == 'i') { dtype = D_INT;  datatypestr++; }
@@ -365,7 +341,7 @@ set_default_datatype(const char *datatypestr)
   else if (datatype == 'p') {                 datatypestr++; }
   // clang-format on
 
-  if (isdigit((int) *datatypestr))
+  if (std::isdigit((int) *datatypestr))
     {
       auto nbits = atoi(datatypestr);
       datatypestr++;
@@ -433,34 +409,41 @@ set_default_datatype(const char *datatypestr)
       else { cdo_abort("Unsupported character in number of bytes: >%s< !", datatypestr); }
 
       datatypestr++;
-      if (*datatypestr != 0)  { cdo_abort("Unsupported character in number of bytes: >%s< !", datatypestr); }
+      if (*datatypestr != 0) { cdo_abort("Unsupported character in number of bytes: >%s< !", datatypestr); }
     }
 
   if (CdoDefault::DataType == -1) { cdo_abort("Number of bits undefined!"); }
 }
 
 static void
-set_default_filetype(const std::string &filetypeString)
+set_default_filetype(std::string filetypeString)
 {
-
   if (filetypeString.size() > 0)
     {
-      size_t len = 0;
+      std::string numbitsString;
+      constexpr char delimiter = '_';
+
+      auto pos = filetypeString.find(delimiter);
+      if (pos != std::string::npos)
+        {
+          numbitsString = filetypeString.substr(pos + 1);
+          filetypeString.resize(pos);
+        }
 
       // clang-format off
-      if      (cdo_cmpstrLenRhs(filetypeString, "grb2",   len)) CdoDefault::FileType = CDI_FILETYPE_GRB2;
-      else if (cdo_cmpstrLenRhs(filetypeString, "grb1",   len)) CdoDefault::FileType = CDI_FILETYPE_GRB;
-      else if (cdo_cmpstrLenRhs(filetypeString, "grb",    len)) CdoDefault::FileType = CDI_FILETYPE_GRB;
-      else if (cdo_cmpstrLenRhs(filetypeString, "nc2",    len)) CdoDefault::FileType = CDI_FILETYPE_NC2;
-      else if (cdo_cmpstrLenRhs(filetypeString, "nc4c",   len)) CdoDefault::FileType = CDI_FILETYPE_NC4C;
-      else if (cdo_cmpstrLenRhs(filetypeString, "nc4",    len)) CdoDefault::FileType = CDI_FILETYPE_NC4;
-      else if (cdo_cmpstrLenRhs(filetypeString, "nc5",    len)) CdoDefault::FileType = CDI_FILETYPE_NC5;
-      else if (cdo_cmpstrLenRhs(filetypeString, "nc1",    len)) CdoDefault::FileType = CDI_FILETYPE_NC;
-      else if (cdo_cmpstrLenRhs(filetypeString, "nczarr", len)) CdoDefault::FileType = CDI_FILETYPE_NCZARR;
-      else if (cdo_cmpstrLenRhs(filetypeString, "nc",     len)) CdoDefault::FileType = CDI_FILETYPE_NC2;
-      else if (cdo_cmpstrLenRhs(filetypeString, "srv",    len)) CdoDefault::FileType = CDI_FILETYPE_SRV;
-      else if (cdo_cmpstrLenRhs(filetypeString, "ext",    len)) CdoDefault::FileType = CDI_FILETYPE_EXT;
-      else if (cdo_cmpstrLenRhs(filetypeString, "ieg",    len)) CdoDefault::FileType = CDI_FILETYPE_IEG;
+      if      (filetypeString == "grb2")   CdoDefault::FileType = CDI_FILETYPE_GRB2;
+      else if (filetypeString == "grb1")   CdoDefault::FileType = CDI_FILETYPE_GRB;
+      else if (filetypeString == "grb")    CdoDefault::FileType = CDI_FILETYPE_GRB;
+      else if (filetypeString == "nc2")    CdoDefault::FileType = CDI_FILETYPE_NC2;
+      else if (filetypeString == "nc4c")   CdoDefault::FileType = CDI_FILETYPE_NC4C;
+      else if (filetypeString == "nc4")    CdoDefault::FileType = CDI_FILETYPE_NC4;
+      else if (filetypeString == "nc5")    CdoDefault::FileType = CDI_FILETYPE_NC5;
+      else if (filetypeString == "nc1")    CdoDefault::FileType = CDI_FILETYPE_NC;
+      else if (filetypeString == "nczarr") CdoDefault::FileType = CDI_FILETYPE_NCZARR;
+      else if (filetypeString == "nc")     CdoDefault::FileType = CDI_FILETYPE_NC2;
+      else if (filetypeString == "srv")    CdoDefault::FileType = CDI_FILETYPE_SRV;
+      else if (filetypeString == "ext")    CdoDefault::FileType = CDI_FILETYPE_EXT;
+      else if (filetypeString == "ieg")    CdoDefault::FileType = CDI_FILETYPE_IEG;
       else
         {
           cdo_warning("Unsupported filetype %s!", filetypeString);
@@ -469,20 +452,7 @@ set_default_filetype(const std::string &filetypeString)
         }
       // clang-format on
 
-      const char *ftstr = filetypeString.c_str() + len;
-
-      if (CdoDefault::FileType != CDI_UNDEFID && *ftstr != 0)
-        {
-          if (*ftstr == '_') { set_default_datatype(++ftstr); }
-          else
-            {
-              cdo_warning("Unexpected character >%c< in file type >%s<!", *ftstr, filetypeString);
-              cdo_warning("Use format[_nbits] with:");
-              cdo_warning("    format = grb1, grb2, nc1, nc2, nc4, nc4c, nc5, nczarr, srv, ext or ieg");
-              cdo_warning("    nbits  = 32/64 for grb2/nc1/nc2/nc4/nc4c/nc5/nczarr/srv/ext/ieg; 1 - 24 for grb1/grb2");
-              cdo_abort("Unexpected character in file type option!");
-            }
-        }
+      if (CdoDefault::FileType != CDI_UNDEFID && numbitsString.size() > 0) { set_default_datatype(numbitsString); }
     }
 }
 
@@ -531,21 +501,15 @@ alignof_vector_data(const std::vector<int> &tsize) -> int
 }
 
 static void
-define_filter(const std::string &argString)
+define_filterspec(const std::string &argString)
 {
   if (argString.size() > 0)
     {
-      if (Options::filterId != 0) { cdo_abort("Filter already defined! Only one filter is allowed."); }
-
-      auto filterArgs = split_with_seperator(argString, ',');
-      Options::filterId = parameter_to_int(filterArgs[0]);
-      if (Options::filterId <= 0) { cdo_abort("Undefined filter id: %d", Options::filterId); }
-      for (size_t i = 1; i < filterArgs.size(); ++i)
-        {
-          if (filterArgs[i].size() > 0) Options::filterParams.push_back(parameter_to_int(filterArgs[i]));
-        }
+      if (Options::filterSpec.size() > 0) { cdo_abort("Filter specs already defined! Only one filter specs is allowed."); }
+      Options::filterSpec = string_to_lower(argString);
+      expand_filter_names(Options::filterSpec);
     }
-  else { cdo_abort("Filter id missing!"); }
+  else { cdo_abort("Filter spec missing!"); }
 }
 
 static void
@@ -569,17 +533,17 @@ define_compress(const std::string &argString)
       Options::cdoCompType = CDI_COMPRESS_JPEG;
       Options::cdoCompLevel = 0;
     }
-  else if (strncmp(arg, "zip", 3) == 0)
+  else if (std::strncmp(arg, "zip", 3) == 0)
     {
       Options::cdoCompType = CDI_COMPRESS_ZIP;
-      Options::cdoCompLevel = (len == 5 && arg[3] == '_' && isdigit(arg[4])) ? atoi(&arg[4]) : 1;
+      Options::cdoCompLevel = (len == 5 && arg[3] == '_' && std::isdigit(arg[4])) ? atoi(&arg[4]) : 1;
     }
-  else if (strncmp(arg, "zstd", 4) == 0)
+  else if (std::strncmp(arg, "zstd", 4) == 0)
     {
-      if (Options::filterId != 0) { cdo_abort("Filter already defined! Only one filter is allowed."); }
-      Options::filterId = 32015;
-      int zstdLevel = (len >= 6 && len <= 7 && arg[4] == '_' && isdigit(arg[5])) ? atoi(&arg[5]) : 1;
-      Options::filterParams.push_back(zstdLevel);
+      int filterIdZstd = 32015;
+      int zstdLevel = (len >= 6 && len <= 7 && arg[4] == '_' && std::isdigit(arg[5])) ? atoi(&arg[5]) : 1;
+      if (Options::filterSpec.size() > 0) { cdo_abort("Filter specs already defined! Only one filter specs is allowed."); }
+      Options::filterSpec = std::to_string(filterIdZstd) + "," + std::to_string(zstdLevel);
     }
   else { cdo_abort("Compression type '%s' unsupported!", arg); }
 }
@@ -769,10 +733,10 @@ print_system_info()
   fprintf(stderr, "STD ANSI C          = %d\n", __STDC__);
 #endif
 #ifdef __STD_VERSION__
-  fprintf(stderr, "STD VERSION         = %ld\n", __STD_VERSION__);
+  fprintf(stderr, "STD VERSION         = %ld\n", (long) __STD_VERSION__);
 #endif
 #ifdef __STDC_VERSION__
-  fprintf(stderr, "STDC VERSION        = %ld\n", __STDC_VERSION__);
+  fprintf(stderr, "STDC VERSION        = %ld\n", (long) __STDC_VERSION__);
 #endif
 #ifdef __STD_HOSTED__
   fprintf(stderr, "STD HOSTED          = %d\n", __STD_HOSTED__);
@@ -824,6 +788,8 @@ cdo_set_options()
       fprintf(stderr, "\n");
     }
 
+  if (Options::test) cdiDefGlobal("THREADSAFE", 1);
+
   if (Options::CMOR_Mode) cdiDefGlobal("CMOR_MODE", Options::CMOR_Mode);  // TODO maybe reposition into effect of "cmor"
   if (Options::CDO_Reduce_Dim) cdiDefGlobal("REDUCE_DIM", Options::CDO_Reduce_Dim);
   if (CDO_netcdf_hdr_pad > 0) cdiDefGlobal("NETCDF_HDR_PAD", CDO_netcdf_hdr_pad);
@@ -854,7 +820,11 @@ evaluate_except_options(const std::string &arg)
   // clang-format on
   return except;
 }
-
+/*
+#if defined(__APPLE__) && defined(__MACH__)
+#include <libproc.h>
+#endif
+*/
 static void
 cdo_rusage(void)
 {
@@ -869,12 +839,30 @@ cdo_rusage(void)
       fprintf(stderr, "  User time:     %.3f seconds\n", ut);
       fprintf(stderr, "  System time:   %.3f seconds\n", st);
       fprintf(stderr, "  Total time:    %.3f seconds\n", ut + st);
+#if defined(__APPLE__) && defined(__MACH__)
       fprintf(stderr, "  Memory usage:  %.2f MBytes\n", ru.ru_maxrss / (1024.0 * 1024.0));
+#else
+      fprintf(stderr, "  Memory usage:  %.2f MBytes\n", ru.ru_maxrss / (1024.0));
+#endif
       fprintf(stderr, "  Page reclaims: %5ld page%s\n", ru.ru_minflt, ADD_PLURAL(ru.ru_minflt));
       fprintf(stderr, "  Page faults:   %5ld page%s\n", ru.ru_majflt, ADD_PLURAL(ru.ru_majflt));
       fprintf(stderr, "  Swaps:         %5ld\n", ru.ru_nswap);
       fprintf(stderr, "  Disk read:     %5ld block%s\n", ru.ru_inblock, ADD_PLURAL(ru.ru_inblock));
       fprintf(stderr, "  Disk Write:    %5ld block%s\n", ru.ru_oublock, ADD_PLURAL(ru.ru_oublock));
+      /*
+#if defined(__APPLE__) && defined(__MACH__)
+#ifdef RUSAGE_INFO_CURRENT
+      pid_t pid = fork();
+      rusage_info_current ruinfo;
+      int rusage_ret = proc_pid_rusage(pid, RUSAGE_INFO_CURRENT, (void **)&ruinfo);
+      if (rusage_ret >= 0 && ruinfo.ri_lifetime_max_phys_footprint > 0)
+        {
+          fprintf(stderr, "  Peak memory:   %.2f MBytes\n", ruinfo.ri_lifetime_max_phys_footprint / 1.0);
+          fprintf(stderr, "  Peak memory:   %.2f MBytes\n", ruinfo.ri_lifetime_max_phys_footprint / (1024.0 * 1024.0));
+        }
+#endif
+#endif
+      */
     }
 #endif
 }
@@ -936,7 +924,9 @@ static void
 print_operator_attributes(const std::string &argument)
 {
   ModListOptions local_modListOpt;
+
   local_modListOpt.parse_request(argument);
+
   operator_print_list(local_modListOpt);
 }
 
@@ -989,10 +979,10 @@ predefined_tables(int p_padding)
   constexpr int id_padding = 4;
   int padding = p_padding + id_padding;
   int numTables = tableInqNumber();
-  std::string tables = std::string("Predefined tables: ");
+  std::string tables{ "Predefined tables: " };
   for (int id = 0; id < numTables; id++)
     {
-      if (id % 7 == 6) tables += "\n" + std::string(padding, ' ');
+      if (id % 7 == 6) tables += std::string("\n") + std::string(padding, ' ');
       if ((name = tableInqNamePtr(id))) tables += std::string(name);
       if (id < numTables - 1) tables += ",";
     }
@@ -1056,6 +1046,11 @@ setup_cli_options()
       })
       ->add_effect([&](const std::string &argument) {
         auto [success, tokens] = tokenize_comma_seperated_int_list(argument);
+        if (tokens.empty())
+          {
+            print_debug_options();
+            exit(EXIT_SUCCESS);
+          }
 
         unsigned cdoDebugLevel = 0;
         unsigned cdiDebugLevel = 0;
@@ -1216,7 +1211,7 @@ setup_cli_options()
       ->describe_argument("module name")
       ->set_category("Info")
       ->add_effect([&](const std::string &argument) {
-        auto names = get_module_operator_names(argument);
+        auto names = Factory::get_module_operator_names(argument);
         if (names.empty())
           {
             std::string errstr = "Module " + argument + " not found\n";
@@ -1258,19 +1253,19 @@ setup_cli_options()
 
   CLIOptions::option("help", "h")
       ->describe_argument("operator")
-      ->add_effect([&](const std::string &argument) { cdo_print_help(operator_help(argument)); })
-      ->on_empty_argument([]() { cdo_usage(); })
+      ->add_effect([&](const std::string &operator_name) { cdo_print_help(operator_name); })
+      ->on_empty_argument([]() { cdo_usage(stdout); })
       ->aborts_program(true)
       ->set_category("Help")
       ->add_help("Shows either help information for the given operator or the usage of CDO.");
 
   CLIOptions::option("history")
-      ->add_effect([&]() { Options::CDO_Append_History = 1; })
+      ->add_effect([&]() { Options::CDO_Append_History = true; })
       ->set_category("History")
       ->add_help("Do append to NetCDF \"history\" global attribute.");
 
   CLIOptions::option("no_history")
-      ->add_effect([&]() { Options::CDO_Append_History = 0; })
+      ->add_effect([&]() { Options::CDO_Append_History = false; })
       ->set_category("History")
       ->add_help("Do not append to NetCDF \"history\" global attribute.");
 
@@ -1290,11 +1285,13 @@ setup_cli_options()
       })
       ->add_help("Generate an absolute time axis.");
 
+  CLIOptions::option("force")->add_effect([&]() { Options::force = true; })->add_help("Forcing a CDO process.");
+
   // clang-format off
   CLIOptions::option("default_datatype", "b")
       ->describe_argument("nbits")
       ->set_category("Numeric")
-      ->add_effect([&](const std::string &argument) { set_default_datatype(argument.c_str()); })
+      ->add_effect([&](const std::string &argument) { set_default_datatype(argument); })
       ->add_help("Set the number of bits for the output precision",
                  "    I8|I16|I32|F32|F64     for nc1,nc2,nc4,nc4c,nc5,nczarr;",
                  "    U8|U16|U32             for nc4,nc4c,nc5;",
@@ -1310,11 +1307,11 @@ setup_cli_options()
       ->describe_argument("grid")
       ->add_effect([&](const std::string &argument) { cdo_set_grids(argument.c_str()); })
       ->add_help("Set default grid name or file. Available grids: ",
-                 "F<XXX>, t<RES>, tl<RES>, r<NX>x<NY>, global_<DXY>, zonal_<DY>, gme<NI>, lon=<LON>/lat=<LAT>");
+                 "F<XXX>, t<RES>, tl<RES>, r<NX>x<NY>, global_<DXY>, zonal_<DY>, gme<NI>, lon=<LON>/lat=<LAT>, hpz<ZOOM>");
 
   CLIOptions::option("institution", "i")
       ->describe_argument("institute_name")
-      ->add_effect([&](const std::string &argument) { define_institution(argument.c_str()); })
+      ->add_effect([&](const std::string &argument) { define_institution(argument); })
       ->add_help("Sets institution name.");
 
   CLIOptions::option("chunktype", "k")
@@ -1414,7 +1411,6 @@ setup_cli_options()
       ->add_effect([&]() {
         Options::silentMode = true;
         MpMO::enable_silent_mode(Options::silentMode);
-        progress::silentMode = true;
       })
       ->set_category("Output")
       ->add_help("Silent mode.");
@@ -1457,15 +1453,20 @@ setup_cli_options()
       ->add_help("Enables multithreaded I/O.")
       ->set_category("Multi Threading");
 
+  CLIOptions::option("shuffle")
+      ->add_effect([&]() { Options::cdoShuffle = true; })
+      ->set_category("Compression")
+      ->add_help("Specify shuffling of variable data bytes before compression (NetCDF)");
+
   CLIOptions::option("compress", "Z")
       ->add_effect([&]() { Options::cdoCompress = true; })
       ->set_category("Compression")
       ->add_help("Enables compression. Default = SZIP");
 
   CLIOptions::option("filter", "F")
-      ->describe_argument("filterId,params")
-      ->add_effect([&](const std::string &argument) { define_filter(argument); })
-      ->set_category("Fromat Specific")
+      ->describe_argument("NetCDF filter specs")
+      ->add_effect([&](const std::string &argument) { define_filterspec(argument); })
+      ->set_category("Compression")
       ->add_help("NetCDF4/HDF5 filter description.");
 
   CLIOptions::option("compression_type", "z")
@@ -1494,11 +1495,13 @@ setup_cli_options()
       ->add_help("Explanation and Examples for subgrouping operators with [ ] syntax")
       ->add_effect([&]() { cdo_display_syntax_help(Parser::subgroup_help, stderr); })
       ->set_category("Help");
+
   CLIOptions::option("apply")
       ->aborts_program(true)
       ->add_help("Explanation and Examples for -apply syntax")
       ->add_effect([&]() { cdo_display_syntax_help(Parser::apply_help, stderr); })
       ->set_category("Help");
+
   CLIOptions::option("sortparam")->add_effect([]() { cdiDefGlobal("SORTPARAM", true); });
 
 #ifdef HIRLAM_EXTENSIONS
@@ -1538,6 +1541,24 @@ setup_cli_options()
 #endif  // HIRLAM_EXTENSIONS
 }
 
+static void
+timer_report(std::vector<cdo::iTimer *> &timers)
+{
+  FILE *fp = stdout;
+  fprintf(fp, "\nTimer report:  shift = %g\n", cdo::timerShift);
+  fprintf(fp, "    Name   Calls          Min      Average          Max        Total\n");
+
+  for (auto &timer : timers)
+    {
+      auto total = timer->elapsed();
+      auto avg = timer->sum;
+      if (timer->calls > 0) avg /= timer->calls;
+
+      // if (timer.stat != rt_stat_undef)
+      fprintf(fp, "%8s %7d %12.4g %12.4g %12.4g %12.4g\n", timer->name.c_str(), timer->calls, timer->min, avg, timer->max, total);
+    }
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -1549,8 +1570,6 @@ main(int argc, char *argv[])
 
   cdo_init_is_tty();
 
-  memExitOnError();
-
   Options::CDO_Reduce_Dim = 0;
 
   // mallopt(M_MMAP_MAX, 0);
@@ -1574,8 +1593,8 @@ main(int argc, char *argv[])
 
   if (CDO_optind >= argc)
     {
+      cdo_usage(stderr);
       fprintf(stderr, "\nNo operator given!\n\n");
-      cdo_usage();
       exit(EXIT_FAILURE);
     }
   else
@@ -1594,10 +1613,6 @@ main(int argc, char *argv[])
 
       if (CdoDefault::TableID != CDI_UNDEFID) cdo_def_table_id(CdoDefault::TableID);
 
-      timer_total = timer_new("total");
-      timer_read = timer_new("read");
-      timer_write = timer_new("write");
-
 #ifdef HAVE_H5DONT_ATEXIT
       H5dont_atexit();  // don't call H5close on exit
 #endif
@@ -1612,13 +1627,22 @@ main(int argc, char *argv[])
           std::cerr << processStructure[0]->to_string() << std::endl;
           exit(applyDryRun ? 0 : -1);
         }
+
+      std::vector<cdo::iTimer *> allTimers;
+      auto totalTimer = cdo::iTimer("total");
+      cdo::readTimer = cdo::iTimer("read");
+      cdo::writeTimer = cdo::iTimer("write");
+      allTimers.push_back(&totalTimer);
+      allTimers.push_back(&cdo::readTimer);
+      allTimers.push_back(&cdo::writeTimer);
+
       g_processManager.buildProcessTree(processStructure);
-      timer_start(timer_total);
+      totalTimer.start();
       g_processManager.run_processes();
-      timer_stop(timer_total);
+      totalTimer.stop();
       g_processManager.clear_processes();
 
-      if (Options::Timer) timer_report();
+      if (Options::Timer) timer_report(allTimers);
     }
 
   if (CDO_Rusage) cdo_rusage();
