@@ -11,7 +11,7 @@ struct CmorVar
   bool remove = false;
   // missing value
   bool changemissval = false;
-  double missval_old = 0.0;
+  double missvalOld = 0.0;
   //
   bool lfactor = false;
   double factor = 0.0;
