@@ -14,6 +14,8 @@
 
 #include <cdi.h>
 
+#include <map>
+
 #ifdef HAVE_NETCDF_META_H
 #include <netcdf_meta.h>
 #endif
@@ -45,12 +47,13 @@ extern "C"
 }
 #endif
 
-#include <stdio.h>
+#include <cstdio>
+#include <cstring>
+#include <iostream>
 
-#include "process_int.h"
 #include "cdo_features.h"
 #include "cdo_rlimit.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "lib/yac/yac_version.h"
 
 #include <thread>  // std::thread::hardware_concurrency()
@@ -136,6 +139,7 @@ static std::map<std::string, std::pair<std::string, bool>> configMap
         { "has-threads", { "PTHREADS", have_threads } },
         { "has-wordexp", { "WORDEXP", have_wordexp } },
         { "has-hirlam_extensions", { "HIRLAM_EXTENSIONS", has_hirlam_extensions } } };
+
 void
 cdo_print_features(void)
 {
@@ -152,10 +156,23 @@ cdo_print_features(void)
   if (numProcs < concurrentThreads) fprintf(fp, "%u/", numProcs);
 #endif
   fprintf(fp, "%uthreads", concurrentThreads);
+#ifdef HAVE_OPENMP4
+  auto numDevices = omp_get_num_devices();
+  if (numDevices > 0) fprintf(fp, " %ddevices", numDevices);
+#endif
   fprintf(fp, " c++%d", (int) ((__cplusplus - 200000) / 100));
+#ifdef __FAST_MATH__
+  fprintf(fp, "/fastmath");
+#endif
 #ifdef _OPENMP
   fprintf(fp, " OpenMP");
-#if defined(HAVE_OPENMP45)
+#if defined(HAVE_OPENMP52)
+  fprintf(fp, "52");
+#elif defined(HAVE_OPENMP51)
+  fprintf(fp, "51");
+#elif defined(HAVE_OPENMP5)
+  fprintf(fp, "5");
+#elif defined(HAVE_OPENMP45)
   fprintf(fp, "45");
 #elif defined(HAVE_OPENMP4)
   fprintf(fp, "4");
