@@ -5,16 +5,14 @@
 
 */
 
-#include <string.h>
-#include <assert.h>
 #include "cdo_getopt.h"
 #include "util_string.h"
+
 #include <cstdio>
 #include <sstream>
 #include <cstdlib>
 
 #include <vector>
-#include <set>
 #include <map>
 
 #define CLIOP_DBG false
@@ -232,10 +230,11 @@ CLIOptions::print_envvar_help()
     {
       if (!it.second->isInternal)
         {
+          auto len0 = helpString.str().size();
           helpString << std::string(4, ' ');
           helpString << it.second->name;
           if (it.second->hasArgument) helpString << " <" + it.second->argument.description + "> ";
-          int spaceLeft = padding - helpString.str().size();
+          int spaceLeft = padding - helpString.str().size() + len0;
           if (spaceLeft < 0) spaceLeft = 0;
           for (auto &line : it.second->description) { helpString << std::string(spaceLeft, ' ') + line + "\n"; }
         }
@@ -279,6 +278,7 @@ CLIOptions::print_options_help(const std::string &p_category)
     }
   return help.str();
 }
+
 #include <algorithm>
 
 cdo_option_2 *
