@@ -9,12 +9,19 @@
 
 #include <cdi.h>
 #include "cdo_options.h"
+#include "cdo_timer.h"
 #include "util_string.h"
 #include "cdo_output.h"
 
 #include <cstring>
 #include <algorithm>
 
+namespace cdo
+{
+iTimer readTimer;
+iTimer writeTimer;
+}  // namespace cdo
+
 namespace cdo
 {
 const char *progname;
@@ -35,10 +42,10 @@ int nsb = 0;  // Number of significant bits
 bool benchmark = false;
 bool silentMode = false;
 bool test = false;
+bool force = false;
 
 // NetCDF4/HDF5 filter
-int filterId = 0;
-std::vector<int> filterParams;
+std::string filterSpec;
 
 int cdoShuffle = 0;
 bool cdoCompress = false;
@@ -147,10 +154,7 @@ set_compression(int streamID, int filetype)
         cdo_warning("Deflate compression not available for non NetCDF4 data!");
     }
 
-  if (Options::filterId != 0)
-    {
-      streamDefFilter(streamID, Options::filterId, (int) Options::filterParams.size(), Options::filterParams.data());
-    }
+  if (Options::filterSpec.size() > 0) { streamDefFilter(streamID, Options::filterSpec.c_str()); }
 }
 
 static double pointSearchRadius = 180.0;  // default point search radius in degrees
