@@ -22,6 +22,7 @@ extern unsigned CDO_DEBUG;
 extern unsigned FACTORY;
 extern unsigned KVLIST;
 extern unsigned MODULE_INFO;
+extern unsigned ARGUMENTS;
 
 extern std::string debug_option_string;
 
@@ -30,14 +31,13 @@ void query_user_exit(const char *argument);
 
 namespace cdo
 {
-
 void parse_debug_arguments(const std::vector<std::string> &tokens, unsigned &cdoDebugLevel, unsigned &cdiDebugLevel);
 void print_debug_levels(unsigned cdoDebugLevel, unsigned cdiDebugLevel);
 void set_debug(unsigned p_debug_level);
 bool dbg();
-extern void (*exitProgram)(void);
+extern void (*exitProgram)(std::string);
 extern const char *(*getContext)(void);
-void set_exit_function(void (*func)(void));
+void set_exit_function(void (*func)(std::string msg));
 void set_context_function(const char *(*func)(void) );
 }  // namespace cdo
 
@@ -46,11 +46,11 @@ std::string cdo_argv_to_string(const std::vector<std::string> &argv);
 
 template <typename... Args>
 void
-cdo_abort(const std::string &format, Args const &...args) noexcept
+cdo_abort(const std::string &format, Args const &...args)
 {
   fflush(stdout);
-  MpMO::PrintCerr(Red("\n%s (Abort): ") + format, cdo::getContext(), args...);
-  if (MpMO::exitOnError) cdo::exitProgram();
+  std::string errmsg = MpMO::PrintCerr(Red("\n%s (Abort): ") + format, cdo::getContext(), args...);
+  if (MpMO::exitOnError) cdo::exitProgram(errmsg);
 }
 
 template <typename... Args>
@@ -71,7 +71,7 @@ cdo_warning(const std::string &format, Args const &...args) noexcept
       if (MpMO::pedantic)
         {
           MpMO::PrintCerr(Red("%s (Warning): ") + format, cdo::getContext(), args...);
-          if (MpMO::exitOnError) cdo::exitProgram();
+          if (MpMO::exitOnError) cdo::exitProgram("cdo_warning (pedantic)");
         }
       else { MpMO::PrintCerr(Yellow("%s (Warning): ") + format, cdo::getContext(), args...); }
     }
