@@ -5,13 +5,8 @@
 
 */
 
-#include <array>
-#include <algorithm>
-
 #include <cdi.h>
-#include "cdo_cdi_wrapper.h"
 #include "cdo_options.h"
-#include "util_string.h"
 #include "cdo_vlist.h"
 #include "compare.h"
 #include "cdo_output.h"
@@ -218,34 +213,33 @@ zaxis_check_levels(int zaxisID1, int zaxisID2)
 }
 
 int
-vlist_compare_x(int vlistID1, int vlistID2, CmpVlist cmpFlag)
+vlist_compare_x(int vlistID1, int vlistID2, int cmpFlag)
 {
-  auto flag = static_cast<int>(cmpFlag);
-  auto nvars = vlistNvars(vlistID1);
-  auto nvars2 = vlistNvars(vlistID2);
-  auto nlevels2 = zaxisInqSize(vlistInqVarZaxis(vlistID2, 0));
+  VarList varList1(vlistID1);
+  VarList varList2(vlistID2);
 
-  if (nvars2 != 1) cdo_abort("Internal problem, vlist_compare_x() called with unexpected vlistID2 argument!");
+  auto nlevels2 = varList2.vars[0].nlevels;
 
-  for (int varID = 0; varID < nvars; ++varID)
+  if (varList2.numVars() != 1) cdo_abort("Internal problem, vlist_compare_x() called with unexpected vlistID2 argument!");
+
+  for (int varID = 0; varID < varList1.numVars(); ++varID)
     {
-      if (flag & static_cast<int>(CmpVlist::GridSize))
+      if (cmpFlag & CmpVarList::GridSize)
         {
-          if (gridInqSize(vlistInqVarGrid(vlistID1, varID)) != gridInqSize(vlistInqVarGrid(vlistID2, 0)))
-            cdo_abort("Grid size of the input fields do not match!");
+          if (varList1.vars[varID].gridsize != varList2.vars[0].gridsize) cdo_abort("Grid size of the input fields do not match!");
         }
 
-      if (flag & static_cast<int>(CmpVlist::NumLevels))
+      if (cmpFlag & CmpVarList::NumLevels)
         {
-          if ((zaxisInqSize(vlistInqVarZaxis(vlistID1, varID)) != nlevels2) && nlevels2 > 1)
+          if ((varList1.vars[varID].nlevels != nlevels2) && nlevels2 > 1)
             cdo_abort("Number of levels of the input fields do not match!");
         }
     }
 
-  if (flag & static_cast<int>(CmpVlist::Grid))
+  if (cmpFlag & CmpVarList::Grid)
     {
-      auto gridID1 = vlistInqVarGrid(vlistID1, 0);
-      auto gridID2 = vlistInqVarGrid(vlistID2, 0);
+      auto gridID1 = varList1.vars[0].gridID;
+      auto gridID2 = varList2.vars[0].gridID;
       if (gridID1 != gridID2) cdo_compare_grids(gridID1, gridID2);
     }
 
@@ -265,16 +259,6 @@ vlist_is_szipped(int vlistID)
   return false;
 }
 
-int
-vlist_inq_nwpv(int vlistID, int varID)
-{
-  auto datatype = vlistInqVarDatatype(vlistID, varID);
-  // number of words per value; real:1  complex:2
-  auto nwpv = (datatype == CDI_DATATYPE_CPX32 || datatype == CDI_DATATYPE_CPX64) ? 2 : 1;
-
-  return nwpv;
-}
-
 size_t
 vlist_check_gridsize(int vlistID)
 {
@@ -282,7 +266,7 @@ vlist_check_gridsize(int vlistID)
   auto ngp = gridInqSize(vlistGrid(vlistID, 0));
 
   // check gridsize
-  auto ngrids = vlistNgrids(vlistID);
+  auto ngrids = vlistNumGrids(vlistID);
   for (int index = 0; index < ngrids; ++index)
     {
       auto gridID = vlistGrid(vlistID, index);
@@ -319,7 +303,7 @@ vlist_read_vct(int vlistID, int &zaxisID_ML, int &numHybridLevels, int &numFullL
   numHalfLevels = 0;
 
   auto haveVCT = false;
-  auto nzaxis = vlistNzaxis(vlistID);
+  auto nzaxis = vlistNumZaxis(vlistID);
   for (int iz = 0; iz < nzaxis; ++iz)
     {
       // auto monoLevel = false;
@@ -438,7 +422,7 @@ vlist_change_hybrid_zaxis(int vlistID1, int vlistID2, int zaxisID1, int zaxisID2
   int vctSize0 = 0;
   Varray<double> vct;
 
-  auto nzaxis = vlistNzaxis(vlistID1);
+  auto nzaxis = vlistNumZaxis(vlistID1);
   for (int i = 0; i < nzaxis; ++i)
     {
       auto zaxisID = vlistZaxis(vlistID1, i);
@@ -468,7 +452,7 @@ int
 vlist_get_first_spectral_grid(int vlistID)
 {
   // find first spectral grid
-  auto ngrids = vlistNgrids(vlistID);
+  auto ngrids = vlistNumGrids(vlistID);
   for (int index = 0; index < ngrids; ++index)
     {
       auto gridID = vlistGrid(vlistID, index);
@@ -482,7 +466,7 @@ int
 vlist_get_first_gaussian_grid(int vlistID)
 {
   // find first gaussian grid
-  auto ngrids = vlistNgrids(vlistID);
+  auto ngrids = vlistNumGrids(vlistID);
   for (int index = 0; index < ngrids; ++index)
     {
       auto gridID = vlistGrid(vlistID, index);
@@ -496,7 +480,7 @@ int
 vlist_get_first_fourier_grid(int vlistID)
 {
   // find first fourier grid
-  auto ngrids = vlistNgrids(vlistID);
+  auto ngrids = vlistNumGrids(vlistID);
   for (int index = 0; index < ngrids; ++index)
     {
       auto gridID = vlistGrid(vlistID, index);
@@ -509,7 +493,7 @@ vlist_get_first_fourier_grid(int vlistID)
 void
 cdo_check_missval(double missval, const std::string &varname)
 {
-  if (dbl_is_equal(0.0, missval) || dbl_is_equal(1.0, missval))
+  if (fp_is_equal(0.0, missval) || fp_is_equal(1.0, missval))
     {
       static auto printWarning = true;
       if (printWarning)
