@@ -12,7 +12,7 @@
 #include "cdo_options.h"
 #include "process_int.h"
 #include "field_functions.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "interpol.h"
 #include "expr.h"
 #include "expr_fun.h"
@@ -646,14 +646,14 @@ ex_fun_std(int funcID, size_t n, bool hasMV, double mv, const double *p1data, do
     {
       if (funcEntry.name == "isMissval")
         {
-          for (size_t i = 0; i < n; ++i) { pdata[i] = dbl_is_equal(p1data[i], mv); }
+          for (size_t i = 0; i < n; ++i) { pdata[i] = fp_is_equal(p1data[i], mv); }
         }
       else
         {
           for (size_t i = 0; i < n; ++i)
             {
               errno = -1;
-              pdata[i] = dbl_is_equal(p1data[i], mv) ? mv : exprfunc(p1data[i]);
+              pdata[i] = fp_is_equal(p1data[i], mv) ? mv : exprfunc(p1data[i]);
               if (errno == EDOM || errno == ERANGE || std::isnan(pdata[i])) pdata[i] = mv;
             }
         }
@@ -680,7 +680,7 @@ func_expr_con_var(int funcID, bool hasMV, size_t n, double mv, double *odat, dou
       for (size_t i = 0; i < n; ++i)
         {
           errno = -1;
-          odat[i] = (dbl_is_equal(idat[i], mv)) ? mv : exprfunc(cval, idat[i]);
+          odat[i] = (fp_is_equal(idat[i], mv)) ? mv : exprfunc(cval, idat[i]);
           if (errno == EDOM || errno == ERANGE || std::isnan(odat[i])) odat[i] = mv;
         }
     }
@@ -706,7 +706,7 @@ func_expr_var_con(int funcID, bool hasMV, size_t n, double mv, double *odat, con
       for (size_t i = 0; i < n; ++i)
         {
           errno = -1;
-          odat[i] = (dbl_is_equal(idat[i], mv)) ? mv : exprfunc(idat[i], cval);
+          odat[i] = (fp_is_equal(idat[i], mv)) ? mv : exprfunc(idat[i], cval);
           if (errno == EDOM || errno == ERANGE || std::isnan(odat[i])) odat[i] = mv;
         }
     }
@@ -732,7 +732,7 @@ func_expr_var_var(int funcID, bool hasMV, size_t n, double mv1, double mv2, doub
       for (size_t i = 0; i < n; ++i)
         {
           errno = -1;
-          odat[i] = (dbl_is_equal(idat1[i], mv1) || dbl_is_equal(idat2[i], mv2)) ? mv1 : exprfunc(idat1[i], idat2[i]);
+          odat[i] = (fp_is_equal(idat1[i], mv1) || fp_is_equal(idat2[i], mv2)) ? mv1 : exprfunc(idat1[i], idat2[i]);
           if (errno == EDOM || errno == ERANGE || std::isnan(odat[i])) odat[i] = mv1;
         }
     }
@@ -1492,7 +1492,7 @@ ex_uminus_var(int init, nodeType *p1)
 
       if (numMissVals)
         {
-          for (size_t i = 0; i < ngp * nlev; ++i) pdata[i] = dbl_is_equal(p1data[i], missval) ? missval : -(p1data[i]);
+          for (size_t i = 0; i < ngp * nlev; ++i) pdata[i] = fp_is_equal(p1data[i], missval) ? missval : -(p1data[i]);
         }
       else
         {
@@ -1565,7 +1565,7 @@ ex_not_var(int init, nodeType *p1)
 
       if (numMissVals)
         {
-          for (size_t i = 0; i < ngp * nlev; ++i) pdata[i] = dbl_is_equal(p1data[i], missval) ? missval : unary_op_not(p1data[i]);
+          for (size_t i = 0; i < ngp * nlev; ++i) pdata[i] = fp_is_equal(p1data[i], missval) ? missval : unary_op_not(p1data[i]);
         }
       else
         {
@@ -1778,12 +1778,12 @@ ex_ifelse(int init, nodeType *p1, nodeType *p2, nodeType *p3)
               auto ival2 = idat2[(ngp2 > 1) ? i : 0];
               auto ival3 = idat3[(ngp3 > 1) ? i : 0];
 
-              if (numMissVals1 && dbl_is_equal(ival1, missval1))
+              if (numMissVals1 && fp_is_equal(ival1, missval1))
                 odat[i] = missval1;
               else if (is_not_equal(ival1, 0.0))
-                odat[i] = dbl_is_equal(ival2, missval2) ? missval1 : ival2;
+                odat[i] = fp_is_equal(ival2, missval2) ? missval1 : ival2;
               else
-                odat[i] = dbl_is_equal(ival3, missval3) ? missval1 : ival3;
+                odat[i] = fp_is_equal(ival3, missval3) ? missval1 : ival3;
             }
 
           numMissVals += array_num_mv(ngp, odat, missval1);
@@ -2028,7 +2028,7 @@ expr_run_var(nodeType *p, ParseParamType &parseArg)
   if (varID == -1) { cdo_abort("Variable >%s< not found!", vnm); }
   else if (init)
     {
-      if (varID < parseArg.nvars1 && !parseArg.needed[varID]) parseArg.needed[varID] = true;
+      if (varID < parseArg.numVars1 && !parseArg.needed[varID]) parseArg.needed[varID] = true;
     }
 
   param_meta_copy(p->param, params[varID]);
@@ -2173,7 +2173,7 @@ expr_run_opr(nodeType *p, ParseParamType &parseArg)
             if (varID >= 0)
               {
                 // printf("  found %s\n", varname2);
-                if (varID < parseArg.nvars1)
+                if (varID < parseArg.numVars1)
                   {
                     if (rnode->param.nlev > 0 && params[varID].nlev != rnode->param.nlev)
                       cdo_abort("The number of layers must not change (name=%s layers: in=%zu out=%zu)!", params[varID].name,
@@ -2254,3 +2254,16 @@ expr_run(nodeType *p, ParseParamType &parseArg)
 
   return nullptr;
 }
+int
+params_get_coord_ID(const ParseParamType &parseArg, int coord, int cdiID)
+{
+  auto ncoords = parseArg.numCoords;
+  for (int coordID = 0; coordID < ncoords; ++coordID)
+    {
+      if (parseArg.coords[coordID].coord == coord && parseArg.coords[coordID].cdiID == cdiID) return coordID;
+    }
+
+  cdo_abort("%s: coordinate %c not found!", __func__, coord);
+
+  return -1;
+}
