@@ -6,6 +6,7 @@
 */
 #ifndef CDO_EXPR_H
 #define CDO_EXPR_H
+
 #include <cstdio>
 #include <cstdarg>
 #include <cassert>
@@ -48,6 +49,7 @@ struct conNodeType
 {
   double value;  // value of constant
 
+  conNodeType() : value(0.0) {}  // Default ctor is needed to initialize variant object
   conNodeType(double _value) : value(_value) {}
 };
 
@@ -135,8 +137,7 @@ struct nodeType
   ParamEntry param;
   NodeEnum type{ NodeEnum::typeUndef };  // type of node
   bool isTmpObj = false;
-  // int variant is a dummy for default constructor
-  std::variant<int, conNodeType, varNodeType, cmdNodeType, funNodeType, oprNodeType> v;
+  std::variant<conNodeType, varNodeType, cmdNodeType, funNodeType, oprNodeType> v;
 
   auto &con() const { assert(std::holds_alternative<conNodeType>(v)); return std::get<conNodeType>(v); }
   auto &var()       { assert(std::holds_alternative<varNodeType>(v)); return std::get<varNodeType>(v); }
@@ -166,8 +167,8 @@ struct ParseParamType
   int maxparams;
   int nparams;
   int cnparams;  // current number of valid params
-  int nvars1;
-  int ncoords;
+  int numVars1;
+  int numCoords;
   int maxCoords;
   int tsID;
   int pointID;
