@@ -5,12 +5,12 @@
 
 */
 
-#include <algorithm>
 #include <cdi.h>
 
 #include "arithmetic.h"
 #include "cdo_options.h"
-#include "process_int.h"
+#include "cdo_output.h"
+#include "cdo_omp.h"
 #include "field_functions.h"
 
 // clang-format off
@@ -52,45 +52,47 @@ const auto arith_vincr_mv = [](auto &a, auto mv_a, auto b, auto mv_b, auto is_EQ
 
 template <typename T1, typename T2>
 static void
-varray2_div(size_t len, Varray<T1> &v1, const Varray<T2> &v2, double missval1)
+varray2_div(Varray<T1> &v1, const Varray<T2> &v2, size_t n, double missval1)
 {
-  assert(len > 0);
+  assert(n > 0);
   assert(v1.size() > 0);
   assert(v2.size() > 0);
-  assert(len <= v1.size());
-  assert(len <= v2.size());
+  assert(n <= v1.size());
+  assert(n <= v2.size());
 
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (n > cdoMinLoopSize) default(shared) schedule(static)
 #endif
-  for (size_t i = 0; i < len; ++i) { v1[i] = is_equal(v2[i], 0.0) ? missval1 : arith_div(v1[i], v2[i]); }
+  for (size_t i = 0; i < n; ++i) { v1[i] = is_equal(v2[i], 0.0) ? missval1 : arith_div(v1[i], v2[i]); }
 }
 
 template <typename T1, typename T2, typename FUNC>
 static void
-varray2_arith(size_t len, Varray<T1> &v1, const Varray<T2> &v2, FUNC func)
+varray2_arith(Varray<T1> &v1, const Varray<T2> &v2, size_t n, FUNC func)
 {
-  assert(len > 0);
+  assert(n > 0);
   assert(v1.size() > 0);
   assert(v2.size() > 0);
-  assert(len <= v1.size());
-  assert(len <= v2.size());
+  assert(n <= v1.size());
+  assert(n <= v2.size());
 
-#ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#ifdef HAVE_OPENMP4
+#pragma omp parallel for simd if (n > cdoMinLoopSize) default(shared) schedule(static)
 #endif
-  for (size_t i = 0; i < len; ++i) { v1[i] = func(v1[i], v2[i]); }
+  for (size_t i = 0; i < n; ++i) { v1[i] = func(v1[i], v2[i]); }
 }
 
+auto varray2_func = [](auto &v1, auto &v2, size_t n, auto arith_func) { varray2_arith(v1, v2, n, arith_func); };
+
 template <typename T1, typename T2, typename FUNC>
 static void
-varray2_arith_mv(size_t len, Varray<T1> &v1, const Varray<T2> &v2, double missval1, double missval2, FUNC func)
+varray2_arith_mv(Varray<T1> &v1, const Varray<T2> &v2, size_t n, double missval1, double missval2, FUNC func)
 {
-  assert(len > 0);
+  assert(n > 0);
   assert(v1.size() > 0);
   assert(v2.size() > 0);
-  assert(len <= v1.size());
-  assert(len <= v2.size());
+  assert(n <= v1.size());
+  assert(n <= v2.size());
 
   T1 mv1 = missval1;
   T2 mv2 = missval2;
@@ -98,34 +100,30 @@ varray2_arith_mv(size_t len, Varray<T1> &v1, const Varray<T2> &v2, double missva
   if (std::isnan(missval1) || std::isnan(missval2))
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (n > cdoMinLoopSize) default(shared) schedule(static)
 #endif
-      for (size_t i = 0; i < len; ++i) func(v1[i], mv1, v2[i], mv2, dbl_is_equal);
+      for (size_t i = 0; i < n; ++i) { func(v1[i], mv1, v2[i], mv2, fp_is_equal); }
     }
   else
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (n > cdoMinLoopSize) default(shared) schedule(static)
 #endif
-      for (size_t i = 0; i < len; ++i) func(v1[i], mv1, v2[i], mv2, is_equal);
+      for (size_t i = 0; i < n; ++i) { func(v1[i], mv1, v2[i], mv2, is_equal); }
     }
 }
 
+auto varray2_func_mv = [](auto &v1, auto &v2, size_t n, double mv1, double mv2, auto arith_mv_func) {
+  varray2_arith_mv(v1, v2, n, mv1, mv2, arith_mv_func);
+};
+
 // init valid values
 void
 field2_vinit(Field &field1, const Field &field2)
 {
   if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
 
-  if (memtype_is_float_float(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_vinit_mv);
-  else if (memtype_is_float_double(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_vinit_mv);
-  else if (memtype_is_double_float(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_vinit_mv);
-  else
-    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_vinit_mv);
-
+  field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_vinit_mv);
   field1.numMissVals = field2.numMissVals;
 }
 
@@ -135,39 +133,31 @@ field2_vincr(Field &field1, const Field &field2)
 {
   if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
 
-  if (memtype_is_float_float(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_vincr_mv);
-  else if (memtype_is_float_double(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_vincr_mv);
-  else if (memtype_is_double_float(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_vincr_mv);
-  else
-    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_vincr_mv);
-
+  field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_vincr_mv);
   field1.numMissVals = field2.numMissVals;
 }
 
 // init valid values
 template <typename T1, typename T2>
 static void
-field2_vinit(size_t len, Varray<T1> &v1, const Varray<T2> &v2, T2 missval, int vinit)
+field2_vinit(Varray<T1> &v1, const Varray<T2> &v2, size_t len, double mv, int vinit)
 {
-  for (size_t i = 0; i < len; ++i) v1[i] = (dbl_is_equal(v2[i], missval)) ? 0 : vinit;
+  auto missval = static_cast<T2>(mv);
+  for (size_t i = 0; i < len; ++i) v1[i] = (fp_is_equal(v2[i], missval)) ? 0 : vinit;
 }
 
 void
 field2_vinit(Field &field1, const Field &field2, int vinit)
 {
   if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
-
-  if (memtype_is_float_float(field1.memType, field2.memType))
-    field2_vinit(field1.size, field1.vec_f, field2.vec_f, (float) field1.missval, vinit);
-  else if (memtype_is_float_double(field1.memType, field2.memType))
-    field2_vinit(field1.size, field1.vec_f, field2.vec_d, field1.missval, vinit);
-  else if (memtype_is_double_float(field1.memType, field2.memType))
-    field2_vinit(field1.size, field1.vec_d, field2.vec_f, (float) field1.missval, vinit);
-  else
-    field2_vinit(field1.size, field1.vec_d, field2.vec_d, field1.missval, vinit);
+  /*
+  auto func = [](auto &v1, auto &v2, auto n, double mv, int vinit) {
+    auto missval = static_cast<T2>(mv);
+    for (size_t i = 0; i < n; ++i) v1[i] = (fp_is_equal(v2[i], missval)) ? 0 : vinit;
+  };
+  */
+  auto func = [&](auto &v1, auto &v2, size_t n, double mv) { field2_vinit(v1, v2, n, mv, vinit); };
+  field_operation2(func, field1, field2, field2.size, field2.missval);
 
   field1.numMissVals = field2.numMissVals;
 }
@@ -175,10 +165,11 @@ field2_vinit(Field &field1, const Field &field2, int vinit)
 // increment valid values
 template <typename T1, typename T2>
 static void
-field2_vincr(size_t len, Varray<T1> &v1, const Varray<T2> &v2, T2 missval, int vincr)
+field2_vincr(Varray<T1> &v1, const Varray<T2> &v2, size_t len, double mv, int vincr)
 {
+  auto missval = static_cast<T2>(mv);
   for (size_t i = 0; i < len; ++i)
-    if (!dbl_is_equal(v2[i], missval)) v1[i] += vincr;
+    if (fp_is_not_equal(v2[i], missval)) v1[i] += vincr;
 }
 
 void
@@ -186,14 +177,8 @@ field2_vincr(Field &field1, const Field &field2, int vincr)
 {
   if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
 
-  if (memtype_is_float_float(field1.memType, field2.memType))
-    field2_vincr(field1.size, field1.vec_f, field2.vec_f, (float) field1.missval, vincr);
-  else if (memtype_is_float_double(field1.memType, field2.memType))
-    field2_vincr(field1.size, field1.vec_f, field2.vec_d, field1.missval, vincr);
-  else if (memtype_is_double_float(field1.memType, field2.memType))
-    field2_vincr(field1.size, field1.vec_d, field2.vec_f, (float) field1.missval, vincr);
-  else
-    field2_vincr(field1.size, field1.vec_d, field2.vec_d, field1.missval, vincr);
+  auto func = [&](auto &v1, auto &v2, size_t n, double mv) { field2_vincr(v1, v2, n, mv, vincr); };
+  field_operation2(func, field1, field2, field2.size, field2.missval);
 
   field1.numMissVals = field2.numMissVals;
 }
@@ -205,28 +190,10 @@ field2_add(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_add_mv);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_add_mv);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_add_mv);
-      else
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_add_mv);
-
+      field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_add_mv);
       field_num_mv(field1);
     }
-  else
-    {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_add);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_add);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_add);
-      else
-        varray2_arith(field1.size, field1.vec_d, field2.vec_d, arith_add);
-    }
+  else { field_operation2(varray2_func, field1, field2, field2.size, arith_add); }
 }
 
 void
@@ -236,28 +203,10 @@ field2_sum(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_sum_mv);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_sum_mv);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_sum_mv);
-      else
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_sum_mv);
-
+      field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_sum_mv);
       field_num_mv(field1);
     }
-  else
-    {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_add);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_add);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_add);
-      else
-        varray2_arith(field1.size, field1.vec_d, field2.vec_d, arith_add);
-    }
+  else { field_operation2(varray2_func, field1, field2, field2.size, arith_add); }
 }
 
 void
@@ -274,12 +223,12 @@ field2_sumw(Field &field1, const Field &field2, double w)
   if (field1.numMissVals || field2.numMissVals)
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < len; ++i)
-        if (!dbl_is_equal(array2[i], missval2))
+        if (fp_is_not_equal(array2[i], missval2))
           {
-            if (!dbl_is_equal(array1[i], missval1))
+            if (fp_is_not_equal(array1[i], missval1))
               array1[i] += w * array2[i];
             else
               array1[i] = w * array2[i];
@@ -290,7 +239,7 @@ field2_sumw(Field &field1, const Field &field2, double w)
   else
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < len; ++i) array1[i] += w * array2[i];
     }
@@ -317,19 +266,19 @@ field2_sumtr(Field &occur, const Field &field, double refval)
   if (occur.numMissVals || field.numMissVals)
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < len; ++i)
-        if (!dbl_is_equal(farray[i], fmissval))
+        if (fp_is_not_equal(farray[i], fmissval))
           {
-            if (!dbl_is_equal(oarray[i], omissval))
-              oarray[i] = (dbl_is_equal(farray[i], refval)) ? 0.0 : oarray[i] + 1.0;
+            if (fp_is_not_equal(oarray[i], omissval))
+              oarray[i] = (fp_is_equal(farray[i], refval)) ? 0.0 : oarray[i] + 1.0;
             else
-              oarray[i] = (dbl_is_equal(farray[i], refval)) ? 0.0 : 1.0;
+              oarray[i] = (fp_is_equal(farray[i], refval)) ? 0.0 : 1.0;
           }
         else
           {
-            if (!dbl_is_equal(oarray[i], omissval)) oarray[i] = 0.0;
+            if (fp_is_not_equal(oarray[i], omissval)) oarray[i] = 0.0;
           }
 
       occur.numMissVals = field_num_miss(occur);
@@ -337,9 +286,9 @@ field2_sumtr(Field &occur, const Field &field, double refval)
   else
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static)
 #endif
-      for (size_t i = 0; i < len; ++i) oarray[i] = (dbl_is_equal(farray[i], refval)) ? 0.0 : oarray[i] + 1.0;
+      for (size_t i = 0; i < len; ++i) oarray[i] = (fp_is_equal(farray[i], refval)) ? 0.0 : oarray[i] + 1.0;
     }
 }
 
@@ -350,28 +299,10 @@ field2_sumq(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_sumq_mv);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_sumq_mv);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_sumq_mv);
-      else
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_sumq_mv);
-
+      field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_sumq_mv);
       field_num_mv(field1);
     }
-  else
-    {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_sumq);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_sumq);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_sumq);
-      else
-        varray2_arith(field1.size, field1.vec_d, field2.vec_d, arith_sumq);
-    }
+  else { field_operation2(varray2_func, field1, field2, field2.size, arith_sumq); }
 }
 
 void
@@ -395,12 +326,12 @@ field2_sumqw(Field &field1, const Field &field2, double w)
   if (field1.numMissVals || field2.numMissVals)
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < len; ++i)
-        if (!dbl_is_equal(array2[i], missval2))
+        if (fp_is_not_equal(array2[i], missval2))
           {
-            if (!dbl_is_equal(array1[i], missval1))
+            if (fp_is_not_equal(array1[i], missval1))
               array1[i] += w * array2[i] * array2[i];
             else
               array1[i] = w * array2[i] * array2[i];
@@ -411,7 +342,7 @@ field2_sumqw(Field &field1, const Field &field2, double w)
   else
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared) schedule(static)
+#pragma omp parallel for if (len > cdoMinLoopSize) default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < len; ++i) array1[i] += w * array2[i] * array2[i];
     }
@@ -424,28 +355,10 @@ field2_sub(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_sub_mv);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_sub_mv);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_sub_mv);
-      else
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_sub_mv);
-
+      field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_sub_mv);
       field_num_mv(field1);
     }
-  else
-    {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_sub);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_sub);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_sub);
-      else
-        varray2_arith(field1.size, field1.vec_d, field2.vec_d, arith_sub);
-    }
+  else { field_operation2(varray2_func, field1, field2, field2.size, arith_sub); }
 }
 
 void
@@ -455,28 +368,10 @@ field2_mul(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_mul_mv);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_mul_mv);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_mul_mv);
-      else
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_mul_mv);
-
+      field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_mul_mv);
       field_num_mv(field1);
     }
-  else
-    {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_mul);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_mul);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_mul);
-      else
-        varray2_arith(field1.size, field1.vec_d, field2.vec_d, arith_mul);
-    }
+  else { field_operation2(varray2_func, field1, field2, field2.size, arith_mul); }
 }
 
 void
@@ -486,28 +381,13 @@ field2_div(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_div_mv);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_div_mv);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_div_mv);
-      else
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_div_mv);
-
+      field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_div_mv);
       field_num_mv(field1);
     }
   else
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_div(field1.size, field1.vec_f, field2.vec_f, field1.missval);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_div(field1.size, field1.vec_f, field2.vec_d, field1.missval);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_div(field1.size, field1.vec_d, field2.vec_f, field1.missval);
-      else
-        varray2_div(field1.size, field1.vec_d, field2.vec_d, field1.missval);
-
+      auto func = [](auto &v1, auto &v2, size_t n, double mv) { varray2_div(v1, v2, n, mv); };
+      field_operation2(func, field1, field2, field1.size, field1.missval);
       field_num_mv(field1);
     }
 }
@@ -517,15 +397,7 @@ field2_atan2(Field &field1, const Field &field2)
 {
   if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
 
-  if (memtype_is_float_float(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_atan2_mv);
-  else if (memtype_is_float_double(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_atan2_mv);
-  else if (memtype_is_double_float(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_atan2_mv);
-  else
-    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_atan2_mv);
-
+  field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_atan2_mv);
   field_num_mv(field1);
 }
 
@@ -541,7 +413,7 @@ field2_set_miss(Field &field1, const Field &field2)
 
   if (field1.numMissVals)
     {
-      for (size_t i = 0; i < len; ++i) array1[i] = dbl_is_equal(array1[i], missval1) ? array2[i] : array1[i];
+      for (size_t i = 0; i < len; ++i) array1[i] = fp_is_equal(array1[i], missval1) ? array2[i] : array1[i];
 
       field1.numMissVals = field_num_miss(field1);
     }
@@ -554,28 +426,10 @@ field2_min(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_min_mv);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_min_mv);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_min_mv);
-      else
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_min_mv);
-
+      field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_min_mv);
       field_num_mv(field1);
     }
-  else
-    {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_min);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_min);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_min);
-      else
-        varray2_arith(field1.size, field1.vec_d, field2.vec_d, arith_min);
-    }
+  else { field_operation2(varray2_func, field1, field2, field2.size, arith_min); }
 }
 
 void
@@ -585,28 +439,10 @@ field2_max(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_max_mv);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_max_mv);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_max_mv);
-      else
-        varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_max_mv);
-
+      field_operation2(varray2_func_mv, field1, field2, field2.size, field1.missval, field2.missval, arith_max_mv);
       field_num_mv(field1);
     }
-  else
-    {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_max);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_max);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_max);
-      else
-        varray2_arith(field1.size, field1.vec_d, field2.vec_d, arith_max);
-    }
+  else { field_operation2(varray2_func, field1, field2, field2.size, arith_max); }
 }
 
 void
@@ -634,11 +470,11 @@ field2_minidx(size_t numMissVals3, size_t len, double missval3, Field &field1, F
     {
       for (size_t i = 0; i < len; ++i)
         {
-          if (dbl_is_equal(v3[i], missval3))
+          if (fp_is_equal(v3[i], missval3))
             {
-              if (dbl_is_equal(v2[i], missval2)) v1[i] = missval1;
+              if (fp_is_equal(v2[i], missval2)) v1[i] = missval1;
             }
-          else if (v3[i] < v2[i] || dbl_is_equal(v2[i], missval2)) { field2_set_index(v1[i], v2[i], v3[i], idx); }
+          else if (v3[i] < v2[i] || fp_is_equal(v2[i], missval2)) { field2_set_index(v1[i], v2[i], v3[i], idx); }
         }
 
       field_num_mv(field1);
@@ -678,11 +514,11 @@ field2_maxidx(size_t numMissVals3, size_t len, double missval3, Field &field1, F
     {
       for (size_t i = 0; i < len; ++i)
         {
-          if (dbl_is_equal(v3[i], missval3))
+          if (fp_is_equal(v3[i], missval3))
             {
-              if (dbl_is_equal(v2[i], missval2)) v1[i] = missval1;
+              if (fp_is_equal(v2[i], missval2)) v1[i] = missval1;
             }
-          else if (v3[i] > v2[i] || dbl_is_equal(v2[i], missval2)) { field2_set_index(v1[i], v2[i], v3[i], idx); }
+          else if (v3[i] > v2[i] || fp_is_equal(v2[i], missval2)) { field2_set_index(v1[i], v2[i], v3[i], idx); }
         }
 
       field_num_mv(field1);
@@ -717,7 +553,7 @@ field_set_numMissVals(size_t len, Varray<double> &v, double missval)
   if (std::isnan(missval))
     {
       for (size_t i = 0; i < len; ++i)
-        if (dbl_is_equal(v[i], missval) || v[i] < 0)
+        if (fp_is_equal(v[i], missval) || v[i] < 0)
           {
             v[i] = missval;
             numMissVals++;
@@ -750,7 +586,7 @@ field2_var(Field &field1, const Field &field2, const Field &field3, int divisor)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      auto is_EQ = dbl_is_equal;
+      auto is_EQ = fp_is_equal;
       for (size_t i = 0; i < len; ++i)
         {
           auto temp = DIVM(MULM(array1[i], array1[i]), array3[i]);
@@ -760,10 +596,11 @@ field2_var(Field &field1, const Field &field2, const Field &field3, int divisor)
     }
   else
     {
+      auto is_EQ = is_equal;
       for (size_t i = 0; i < len; ++i)
         {
-          auto temp = DIV(MUL(array1[i], array1[i]), array3[i]);
-          array1[i] = DIV(SUB(array2[i], temp), array3[i] - divisor);
+          auto temp = DIVX(MUL(array1[i], array1[i]), array3[i]);
+          array1[i] = DIVX(SUB(array2[i], temp), array3[i] - divisor);
           if (array1[i] < 0 && array1[i] > -1.e-5) array1[i] = 0;
         }
     }
@@ -784,7 +621,7 @@ field2_std(Field &field1, const Field &field2, const Field &field3, int divisor)
 
   size_t numMissVals = 0;
   for (size_t i = 0; i < len; ++i)
-    if (dbl_is_equal(array1[i], missval1) || array1[i] < 0)
+    if (fp_is_equal(array1[i], missval1) || array1[i] < 0)
       {
         array1[i] = missval1;
         numMissVals++;
@@ -811,7 +648,7 @@ fieldc_var(Field &field1, const Field &field2, int numSets, int divisor)
     }
   else if (field1.numMissVals || field2.numMissVals)
     {
-      auto is_EQ = dbl_is_equal;
+      auto is_EQ = fp_is_equal;
       for (size_t i = 0; i < len; ++i)
         {
           auto temp = MULM(array1[i], array1[i]) / numSets;
@@ -845,7 +682,7 @@ fieldc_std(Field &field1, const Field &field2, int numSets, int divisor)
 
   size_t numMissVals = 0;
   for (size_t i = 0; i < len; ++i)
-    if (dbl_is_equal(array1[i], missval1) || array1[i] < 0)
+    if (fp_is_equal(array1[i], missval1) || array1[i] < 0)
       {
         array1[i] = missval1;
         numMissVals++;
@@ -869,7 +706,7 @@ field2_moq(Field &field1, const Field &field2)
   if (field2.numMissVals)
     {
       for (size_t i = 0; i < len; ++i)
-        if (!dbl_is_equal(array2[i], missval2))
+        if (fp_is_not_equal(array2[i], missval2))
           array1[i] = array2[i] * array2[i];
         else
           array1[i] = missval1;
@@ -896,7 +733,7 @@ field2_moqw(Field &field1, const Field &field2, double w)
   if (field2.numMissVals)
     {
       for (size_t i = 0; i < len; ++i)
-        if (!dbl_is_equal(array2[i], missval2))
+        if (fp_is_not_equal(array2[i], missval2))
           array1[i] = w * array2[i] * array2[i];
         else
           array1[i] = missval1;
@@ -923,7 +760,7 @@ field2_moqw(Field &field1, const Field &field2, double w)
  */
 template <typename T1, typename T2>
 static void
-varray2_count_mv(size_t len, Varray<T1> &v1, const Varray<T2> &v2, double mv1, double mv2)
+varray2_count_mv(Varray<T1> &v1, const Varray<T2> &v2, size_t len, double mv1, double mv2)
 {
   assert(len > 0);
   assert(v1.size() > 0);
@@ -932,9 +769,9 @@ varray2_count_mv(size_t len, Varray<T1> &v1, const Varray<T2> &v2, double mv1, d
   assert(len <= v2.size());
 
   for (size_t i = 0; i < len; ++i)
-    if (!dbl_is_equal(v2[i], mv2))
+    if (fp_is_not_equal(v2[i], mv2))
       {
-        if (!dbl_is_equal(v1[i], mv1))
+        if (fp_is_not_equal(v1[i], mv1))
           v1[i] += 1.0;
         else
           v1[i] = 1.0;
@@ -943,7 +780,7 @@ varray2_count_mv(size_t len, Varray<T1> &v1, const Varray<T2> &v2, double mv1, d
 
 template <typename T>
 static void
-varray2_count(size_t len, Varray<T> &v)
+varray_count(Varray<T> &v, size_t len)
 {
   assert(len > 0);
 
@@ -957,23 +794,14 @@ field2_count(Field &field1, const Field &field2)
 
   if (field1.numMissVals || field2.numMissVals)
     {
-      if (memtype_is_float_float(field1.memType, field2.memType))
-        varray2_count_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval);
-      else if (memtype_is_float_double(field1.memType, field2.memType))
-        varray2_count_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval);
-      else if (memtype_is_double_float(field1.memType, field2.memType))
-        varray2_count_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval);
-      else
-        varray2_count_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval);
-
+      auto func = [](auto &v1, auto &v2, size_t n, double mv1, double mv2) { varray2_count_mv(v1, v2, n, mv1, mv2); };
+      field_operation2(func, field1, field2, field1.size, field1.missval, field2.missval);
       field1.numMissVals = field_num_miss(field1);
     }
   else
     {
-      if (field1.memType == MemType::Float)
-        varray2_count(field1.size, field1.vec_f);
-      else
-        varray2_count(field1.size, field1.vec_d);
+      auto func = [](auto &v, size_t n) { varray_count(v, n); };
+      field_operation(func, field1, field1.size);
     }
 }
 
