@@ -20,9 +20,8 @@
 #include "cdo_default_values.h"
 #include "cdo_history.h"
 #include "cdo_query.h"
+#include "cdo_timer.h"
 #include "process.h"
-
-#include "timer.h"
 #include "commandline.h"
 
 bool FileStream::TimerEnabled = false;
@@ -93,13 +92,13 @@ FileStream::open_write(int p_filetype)
     }
 #endif
 
-  // TODO FIX THIS: if (FileStream::timersEnabled()) timer_start(timer_write);
+  // TODO FIX THIS: if (FileStream::timersEnabled()) cdo::writeTimer.start();
 
   open_lock();
   auto fileID = streamOpenWrite(m_filename.c_str(), p_filetype);
   open_unlock();
 
-  // TODO FIX THIS: if(FileStream::timersEnabled()) timer_stop(timer_write);
+  // TODO FIX THIS: if(FileStream::timersEnabled()) cdo::writeTimer.stop();
   if (fileID < 0) cdi_open_error(fileID, "Open failed on >%s<", m_name.c_str());
   isopen = true;
 
@@ -116,13 +115,13 @@ FileStream::open_write(int p_filetype)
 int
 FileStream::open_append()
 {
-  if (FileStream::timersEnabled()) timer_start(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.start();
 
   open_lock();
   auto fileID = streamOpenAppend(m_filename.c_str());
   open_unlock();
 
-  if (FileStream::timersEnabled()) timer_stop(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.stop();
 
   if (fileID < 0) cdi_open_error(fileID, "Open failed on >%s<", m_filename.c_str());
 
@@ -208,17 +207,17 @@ FileStream::def_vlist(int p_vlistID)
 #endif
   defDatarangeList(p_vlistID);
 
-  if (FileStream::timersEnabled()) timer_start(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.start();
   stream_def_vlist_locked(m_fileID, p_vlistID);
-  if (FileStream::timersEnabled()) timer_stop(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.stop();
 }
 
 int
 FileStream::inq_vlist()
 {
-  if (FileStream::timersEnabled()) timer_start(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.start();
   auto vlistID = stream_inq_vlist_locked(m_fileID);
-  if (FileStream::timersEnabled()) timer_stop(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.stop();
   if (vlistID == -1) cdo_abort("Couldn't read data from input fileID %d!", m_fileID);
 
   auto nsubtypes = vlistNsubtypes(vlistID);
@@ -233,35 +232,35 @@ FileStream::inq_vlist()
 void
 FileStream::inq_record(int *const varID, int *const levelID)
 {
-  if (FileStream::timersEnabled()) timer_start(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.start();
   stream_inq_rec_locked(m_fileID, varID, levelID);
-  if (FileStream::timersEnabled()) timer_stop(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.stop();
   m_varID = *varID;
 }
 
 void
 FileStream::defRecord(int varID, int levelID)
 {
-  if (FileStream::timersEnabled()) timer_start(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.start();
   stream_def_rec_locked(m_fileID, varID, levelID);
-  if (FileStream::timersEnabled()) timer_stop(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.stop();
   m_varID = varID;
 }
 
 void
 FileStream::read_record(float *const p_data, size_t *const numMissVals)
 {
-  if (FileStream::timersEnabled()) timer_start(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.start();
   stream_readrecord_float_locked(m_fileID, p_data, numMissVals);
-  if (FileStream::timersEnabled()) timer_stop(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.stop();
 }
 
 void
 FileStream::read_record(double *const p_data, size_t *const numMissVals)
 {
-  if (FileStream::timersEnabled()) timer_start(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.start();
   stream_readrecord_double_locked(m_fileID, p_data, numMissVals);
-  if (FileStream::timersEnabled()) timer_stop(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.stop();
 }
 
 void
@@ -273,7 +272,7 @@ FileStream::read_record(Field *const p_field, size_t *const numMissVals)
 void
 FileStream::write_record(const float *const p_data, size_t p_numMissVals)
 {
-  if (FileStream::timersEnabled()) timer_start(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.start();
 
   auto varID = m_varID;
   if (varID < (int) m_datarangelist.size())
@@ -281,13 +280,13 @@ FileStream::write_record(const float *const p_data, size_t p_numMissVals)
 
   stream_write_record_float_locked(m_fileID, p_data, p_numMissVals);
 
-  if (FileStream::timersEnabled()) timer_stop(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.stop();
 }
 
 void
 FileStream::write_record(const double *const p_data, size_t p_numMissVals)
 {
-  if (FileStream::timersEnabled()) timer_start(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.start();
 
   auto varID = m_varID;
   if (varID < (int) m_datarangelist.size())
@@ -295,7 +294,7 @@ FileStream::write_record(const double *const p_data, size_t p_numMissVals)
 
   stream_write_record_double_locked(m_fileID, p_data, p_numMissVals);
 
-  if (FileStream::timersEnabled()) timer_stop(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.stop();
 }
 
 void
@@ -322,9 +321,9 @@ FileStream::copyRecord(CdoStreamID p_destination)
 int
 FileStream::inq_timestep(int p_tsID)
 {
-  if (FileStream::timersEnabled()) timer_start(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.start();
   auto nrecs = stream_inq_time_step_locked(m_fileID, p_tsID);
-  if (FileStream::timersEnabled()) timer_stop(timer_read);
+  if (FileStream::timersEnabled()) cdo::readTimer.stop();
 
   if (p_tsID == 0 && CdoDefault::TaxisType != CDI_UNDEFID) taxisDefType(vlistInqTaxis(m_vlistID), CdoDefault::TaxisType);
 
@@ -337,13 +336,13 @@ FileStream::inq_timestep(int p_tsID)
 void
 FileStream::def_timestep(int p_tsID)
 {
-  if (FileStream::timersEnabled()) timer_start(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.start();
   // don't use sync -> very slow on GPFS
   //  if ( p_tsID > 0 ) streamSync(fileID);
 
   stream_def_time_step_locked(m_fileID, p_tsID);
 
-  if (FileStream::timersEnabled()) timer_stop(timer_write);
+  if (FileStream::timersEnabled()) cdo::writeTimer.stop();
 }
 
 int
