@@ -2,6 +2,7 @@
 // https://schneide.wordpress.com/2016/07/15/generating-an-icosphere-in-c
 
 #include "vector3d.h"
+#include <inttypes.h>
 
 #include <utility>
 #include <limits>
@@ -9,16 +10,46 @@
 #include <iostream>
 #include <vector>
 #include <array>
-#include <map>
-#include <unordered_map>
 
-using Index = size_t;
+#define UseUnorderedMap 1
+
+#ifdef UseUnorderedMap
+#include <unordered_map>
+#else
+#include <map>
+#endif
+
+// using Index = size_t;
+using Index = uint32_t;
 using Vertex = Vector3d;
 using Triangle = std::array<Index, 3>;
 using TriangleList = std::vector<Triangle>;
 using VertexList = std::vector<Vertex>;
 
+#ifdef UseUnorderedMap
+struct S
+{
+  Index first;
+  Index second;
+  S(Index _first, Index _second) : first(_first), second(_second) {}
+  bool operator==(const S &) const = default;  // since C++20
+};
+// Custom specialization of std::hash can be injected in namespace std.
+template <>
+struct std::hash<S>
+{
+  std::size_t
+  operator()(const S &s) const noexcept
+  {
+    std::size_t h1 = std::hash<Index>{}(s.first);
+    std::size_t h2 = std::hash<Index>{}(s.second);
+    return h1 ^ (h2 << 1);  // or use boost::hash_combine
+  }
+};
+using Lookup = std::unordered_map<S, Index>;
+#else
 using Lookup = std::map<std::pair<Index, Index>, Index>;
+#endif
 
 // icosahedron from ICON
 namespace icosahedron
@@ -29,7 +60,7 @@ namespace icosahedron
 // 12 vertices
 static VertexList vertices(12);
 
-void
+static void
 init(void)
 {
   constexpr auto pi_5 = M_PI * 0.2;
@@ -41,20 +72,14 @@ init(void)
   vertices[11] = Vertex{ 0.0, 0.0, -1.0 };
   // now set the vertices on the two latitude rings
   int i_mdist[10];
-  for (int j = 1; j < 11; ++j)
-    {
-      if (j % 2 == 0)
-        i_mdist[j / 2 + 4] = -1 + (j - 1) - 10 * ((j - 1) / 7);
-      else
-        i_mdist[(j + 1) / 2 - 1] = -1 + (j - 1) - 10 * ((j - 1) / 7);
-    }
+  for (int j = 1; j < 11; ++j) { i_mdist[(j % 2 == 0) ? (j / 2 + 4) : ((j + 1) / 2 - 1)] = -1 + (j - 1) - 10 * ((j - 1) / 7); }
 
   for (int j = 1; j < 11; ++j)
     {
       // toggle the hemisphere
-      const auto i_msgn = (j >= 6) ? -1.0 : 1.0;
+      auto i_msgn = (j >= 6) ? -1.0 : 1.0;
       // compute the meridian angle for the base vertex.
-      const auto z_rlon = (1.0 + i_mdist[j - 1]) * pi_5;
+      auto z_rlon = (1.0 + i_mdist[j - 1]) * pi_5;
       // now initialize the coordinates
       vertices[j] = Vertex{ std::sin(z_w) * std::cos(z_rlon), std::sin(z_w) * std::sin(z_rlon), std::cos(z_w) * i_msgn };
     }
@@ -70,12 +95,12 @@ static const TriangleList triangles
 }  // namespace icosahedron
 
 static Index
-vertexForEdge(Lookup &lookup, VertexList &vertices, Index first, Index second)
+vertex_for_edge(Lookup &lookup, VertexList &vertices, Index first, Index second)
 {
   Lookup::key_type key(first, second);
   if (key.first > key.second) std::swap(key.first, key.second);
 
-  const auto inserted = lookup.insert({ key, vertices.size() });
+  auto inserted = lookup.insert({ key, vertices.size() });
   if (inserted.second) vertices.push_back((vertices[first] + vertices[second]).normalised());
 
   return inserted.first->second;
@@ -87,12 +112,15 @@ subdivide(VertexList &vertices, const TriangleList &triangles)
   Lookup lookup;
   Triangle mid;
 
-  const auto n = triangles.size();
+  auto n = triangles.size();
+#ifdef UseUnorderedMap
+  lookup.reserve(1.5 * n);
+#endif
   TriangleList result(4 * n);
   for (size_t i = 0; i < n; ++i)
     {
       const auto &each = triangles[i];
-      for (int edge = 0; edge < 3; edge++) { mid[edge] = vertexForEdge(lookup, vertices, each[edge], each[(edge + 1) % 3]); }
+      for (int edge = 0; edge < 3; edge++) { mid[edge] = vertex_for_edge(lookup, vertices, each[edge], each[(edge + 1) % 3]); }
 
       result[i * 4 + 0] = { each[0], mid[0], mid[2] };
       result[i * 4 + 1] = { each[1], mid[1], mid[0] };
@@ -103,29 +131,15 @@ subdivide(VertexList &vertices, const TriangleList &triangles)
   return result;
 }
 
-using IndexedMesh = std::pair<VertexList, TriangleList>;
-
-static IndexedMesh
-makeIcosphere(int subdivisions)
-{
-  icosahedron::init();
-  auto vertices = icosahedron::vertices;
-  auto triangles = icosahedron::triangles;
-
-  for (int i = 0; i < subdivisions; ++i) triangles = subdivide(vertices, triangles);
-
-  return { vertices, triangles };
-}
-
 static inline void
 d_normalize(Vertex &v)
 {
-  const auto dnorm = std::sqrt(v * v);
+  auto dnorm = std::sqrt(v * v);
   v /= dnorm;
 }
 
 static Vertex
-circumCenterMean(const Vertex &v0, const Vertex &v1, const Vertex &v2)
+circum_center_mean(const Vertex &v0, const Vertex &v1, const Vertex &v2)
 {
   /*
     v0, v1, v2: the coordinates of the three triangle vertices (_dmo,nit vectors) in
@@ -159,26 +173,38 @@ circumCenterMean(const Vertex &v0, const Vertex &v1, const Vertex &v2)
 }
 
 size_t
-genIcosphereCoords(int subdivisions, bool withBounds, std::vector<double> &xvals, std::vector<double> &yvals,
-                   std::vector<double> &xbounds, std::vector<double> &ybounds)
+gen_icosphere_coords(int subdivisions, bool withBounds, std::vector<double> &xvals, std::vector<double> &yvals,
+                     std::vector<double> &xbounds, std::vector<double> &ybounds)
 {
-  const auto mesh = makeIcosphere(subdivisions);
-  const auto &vertices = mesh.first;
-  const auto &triangles = mesh.second;
+  icosahedron::init();
+  auto triangles = icosahedron::triangles;
+  auto vertices = icosahedron::vertices;
 
-  const auto ncells = triangles.size();
-  xvals.resize(ncells);
-  yvals.resize(ncells);
+  size_t numTriangles = std::pow(4, subdivisions) * 20;
+  if (numTriangles > (size_t) std::numeric_limits<Index>::max())
+    fprintf(stderr, "Too many grid cells:%zu (limit=%zu)!\n", numTriangles, (size_t) std::numeric_limits<Index>::max());
+  size_t numVerticies = std::pow(4, subdivisions) * 10 + 2;
+  vertices.reserve(numVerticies);
+  // printf("numTriangles %zu, numVerticies %zu\n", numTriangles, numVerticies);
+
+  for (int i = 0; i < subdivisions; ++i) triangles = subdivide(vertices, triangles);
+
+  auto numCells = triangles.size();
+  xvals.resize(numCells);
+  yvals.resize(numCells);
   if (withBounds)
     {
-      xbounds.resize(3 * ncells);
-      ybounds.resize(3 * ncells);
+      xbounds.resize(3 * numCells);
+      ybounds.resize(3 * numCells);
     }
 
-  size_t i = 0;
-  for (const Triangle &t : triangles)
+#ifdef _OPENMP
+#pragma omp parallel for if (numCells > 999999) default(shared) schedule(static)
+#endif
+  for (size_t i = 0; i < numCells; ++i)
     {
-      const auto center = circumCenterMean(vertices[t[0]], vertices[t[1]], vertices[t[2]]);
+      const auto &t = triangles[i];
+      auto center = circum_center_mean(vertices[t[0]], vertices[t[1]], vertices[t[2]]);
       xvals[i] = center.longitude();
       yvals[i] = center.latitude();
       if (withBounds)
@@ -187,11 +213,9 @@ genIcosphereCoords(int subdivisions, bool withBounds, std::vector<double> &xvals
             xbounds[i * 3 + k] = vertices[t[k]].longitude();
             ybounds[i * 3 + k] = vertices[t[k]].latitude();
           }
-
-      i++;
     }
 
-  return ncells;
+  return numCells;
 }
 
 #ifdef TEST_ICO
@@ -215,17 +239,17 @@ subDivdeAndVertexForEdgeTest(int subdivisions)
   auto end = std::chrono::steady_clock::now();
   auto elapsedM = std::chrono::duration_cast<std::chrono::nanoseconds>(end - start).count();
 
-  const size_t expectedNumTriangles = std::pow(4, subdivisions) * 20;
-  const size_t expectedNumVerticies = std::pow(4, subdivisions) * 10 + 2;
+  size_t expectedNumTriangles = std::pow(4, subdivisions) * 20;
+  size_t expectedNumVerticies = std::pow(4, subdivisions) * 10 + 2;
   if (triangles.size() != expectedNumTriangles)
     {
-      std::cout << "ERROR: unexpected number of triangles for T: std::map, expected " << expectedNumTriangles << " got "
-                << triangles.size() << std::endl;
+      std::cout << "ERROR: unexpected number of triangles, expected " << expectedNumTriangles << " got " << triangles.size()
+                << std::endl;
     }
   if (vertices.size() != expectedNumVerticies)
     {
-      std::cout << "ERROR: unexpected number of verticies for T: std::map, expected " << expectedNumVerticies << " got "
-                << vertices.size() << std::endl;
+      std::cout << "ERROR: unexpected number of verticies, expected " << expectedNumVerticies << " got " << vertices.size()
+                << std::endl;
     }
 }
 
