@@ -15,7 +15,7 @@
 #include "cdo_output.h"
 #include "cdo_math.h"
 #include "cdo_options.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "grid_point_search.h"
 #include "kdtreelib/kdtree.h"
 #include "nanoflann.hpp"
@@ -238,7 +238,7 @@ gps_create_kdtree(size_t n, const Varray<double> &lons, const Varray<double> &la
   kdata_t max[3] = { -1.e9, -1.e9, -1.e9 };
 
 #ifdef HAVE_OPENMP45
-#pragma omp parallel for schedule(static) reduction(min : min[:3]) reduction(max : max[:3])
+#pragma omp parallel for if (n > cdoMinLoopSize) schedule(static) reduction(min : min[:3]) reduction(max : max[:3])
 #endif
   for (size_t i = 0; i < n; ++i)
     {
@@ -277,7 +277,7 @@ gps_create_nanoflann(size_t n, const Varray<double> &lons, const Varray<double>
   // Generating Point Cloud
   pointCloud->pts.resize(n);
 #ifdef HAVE_OPENMP45
-#pragma omp parallel for schedule(static) reduction(min : min[:3]) reduction(max : max[:3])
+#pragma omp parallel for if (n > cdoMinLoopSize) schedule(static) reduction(min : min[:3]) reduction(max : max[:3])
 #endif
   for (size_t i = 0; i < n; ++i)
     {
@@ -322,7 +322,7 @@ gps_create_spherepart(size_t n, const Varray<double> &lons, const Varray<double>
   double max[3] = { -1.e9, -1.e9, -1.e9 };
 
 #ifdef HAVE_OPENMP45
-#pragma omp parallel for schedule(static) reduction(min : min[:3]) reduction(max : max[:3])
+#pragma omp parallel for if (n > cdoMinLoopSize) schedule(static) reduction(min : min[:3]) reduction(max : max[:3])
 #endif
   for (size_t i = 0; i < n; ++i)
     {
