@@ -9,7 +9,6 @@
 #include "cdi_uuid.h"
 
 #include "cdo_output.h"
-#include "readline.h"
 #include "param_conversion.h"
 #include "griddes.h"
 #include "parse_literals.h"
@@ -100,19 +99,19 @@ grid_read_data(size_t ikv, size_t nkv, KVMap *kvmap, GridDesciption &grid, size_
           else
             cdo_warning("Warning: %d not in allowed modes: <0, 64, 96>; Using default: 64\n", scmode);
         }
-      else if (key == "xname")     strcpy(grid.xname, parameter_to_word(value.c_str()));
-      else if (key == "yname")     strcpy(grid.yname, parameter_to_word(value.c_str()));
-      else if (key == "xdimname")  strcpy(grid.xdimname, parameter_to_word(value.c_str()));
-      else if (key == "ydimname")  strcpy(grid.ydimname, parameter_to_word(value.c_str()));
-      else if (key == "vdimname")  strcpy(grid.vdimname, parameter_to_word(value.c_str()));
-      else if (key == "xlongname") strcpy(grid.xlongname, value.c_str());
-      else if (key == "ylongname") strcpy(grid.ylongname, value.c_str());
-      else if (key == "xunits")    strcpy(grid.xunits, value.c_str());
-      else if (key == "yunits")    strcpy(grid.yunits, value.c_str());
-      else if (key == "path")      strcpy(grid.path, value.c_str());
+      else if (key == "xname")     grid.xname = parameter_to_word(value);
+      else if (key == "yname")     grid.yname = parameter_to_word(value);
+      else if (key == "xdimname")  grid.xdimname = parameter_to_word(value);
+      else if (key == "ydimname")  grid.ydimname = parameter_to_word(value);
+      else if (key == "vdimname")  grid.vdimname = parameter_to_word(value);
+      else if (key == "xlongname") grid.xlongname = value;
+      else if (key == "ylongname") grid.ylongname = value;
+      else if (key == "xunits")    grid.xunits = value;
+      else if (key == "yunits")    grid.yunits = value;
+      else if (key == "path")      grid.path = value;
       else if (key == "uuid")
         {
-          strcpy(uuidStr, value.c_str());
+          std::strcpy(uuidStr, value.c_str());
           cdiStr2UUID(uuidStr, grid.uuid);
         }
       else if (key == "xfirst") grid.xfirst = parameter_to_double(value);
@@ -131,9 +130,9 @@ grid_read_data(size_t ikv, size_t nkv, KVMap *kvmap, GridDesciption &grid, size_
 
           grid.xcvals = (char **) malloc(size * sizeof(char *));
           size_t xstrlen = 64;
-          for (size_t i = 0; i < size; ++i) std::max(xstrlen, values[i].size());
+          for (size_t i = 0; i < size; ++i) xstrlen = std::max(xstrlen, values[i].size());
           for (size_t i = 0; i < size; ++i) grid.xcvals[i] = (char *) malloc((xstrlen + 1) * sizeof(char));
-          for (size_t i = 0; i < size; ++i) strcpy(grid.xcvals[i], parameter_to_word(values[i].c_str()));
+          for (size_t i = 0; i < size; ++i) std::strcpy(grid.xcvals[i], parameter_to_word(values[i].c_str()));
         }
       else if (key == "ycvals")
         {
@@ -144,9 +143,9 @@ grid_read_data(size_t ikv, size_t nkv, KVMap *kvmap, GridDesciption &grid, size_
 
           grid.ycvals = (char **) malloc(size * sizeof(char *));
           size_t ystrlen = 64;
-          for (size_t i = 0; i < size; ++i) std::max(ystrlen, values[i].size());
+          for (size_t i = 0; i < size; ++i) ystrlen = std::max(ystrlen, values[i].size());
           for (size_t i = 0; i < size; ++i) grid.ycvals[i] = (char *) malloc((ystrlen + 1) * sizeof(char));
-          for (size_t i = 0; i < size; ++i) strcpy(grid.ycvals[i], parameter_to_word(values[i].c_str()));
+          for (size_t i = 0; i < size; ++i) std::strcpy(grid.ycvals[i], parameter_to_word(values[i].c_str()));
         }
       else if (key == "xvals")
         {
@@ -323,13 +322,9 @@ grid_read(FILE *gfp, const char *dname)
   const std::string firstKey = "gridtype";
   for (auto &kv : kvlist)
     {
-      if (ik == 0 && kv.key != firstKey)
-        cdo_abort("First grid description keyword must be >%s< (found: %s)!", firstKey, kv.key);
+      if (ik == 0 && kv.key != firstKey) cdo_abort("First grid description keyword must be >%s< (found: %s)!", firstKey, kv.key);
 
-      if (kv.nvalues == 0)
-        {
-          cdo_warning("Grid description keyword %s has no values, skipped!", kv.key);
-        }
+      if (kv.nvalues == 0) { cdo_warning("Grid description keyword %s has no values, skipped!", kv.key); }
       else
         {
           kvmap[ik].isValid = true;
