@@ -315,19 +315,20 @@ gridFromMPAS(const char *filename)
   if (streamID >= 0)
     {
       auto vlistID = streamInqVlist(streamID);
-      auto nvars = vlistNvars(vlistID);
+      VarList varList(vlistID);
+
       int latCellID = -1, lonCellID = -1, areaCellID = -1;
       int latVertexID = -1, lonVertexID = -1, verticesOnCellID = -1;
-      for (int varID = 0; varID < nvars; ++varID)
+      for (int varID = 0; varID < varList.numVars(); ++varID)
         {
-          auto varname = cdo::inq_var_name(vlistID, varID);
+          const auto &var = varList.vars[varID];
           // clang-format off
-          if      (varname == "latCell")   latCellID = varID;
-          else if (varname == "lonCell")   lonCellID = varID;
-          else if (varname == "latVertex") latVertexID = varID;
-          else if (varname == "lonVertex") lonVertexID = varID;
-          else if (varname == "areaCell")  areaCellID = varID;
-          else if (varname == "verticesOnCell") verticesOnCellID = varID;
+          if      (var.name == "latCell")   latCellID = varID;
+          else if (var.name == "lonCell")   lonCellID = varID;
+          else if (var.name == "latVertex") latVertexID = varID;
+          else if (var.name == "lonVertex") lonVertexID = varID;
+          else if (var.name == "areaCell")  areaCellID = varID;
+          else if (var.name == "verticesOnCell") verticesOnCellID = varID;
           // clang-format on
         }
 
@@ -339,10 +340,10 @@ gridFromMPAS(const char *filename)
           return -1;
         }
 
-      auto maxEdges = gridInqXsize(vlistInqVarGrid(vlistID, verticesOnCellID));
-      auto ncells = gridInqSize(vlistInqVarGrid(vlistID, latCellID));
+      auto maxEdges = gridInqXsize(varList.vars[verticesOnCellID].gridID);
+      auto ncells = varList.vars[latCellID].gridsize;
       std::vector<double> latCell(ncells), lonCell(ncells), areaCell(ncells);
-      auto nvertices = gridInqSize(vlistInqVarGrid(vlistID, latVertexID));
+      auto nvertices = varList.vars[latVertexID].gridsize;
       std::vector<double> latVertex(nvertices), lonVertex(nvertices);
       std::vector<double> verticesOnCell(maxEdges * ncells);
       std::vector<double> xbounds(maxEdges * ncells), ybounds(maxEdges * ncells);
@@ -512,7 +513,7 @@ cdo_define_grid(const char *pgridfile)
           if (streamID >= 0)
             {
               auto vlistID = streamInqVlist(streamID);
-              auto ngrids = vlistNgrids(vlistID);
+              auto ngrids = vlistNumGrids(vlistID);
               if (gridno < 1 || gridno > ngrids) cdo_abort("Grid number %d not available in %s!", gridno, filename);
               gridID = vlistGrid(vlistID, gridno - 1);
               streamClose(streamID);
