@@ -15,7 +15,7 @@
 #include "cdo_options.h"
 #include "interpol.h"
 #include "progress.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "matrix_view.h"
 
 /**
@@ -81,7 +81,7 @@ find_element(double x, long nelem, const Varray<double> &v)
         }
     }
 
-  if (mid > 1 && IS_EQUAL(x, v[mid - 1])) mid--;
+  if (mid > 1 && is_equal(x, v[mid - 1])) mid--;
 
   return mid;
 }
@@ -201,11 +201,12 @@ intlinarr2p(long nxm, long nym, double **fieldm, const Varray<double> &xm, const
   return value;
 }
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-intlinarr2(T missval, int lonIsCircular, size_t nxm, size_t nym, const Varray<T> &varray1, const Varray<double> &xm,
-           const Varray<double> &ym, size_t gridsize2, Varray<T> &varray2, const Varray<double> &x, const Varray<double> &y)
+intlinarr2(double mv, int lonIsCircular, size_t nxm, size_t nym, const Varray<T1> &varray1, const Varray<double> &xm,
+           const Varray<double> &ym, size_t gridsize2, Varray<T2> &varray2, const Varray<double> &x, const Varray<double> &y)
 {
+  T1 missval = mv;
   auto nlon1 = nxm;
   std::atomic<size_t> atomicCount{ 0 };
 
@@ -214,9 +215,9 @@ intlinarr2(T missval, int lonIsCircular, size_t nxm, size_t nym, const Varray<T>
 
   std::vector<char> grid1_mask(gridsize1);
   for (size_t jj = 0; jj < nym; ++jj)
-    for (size_t ii = 0; ii < nlon1; ++ii) grid1_mask[jj * nlon1 + ii] = !DBL_IS_EQUAL(varray1[jj * nlon1 + ii], missval);
+    for (size_t ii = 0; ii < nlon1; ++ii) grid1_mask[jj * nlon1 + ii] = !fp_is_equal(varray1[jj * nlon1 + ii], missval);
 
-  progress::init();
+  cdo::Progress progress;
 
 #ifdef _OPENMP
 #pragma omp parallel for default(shared)
@@ -228,7 +229,7 @@ intlinarr2(T missval, int lonIsCircular, size_t nxm, size_t nym, const Varray<T>
       varray2[i] = missval;
 
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double) atomicCount / gridsize2);
+      if (cdo_omp_get_thread_num() == 0) progress.update((double) atomicCount / gridsize2);
 
       size_t ii, jj;
       auto lfound = rect_grid_search(ii, jj, x[i], y[i], nxm, nym, xm, ym);
@@ -263,8 +264,6 @@ intlinarr2(T missval, int lonIsCircular, size_t nxm, size_t nym, const Varray<T>
           varray2[i] = fwsum;
         }
     }
-
-  progress::update(0, 1, 1);
 }
 
 void
@@ -371,12 +370,10 @@ intgridbil(const Field &field1, Field &field2)
 
   if (field2.grid != gridID2) gridDestroy(gridID2);
 
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    intlinarr2((float) missval, lonIsCircular, nlon1, nlat1, field1.vec_f, lons1, lats1, gridsize2, field2.vec_f, xvals2, yvals2);
-  else
-    intlinarr2(missval, lonIsCircular, nlon1, nlat1, field1.vec_d, lons1, lats1, gridsize2, field2.vec_d, xvals2, yvals2);
+  auto func = [&](auto &v1, auto &v2) {
+    intlinarr2(missval, lonIsCircular, nlon1, nlat1, v1, lons1, lats1, gridsize2, v2, xvals2, yvals2);
+  };
+  field_operation2(func, field1, field2);
 
   field_num_mv(field2);
 }
@@ -482,7 +479,7 @@ interpolate(const Field &field1, Field &field2)
     }
 
   for (i = 0; i < out_nlat - 1; ++i)
-    if (IS_EQUAL(lato[i + 1], lato[i]) || (i < out_nlat - 2 && ((lato[i + 1] > lato[i]) != (lato[i + 2] > lato[i + 1]))))
+    if (is_equal(lato[i + 1], lato[i]) || (i < out_nlat - 2 && ((lato[i + 1] > lato[i]) != (lato[i + 2] > lato[i + 1]))))
       {
         cdo_abort("Latitudes of output grid must be in descending or ascending order!");
       }
@@ -545,7 +542,7 @@ interpolate(const Field &field1, Field &field2)
     {
       volon1 = (lono[olon - 1] + lono[olon]) / 2;
       volon2 = (lono[olon] + lono[olon + 1]) / 2;
-      if (IS_EQUAL(volon1, volon2)) volon2 += 360;
+      if (is_equal(volon1, volon2)) volon2 += 360;
       volon2 -= 360 * std::floor((volon1 - xlon[0]) / 360);
       volon1 -= 360 * std::floor((volon1 - xlon[0]) / 360);
       volon21[olon] = volon1;
@@ -626,12 +623,12 @@ interpolate(const Field &field1, Field &field2)
       {
         double sum = 0.0;
         n = 0;
-        if (ilat > 0 && !DBL_IS_EQUAL(xin[ilat - 1][ilon], missval))
+        if (ilat > 0 && !fp_is_equal(xin[ilat - 1][ilon], missval))
           {
             sum += xin[ilat - 1][ilon];
             n++;
           }
-        if (ilat < nxlat - 1 && !DBL_IS_EQUAL(xin[ilat + 1][ilon], missval))
+        if (ilat < nxlat - 1 && !fp_is_equal(xin[ilat + 1][ilon], missval))
           {
             sum += xin[ilat + 1][ilon];
             n++;
@@ -644,22 +641,22 @@ interpolate(const Field &field1, Field &field2)
       {
         double sum = 0.0;
         n = 0;
-        if (ilon > 0 && !DBL_IS_EQUAL(xin[ilat][ilon - 1], missval))
+        if (ilon > 0 && !fp_is_equal(xin[ilat][ilon - 1], missval))
           {
             sum += xin[ilat][ilon - 1];
             n++;
           }
-        if (ilon == 0 && wrap_around && !DBL_IS_EQUAL(xin[ilat][2 * nlon - 1], missval))
+        if (ilon == 0 && wrap_around && !fp_is_equal(xin[ilat][2 * nlon - 1], missval))
           {
             sum += xin[ilat][2 * nlon - 1];
             n++;
           }
-        if (ilon < nxlon - 1 && !DBL_IS_EQUAL(xin[ilat][ilon + 1], missval))
+        if (ilon < nxlon - 1 && !fp_is_equal(xin[ilat][ilon + 1], missval))
           {
             sum += xin[ilat][ilon + 1];
             n++;
           }
-        if (ilon == nxlon - 1 && wrap_around && !DBL_IS_EQUAL(xin[ilat][1], missval))
+        if (ilon == nxlon - 1 && wrap_around && !fp_is_equal(xin[ilat][1], missval))
           {
             sum += xin[ilat][1];
             n++;
@@ -672,32 +669,32 @@ interpolate(const Field &field1, Field &field2)
       {
         double sum = 0.0;
         n = 0;
-        if (ilon > 0 && !DBL_IS_EQUAL(xin[ilat][ilon - 1], missval))
+        if (ilon > 0 && !fp_is_equal(xin[ilat][ilon - 1], missval))
           {
             sum += xin[ilat][ilon - 1];
             n++;
           }
-        if (ilon == 0 && wrap_around && !DBL_IS_EQUAL(xin[ilat][2 * nlon - 1], missval))
+        if (ilon == 0 && wrap_around && !fp_is_equal(xin[ilat][2 * nlon - 1], missval))
           {
             sum += xin[ilat][2 * nlon - 1];
             n++;
           }
-        if (ilon < nxlon - 1 && !DBL_IS_EQUAL(xin[ilat][ilon + 1], missval))
+        if (ilon < nxlon - 1 && !fp_is_equal(xin[ilat][ilon + 1], missval))
           {
             sum += xin[ilat][ilon + 1];
             n++;
           }
-        if (ilon == nxlon - 1 && wrap_around && !DBL_IS_EQUAL(xin[ilat][1], missval))
+        if (ilon == nxlon - 1 && wrap_around && !fp_is_equal(xin[ilat][1], missval))
           {
             sum += xin[ilat][1];
             n++;
           }
-        if (ilat > 0 && !DBL_IS_EQUAL(xin[ilat - 1][ilon], missval))
+        if (ilat > 0 && !fp_is_equal(xin[ilat - 1][ilon], missval))
           {
             sum += xin[ilat - 1][ilon];
             n++;
           }
-        if (ilat < nxlat - 1 && !DBL_IS_EQUAL(xin[ilat + 1][ilon], missval))
+        if (ilat < nxlat - 1 && !fp_is_equal(xin[ilat + 1][ilon], missval))
           {
             sum += xin[ilat + 1][ilon];
             n++;
@@ -765,8 +762,8 @@ interpolate(const Field &field1, Field &field2)
                           a21 = xin[ilat - 1][ilon - 1];
                           a22 = xin[ilat - 1][ilon];
                         }
-                      if (DBL_IS_EQUAL(a11, missval) || DBL_IS_EQUAL(a12, missval) || DBL_IS_EQUAL(a21, missval)
-                          || DBL_IS_EQUAL(a22, missval))
+                      if (fp_is_equal(a11, missval) || fp_is_equal(a12, missval) || fp_is_equal(a21, missval)
+                          || fp_is_equal(a22, missval))
                         {
                           continue;
                         }
