@@ -5,13 +5,11 @@
 
 */
 
-#include <cstdlib>
 #include <string>
 
 #include "cdo_options.h"
 #include "cdo_output.h"
 #include "pmlist.h"
-#include "convert_units.h"
 #include "param_conversion.h"
 #include "parse_literals.h"
 #include "cdo_cmor.h"
@@ -104,11 +102,11 @@ mapvar(int vlistID, int varID, const KeyValues &kv, const std::string &key, Cmor
         {
           auto missval = parameter_to_double(value);
           auto missval_old = vlistInqVarMissval(vlistID, varID);
-          if (!DBL_IS_EQUAL(missval, missval_old))
+          if (!fp_is_equal(missval, missval_old))
             {
               if (Options::cdoVerbose) cdo_print("%s - change missval from %g to %g", var->name, missval_old, missval);
               var->changemissval = true;
-              var->missval_old = missval_old;
+              var->missvalOld = missval_old;
               vlistDefVarMissval(vlistID, varID, missval);
             }
         }
