@@ -8,18 +8,13 @@
 #include <cdi.h>
 
 #include "process_int.h"
-#include "param_conversion.h"
-#include "util_files.h"
-#include "cdo_options.h"
 #include "varray.h"
 
-#include <cassert>
 #include <unistd.h>
 #include <mpim_grid.h>
 
 #include "pmlist.h"
 #include "merge_axis.h"
-#include "listbuffer.h"
 
 /** All Vars in the input file will be merged.
 *** Therefore, they need to have the same structure i.e. axis sizes
