@@ -38,4 +38,7 @@ std::vector<double> cdo_argv_to_flt(const std::vector<std::string> &argv);
 
 void split_intstring(const std::string &intstr, int &first, int &last, int &inc);
 
+template <typename T>
+T convert(const std::string &str_value);
+
 #endif
