@@ -83,39 +83,39 @@ PipeStream::defRecord(int varID, int levelID)
 }
 
 void
-PipeStream::read_record(float *p_data, size_t *p_nmiss)
+PipeStream::read_record(float *p_data, size_t *p_numMissVals)
 {
-  m_nvals += m_pipe->pipe_read_record(m_vlistID, p_data, p_nmiss);
+  m_nvals += m_pipe->pipe_read_record(m_vlistID, p_data, p_numMissVals);
 }
 
 void
-PipeStream::read_record(double *p_data, size_t *p_nmiss)
+PipeStream::read_record(double *p_data, size_t *p_numMissVals)
 {
-  m_nvals += m_pipe->pipe_read_record(m_vlistID, p_data, p_nmiss);
+  m_nvals += m_pipe->pipe_read_record(m_vlistID, p_data, p_numMissVals);
 }
 
 void
-PipeStream::read_record(Field *p_field, size_t *p_nmiss)
+PipeStream::read_record(Field *p_field, size_t *p_numMissVals)
 {
-  m_nvals += m_pipe->pipe_read_record(m_vlistID, p_field, p_nmiss);
+  m_nvals += m_pipe->pipe_read_record(m_vlistID, p_field, p_numMissVals);
 }
 
 void
-PipeStream::write_record(float *p_data, size_t p_nmiss)
+PipeStream::write_record(const float *p_data, size_t p_numMissVals)
 {
-  m_pipe->pipe_write_record(p_data, p_nmiss);
+  m_pipe->pipe_write_record(p_data, p_numMissVals);
 }
 
 void
-PipeStream::write_record(double *p_data, size_t p_nmiss)
+PipeStream::write_record(const double *p_data, size_t p_numMissVals)
 {
-  m_pipe->pipe_write_record(p_data, p_nmiss);
+  m_pipe->pipe_write_record(p_data, p_numMissVals);
 }
 
 void
-PipeStream::write_record(Field *p_field, size_t p_nmiss)
+PipeStream::write_record(const Field *p_field, size_t p_numMissVals)
 {
-  m_pipe->pipe_write_record(p_field, p_nmiss);
+  m_pipe->pipe_write_record(p_field, p_numMissVals);
 }
 
 void
