@@ -109,7 +109,7 @@ KVList::append(const char *key, const char *const *values, int nvalues)
 }
 
 void
-KVList::append(std::string &key, std::vector<std::string> values)
+KVList::append(std::string &key, const std::vector<std::string> &values)
 {
   KeyValues kv;
   kv.key = key;
