@@ -37,7 +37,7 @@ public:
   const KeyValues *search(const std::string &key) const;
   void remove(const std::string &inkey);
   void append(const char *, const char *const *, int);
-  void append(std::string &key, std::vector<std::string> values);
+  void append(std::string &key, const std::vector<std::string> &values);
   void append(std::string &key, std::string &value);
   char *get_first_value(const char *key, const char *replacer);
 };
