@@ -464,7 +464,7 @@ printGridInfoKernel(int gridID, int index, int lproj)
 void
 print_grid_info(int vlistID)
 {
-  auto ngrids = vlistNgrids(vlistID);
+  auto ngrids = vlistNumGrids(vlistID);
   for (int index = 0; index < ngrids; ++index)
     {
       auto gridID = vlistGrid(vlistID, index);
@@ -599,7 +599,7 @@ print_zaxis_info(int vlistID)
   auto dig = Options::CDO_flt_digits;
   char zaxisname[CDI_MAX_NAME];
 
-  auto nzaxis = vlistNzaxis(vlistID);
+  auto nzaxis = vlistNumZaxis(vlistID);
   for (int index = 0; index < nzaxis; ++index)
     {
       auto zaxisID = vlistZaxis(vlistID, index);
