@@ -58,7 +58,7 @@ Process::replace_alias(const std::string &p_calledBy, const CdoModule &p_module)
 
 Process::Process(int p_ID, const std::string &p_operatorName, const std::vector<std::string> &p_arguments,
                  const CdoModule &p_module)
-    : m_ID(p_ID), m_module(p_module), m_oargv(p_arguments)
+    : arguments(p_module.arguments), m_ID(p_ID), m_module(p_module), m_oargv(p_arguments)
 {
 #ifdef HAVE_LIBPTHREAD
   threadID = pthread_self();
@@ -306,6 +306,7 @@ Process::get_id()
 {
   return m_ID;
 }
+
 void
 Process::cdo_initialize()
 {
@@ -322,6 +323,7 @@ Process::cdo_initialize()
   Debug(PROCESS_INT, "process %d thread %ld", m_ID, pthread_self());
 #endif
 }
+
 void
 Process::cdo_finish(void)
 {
