@@ -528,6 +528,6 @@ cdo_set_nan(double missval, size_t gridsize, double *array)
     {
       constexpr double newmissval = -9.e33;
       for (size_t i = 0; i < gridsize; ++i)
-        if (DBL_IS_EQUAL(array[i], missval)) array[i] = newmissval;
+        if (fp_is_equal(array[i], missval)) array[i] = newmissval;
     }
 }
