@@ -7,6 +7,7 @@
 
 #include <atomic>
 
+#include "cpp_lib.h"
 #include "process_int.h"
 #include "cdo_timer.h"
 #include <mpim_grid.h>
@@ -14,7 +15,7 @@
 #include "remap.h"
 #include "remap_store_link.h"
 #include "progress.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 
 // bicubic interpolation
 
@@ -59,14 +60,26 @@ renormalize_weights(const double (&srcLats)[4], double (&weights)[4][4])
   for (int i = 0; i < 4; ++i) weights[i][2] = 0.0;
   for (int i = 0; i < 4; ++i) weights[i][3] = 0.0;
 }
-
+/*
+#ifdef HAVE_LIB_RANGES_ZIP
+#include <ranges>
 static void
-bicubic_sort_weights(size_t (&indices)[4], double (&weights)[4][4])
+bicubic_sort_weights_by_index_zip(size_t (&indices)[4], double (&weights)[4][4])
+{
+  auto r = std::views::zip(indices, weights);
+  std::sort(r.begin(), r.end, [](auto a, auto b) {
+    auto [ai, aw] = a;  // std::tuple
+    auto [bi, bw] = b;
+    return (ai < bi);
+  });
+}
+#endif
+*/
+static void
+bicubic_sort_weights_by_index(size_t (&indices)[4], double (&weights)[4][4])
 {
   constexpr size_t numWeights = 4;
 
-  if (is_sorted_list(numWeights, indices)) return;
-
   struct IndexWeightX
   {
     size_t index;
@@ -90,6 +103,19 @@ bicubic_sort_weights(size_t (&indices)[4], double (&weights)[4][4])
     }
 }
 
+static void
+bicubic_sort_weights(size_t (&indices)[4], double (&weights)[4][4])
+{
+  constexpr size_t numWeights = 4;
+  if (is_sorted_list(numWeights, indices)) return;
+
+  // #ifdef HAVE_LIB_RANGES_ZIP
+  //   bicubic_sort_weights_by_index_zip(indices, weights);
+  // #else
+  bicubic_sort_weights_by_index(indices, weights);
+  // #endif
+}
+
 static void
 bicubic_warning()
 {
@@ -120,8 +146,7 @@ remap_bicubic_weights(RemapSearch &rsearch, RemapVars &rv)
   if (srcGrid->rank != 2) cdo_abort("Can't do bicubic interpolation if the source grid is not a regular 2D grid!");
 
   cdo::timer timer;
-
-  progress::init();
+  cdo::Progress progress;
 
   // Compute mappings from source to target grid
 
@@ -140,7 +165,7 @@ remap_bicubic_weights(RemapSearch &rsearch, RemapVars &rv)
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
+      if (cdo_omp_get_thread_num() == 0) progress.update((double) atomicCount / tgtGridSize);
 
       weightLinks[tgtCellIndex].nlinks = 0;
 
@@ -191,11 +216,9 @@ remap_bicubic_weights(RemapSearch &rsearch, RemapVars &rv)
         }
     }
 
-  progress::update(0, 1, 1);
-
   weight_links_4_to_remap_links(tgtGridSize, weightLinks, rv);
 
-  rv.linksPerValue = 4;
+  rv.numLinksPerValue = 4;
 
   if (Options::cdoVerbose) cdo_print("%s: %.2f seconds", __func__, timer.elapsed());
 }  // remap_bicubic_weights
@@ -224,10 +247,11 @@ bicubic_remap(const Varray<T> &srcArray, const double (&weights)[4][4], const si
   return tgtPoint;
 }
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-remap_bicubic(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtArray, T missval, size_t numMissVals)
+remap_bicubic(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissval, size_t numMissVals, RemapSearch &rsearch)
 {
+  T1 missval = srcMissval;
   auto srcGrid = rsearch.srcGrid;
   auto tgtGrid = rsearch.tgtGrid;
 
@@ -236,19 +260,18 @@ remap_bicubic(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtArr
   if (srcGrid->rank != 2) cdo_abort("Can't do bicubic interpolation if the source grid is not a regular 2D grid!");
 
   cdo::timer timer;
-
-  progress::init();
+  cdo::Progress progress;
 
   auto tgtGridSize = tgtGrid->size;
   auto srcGridSize = srcGrid->size;
 
-  Varray<short> srcGridMask;
-  if (numMissVals) remap_set_mask(srcGridSize, srcArray, numMissVals, missval, srcGridMask);
+  Varray<short> srcGridMask(srcGridSize, 1);
+  if (numMissVals) remap_set_mask(srcArray, srcGridSize, numMissVals, srcMissval, srcGridMask);
 
   // Compute mappings from source to target grid
 
   RemapGradients gradients(srcGrid->size);
-  remap_gradients(*srcGrid, srcGridMask, srcArray, gradients);
+  remap_gradients(srcArray, *srcGrid, srcGridMask, gradients);
 
   std::atomic<size_t> atomicCount{ 0 };
 
@@ -260,7 +283,7 @@ remap_bicubic(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtArr
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
+      if (cdo_omp_get_thread_num() == 0) progress.update((double) atomicCount / tgtGridSize);
 
       tgtArray[tgtCellIndex] = missval;
 
@@ -310,18 +333,13 @@ remap_bicubic(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtArr
         }
     }
 
-  progress::update(0, 1, 1);
-
   if (Options::cdoVerbose) cdo_print("%s: %.2f seconds", __func__, timer.elapsed());
 }  // remap_bicubic
 
 void
-remap_bicubic(RemapSearch &rsearch, const Field &field1, Field &field2)
+remap_bicubic(RemapSearch &remapSearch, const Field &field1, Field &field2)
 {
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    remap_bicubic(rsearch, field1.vec_f, field2.vec_f, (float) field1.missval, field1.numMissVals);
-  else
-    remap_bicubic(rsearch, field1.vec_d, field2.vec_d, field1.missval, field1.numMissVals);
+  auto func
+      = [&](auto &v1, auto &v2, double missval, size_t numMissVals) { remap_bicubic(v1, v2, missval, numMissVals, remapSearch); };
+  field_operation2(func, field1, field2, field1.missval, field1.numMissVals);
 }
