@@ -7,13 +7,14 @@
 
 #include <atomic>
 
+#include "cpp_lib.h"
 #include "process_int.h"
 #include "cdo_timer.h"
 #include "remap.h"
 #include "remap_store_link.h"
 #include "cdo_options.h"
 #include "progress.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "grid_healpix.h"
 
 // bilinear interpolation
@@ -120,13 +121,25 @@ renormalize_weights(const double (&srcLats)[4], double (&weights)[4])
   for (int i = 0; i < 4; ++i) weights[i] = std::fabs(srcLats[i]) / sumWeights;
 }
 
+#ifdef HAVE_LIB_RANGES_ZIP
+#include <ranges>
 static void
-bilinear_sort_weights(size_t (&indices)[4], double (&weights)[4])
+bilinear_sort_weights_by_index_zip(size_t (&indices)[4], double (&weights)[4])
+{
+  auto r = std::views::zip(indices, weights);
+  std::sort(r.begin(), r.end(), [](auto a, auto b) {
+    auto [ai, aw] = a;  // std::tuple
+    auto [bi, bw] = b;
+    return (ai < bi);
+  });
+}
+#endif
+
+static void
+bilinear_sort_weights_by_index(size_t (&indices)[4], double (&weights)[4])
 {
   constexpr size_t numWeights = 4;
 
-  if (is_sorted_list(numWeights, indices)) return;
-
   struct IndexWeightX
   {
     size_t index;
@@ -150,6 +163,19 @@ bilinear_sort_weights(size_t (&indices)[4], double (&weights)[4])
     }
 }
 
+static void
+bilinear_sort_weights(size_t (&indices)[4], double (&weights)[4])
+{
+  constexpr size_t numWeights = 4;
+  if (is_sorted_list(numWeights, indices)) return;
+
+#ifdef HAVE_LIB_RANGES_ZIP
+  bilinear_sort_weights_by_index_zip(indices, weights);
+#else
+  bilinear_sort_weights_by_index(indices, weights);
+#endif
+}
+
 static void
 bilinear_warning()
 {
@@ -248,8 +274,7 @@ remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
     cdo_abort("Can't do bilinear interpolation if the source grid is not a regular 2D grid!");
 
   cdo::timer timer;
-
-  progress::init();
+  cdo::Progress progress;
 
   // Compute mappings from source to target grid
 
@@ -268,7 +293,7 @@ remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
+      if (cdo_omp_get_thread_num() == 0) progress.update((double) atomicCount / tgtGridSize);
 
       weightLinks[tgtCellIndex].nlinks = 0;
 
@@ -283,11 +308,9 @@ remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
         remap_bilinear_weights_regular(rsearch, srcGrid->mask, llpoint, tgtCellFrac, tgtCellIndex, weightLinks);
     }
 
-  progress::update(0, 1, 1);
-
   weight_links_to_remap_links(0, tgtGridSize, weightLinks, rv);
 
-  rv.linksPerValue = 4;
+  rv.numLinksPerValue = 4;
 
   if (Options::cdoVerbose) cdo_print("%s: %.2f seconds", __func__, timer.elapsed());
 }  // remap_bilinear_weights
@@ -302,10 +325,10 @@ bilinear_remap(const Varray<T> &srcArray, const double (&weights)[4], const size
          + srcArray[indices[3]] * weights[3];
 }
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-remap_bilinear_regular(RemapSearch &rsearch, const Varray<T> &srcArray, const Varray<short> &srcGridMask,
-                       const LonLatPoint &llpoint, T &tgtValue)
+remap_bilinear_regular(RemapSearch &rsearch, const Varray<T1> &srcArray, const Varray<short> &srcGridMask,
+                       const LonLatPoint &llpoint, T2 &tgtValue)
 {
   double srcLats[4];  //  latitudes  of four bilinear corners
   double srcLons[4];  //  longitudes of four bilinear corners
@@ -351,10 +374,10 @@ remap_bilinear_regular(RemapSearch &rsearch, const Varray<T> &srcArray, const Va
     }
 }
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T> &srcArray, const Varray<short> &srcGridMask,
-                       const LonLatPoint &llpoint, T &tgtValue)
+remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T1> &srcArray, const Varray<short> &srcGridMask,
+                       const LonLatPoint &llpoint, T2 &tgtValue)
 {
   auto nside = rsearch.srcGrid->nside;
   auto order = rsearch.srcGrid->order;
@@ -375,10 +398,11 @@ remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T> &srcArray, co
 }
 
 // This routine computes and apply the weights for a bilinear interpolation.
-template <typename T>
+template <typename T1, typename T2>
 static void
-remap_bilinear(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtArray, T missval, size_t numMissVals)
+remap_bilinear(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissval, size_t numMissVals, RemapSearch &rsearch)
 {
+  T1 missval = srcMissval;
   const auto srcGrid = rsearch.srcGrid;
   auto tgtGrid = rsearch.tgtGrid;
 
@@ -390,14 +414,13 @@ remap_bilinear(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtAr
     cdo_abort("Can't do bilinear interpolation if the source grid is not a regular 2D grid!");
 
   cdo::timer timer;
-
-  progress::init();
+  cdo::Progress progress;
 
   auto tgtGridSize = tgtGrid->size;
   auto srcGridSize = srcGrid->size;
 
   Varray<short> srcGridMask;
-  if (numMissVals) remap_set_mask(srcGridSize, srcArray, numMissVals, missval, srcGridMask);
+  if (numMissVals) remap_set_mask(srcArray, srcGridSize, numMissVals, srcMissval, srcGridMask);
 
   // Compute mappings from source to target grid
 
@@ -411,7 +434,7 @@ remap_bilinear(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtAr
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
+      if (cdo_omp_get_thread_num() == 0) progress.update((double) atomicCount / tgtGridSize);
 
       auto &tgtValue = tgtArray[tgtCellIndex];
       tgtValue = missval;
@@ -426,18 +449,13 @@ remap_bilinear(RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtAr
         remap_bilinear_regular(rsearch, srcArray, srcGridMask, llpoint, tgtValue);
     }
 
-  progress::update(0, 1, 1);
-
   if (Options::cdoVerbose) cdo_print("%s: %.2f seconds", __func__, timer.elapsed());
 }  // remap_bilinear
 
 void
-remap_bilinear(RemapSearch &rsearch, const Field &field1, Field &field2)
+remap_bilinear(RemapSearch &remapSearch, const Field &field1, Field &field2)
 {
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    remap_bilinear(rsearch, field1.vec_f, field2.vec_f, (float) field1.missval, field1.numMissVals);
-  else
-    remap_bilinear(rsearch, field1.vec_d, field2.vec_d, field1.missval, field1.numMissVals);
+  auto func
+      = [&](auto &v1, auto &v2, double missval, size_t numMissVals) { remap_bilinear(v1, v2, missval, numMissVals, remapSearch); };
+  field_operation2(func, field1, field2, field1.missval, field1.numMissVals);
 }
