@@ -10,8 +10,7 @@
 #include "remap.h"
 #include "remap_store_link_cnsrv.h"
 #include "cdo_options.h"
-#include "progress.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 
 #define ZERO 0.0
 #define ONE 1.0
@@ -186,7 +185,7 @@ pole_intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool
 
               /* If endpoint coincident with vertex, offset the endpoint */
 
-              if (IS_EQUAL(vec2_x, 0) && IS_EQUAL(vec2_y, 0))
+              if (is_equal(vec2_x, 0) && is_equal(vec2_y, 0))
                 {
                   x1 += 1.e-10 * (x2 - x1);
                   y1 += 1.e-10 * (y2 - y1);
@@ -207,9 +206,9 @@ pole_intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool
                   dot product and only choose the cell if the dot
                   product is positive (parallel vs anti-parallel).
               */
-              if (IS_EQUAL(cross_product, 0))
+              if (is_equal(cross_product, 0))
                 {
-                  if (IS_NOT_EQUAL(vec1_x, 0) || IS_NOT_EQUAL(vec1_y, 0))
+                  if (is_not_equal(vec1_x, 0) || is_not_equal(vec1_y, 0))
                     {
                       vec2_x = x2 - x1;
                       vec2_y = y2 - y1;
@@ -218,7 +217,7 @@ pole_intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool
                   else
                     cross_product = ONE;
 
-                  if (IS_EQUAL(cross_product, 0))
+                  if (is_equal(cross_product, 0))
                     {
                       *lcoinc = true;
                       cross_product = vec1_x * vec2_x + vec1_y * vec2_y;
@@ -355,7 +354,7 @@ after_srch_loop:
                 are actually coincident.  If this is the
                 case, skip the rest.
               */
-              if (IS_NOT_EQUAL(determ, 0))
+              if (is_not_equal(determ, 0))
                 {
                   s1 = (rhs1 * mat4 - mat2 * rhs2) / determ;
                   s2 = (mat1 * rhs2 - rhs1 * mat3) / determ;
@@ -423,7 +422,7 @@ after_srch_loop:
      (it is ok for endpoint to be pole point)
   */
 
-  if (std::fabs(*intrsct_x) < 1.e-10 && std::fabs(*intrsct_y) < 1.e-10 && (IS_NOT_EQUAL(endx, 0) && IS_NOT_EQUAL(endy, 0)))
+  if (std::fabs(*intrsct_x) < 1.e-10 && std::fabs(*intrsct_y) < 1.e-10 && (is_not_equal(endx, 0) && is_not_equal(endy, 0)))
     {
       if (*avoid_pole_count > 2)
         {
@@ -491,7 +490,7 @@ after_srch_loop:
 
   /* If reached end of segment, do not use x,y intersect on next entry */
 
-  if (IS_EQUAL(*intrsct_lat, endlat) && IS_EQUAL(*intrsct_lon, endlon)) *luse_last = false;
+  if (is_equal(*intrsct_lat, endlat) && is_equal(*intrsct_lon, endlon)) *luse_last = false;
 
 } /* pole_intersection */
 
@@ -628,7 +627,7 @@ intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool *lco
 
               /* If endpoint coincident with vertex, offset the endpoint */
 
-              if (IS_EQUAL(vec2_lat, 0) && IS_EQUAL(vec2_lon, 0))
+              if (is_equal(vec2_lat, 0) && is_equal(vec2_lon, 0))
                 {
                   lat1 += 1.e-10 * (lat2 - lat1);
                   lon1 += 1.e-10 * (lon2 - lon1);
@@ -662,9 +661,9 @@ intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool *lco
                  dot product and only choose the cell if the dot
                  product is positive (parallel vs anti-parallel).
               */
-              if (IS_EQUAL(cross_product, 0))
+              if (is_equal(cross_product, 0))
                 {
-                  if (IS_NOT_EQUAL(vec1_lat, 0) || IS_NOT_EQUAL(vec1_lon, 0))
+                  if (is_not_equal(vec1_lat, 0) || is_not_equal(vec1_lon, 0))
                     {
                       vec2_lat = lat2 - lat1;
                       vec2_lon = lon2 - lon1;
@@ -679,7 +678,7 @@ intersection(long *location, double *intrsct_lat, double *intrsct_lon, bool *lco
                   else
                     cross_product = ONE;
 
-                  if (IS_EQUAL(cross_product, 0))
+                  if (is_equal(cross_product, 0))
                     {
                       *lcoinc = true;
                       cross_product = vec1_lon * vec2_lon + vec1_lat * vec2_lat;
@@ -837,7 +836,7 @@ after_srch_loop:
                 are actually coincident.  If this is the
                 case, skip the rest.
               */
-              if (IS_NOT_EQUAL(determ, 0))
+              if (is_not_equal(determ, 0))
                 {
                   s1 = (rhs1 * mat4 - mat2 * rhs2) / determ;
                   s2 = (mat1 * rhs2 - rhs1 * mat3) / determ;
@@ -1130,28 +1129,28 @@ normalize_weights(RemapGrid *tgtGrid, RemapVars &rv, std::vector<double> &src_ce
   if (rv.normOpt == NormOpt::DESTAREA)
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(numLinks, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon)
+#pragma omp parallel for default(none) shared(numLinks, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon, is_not_equal)
 #endif
       for (long n = 0; n < numLinks; ++n)
         {
           const auto src_add = rv.srcCellIndices[n];
           const auto tgt_add = rv.tgtCellIndices[n];
           const auto tgt_cell_area = tgtGrid->cell_area[tgt_add];
-          const auto norm_factor = IS_NOT_EQUAL(tgt_cell_area, 0) ? ONE / tgt_cell_area : ZERO;
+          const auto norm_factor = is_not_equal(tgt_cell_area, 0) ? ONE / tgt_cell_area : ZERO;
           norm_weight(norm_factor, &weights[n * 3], src_centroid_lat[src_add], src_centroid_lon[src_add]);
         }
     }
   else if (rv.normOpt == NormOpt::FRACAREA)
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(numLinks, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon)
+#pragma omp parallel for default(none) shared(numLinks, rv, weights, tgtGrid, src_centroid_lat, src_centroid_lon, is_not_equal)
 #endif
       for (long n = 0; n < numLinks; ++n)
         {
           const auto src_add = rv.srcCellIndices[n];
           const auto tgt_add = rv.tgtCellIndices[n];
           const auto tgt_cell_frac = tgtGrid->cell_frac[tgt_add];
-          const auto norm_factor = IS_NOT_EQUAL(tgt_cell_frac, 0) ? ONE / tgt_cell_frac : ZERO;
+          const auto norm_factor = is_not_equal(tgt_cell_frac, 0) ? ONE / tgt_cell_frac : ZERO;
           // printf("i: %ld %g  %g %g  %g %g %g\n", n+1, norm_factor, src_centroid_lon[src_add], src_centroid_lat[src_add],
           // weights[n * 3], weights[n * 3+1], weights[n * 3+2]);
           norm_weight(norm_factor, &weights[n * 3], src_centroid_lat[src_add], src_centroid_lon[src_add]);
@@ -1221,8 +1220,6 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 
   if (Options::cdoVerbose) cdo_print("Called %s()", __func__);
 
-  progress::init();
-
   long numWeights = rv.numWeights;
 
   GridStore grid_store;
@@ -1280,9 +1277,10 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   srch_corners = tgtNumCorners;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(findex, rsearch, numWeights, src_centroid_lon, src_centroid_lat, grid_store, rv,   \
-                                              Options::cdoVerbose, max_subseg, srch_corner_lat, srch_corner_lon, maxSearchCells, \
-                                              srcNumCorners, srch_corners, srcGrid, tgtGrid, tgtGridSize, srcGridSize, srch_add)
+#pragma omp parallel for default(none)                                                                                       \
+    shared(findex, rsearch, numWeights, src_centroid_lon, src_centroid_lat, grid_store, rv, Options::cdoVerbose, max_subseg, \
+           srch_corner_lat, srch_corner_lon, maxSearchCells, srcNumCorners, srch_corners, srcGrid, tgtGrid, tgtGridSize,     \
+           srcGridSize, srch_add, is_equal, is_not_equal)
 #endif
   for (long srcCellIndex = 0; srcCellIndex < srcGridSize; ++srcCellIndex)
     {
@@ -1292,7 +1290,6 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 #pragma omp atomic
 #endif
       findex++;
-      if (ompthID == 0) progress::update(0, 0.5, findex / srcGridSize);
 
       bool lcoinc;  // flag for coincident segments
       bool lthresh = false;
@@ -1350,7 +1347,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 
           /* To ensure exact path taken during both sweeps, always integrate
            * segments in the same direction (SW to NE). */
-          if ((endlat < beglat) || (IS_EQUAL(endlat, beglat) && endlon < beglon))
+          if ((endlat < beglat) || (is_equal(endlat, beglat) && endlon < beglon))
             {
               beglat = srcGrid->cell_corner_lat[ioffset + next_corn];
               beglon = srcGrid->cell_corner_lon[ioffset + next_corn];
@@ -1363,7 +1360,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
             If this is a constant-longitude segment, skip the rest
             since the line integral contribution will be ZERO.
           */
-          if (IS_EQUAL(endlon, beglon)) continue;
+          if (is_equal(endlon, beglon)) continue;
 
           double weights[6];  // local wgt array
           double begseg[2];   // begin lat/lon for full segment
@@ -1376,7 +1373,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
             Integrate along this segment, detecting intersections
             and computing the line integral for each sub-segment
           */
-          while (IS_NOT_EQUAL(beglat, endlat) || IS_NOT_EQUAL(beglon, endlon))
+          while (is_not_equal(beglat, endlat) || is_not_equal(beglon, endlon))
             {
               /* Prevent infinite loops if integration gets stuck near cell or threshold boundary */
               num_subseg++;
@@ -1467,9 +1464,10 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   findex = 0;
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(findex, rsearch, numWeights, tgt_centroid_lon, tgt_centroid_lat, grid_store, rv,   \
-                                              Options::cdoVerbose, max_subseg, srch_corner_lat, srch_corner_lon, maxSearchCells, \
-                                              tgtNumCorners, srch_corners, srcGrid, tgtGrid, tgtGridSize, srcGridSize, srch_add)
+#pragma omp parallel for default(none)                                                                                       \
+    shared(findex, rsearch, numWeights, tgt_centroid_lon, tgt_centroid_lat, grid_store, rv, Options::cdoVerbose, max_subseg, \
+           srch_corner_lat, srch_corner_lon, maxSearchCells, tgtNumCorners, srch_corners, srcGrid, tgtGrid, tgtGridSize,     \
+           srcGridSize, srch_add, is_equal, is_not_equal)
 #endif
   for (long tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
@@ -1479,7 +1477,6 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
 #pragma omp atomic
 #endif
       findex++;
-      if (ompthID == 0) progress::update(0.5, 0.5, findex / tgtGridSize);
 
       bool lcoinc;  // flag for coincident segments
       bool lthresh = false;
@@ -1535,7 +1532,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
           bool lrevers = false;
 
           /* To ensure exact path taken during both sweeps, always integrate in the same direction */
-          if ((endlat < beglat) || (IS_EQUAL(endlat, beglat) && endlon < beglon))
+          if ((endlat < beglat) || (is_equal(endlat, beglat) && endlon < beglon))
             {
               beglat = tgtGrid->cell_corner_lat[ioffset + next_corn];
               beglon = tgtGrid->cell_corner_lon[ioffset + next_corn];
@@ -1548,7 +1545,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
             If this is a constant-longitude segment, skip the rest
             since the line integral contribution will be ZERO.
           */
-          if (IS_EQUAL(endlon, beglon)) continue;
+          if (is_equal(endlon, beglon)) continue;
 
           double weights[6];  // local wgt array
           double begseg[2];   // begin lat/lon for full segment
@@ -1561,7 +1558,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
             Integrate along this segment, detecting intersections
             and computing the line integral for each sub-segment
           */
-          while (IS_NOT_EQUAL(beglat, endlat) || IS_NOT_EQUAL(beglon, endlon))
+          while (is_not_equal(beglat, endlat) || is_not_equal(beglon, endlon))
             {
               /* Prevent infinite loops if integration gets stuck near cell or threshold boundary */
               num_subseg++;
@@ -1637,8 +1634,6 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
         }
     }
 
-  progress::update(0, 1, 1);
-
   /* Finished with all cells: deallocate search arrays */
 
   for (int i = 0; i < Threading::ompNumThreads; ++i) free(srch_corner_lon[i]);
@@ -1663,7 +1658,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   // srvout("clat1.srv", nlon, nlat, src_centroid_lat);
   // srvout("clon1.srv", nlon, nlat, src_centroid_lon);
   for (long n = 0; n < srcGridSize; ++n)
-    if (IS_NOT_EQUAL(srcGrid->cell_area[n], 0))
+    if (is_not_equal(srcGrid->cell_area[n], 0))
       {
         src_centroid_lat[n] /= srcGrid->cell_area[n];
         src_centroid_lon[n] /= srcGrid->cell_area[n];
@@ -1672,7 +1667,7 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   // srvout("clon2.srv", nlon, nlat, src_centroid_lon);
 
   for (long n = 0; n < tgtGridSize; ++n)
-    if (IS_NOT_EQUAL(tgtGrid->cell_area[n], 0))
+    if (is_not_equal(tgtGrid->cell_area[n], 0))
       {
         tgt_centroid_lat[n] /= tgtGrid->cell_area[n];
         tgt_centroid_lon[n] /= tgtGrid->cell_area[n];
@@ -1726,10 +1721,10 @@ remap_conserv_weights_scrip(RemapSearch &rsearch, RemapVars &rv)
   if (Options::cdoVerbose) cdo_print("Total number of links = %zu", rv.numLinks);
 
   for (long n = 0; n < srcGridSize; ++n)
-    if (IS_NOT_EQUAL(srcGrid->cell_area[n], 0)) srcGrid->cell_frac[n] /= srcGrid->cell_area[n];
+    if (is_not_equal(srcGrid->cell_area[n], 0)) srcGrid->cell_frac[n] /= srcGrid->cell_area[n];
 
   for (long n = 0; n < tgtGridSize; ++n)
-    if (IS_NOT_EQUAL(tgtGrid->cell_area[n], 0)) tgtGrid->cell_frac[n] /= tgtGrid->cell_area[n];
+    if (is_not_equal(tgtGrid->cell_area[n], 0)) tgtGrid->cell_frac[n] /= tgtGrid->cell_area[n];
 
   /* Perform some error checking on final weights  */
 
