@@ -13,7 +13,7 @@
 #include "remap.h"
 #include "remap_store_link.h"
 #include "progress.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 
 // Interpolation using a distance-weighted average
 
@@ -26,7 +26,7 @@ remap_distwgt_weights(size_t numNeighbors, RemapSearch &rsearch, RemapVars &rv)
 
   if (Options::cdoVerbose) cdo_print("Called %s()", __func__);
 
-  progress::init();
+  cdo::Progress progress;
 
   // Compute mappings from source to target grid
 
@@ -43,7 +43,7 @@ remap_distwgt_weights(size_t numNeighbors, RemapSearch &rsearch, RemapVars &rv)
 
   // Loop over target grid
 
-  std::atomic<long> linksPerValue{ -1 };
+  std::atomic<long> numLinksPerValue{ -1 };
   std::atomic<size_t> atomicCount{ 0 };
 
 #ifdef _OPENMP
@@ -54,7 +54,7 @@ remap_distwgt_weights(size_t numNeighbors, RemapSearch &rsearch, RemapVars &rv)
       auto ompthID = cdo_omp_get_thread_num();
 
       atomicCount++;
-      if (ompthID == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
+      if (ompthID == 0) progress.update((double) atomicCount / tgtGridSize);
 
       weightLinks[tgtCellIndex].nlinks = 0;
 
@@ -77,37 +77,37 @@ remap_distwgt_weights(size_t numNeighbors, RemapSearch &rsearch, RemapVars &rv)
 
       if (numNeighbors > 1 && nadds > 0)
         {
-          if (linksPerValue == -1)
-            linksPerValue = nadds;
-          else if (linksPerValue > 0 && linksPerValue != (long) nadds)
-            linksPerValue = 0;
+          if (numLinksPerValue == -1)
+            numLinksPerValue = nadds;
+          else if (numLinksPerValue > 0 && numLinksPerValue != (long) nadds)
+            numLinksPerValue = 0;
         }
     }
 
-  progress::update(0, 1, 1);
-
   grid_point_search_delete(rsearch.gps);
 
   weight_links_to_remap_links(0, tgtGridSize, weightLinks, rv);
 
   if (numNeighbors == 1)
-    rv.linksPerValue = 1;
-  else if (linksPerValue > 0)
-    rv.linksPerValue = linksPerValue;
+    rv.numLinksPerValue = 1;
+  else if (numLinksPerValue > 0)
+    rv.numLinksPerValue = numLinksPerValue;
 
   if (Options::cdoVerbose) cdo_print("Point search nearest: %.2f seconds", timer.elapsed());
 }  // remap_distwgt_weights
 
-template <typename T>
+template <typename T1, typename T2>
 static void
-remap_distwgt(size_t numNeighbors, RemapSearch &rsearch, const Varray<T> &srcArray, Varray<T> &tgtArray, T missval, size_t numMissVals)
+remap_distwgt(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissval, size_t numMissVals, size_t numNeighbors,
+              RemapSearch &rsearch)
 {
+  T1 missval = srcMissval;
   auto srcGrid = rsearch.srcGrid;
   auto tgtGrid = rsearch.tgtGrid;
 
   if (Options::cdoVerbose) cdo_print("Called %s()", __func__);
 
-  progress::init();
+  cdo::Progress progress;
 
   // Compute mappings from source to target grid
 
@@ -115,7 +115,7 @@ remap_distwgt(size_t numNeighbors, RemapSearch &rsearch, const Varray<T> &srcArr
   auto srcGridSize = srcGrid->size;
 
   Varray<short> srcGridMask;
-  if (numMissVals) remap_set_mask(srcGridSize, srcArray, numMissVals, missval, srcGridMask);
+  if (numMissVals) remap_set_mask(srcArray, srcGridSize, numMissVals, srcMissval, srcGridMask);
 
   std::vector<knnWeightsType> knnWeights;
   knnWeights.reserve(Threading::ompNumThreads);
@@ -135,7 +135,7 @@ remap_distwgt(size_t numNeighbors, RemapSearch &rsearch, const Varray<T> &srcArr
       auto ompthID = cdo_omp_get_thread_num();
 
       atomicCount++;
-      if (ompthID == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
+      if (ompthID == 0) progress.update((double) atomicCount / tgtGridSize);
 
       auto &tgtValue = tgtArray[tgtCellIndex];
       tgtValue = missval;
@@ -153,20 +153,16 @@ remap_distwgt(size_t numNeighbors, RemapSearch &rsearch, const Varray<T> &srcArr
       if (nadds) tgtValue = knnWgt.arrayWeightsSum(srcArray);
     }
 
-  progress::update(0, 1, 1);
-
   if (Options::cdoVerbose) cdo_print("Point search nearest: %.2f seconds", timer.elapsed());
 }  // remap_distwgt
 
 void
-remap_distwgt(size_t numNeighbors, RemapSearch &rsearch, const Field &field1, Field &field2)
+remap_distwgt(size_t numNeighbors, RemapSearch &remapSearch, const Field &field1, Field &field2)
 {
-  if (field1.memType != field2.memType) cdo_abort("Interal error, memType of field1 and field2 differ!");
-
-  if (field1.memType == MemType::Float)
-    remap_distwgt(numNeighbors, rsearch, field1.vec_f, field2.vec_f, (float) field1.missval, field1.numMissVals);
-  else
-    remap_distwgt(numNeighbors, rsearch, field1.vec_d, field2.vec_d, field1.missval, field1.numMissVals);
+  auto func = [&](auto &v1, auto &v2, double missval, size_t numMissVals) {
+    remap_distwgt(v1, v2, missval, numMissVals, numNeighbors, remapSearch);
+  };
+  field_operation2(func, field1, field2, field1.missval, field1.numMissVals);
 }
 
 void
@@ -182,7 +178,7 @@ intgriddis(const Field &field1, Field &field2, size_t numNeighbors)
 
   if (Options::cdoVerbose) cdo_print("Called %s()", __func__);
 
-  progress::init();
+  cdo::Progress progress;
 
   // Interpolate from source to target grid
 
@@ -196,7 +192,7 @@ intgriddis(const Field &field1, Field &field2, size_t numNeighbors)
   auto tgtGridSize = remap.tgtGrid.size;
 
   Varray<short> srcGridMask;
-  if (field1.numMissVals) remap_set_mask(srcGridSize, srcArray, field1.numMissVals, srcMissval, srcGridMask);
+  if (field1.numMissVals) remap_set_mask(srcArray, srcGridSize, field1.numMissVals, srcMissval, srcGridMask);
 
   std::vector<knnWeightsType> knnWeights;
   knnWeights.reserve(Threading::ompNumThreads);
@@ -219,7 +215,7 @@ intgriddis(const Field &field1, Field &field2, size_t numNeighbors)
       auto ompthID = cdo_omp_get_thread_num();
 
       atomicCount++;
-      if (ompthID == 0) progress::update(0, 1, (double) atomicCount / tgtGridSize);
+      if (ompthID == 0) progress.update((double) atomicCount / tgtGridSize);
 
       auto &tgtValue = tgtArray[tgtCellIndex];
       tgtValue = tgtMissval;
@@ -240,8 +236,6 @@ intgriddis(const Field &field1, Field &field2, size_t numNeighbors)
         numMissVals++;
     }
 
-  progress::update(0, 1, 1);
-
   field2.numMissVals = numMissVals;
 
   remap_grid_free(remap.srcGrid);
