@@ -12,7 +12,7 @@
 #include "compare.h"
 #include "varray.h"
 #include "cdo_options.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include <mpim_grid.h>
 
 extern "C"
