@@ -26,6 +26,7 @@
 #include "commandline.h"
 
 constexpr size_t IndexLimit = 0x7FFFFC00;  // 2**31 - 1024 (<2GB)
+static auto filterAvail{ false };
 
 enum class Compress
 {
@@ -94,16 +95,6 @@ define_compression_zip(int ncId, int ncVarId)
   nce(nc_def_var_deflate(ncId, ncVarId, shuffle, deflate, deflateLevel));
 #endif
 }
-
-static void
-define_compression_zstd(int ncId, int ncVarId)
-{
-#ifdef HAVE_NETCDF4
-  unsigned int filterId = Options::filterId;
-  unsigned int filterParams = Options::filterParams[0];
-  nce(nc_def_var_filter(ncId, ncVarId, filterId, 1, &filterParams));
-#endif
-}
 #endif
 
 #ifdef HAVE_LIBNETCDF
@@ -114,7 +105,7 @@ define_var(Compress compress, int ncId, const char *name, nc_type xtype, int ndi
   nce(nc_def_var(ncId, name, xtype, ndims, dimidsp, &ncVarId));
   // clang-format off
   if      (compress == Compress::ZIP)  define_compression_zip(ncId, ncVarId);
-  else if (compress == Compress::ZSTD) define_compression_zstd(ncId, ncVarId);
+  else if (Options::filterSpec.size() && filterAvail) cdf_def_var_filter(ncId, ncVarId, Options::filterSpec.c_str());
   // clang-format on
   return ncVarId;
 }
@@ -268,10 +259,10 @@ remap_write_data_scrip(const std::string &weightsfile, const RemapSwitches &rema
 #ifdef HAVE_NETCDF4
   if (CdoDefault::FileType == CDI_FILETYPE_NC4 || CdoDefault::FileType == CDI_FILETYPE_NC4C)
     {
+      filterAvail = true;
       writemode = NC_CLOBBER | NC_NETCDF4;
       if (CdoDefault::FileType == CDI_FILETYPE_NC4C && largeSizetype != NC_UINT64) writemode |= NC_CLASSIC_MODEL;
       if (Options::cdoCompType == CDI_COMPRESS_ZIP) compress = Compress::ZIP;
-      if (Options::filterId == 32015) compress = Compress::ZSTD;
     }
 #endif
 
@@ -593,7 +584,7 @@ remap_read_data_scrip(const std::string &weightsfile, int gridID1, int gridID2,
   remap_vars_init(remapSwitches.mapType, remapSwitches.remapOrder, rv);
 
   rv.mapType = remapSwitches.mapType;
-  rv.linksPerValue = -1;
+  rv.numLinksPerValue = -1;
   rv.sort_add = false;
 
   // Normalization option
