@@ -110,11 +110,11 @@ store_link_cnsrv(RemapVars &rv, long add1, long add2, long numWeights, double *w
   /*  If all weights are ZERO, do not bother storing the link */
   if (numWeights == 3)
     {
-      if (IS_EQUAL(weights[0], 0) && IS_EQUAL(weights[1], 0) && IS_EQUAL(weights[2], 0)) return;
+      if (is_equal(weights[0], 0) && is_equal(weights[1], 0) && is_equal(weights[2], 0)) return;
     }
   else
     {
-      if (IS_EQUAL(weights[0], 0)) return;
+      if (is_equal(weights[0], 0)) return;
     }
 
   /* If the link already exists, add the weight to the current weight arrays */
