@@ -60,7 +60,7 @@ struct RemapSwitches
 struct RemapVars
 {
   bool sort_add{ false };
-  long linksPerValue{ -1 };
+  long numLinksPerValue{ -1 };
   RemapMethod mapType{ RemapMethod::UNDEF };  // identifier for remapping method
   NormOpt normOpt{ NormOpt::NONE };           // option for normalization (conserv only)
   size_t numLinks{ 0 };                       // actual number of links for remapping
@@ -68,6 +68,8 @@ struct RemapVars
   size_t numWeights{ 0 };                     // num of weights used in remapping
   const size_t resizeIncrement{ 1024 };       // default amount to increase array size
 
+  Varray<size_t> linksOffset;
+  Varray<size_t> linksPerValue;
   Varray<size_t> srcCellIndices;  // source grid indices for each link
   Varray<size_t> tgtCellIndices;  // target grid indices for each link
   Varray<double> weights;         // map weights for each link [maxLinks*numWeights]
