@@ -56,7 +56,7 @@
 
 #include "cdo_options.h"
 #include "cdo_timer.h"
-#include "cimdOmp.h"
+#include "cdo_omp.h"
 #include "process_int.h"
 #include <mpim_grid.h>
 #include "gridreference.h"
@@ -69,6 +69,14 @@ static int remap_num_srch_bins = 180;
 constexpr size_t DEFAULT_MAX_ITER = 100;
 size_t remap_max_iter = DEFAULT_MAX_ITER;  // Max iteration count for i, j iteration
 
+static void
+print_warning_and_abort(void)
+{
+  cdo_warning("HEALPix cell edges are not located on great circles. This leads to inaccuracies in the calculation of "
+              "cell areas.");
+  cdo_abort("Use the CDO option --force to perform this operation.");
+}
+
 int
 remap_check_mask_indices(const size_t (&indices)[4], const Varray<short> &mask)
 {
@@ -169,9 +177,9 @@ boundboxFromCenter(bool lonIsCyclic, size_t size, size_t nx, size_t ny, const Va
 }
 
 LonLatPoint
-remapgrid_get_lonlat(RemapGrid *grid, size_t index)
+remapgrid_get_lonlat(const RemapGrid *grid, size_t index)
 {
-  double lon, lat;
+  double lon{}, lat{};
 
   if (grid->type == RemapGridType::Reg2D)
     {
@@ -371,9 +379,17 @@ remap_define_reg2d(int gridID, RemapGrid &grid, bool conservMapping, const char
   gridInqXvals(gridID, grid.reg2d_center_lon.data());
   gridInqYvals(gridID, grid.reg2d_center_lat.data());
 
+  static bool doCheck = true;
+  if (doCheck)
+    {
+      doCheck = false;
+      check_longitude_range(grid.reg2d_center_lon, "center", cdo_grid_get_units(gridID, CDI_XAXIS, "grid center lon"));
+      check_latitude_range(grid.reg2d_center_lat, "center", cdo_grid_get_units(gridID, CDI_YAXIS, "grid center lat"));
+    }
+
   // Convert lat/lon units if required
-  cdo_grid_to_radian(gridID, CDI_XAXIS, nx, grid.reg2d_center_lon.data(), "grid reg2d center lon");
-  cdo_grid_to_radian(gridID, CDI_YAXIS, ny, grid.reg2d_center_lat.data(), "grid reg2d center lat");
+  cdo_grid_to_radian(gridID, CDI_XAXIS, grid.reg2d_center_lon, "grid reg2d center lon");
+  cdo_grid_to_radian(gridID, CDI_YAXIS, grid.reg2d_center_lat, "grid reg2d center lat");
 
   if (grid.reg2d_center_lon[nx - 1] < grid.reg2d_center_lon[0])
     for (size_t i = 1; i < nx; ++i)
@@ -389,7 +405,7 @@ remap_define_reg2d(int gridID, RemapGrid &grid, bool conservMapping, const char
       Varray<double> xbounds(2 * nx);
       gridInqXbounds(gridID, xbounds.data());
       convert_bounds_reg2d(nx, xbounds, grid.reg2d_corner_lon);
-      cdo_grid_to_radian(gridID, CDI_XAXIS, nx + 1, grid.reg2d_corner_lon.data(), "grid reg2d corner lon");
+      cdo_grid_to_radian(gridID, CDI_XAXIS, grid.reg2d_corner_lon, "grid reg2d corner lon");
     }
   else
     {
@@ -402,7 +418,7 @@ remap_define_reg2d(int gridID, RemapGrid &grid, bool conservMapping, const char
       Varray<double> ybounds(2 * ny);
       gridInqYbounds(gridID, ybounds.data());
       convert_bounds_reg2d(ny, ybounds, grid.reg2d_corner_lat);
-      cdo_grid_to_radian(gridID, CDI_YAXIS, ny + 1, grid.reg2d_corner_lat.data(), "grid reg2d corner lat");
+      cdo_grid_to_radian(gridID, CDI_YAXIS, grid.reg2d_corner_lat, "grid reg2d corner lat");
     }
   else
     {
@@ -457,8 +473,10 @@ remap_define_grid(RemapMethod mapType, int gridID, RemapGrid &grid, const char *
         }
       else if (gridtype == GRID_GAUSSIAN_REDUCED || is_healpix_grid(gridID))
         {
+          auto needCorners = grid.needCellCorners ? NeedCorners::Yes : NeedCorners::No;
+          if (Options::force == false && is_healpix_grid(gridID) && needCorners == NeedCorners::Yes) print_warning_and_abort();
           destroyGrid = true;
-          gridID = gridToUnstructured(grid.gridID, NeedCorners::Yes);
+          gridID = gridToUnstructured(grid.gridID, needCorners);
         }
       else if (remap_write_remap || grid.type != RemapGridType::Reg2D)
         {
@@ -520,12 +538,12 @@ remap_define_grid(RemapMethod mapType, int gridID, RemapGrid &grid, const char *
       if (gridInqType(grid.gridID) == GRID_GME) gridInqMaskGME(gridID_gme, &grid.vgpm[0]);
 
       // Convert lat/lon units if required
-      cdo_grid_to_radian(gridID, CDI_XAXIS, grid.size, grid.cell_center_lon.data(), "grid center lon");
-      cdo_grid_to_radian(gridID, CDI_YAXIS, grid.size, grid.cell_center_lat.data(), "grid center lat");
+      cdo_grid_to_radian(gridID, CDI_XAXIS, grid.cell_center_lon, "grid center lon");
+      cdo_grid_to_radian(gridID, CDI_YAXIS, grid.cell_center_lat, "grid center lat");
       if (grid.num_cell_corners && grid.needCellCorners)
         {
-          cdo_grid_to_radian(gridID, CDI_XAXIS, grid.num_cell_corners * grid.size, grid.cell_corner_lon.data(), "grid corner lon");
-          cdo_grid_to_radian(gridID, CDI_YAXIS, grid.num_cell_corners * grid.size, grid.cell_corner_lat.data(), "grid corner lat");
+          cdo_grid_to_radian(gridID, CDI_XAXIS, grid.cell_corner_lon, "grid corner lon");
+          cdo_grid_to_radian(gridID, CDI_YAXIS, grid.cell_corner_lat, "grid corner lat");
         }
 
       // Convert longitudes to 0,2pi interval
@@ -612,10 +630,10 @@ remap_grid_alloc(RemapMethod mapType, RemapGrid &grid)
 }
 
 void
-remap_grid_free(RemapGrid &grid)
+remap_grid_free(RemapGrid &grid, bool removeMask)
 {
   varray_free(grid.vgpm);
-  varray_free(grid.mask);
+  if (removeMask) varray_free(grid.mask);
 
   varray_free(grid.reg2d_center_lat);
   varray_free(grid.reg2d_center_lon);
@@ -630,7 +648,11 @@ remap_grid_free(RemapGrid &grid)
   varray_free(grid.cell_area);
   varray_free(grid.cell_frac);
 
-  if (grid.tmpgridID != -1) gridDestroy(grid.tmpgridID);
+  if (grid.tmpgridID != -1)
+    {
+      gridDestroy(grid.tmpgridID);
+      grid.tmpgridID = -1;
+    }
 }
 
 static void
@@ -754,15 +776,15 @@ remap_init_grids(RemapMethod mapType, bool doExtrapolate, int gridID1, RemapGrid
         srcGrid.type = RemapGridType::HealPix;
     }
 
-  //#ifdef YAC_CELL_SEARCH
-  // if (is_reg2d_grid(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
-  //#else
+  // #ifdef YAC_CELL_SEARCH
+  //  if (is_reg2d_grid(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
+  // #else
   if (srcGrid.type == RemapGridType::Reg2D)
     {
       if (is_reg2d_grid(gridID2) && mapType == RemapMethod::CONSERV) tgtGrid.type = RemapGridType::Reg2D;
       // else srcGrid.type = -1;
     }
-  //#endif
+  // #endif
 
   if (!remap_gen_weights && is_reg2d_grid(gridID2) && tgtGrid.type != RemapGridType::Reg2D)
     {
@@ -815,9 +837,11 @@ remap_init_grids(RemapMethod mapType, bool doExtrapolate, int gridID1, RemapGrid
     {
       auto needCorners = srcGrid.needCellCorners ? NeedCorners::Yes : NeedCorners::No;
       if (is_healpix_grid(sgridID))
-        gridID1 = gridToUnstructured(srcGrid.gridID, needCorners);
-      else
-        gridID1 = gridToCurvilinear(srcGrid.gridID, needCorners);
+        {
+          if (Options::force == false && needCorners == NeedCorners::Yes) print_warning_and_abort();
+          gridID1 = gridToUnstructured(srcGrid.gridID, needCorners);
+        }
+      else { gridID1 = gridToCurvilinear(srcGrid.gridID, needCorners); }
       srcGrid.gridID = gridID1;
       srcGrid.tmpgridID = srcGrid.gridID;
     }
@@ -835,8 +859,8 @@ remap_init_grids(RemapMethod mapType, bool doExtrapolate, int gridID1, RemapGrid
 
 template <typename T1, typename T2>
 static void
-remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv, const Varray<T1> &array1,
-           const Varray<T2> &array2, double missval)
+remap_stat(const Varray<T1> &array1, const Varray<T2> &array2, double missval, int remapOrder, RemapGrid &srcGrid,
+           RemapGrid &tgtGrid, RemapVars &rv)
 {
   T1 mv1 = missval;
   T2 mv2 = missval;
@@ -844,10 +868,10 @@ remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv
   cdo_print("%s order mapping from grid1 to grid2:", (remapOrder == 2) ? "Second" : "First");
   cdo_print("----------------------------------------------");
 
-  auto mmm = varray_min_max_mean_mv(srcGrid.size, array1, mv1);
+  auto mmm = varray_min_max_mean_mv(array1, srcGrid.size, mv1);
   cdo_print("  Grid1 min,mean,max: %g %g %g", mmm.min, mmm.mean, mmm.max);
 
-  mmm = varray_min_max_mean_mv(tgtGrid.size, array2, mv2);
+  mmm = varray_min_max_mean_mv(array2, tgtGrid.size, mv2);
   cdo_print("  Grid2 min,mean,max: %g %g %g", mmm.min, mmm.mean, mmm.max);
 
   // Conservation Test
@@ -857,23 +881,23 @@ remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv
       cdo_print("  Conservation:");
       double sum = 0.0;
       for (size_t i = 0; i < srcGrid.size; ++i)
-        if (!dbl_is_equal(array1[i], mv1)) sum += array1[i] * srcGrid.cell_area[i] * srcGrid.cell_frac[i];
+        if (fp_is_not_equal(array1[i], mv1)) sum += array1[i] * srcGrid.cell_area[i] * srcGrid.cell_frac[i];
       cdo_print("  Grid1 Integral = %g", sum);
 
       sum = 0;
       for (size_t i = 0; i < tgtGrid.size; ++i)
-        if (!dbl_is_equal(array2[i], mv2)) sum += array2[i] * tgtGrid.cell_area[i] * tgtGrid.cell_frac[i];
+        if (fp_is_not_equal(array2[i], mv2)) sum += array2[i] * tgtGrid.cell_area[i] * tgtGrid.cell_frac[i];
       cdo_print("  Grid2 Integral = %g", sum);
     }
 
-  cdo_print("  Number of weights %zu", rv.num_wts);
+  cdo_print("  Number of weights %zu", rv.numWeights);
   cdo_print("  Number of sparse matrix entries %zu", rv.numLinks);
   cdo_print("  Total number of dest cells %zu", tgtGrid.size);
 
   std::vector<size_t> tgt_count(tgtGrid.size, 0);
 
 #ifdef HAVE_OPENMP4
-  //#pragma omp simd -> wrong result with clang
+  // #pragma omp simd -> wrong result with clang
 #endif
   for (size_t i = 0; i < rv.numLinks; ++i) tgt_count[rv.tgtCellIndices[i]]++;
 
@@ -920,21 +944,15 @@ remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv
 void
 remap_stat(int remapOrder, RemapGrid &srcGrid, RemapGrid &tgtGrid, RemapVars &rv, const Field &field1, const Field &field2)
 {
-  if (memtype_is_float_float(field1.memType, field2.memType))
-    remap_stat(remapOrder, srcGrid, tgtGrid, rv, field1.vec_f, field2.vec_f, field1.missval);
-  else if (memtype_is_float_double(field1.memType, field2.memType))
-    remap_stat(remapOrder, srcGrid, tgtGrid, rv, field1.vec_f, field2.vec_d, field1.missval);
-  else if (memtype_is_double_float(field1.memType, field2.memType))
-    remap_stat(remapOrder, srcGrid, tgtGrid, rv, field1.vec_d, field2.vec_f, field1.missval);
-  else
-    remap_stat(remapOrder, srcGrid, tgtGrid, rv, field1.vec_d, field2.vec_d, field1.missval);
+  auto func = [&](auto &v1, auto &v2, double mv1) { remap_stat(v1, v2, mv1, remapOrder, srcGrid, tgtGrid, rv); };
+  field_operation2(func, field1, field2, field1.missval);
 }
 
 /*****************************************************************************/
 
 template <typename T>
 void
-remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &array, RemapGradients &gradients)
+remap_gradients(const Varray<T> &array, RemapGrid &grid, const Varray<short> &mask, RemapGradients &gradients)
 {
   if (grid.rank != 2) cdo_abort("Internal problem (remap_gradients), grid rank = %d!", grid.rank);
 
@@ -1100,11 +1118,11 @@ remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<T> &arr
 }  // remap_gradients
 
 // Explicit instantiation
-template void remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<float> &array, RemapGradients &gradients);
-template void remap_gradients(RemapGrid &grid, const Varray<short> &mask, const Varray<double> &array, RemapGradients &gradients);
+template void remap_gradients(const Varray<float> &array, RemapGrid &grid, const Varray<short> &mask, RemapGradients &gradients);
+template void remap_gradients(const Varray<double> &array, RemapGrid &grid, const Varray<short> &mask, RemapGradients &gradients);
 
 void
-remap_gradients(RemapGrid &grid, const Field &field, RemapGradients &gradients)
+remap_gradients(const Field &field, RemapGrid &grid, RemapGradients &gradients)
 {
   auto gridSize = grid.size;
   Varray<short> mask(gridSize);
@@ -1113,10 +1131,8 @@ remap_gradients(RemapGrid &grid, const Field &field, RemapGradients &gradients)
 #endif
   for (size_t i = 0; i < gridSize; ++i) mask[i] = (grid.mask[i] > 0);
 
-  if (field.memType == MemType::Float)
-    remap_gradients(grid, mask, field.vec_f, gradients);
-  else
-    remap_gradients(grid, mask, field.vec_d, gradients);
+  auto func = [&](const auto &v) { remap_gradients(v, grid, mask, gradients); };
+  field_operation(func, field);
 }
 
 /*****************************************************************************/
