@@ -16,6 +16,67 @@
 
 #include <cdi.h>
 #include "util_string.h"
+#include "cdo_output.h"
+
+std::vector<std::string>
+get_operator_argv(std::string operatorArguments)
+{
+  std::vector<std::string> argument_vector;
+  Debug(ARGUMENTS && strchr(operatorArguments.c_str(), ',') != nullptr, "Setting operator arguments: %s", operatorArguments);
+
+  constexpr char delimiter = ',';
+
+  auto pos = operatorArguments.find(delimiter);
+  if (pos != std::string::npos)
+    {
+      // remove operator name
+      operatorArguments.erase(0, pos + 1);
+
+      while ((pos = operatorArguments.find(delimiter)) != std::string::npos)
+        {
+          argument_vector.push_back(operatorArguments.substr(0, pos));
+          Debug(ARGUMENTS, "added argument %s", argument_vector.back());
+          operatorArguments.erase(0, pos + 1);
+        }
+      argument_vector.push_back(operatorArguments);
+    }
+  return argument_vector;
+}
+
+std::vector<std::string>
+split_args(std::string operatorArguments)
+{
+  if (operatorArguments.empty()) return {};
+  Debug(ARGUMENTS, "Setting operator arguments: '%s'", operatorArguments);
+  std::vector<std::string> argument_vector = {};
+  constexpr char delimiter = ',';
+
+  std::size_t pos = 0;
+  std::size_t pos_start = 0;
+  std::size_t arg_start = 0;
+  while ((pos = operatorArguments.find(delimiter, pos_start)) != std::string::npos)
+    {
+      if (operatorArguments[pos - 1] != '\\')
+        {
+          auto new_arg = operatorArguments.substr(arg_start, pos - arg_start);
+          auto escape_pos = new_arg.find("\\,");
+          if (escape_pos != std::string::npos) {
+            new_arg.replace(escape_pos, 2, ","); }
+          argument_vector.push_back(new_arg);
+          Debug(ARGUMENTS, "added argument %s", argument_vector.back());
+          arg_start = pos + 1;
+        }
+      else
+        {
+          operatorArguments.erase(pos - 1, 1);
+          pos -= 1;
+        }
+      pos_start = pos + 1;
+    }
+  argument_vector.push_back(operatorArguments.substr(arg_start, operatorArguments.size() - arg_start));
+  Debug(ARGUMENTS, "added argument %s", argument_vector.back());
+  return argument_vector;
+}
 
 std::string
 getenv_string(const std::string &envVar)
