@@ -69,13 +69,13 @@ public:
 
   // Division by scalars
   Vector3d
-  operator/(const double scalar) const noexcept
+  operator/(double scalar) const noexcept
   {
     return Vector3d(X / scalar, Y / scalar, Z / scalar);
   }
 
   Vector3d
-  operator/=(const double scalar) noexcept
+  operator/=(double scalar) noexcept
   {
     return *this = *this / scalar;
   }
@@ -101,7 +101,7 @@ public:
   /*
   Vector3d d_normalize()
   {
-    const double dnorm = std::sqrt(*this * *this);
+    double dnorm = std::sqrt(*this * *this);
     return Vector3d(*this) / dnorm;
   }
   */
