@@ -1,7 +1,7 @@
 #include "bandit/bandit/bandit.h"
 
 #ifdef HAVE_CONFIG_H
-#include "../../src/config.h"
+#include <config.h>
 #endif
 
 #ifdef HAVE_WORDEXP_H
